@@ -256,8 +256,8 @@ void KcmSambaConf::init() {
   connect( _interface->removeSambaUserBtn, SIGNAL(clicked()),
           this, SLOT( removeSambaUserBtnClicked() ));
 
-  _interface->removeSambaUserBtn->setIconSet(SmallIcon("1rightarrow"));
-  _interface->addSambaUserBtn->setIconSet(SmallIcon("1leftarrow"));
+  _interface->removeSambaUserBtn->setIconSet(SmallIconSet("1rightarrow"));
+  _interface->addSambaUserBtn->setIconSet(SmallIconSet("1leftarrow"));
 
 
   connect( _interface->sambaUsersListView, SIGNAL(mouseButtonPressed(int,QListViewItem*,const QPoint &,int)),
@@ -756,7 +756,7 @@ void KcmSambaConf::loadWins(SambaShare* share)
   _dictMngr->add("wins server", _interface->winsServerEdit);
   _dictMngr->add("wins hook", _interface->winsHookEdit);
   _interface->winsSupportRadio->setChecked( share->getBoolValue("wins support",false,true));
-  _interface->otherWinsRadio->setChecked( share->getValue("wins server",false,true) != "" );
+  _interface->otherWinsRadio->setChecked( !share->getValue("wins server",false,true).isEmpty() );
 }
 
 
@@ -1431,7 +1431,7 @@ QString KcmSambaConf::quickHelp() const
 
 extern "C"
 {
-  KCModule *create_KcmSambaConf(QWidget *parent, const char *name)
+  KDE_EXPORT KCModule *create_KcmSambaConf(QWidget *parent, const char *name)
   {
     KGlobal::locale()->insertCatalogue("kfileshare");
     return new KcmSambaConf(parent, name);
