@@ -53,7 +53,7 @@ SaveHelper::~SaveHelper()
   } else
     if (tmpFile) {      // network location, initiate transaction
       tmpFile->close();
-      if (KIO::NetAccess::upload(tmpFile->name(),url) == false)
+      if (KIO::NetAccess::upload(tmpFile->name(),url, p_arent) == false)
          KMessageBox::error(global->topLevel, i18n("Unable to save remote file."));
       tmpFile->unlink();   // delete temp file
       delete tmpFile;
@@ -141,7 +141,6 @@ QueryView::QueryView(QWidget *_parent)
   part->setJavaEnabled(false);
   part->setURLCursor(KCursor::handCursor());
   setFocusPolicy(QWidget::NoFocus);
-
   connect(part, SIGNAL(completed()), SLOT(partCompleted()));
   connect(part, SIGNAL(middleButtonClicked()), SLOT(middleButtonClicked()));
   rightBtnMenu = new KPopupMenu(this);
@@ -149,9 +148,7 @@ QueryView::QueryView(QWidget *_parent)
   connect(part->browserExtension(),SIGNAL(openURLRequest(const KURL &,const KParts::URLArgs &)),
           this,SLOT(slotURLRequest(const KURL &,const KParts::URLArgs &)));
   connect(part->browserExtension(),SIGNAL(enableAction(const char *,bool)),this,SLOT(enableAction(const char *,bool)));
-
-  optionsChanged();              // for setting the background etc.
-
+  QTimer::singleShot( 0, this, SLOT(optionsChanged()) );
   connect(interface,SIGNAL(resultReady(const QString &)), SLOT(resultReady(const QString &)));
 }
 
