@@ -2,7 +2,7 @@
 *                               dlgIndividual.cpp
 *                             -------------------
 *
-*    Revision     : $Id: dlgIndividual.cpp,v 1.29 2004/04/12 21:01:18 pfeiffer Exp $
+*    Revision     : $Id: dlgIndividual.cpp 379676 2005-01-18 10:06:20Z pino $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -149,9 +149,7 @@ DlgIndividual::DlgIndividual(Transfer * _item)
 
     pbAdvanced = new KPushButton( i18n("Advanced"), this );
 
-    pbAdvanced->setToggleButton(true);
-
-    connect(pbAdvanced, SIGNAL(toggled(bool)), SLOT(slotToggleAdvanced(bool)));
+    connect(pbAdvanced, SIGNAL(clicked()), SLOT(slotToggleAdvanced()));
 
     hBox->addWidget( pbAdvanced );
 
@@ -195,7 +193,8 @@ DlgIndividual::DlgIndividual(Transfer * _item)
 
 
     topLayout->addWidget(panelAdvanced);
-    slotToggleAdvanced(ksettings.b_advancedIndividual);
+    advanced = ksettings.b_advancedIndividual;
+    slotToggleAdvanced();
 
     resize( sizeHint() );
 
@@ -260,7 +259,8 @@ void DlgIndividual::setCanResume(bool resume)
         resumeLabel->setText(i18n("Not resumed"));
 }
 
-void DlgIndividual::slotToggleAdvanced(bool advanced)
+//void DlgIndividual::slotToggleAdvanced(bool advanced)
+void DlgIndividual::slotToggleAdvanced()
 {
 #ifdef _DEBUG
     sDebugIn<<endl;
@@ -273,6 +273,7 @@ void DlgIndividual::slotToggleAdvanced(bool advanced)
         panelAdvanced->hide();
         adjustSize();
     }
+    advanced = !advanced;
 
 #ifdef _DEBUG
     sDebugOut<<endl;
