@@ -2,7 +2,7 @@
 *                               dlgIndividual.h
 *                             -------------------
 *
-*    Revision     : $Id: dlgIndividual.h,v 1.14 2004/04/12 21:01:18 pfeiffer Exp $
+*    Revision     : $Id: dlgIndividual.h 379676 2005-01-18 10:06:20Z pino $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -73,7 +73,7 @@ public slots:
     bool keepDialogOpen() const { return bKeepDlgOpen; }
     
 protected slots:
-    void slotToggleAdvanced(bool);
+    void slotToggleAdvanced();
     void slotToggleDock();
     
 protected:
@@ -105,6 +105,7 @@ protected:
 
     unsigned long m_iTotalSize;
     
+    bool advanced;
 }
 
 ;
