@@ -22,6 +22,7 @@
 #include "kget_plug_in.h"
 
 #include <dcopref.h>
+#include <kapplication.h>
 #include <kdatastream.h>
 #include <kdebug.h>
 #include <khtml_part.h>
@@ -160,9 +161,11 @@ void KGet_plug_in::slotShowLinks()
 
 void KGet_plug_in::startDownload( const KURL::List& urls )
 {
-    if (!p_dcopServer->isApplicationRegistered ("kget"))
-        KRun::runCommand("kget");
+  if (!p_dcopServer->isApplicationRegistered ("kget")) {
+    KApplication::startServiceByDesktopName("kget");
+  }
 
+    kapp->updateRemoteUserTimestamp("kget");
     QByteArray data;
     QDataStream stream( data, IO_WriteOnly );
     stream << urls << QString::null;
@@ -170,7 +173,7 @@ void KGet_plug_in::startDownload( const KURL::List& urls )
                                               "addTransfers(KURL::List, QString)",
                                               data );
 
-    qDebug("*** startDownload: %i", ok );
+    kdDebug() << "*** startDownload: " << ok << endl;
 }
 
 KPluginFactory::KPluginFactory( QObject* parent, const char* name )
@@ -190,7 +193,7 @@ KPluginFactory::~KPluginFactory()
 
 extern "C"
 {
-    void* init_khtml_kget()
+    KDE_EXPORT void* init_khtml_kget()
     {
 		KGlobal::locale()->insertCatalogue("kget");
         return new KPluginFactory;
