@@ -17,11 +17,11 @@
 #ifndef __plugin_kget_plug_in_h
 #define __plugin_kget_plug_in_h
 
-#include <kaction.h>
 #include <kparts/plugin.h>
 #include <klibloader.h>
+#include <dcopclient.h>
+#include <kurl.h>
 
-class KURL;
 class KInstance;
 
 class KGet_plug_in : public KParts::Plugin
@@ -30,10 +30,14 @@ class KGet_plug_in : public KParts::Plugin
 public:
     KGet_plug_in( QObject* parent = 0, const char* name = 0 );
     KToggleAction *m_paToggleDropTarget ;
+    DCOPClient* p_dcopServer;
     virtual ~KGet_plug_in();
 
-public slots:
+private slots:
     void slotShowDrop();
+    void slotShowLinks();
+    void showPopup();
+    void startDownload( const KURL::List& urls );
 };
 
 
