@@ -110,7 +110,7 @@ int ddp_sock = -1;              /* Appletalk DDP socket */
 
 KMainWidget::KMainWidget(bool bStartDocked)
     : KGetIface( "KGet-Interface" ),
-      KMainWindow(0, "kget mainwindow"),
+      KMainWindow(0, "kget mainwindow",0),
       prefDlg( 0 ), kdock( 0 )
 {
 #ifdef _DEBUG
@@ -124,7 +124,7 @@ KMainWidget::KMainWidget(bool bStartDocked)
         cfg.sync();
     }
 
-    b_online = TRUE;
+    b_connected = TRUE;
     b_viewLogWindow = FALSE;
     b_viewPreferences = FALSE;
 
@@ -174,9 +174,8 @@ KMainWidget::KMainWidget(bool bStartDocked)
     }
 
     checkOnline();
-    if (!b_online) {
-        log(i18n("Starting offline"));
-    }
+    ksettings.b_offline=( !b_connected || ksettings.b_offlineMode );
+
     // Setup animation timer
     animTimer = new QTimer(this);
     animCounter = 0;
@@ -208,8 +207,9 @@ KMainWidget::KMainWidget(bool bStartDocked)
     readTransfers();
 
     // Setup special windows
-    kdrop = new DropTarget();
+    kdrop = new DropTarget(this);
     kdock = new DockWidget(this);
+    connect(kdock, SIGNAL(quitSelected()), SLOT(slotQuit()));
 
     // Set geometry
     if (ksettings.mainPosition.x() != -1) {
@@ -234,15 +234,16 @@ KMainWidget::KMainWidget(bool bStartDocked)
     m_paAutoShutdown->setChecked(ksettings.b_autoShutdown);
 
 
-    m_paOfflineMode->setChecked(ksettings.b_offlineMode);
-
-
-    if (ksettings.b_offlineMode)
-        setCaption(i18n("Offline"), false);
-    else {
-        setCaption(QString::null, false);
+    m_paOfflineMode->setChecked(ksettings.b_offline);
+    if (!ksettings.b_offlineMode) 
         m_paOfflineMode->setIconSet(LOAD_ICON("tool_offline_mode_on"));
-    }
+
+    if (ksettings.b_offline) {
+        setCaption(i18n("Offline"), false);
+        log(i18n("Starting offline"));
+    } else
+        setCaption(QString::null, false);
+    
     m_paAutoPaste->setChecked(ksettings.b_autoPaste);
     m_paShowLog->setChecked(b_viewLogWindow);
 
@@ -349,7 +350,7 @@ void KMainWidget::setupGUI()
 #endif
     m_paResume = new KAction(i18n("&Resume"),"tool_resume", 0, this, SLOT(slotResumeCurrent()), coll, "resume");
     m_paPause = new KAction(i18n("&Pause"),"tool_pause", 0, this, SLOT(slotPauseCurrent()), coll, "pause");
-    m_paDelete = new KAction(i18n("&Delete"),"tool_delete", 0, this, SLOT(slotDeleteCurrent()), coll, "delete");
+    m_paDelete = new KAction(i18n("&Delete"),"editdelete", Qt::Key_Delete, this, SLOT(slotDeleteCurrent()), coll, "delete");
     m_paRestart = new KAction(i18n("Re&start"),"tool_restart", 0, this, SLOT(slotRestartCurrent()), coll, "restart");
 
     m_paQueue = new KRadioAction(i18n("&Queue"),"tool_queue", 0, this, SLOT(slotQueueCurrent()), coll, "queue");
@@ -372,7 +373,7 @@ void KMainWidget::setupGUI()
 
     m_paPreferences    =  KStdAction::preferences(this, SLOT(slotPreferences()), coll);
 
-    KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), 
+    KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()),
 actionCollection());
     KStdAction::configureToolbars(this, SLOT(slotConfigureToolbars()), coll);
 
@@ -694,6 +695,7 @@ void KMainWidget::slotQuit()
 
                 return;
             }
+            break;
         }
     }
 
@@ -797,19 +799,19 @@ void KMainWidget::slotDeleteCurrent()
     {
         if ( selectedItems.count() > 1 )
         {
-            if (KMessageBox::questionYesNoList(this, i18n("Are you sure you want to delete these transfers?"),
+            if (KMessageBox::warningContinueCancelList(this, i18n("Are you sure you want to delete these transfers?"),
                                                itemNames, i18n("Question"),
-                                               KStdGuiItem::yes(),KStdGuiItem::no(),
+                                               KStdGuiItem::del(),
                                                QString("multiple_delete_transfer"))
-                != KMessageBox::Yes)
+                != KMessageBox::Continue)
                 return; // keep 'em
         }
         else
         {
-            if (KMessageBox::questionYesNo(this, i18n("Are you sure you want to delete this transfer?"),
-                                           i18n("Question"), KStdGuiItem::yes(),KStdGuiItem::no(),
+            if (KMessageBox::warningContinueCancel(this, i18n("Are you sure you want to delete this transfer?"),
+                                           i18n("Question"), KStdGuiItem::del(),
                                            QString("delete_transfer"))
-                != KMessageBox::Yes)
+                != KMessageBox::Continue)
                 return;
         }
     }
@@ -844,22 +846,22 @@ void KMainWidget::slotDeleteCurrent()
 }
 
 
-void KMainWidget::pauseAll()
+void KMainWidget::stopAll()
 {
 #ifdef _DEBUG
     sDebugIn << endl;
 #endif
 
-    log(i18n("Pausing all jobs"), false);
+    log(i18n("Stopping all jobs"), false);
 
     TransferIterator it(myTransferList);
     Transfer::TransferStatus Status;
     for (; it.current(); ++it) {
         Status = it.current()->getStatus();
         if (Status == Transfer::ST_TRYING || Status == Transfer::ST_RUNNING)
-            it.current()->slotRequestPause();
+            it.current()->slotStop();
     }
-
+    slotUpdateActions();
 
 #ifdef _DEBUG
     sDebugOut << endl;
@@ -1177,6 +1179,10 @@ void KMainWidget::addTransfers( const KURL::List& src, const QString& destDir )
                         destFile = destURL;
                     }
                 }
+                else 
+                {
+                  destFile = destURL;
+                }
             }
         }
 
@@ -1272,10 +1278,9 @@ void KMainWidget::checkQueue()
     uint numRun = 0;
     int status;
     Transfer *item;
+    TransferIterator it(myTransferList);
 
-    if (!ksettings.b_offlineMode && b_online) {
-
-        TransferIterator it(myTransferList);
+    if (!ksettings.b_offline) {
 
         // count running transfers
         for (; it.current(); ++it) {
@@ -1289,11 +1294,12 @@ void KMainWidget::checkQueue()
         bool isQuequed;
         for (; it.current() && numRun < ksettings.maxSimultaneousConnections; ++it) {
             item = it.current();
-            isRunning = (item->getStatus() == Transfer::ST_RUNNING) || (item->getStatus() == Transfer::ST_TRYING);
+            isRunning = (item->getStatus() == Transfer::ST_RUNNING) || ((item->getStatus() == Transfer::ST_TRYING));
 
-            isQuequed = (item->getMode() == Transfer::MD_QUEUED);
+            isQuequed = (item->getMode() == Transfer::MD_QUEUED || item->getMode() == Transfer::MD_NEW);
 
-            if (!isRunning && isQuequed && !ksettings.b_offlineMode) {
+            if     (!isRunning && isQuequed && !ksettings.b_offline)
+            {
                 log(i18n("Starting another queued job."));
                 item->slotResume();
                 numRun++;
@@ -1304,11 +1310,19 @@ void KMainWidget::checkQueue()
 
         updateStatusBar();
 
-    } else {
-        log(i18n("Cannot continue offline status"));
+//    } else {//TODO this has to be solved different
+//        log(i18n("Cannot continue offline status"));
     }
 
-
+    it.reset();
+    for (; it.current(); ++it)
+    {
+        item = it.current();
+        if (item->getMode() == Transfer::MD_NEW && item->getStatus() == Transfer::ST_STOPPED)
+        {
+            item->checkCache();
+        }
+    }
 #ifdef _DEBUG
     sDebugOut << endl;
 #endif
@@ -1406,8 +1420,8 @@ void KMainWidget::slotStatusChanged(Transfer * item, int _operation)
         else
             item->setMode(Transfer::MD_NONE);
 
-        if (myTransferList->isQueueEmpty()) {
-            // no items in the TransferList or we have donwload all items
+        if (!myTransferList->areTransfersQueuedOrScheduled()) {
+            // no items or only delayed and finished items in the TransferList
             if (ksettings.b_autoDisconnect)
                 onlineDisconnect();
 
@@ -1672,24 +1686,24 @@ void KMainWidget::slotToggleOfflineMode()
     sDebugIn "ksettings.b_offlineMode = " << ksettings.b_offlineMode << endl;
 #endif
 
-
     ksettings.b_offlineMode = !ksettings.b_offlineMode;
-    if (ksettings.b_offlineMode) {
+    ksettings.b_offline=(ksettings.b_offlineMode || !b_connected);
+    if (ksettings.b_offline) {
         log(i18n("Offline mode on."));
-        pauseAll();
+        stopAll();
         setCaption(i18n("Offline"), false);
         m_paOfflineMode->setIconSet(LOAD_ICON("tool_offline_mode_off"));
     } else {
         log(i18n("Offline mode off."));
-        setCaption(i18n(""), false);
+        setCaption(QString::null, false);
         m_paOfflineMode->setIconSet(LOAD_ICON("tool_offline_mode_on"));
     }
-    m_paOfflineMode->setChecked(ksettings.b_offlineMode);
+
+    m_paOfflineMode->setChecked(ksettings.b_offline);
 
 
     slotUpdateActions();
     checkQueue();
-
 #ifdef _DEBUG
     sDebugOut << endl;
 #endif
@@ -1922,9 +1936,9 @@ void KMainWidget::slotUpdateActions()
             }
             // enable PAUSE, RESUME and RESTART only when we are online and not in offline mode
 #ifdef _DEBUG
-            sDebug << "-->ONLINE= " << ksettings.b_offlineMode << endl;
+            sDebug << "-->ONLINE= " << ksettings.b_offline << endl;
 #endif
-            if (item == first_item && !ksettings.b_offlineMode) {
+            if (item == first_item && !ksettings.b_offline) {
                 switch (item->getStatus()) {
                 case Transfer::ST_TRYING:
                 case Transfer::ST_RUNNING:
@@ -2058,11 +2072,11 @@ void KMainWidget::updateStatusBar()
     statusBar()->changeItem(i18n(" %1/s ").arg(KIO::convertSize(totalSpeed)), ID_TOTAL_SPEED);
 
     if (kdock) {
-    tmpstr = i18n(" Transfers: %1 ").arg(myTransferList->childCount()) +
-    i18n(" Files: %1 ").arg(totalFiles)+
-    i18n(" Size: %1 ").arg(KIO::convertSize(totalSize))+
-    i18n(" Time: %1 %2/s").arg(remTime.toString()).arg(KIO::convertSize(totalSpeed));
-    kdock->updateToolTip( tmpstr );
+        tmpstr = i18n(" Transfers: %1 ").arg(myTransferList->childCount()) +
+                 i18n(" Files: %1 ").arg(totalFiles)+
+                 i18n(" Size: %1 ").arg(KIO::convertSize(totalSize))+
+                 i18n(" Time: %1 %2/s").arg(remTime.toString()).arg(KIO::convertSize(totalSpeed));
+        kdock->updateToolTip( tmpstr );
     }
 #ifdef _DEBUG
     //sDebugOut << endl;
@@ -2076,7 +2090,7 @@ void KMainWidget::onlineDisconnect()
     sDebugIn << endl;
 #endif
 
-    if (!b_online) {
+    if (!b_connected) {
         return;
     }
 
@@ -2103,9 +2117,21 @@ void KMainWidget::slotCheckConnection()
 #ifdef _DEBUG
     //sDebugIn << endl;
 #endif
-
+    bool old = b_connected;
     checkOnline();
-
+    if (b_connected != old) {
+        if (b_connected) {
+            log(i18n("We are online."));
+            setCaption(QString::null, false);
+            ksettings.b_offline=ksettings.b_offlineMode;
+            checkQueue();
+        } else {
+            log(i18n("We are offline."));
+            setCaption(i18n("Offline"), false);
+            ksettings.b_offline=true;
+            stopAll();
+        }
+    }
 #ifdef _DEBUG
     //sDebugOut << endl;
 #endif
@@ -2118,8 +2144,6 @@ void KMainWidget::checkOnline()
     //sDebugIn << endl;
 #endif
 
-    bool old = b_online;
-
     struct ifreq ifr;
 
     memset(&ifr, 0, sizeof(ifreq));
@@ -2133,40 +2157,28 @@ void KMainWidget::checkOnline()
         // get the flags for particular device
         if (ioctl(_sock, SIOCGIFFLAGS, &ifr) < 0) {
             flag = true;
-            b_online = false;
+            b_connected = false;
         } else if (ifr.ifr_flags == 0) {
 #ifdef _DEBUG
             sDebug << "Can't get flags from interface " << ifr.ifr_name << endl;
 #endif
-            b_online = false;
+            b_connected = false;
         } else if (ifr.ifr_flags & IFF_UP) {    // if (ifr.ifr_flags & IFF_RUNNING)
-            b_online = true;
+            b_connected = true;
         } else {
-            b_online = false;
+            b_connected = false;
         }
     } else {
-        b_online = true;        // PERMANENT connection
+        b_connected = true;        // PERMANENT connection
     }
 
-    m_paOfflineMode->setEnabled(b_online);
+    m_paOfflineMode->setEnabled(b_connected);
 
-    if (b_online != old) {
-        if (flag) {             // so that we write this only once when connection is changed
+    if (flag) {
 #ifdef _DEBUG
             sDebug << "Unknown interface " << ifr.ifr_name << endl;
 #endif
         }
-
-        if (b_online) {
-            log(i18n("We are online."));
-            checkQueue();
-        } else {
-            log(i18n("We are offline."));
-            pauseAll();
-        }
-    }
-
-
 #ifdef _DEBUG
     //sDebugOut << endl;
 #endif
@@ -2287,6 +2299,10 @@ void KMainWidget::customEvent(QCustomEvent * _e)
     case Slave::SLV_INFO:
         e->getItem()->logMessage(e->getMsg());
         break;
+        
+        case Slave::SLV_NOTINCACHE:
+        e->getItem()->NotInCache();
+        break;
     default:
 #ifdef _DEBUG
         sDebug << "Unknown Result..die" << result << endl;
