@@ -2,7 +2,7 @@
 *                                kmainwidget.h
 *                             -------------------
 *
-*    Revision     : $Id: kmainwidget.h,v 1.28 2004/05/23 00:50:10 bmeyer Exp $
+*    Revision     : $Id: kmainwidget.h 393399 2005-02-27 00:13:41Z  $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -102,6 +102,7 @@ public slots:
     void slotToggleAnimation();
     void slotToggleSound();
     void slotUpdateActions();
+
 protected slots:
     void slotQuit();
 
@@ -162,13 +163,13 @@ protected:
     void updateStatusBar();
 
     // some flags
-    bool b_online;
+    bool b_connected;
     bool b_viewPreferences;
 
     // utility functions
     void onlineDisconnect();
     void checkOnline();
-    void pauseAll();
+    void stopAll();
     void log(const QString & message, bool statusbar = true);
 
     /** No descriptions */
