@@ -2,7 +2,7 @@
 *                                  main.cpp
 *                             -------------------
 *
-*    Revision     : $Id: main.cpp,v 1.29 2003/12/10 11:39:04 raabe Exp $
+*    Revision     : $Id: main.cpp 379676 2005-01-18 10:06:20Z pino $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -31,6 +31,7 @@
 #include <kcmdlineargs.h>
 #include <kurl.h>
 #include <kuniqueapplication.h>
+#include <kstartupinfo.h>
 
 #include <signal.h>
 #include <unistd.h>
@@ -41,14 +42,14 @@
 
 
 
-static const char description[] = I18N_NOOP("An advanced download manager for KDE.");
+static const char description[] = I18N_NOOP("An advanced download manager for KDE");
 
 static const char version[] = KGETVERSION;
 
 
 static KCmdLineOptions option[] = {
                                       { "showDropTarget", I18N_NOOP("Start KGet with drop target"), 0 },
-                                      {"+[URL(s)]", I18N_NOOP("URL(s) to download."), 0},
+                                      {"+[URL(s)]", I18N_NOOP("URL(s) to download"), 0},
                                       KCmdLineLastOption
                                   };
 
@@ -147,7 +148,7 @@ public:
         }
 
         else
-            KWin::activateWindow (kmainwidget->winId());
+            KStartupInfo::setNewStartupId( mainWidget(), kapp->startupId());
 
         if (args->isSet("showDropTarget"))
             kmain->activateDropTarget();
@@ -159,7 +160,7 @@ public:
 #endif
             QString txt(args->arg(0));
             if ( txt.endsWith( ".kgt" ) )
-                kmain->readTransfersEx(txt);
+                kmain->readTransfersEx(KURL::fromPathOrURL( txt ));
             else
                 kmain->addTransferEx( KURL::fromPathOrURL( txt ),
                                       KURL());
@@ -183,7 +184,7 @@ public:
 
 int main(int argc, char *argv[])
 {
-    KAboutData aboutData("kget", I18N_NOOP("KGet"), version, description, KAboutData::License_GPL, "(C) 2001 - 2002, Patrick Charbonnier \n(C) 2002, Carsten Pfeiffer\n(C) 1998 - 2000, Matej Koss", "http://kget.sourceforge.net");
+    KAboutData aboutData("kget", I18N_NOOP("KGet"), version, description, KAboutData::License_GPL, "(C) 2001 - 2002, Patrick Charbonnier \n(C) 2002, Carsten Pfeiffer\n(C) 1998 - 2000, Matej Koss", 0, "http://kget.sourceforge.net");
 
     aboutData.addAuthor("Patrick  Charbonnier", 0, "pch@freeshell.org");
     aboutData.addAuthor("Carsten Pfeiffer", 0, "pfeiffer@kde.org");
@@ -197,7 +198,7 @@ int main(int argc, char *argv[])
 
     if (!KGetApp::start()) {
         fprintf(stderr, "kget is already running!\n");
-        exit(0);
+        return 0;
     }
 
     KGetApp kApp;
@@ -206,7 +207,4 @@ int main(int argc, char *argv[])
     kApp.exec();
 
     cleanup();
-
-
-
 }
