@@ -2,7 +2,7 @@
 *                                settings.h
 *                             -------------------
 *
-*    Revision     : $Id: settings.h,v 1.13 2002/12/04 21:12:31 faure Exp $
+*    Revision     : $Id: settings.h 388162 2005-02-10 21:21:31Z ratz $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -132,7 +132,9 @@ public:
 
     uint connectionType;
     uint linkNumber;
-    bool b_offlineMode;
+    bool b_offlineMode;// If we want to be offline
+    bool b_offline;    // If we really are offline
+
 
     // automation options
     bool b_autoSave;
