@@ -2,9 +2,8 @@
 *                                transfer.cpp
 *                             -------------------
 *
-*    Revision     : $Id: transfer.cpp,v 1.48.2.3 2004/04/28 13:45:26 mcamen Exp $
 *    begin        : Tue Jan 29 2002
-*    copyright    : (C) 2002 by Patrick Charbonnier
+*    copyright    : (C) 2002, 2003, 2004, 2005 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
 *    email        : pch@freeshell.org
 *
@@ -24,6 +23,7 @@
  *
  ***************************************************************************/
 
+#include <qheader.h>
 
 #include <kurl.h>
 #include <kmessagebox.h>
@@ -52,9 +52,10 @@
 extern Settings ksettings;
 
 
-Transfer::Transfer(TransferList * _view, const KURL & _src, const KURL & _dest)
+Transfer::Transfer(TransferList * _view, const KURL & _src, const KURL & _dest, const uint _id)
     : QObject( _view ),
-      KListViewItem(_view)
+      KListViewItem(_view),
+      dlgIndividual( 0 )
 {
     sDebugIn << endl;
 
@@ -62,22 +63,24 @@ Transfer::Transfer(TransferList * _view, const KURL & _src, const KURL & _dest)
     dest = _dest;
 
     view = _view;
-    init();
+    init(_id);
 
     sDebugOut << endl;
 }
 
 
-Transfer::Transfer(TransferList * _view, Transfer * after, const KURL & _src, const KURL & _dest)
+Transfer::Transfer(TransferList * _view, Transfer * after, const KURL & _src, const KURL & _dest, const uint _id)
     : QObject( _view ),
-      KListViewItem(_view, (QListViewItem *) after)
+      KListViewItem(_view, (QListViewItem *) after),
+      src(_src), dest(_dest), view(_view),
+      dlgIndividual( 0 )
 {
     sDebugIn << endl;
 
     view = _view;
     src = _src;
     dest = _dest;
-    init();
+    init(_id);
 
     sDebugOut << endl;
 }
@@ -88,21 +91,21 @@ Transfer::~Transfer()
     sDebugIn << endl;
 
     synchronousAbort();
-
     delete dlgIndividual;
+
     sDebugOut << endl;
 }
 
 
 void
-Transfer::init()
+Transfer::init(const uint _id)
 {
     sDebugIn << endl;
 
     totalSize = 0;
     processedSize = 0;
     percent = 0;
-    id = 0;
+    id = _id;
     m_pSlave = new Slave(this, src, dest);
     canResume = false;
     startTime = QDateTime::currentDateTime();
@@ -113,12 +116,6 @@ Transfer::init()
 
     status = ST_STOPPED;
 
-    if (ksettings.b_addQueued)
-        mode = MD_QUEUED;
-    else
-        mode = MD_DELAYED;
-
-
 
     connect(this, SIGNAL(statusChanged(Transfer *, int)), kmain, SLOT(slotStatusChanged(Transfer *, int)));
     connect(this, SIGNAL(statusChanged(Transfer *, int)), this, SLOT(slotUpdateActions()));
@@ -130,7 +127,7 @@ Transfer::init()
 
     m_paPause = new KAction(i18n("&Pause"), "tool_pause", 0, this, SLOT(slotRequestPause()), this, "pause");
 
-    m_paDelete = new KAction(i18n("&Delete"), "tool_delete", 0, this, SLOT(slotRequestRemove()), this, "delete");
+    m_paDelete = new KAction(i18n("&Delete"), "editdelete", 0, this, SLOT(slotRequestRemove()), this, "delete");
 
     m_paRestart = new KAction(i18n("Re&start"), "tool_restart", 0, this, SLOT(slotRequestRestart()), this, "restart");
 
@@ -149,10 +146,8 @@ Transfer::init()
     // m_paDock = new KAction(i18n("&Dock"),"tool_dock", 0, this,SLOT(slotRequestDelay()), this, "dockIndividual");
 
     // setup individual transfer dialog
-    dlgIndividual = new DlgIndividual(this);
-    if (ksettings.b_iconifyIndividual) {
-        KWin::iconifyWindow( dlgIndividual->winId() );
-    }
+
+    mode = MD_NEW;
 
     sDebugOut << endl;
 }
@@ -162,7 +157,14 @@ void Transfer::synchronousAbort()
 {
     if ( m_pSlave )
     {
-        m_pSlave->Op(Slave::KILL);
+        if ( m_pSlave->running() )
+        {
+            m_pSlave->Op(Slave::KILL);
+            m_pSlave->wait();
+        }
+
+        if ( m_pSlave->running() )
+            m_pSlave->terminate();
 
         delete m_pSlave;
         m_pSlave = 0L;
@@ -175,20 +177,22 @@ void Transfer::synchronousAbort()
 
 void Transfer::slotUpdateActions()
 {
-    sDebugIn << "the item Status is =" << status << "offline=" << ksettings.b_offlineMode << endl;
-    //if we are in offlinemode just disable all actions  and return
-    if (ksettings.b_offlineMode) {
+    sDebugIn << "the item Status is =" << status << "offline=" << ksettings.b_offline << endl;
+     //if we are offline just disable Resume and Pause and return
+    if (ksettings.b_offline) {
         m_paResume->setEnabled(false);
         m_paPause->setEnabled(false);
         m_paRestart->setEnabled(false);
-        dlgIndividual->update();
+        if(dlgIndividual)
+			dlgIndividual->update();
         return;
     }
 
     UpdateRetry();
 
     switch (status) {
-    case ST_TRYING:
+
+    case ST_TRYING://fall-through
     case ST_RUNNING:
         m_paResume->setEnabled(false);
         m_paPause->setEnabled(true);
@@ -222,6 +226,7 @@ void Transfer::slotUpdateActions()
     case MD_DELAYED:
         m_paDelay->setChecked(true);
         break;
+    case MD_NEW: //fall through
     case MD_NONE:
         m_paQueue->setChecked(false);
         m_paTimer->setChecked(false);
@@ -240,7 +245,7 @@ void Transfer::slotUpdateActions()
     m_paTimer->blockSignals(false);
     m_paDelay->blockSignals(false);
 
-    if (isVisible())
+    if (dlgIndividual)
         dlgIndividual->update();
 
     sDebugOut << endl;
@@ -265,8 +270,8 @@ void Transfer::updateAll()
 
     updateStatus(status);       // first phase of animation
 
-    logMessage(i18n("Copy file from: %1").arg(src.url()));
-    logMessage(i18n("To: %1").arg(dest.url()));
+    logMessage(i18n("Copy file from: %1").arg(src.prettyURL()));
+    logMessage(i18n("To: %1").arg(dest.prettyURL()));
 
     // source
     setText(view->lv_url, src.prettyURL());
@@ -274,8 +279,14 @@ void Transfer::updateAll()
     // destination
     setText(view->lv_filename, dest.fileName());
 
-    dlgIndividual->setCopying(src, dest);
-    dlgIndividual->setCanResume(canResume);
+    if(dlgIndividual)
+		{
+		dlgIndividual->setCopying(src, dest);
+    	dlgIndividual->setCanResume(canResume);
+		dlgIndividual->setTotalSize(totalSize);
+		dlgIndividual->setPercent(0);
+		dlgIndividual->setProcessedSize(0);
+	}
 
     if (totalSize != 0) {
         //logMessage(i18n("Total size is %1 bytes").arg((double)totalSize));
@@ -285,9 +296,6 @@ void Transfer::updateAll()
         setText(view->lv_total, i18n("unknown"));
     }
 
-    dlgIndividual->setTotalSize(totalSize);
-    dlgIndividual->setPercent(0);
-    dlgIndividual->setProcessedSize(0);
 
     sDebugOut << endl;
 }
@@ -300,28 +308,48 @@ bool Transfer::updateStatus(int counter)
     QPixmap *pix = 0L;
     bool isTransfer = false;
 
-    if (status == ST_RUNNING) {
-        pix = view->animConn.at(counter);
-        isTransfer = true;
-    } else if (status == ST_TRYING) {
-        pix = view->animTry.at(counter);
-        isTransfer = true;
+    view->setUpdatesEnabled(false);
 
-    } else if (status == ST_STOPPED /*|| status==ST_PAUSED||status==ST_ABORTED */ ) {
-        if (mode == MD_QUEUED) {
-            pix = &view->pixQueued;
-        } else if (mode == MD_SCHEDULED) {
-            pix = &view->pixScheduled;
-        } else {
-            pix = &view->pixDelayed;
-        }
-    } else if (status == ST_FINISHED) {
-        pix = &view->pixFinished;
+    switch(status)
+        {
+        case ST_RUNNING:
+            pix = view->animConn.at(counter);
+            isTransfer = true;
+            break;
+        case ST_TRYING:
+            pix = view->animTry.at(counter);
+            isTransfer = true;
+            break;
+        case ST_STOPPED:
+            if(mode == MD_QUEUED)
+                pix = &view->pixQueued;
+            else if(mode == MD_SCHEDULED)
+                pix = &view->pixScheduled;
+            else
+                pix = &view->pixDelayed;
+            break;
+        case ST_FINISHED:
+            pix = &view->pixFinished;
     }
 
     setPixmap(view->lv_pixmap, *pix);
+    view->setUpdatesEnabled(true);
+
+    if(prevStatus!=status || prevMode != mode || status==ST_RUNNING || status==ST_TRYING)
+        {
+        QRect rect = view->header()->sectionRect(view->lv_pixmap);
+
+        int x = rect.x();
+        int y = view->itemRect(this).y();
+        int w = rect.width();
+        int h = rect.height();
+
+        view->QScrollView::updateContents(x,y,w,h);
+
+        prevStatus = status;
+       prevMode = mode;
+    }
 
-    //sDebug<< "<<<<Leaving"<<endl;
     return isTransfer;
 }
 
@@ -345,17 +373,18 @@ void Transfer::slotResume()
 
     retryCount++;
     if (retryCount > ksettings.reconnectRetries)
-        ksettings.reconnectRetries = retryCount;
+        retryCount = 1;
     UpdateRetry();
     assert(status == ST_STOPPED);
 
-    sDebug << "src: " << src.url() << endl;
-    sDebug << "dest " << dest.url() << endl;
+    sDebug << "src: " << src.prettyURL() << endl;
+    sDebug << "dest " << dest.prettyURL() << endl;
 
     m_paResume->setEnabled(false);
 
     status = ST_TRYING;
     mode = MD_QUEUED;
+    logMessage(i18n("Attempt number %1").arg(retryCount));
 
     sDebug << "sending Resume to slave " << endl;
     m_pSlave->Op(Slave::RETR);
@@ -364,6 +393,26 @@ void Transfer::slotResume()
 }
 
 
+ void Transfer::slotStop()
+{
+    sDebugIn << endl;
+
+    logMessage(i18n("Stopping"));
+
+    assert(status <= ST_RUNNING && ksettings.b_offline);
+
+    m_pSlave->Op(Slave::KILL); // KILL doesn't post a Message
+    sDebug << "Killing Slave" << endl;
+
+    slotSpeed(0);
+    mode = MD_QUEUED;
+    status=ST_STOPPED;
+    m_paQueue->setChecked(true);
+
+    slotUpdateActions();
+
+    sDebugOut << endl;
+}
 
 
 void Transfer::slotRequestPause()
@@ -403,14 +452,17 @@ void Transfer::slotRequestRemove()
     sDebugIn << endl;
     m_paDelete->setEnabled(false);
     m_paPause->setEnabled(false);
-    dlgIndividual->close();
+    if(dlgIndividual)
+                dlgIndividual->close();
+
 
     if ( status != ST_FINISHED )
     {
-        // delete the partly downloaded file, if any
         KURL file = dest;
+        // delete the partly downloaded file, if any
         file.setFileName( dest.fileName() + ".part" ); // ### get it from the job?
-        if ( KIO::NetAccess::exists( file ) ) // don't pollute user with warnings
+  
+        if ( KIO::NetAccess::exists( file, false, view ) ) // don't pollute user with warnings
         {
             SafeDelete::deleteFile( file ); // ### messagebox on failure?
         }
@@ -503,7 +555,8 @@ void Transfer::slotFinished()
     slotProcessedSize(totalSize);
 
     slotSpeed(0);
-    dlgIndividual->enableOpenFile();
+    if(dlgIndividual)
+		dlgIndividual->enableOpenFile();
     emit statusChanged(this, OP_FINISHED);
     sDebugOut << endl;
 }
@@ -518,7 +571,7 @@ void Transfer::slotRenaming(KIO::Job *, const KURL &, const KURL & to)
 
         dest = to;
 
-        logMessage(i18n("Renaming to %1").arg(dest.url().ascii()));
+        logMessage(i18n("Renaming to %1").arg(dest.prettyURL().ascii()));
 
           // destination
           setText (view->lv_filename, dest.fileName ());
@@ -559,7 +612,8 @@ void Transfer::slotSpeed(unsigned long bytes_per_second)
         setText(view->lv_remaining, remainingTime.toString());
     }
 
-    dlgIndividual->setSpeed(speed, remainingTime);
+	if(dlgIndividual)
+    	dlgIndividual->setSpeed(speed, remainingTime);
 
     //sDebugOut<<endl;
 }
@@ -575,11 +629,14 @@ void Transfer::slotTotalSize(KIO::filesize_t bytes)
     if (totalSize == 0) {
         totalSize = bytes;
         if (totalSize != 0) {
-            logMessage(i18n("Total size is %1 bytes").arg((double)totalSize,0,'f'));
+            logMessage(i18n("Total size is %1 bytes").arg((double)totalSize,0,'f',0));
             setText(view->lv_total, KIO::convertSize(totalSize));
-            dlgIndividual->setTotalSize(totalSize);
-            dlgIndividual->setPercent(0);
-            dlgIndividual->setProcessedSize(0);
+			if(dlgIndividual)
+				{
+				dlgIndividual->setTotalSize(totalSize);
+				dlgIndividual->setPercent(0);
+				dlgIndividual->setProcessedSize(0);
+			}
         }
     } else {
 
@@ -588,7 +645,7 @@ void Transfer::slotTotalSize(KIO::filesize_t bytes)
         assert(totalSize == bytes);
 #endif
         if (totalSize != bytes)
-            logMessage(i18n("The file size does not match!"));
+            logMessage(i18n("The file size does not match."));
         else
             logMessage(i18n("File Size checked"));
     }
@@ -617,12 +674,14 @@ void Transfer::slotProcessedSize(KIO::filesize_t bytes)
         totalSize = processedSize;
 
         setText(view->lv_total, KIO::convertSize(totalSize));
-        dlgIndividual->setTotalSize(totalSize);
+		if(dlgIndividual)
+        	dlgIndividual->setTotalSize(totalSize);
     }
     else {
         percent = (int) (((float) processedSize / (float) totalSize) * 100.0);
     }
-    dlgIndividual->setProcessedSize(processedSize);
+	if(dlgIndividual)
+    	dlgIndividual->setProcessedSize(processedSize);
 
     if (percent != old) {
         QString tmps;
@@ -634,7 +693,8 @@ void Transfer::slotProcessedSize(KIO::filesize_t bytes)
 
         setText(view->lv_progress, tmps);
 
-        dlgIndividual->setPercent(percent);
+		if(dlgIndividual)
+        	dlgIndividual->setPercent(percent);
     }
     //sDebug<< "<<<<Leaving"<<endl;
 }
@@ -646,6 +706,25 @@ void Transfer::showIndividual()
 {
     sDebugIn << endl;
 
+    //    create a DlgIndividual only if it hasn't been created yet
+    if(!dlgIndividual)
+    {
+        dlgIndividual = new DlgIndividual(this);
+        dlgIndividual->setLog(transferLog);
+        dlgIndividual->setCopying(src, dest);
+        dlgIndividual->setCanResume(canResume);
+        dlgIndividual->setTotalSize(totalSize);
+        dlgIndividual->setPercent(percent);
+        dlgIndividual->setProcessedSize(processedSize);
+    }
+
+    dlgIndividual->raise();
+
+
+    if (ksettings.b_iconifyIndividual) {
+        KWin::iconifyWindow( dlgIndividual->winId() );
+    }
+
     //      update the actions
     slotUpdateActions();
     //     then show the single dialog
@@ -656,13 +735,18 @@ void Transfer::showIndividual()
 }
 
 
-
 void Transfer::logMessage(const QString & message)
 {
     sDebugIn << message << endl;
 
     emit log(id, src.fileName(), message);
-    dlgIndividual->addLog(message);
+
+    QString tmps = "<font color=\"blue\">" + QTime::currentTime().toString() + "</font> : " + message;
+
+    transferLog.append(tmps + '\n');
+
+    if(dlgIndividual)
+        dlgIndividual->appendLog(tmps);
 
     sDebugOut << endl;
 }
@@ -683,7 +767,7 @@ bool Transfer::read(KSimpleConfig * config, int id)
     }
 
     if (!src.isValid() && !ksettings.b_expertMode) {
-        KMessageBox::error(kmain, i18n("Malformed URL:\n") + src.url(), i18n("Error"));
+        KMessageBox::error(kmain, i18n("Malformed URL:\n") + src.prettyURL(), i18n("Error"));
         return false;
     }
 
@@ -691,8 +775,8 @@ bool Transfer::read(KSimpleConfig * config, int id)
     status = (TransferStatus) config->readNumEntry("Status", ST_RUNNING);
     startTime = config->readDateTimeEntry("ScheduledTime");
     canResume = config->readBoolEntry("CanResume", true);
-    totalSize = config->readNumEntry("TotalSize", 0);
-    processedSize = config->readNumEntry("ProcessedSize", 0);
+    totalSize = config->readUnsignedNum64Entry("TotalSize", 0);
+    processedSize = config->readUnsignedNum64Entry("ProcessedSize", 0);
 
     if (status != ST_FINISHED && totalSize != 0) {
         //TODO insert additional check
@@ -718,8 +802,8 @@ void Transfer::write(KSimpleConfig * config, int id)
     config->writeEntry("Mode", mode);
     config->writeEntry("Status", status);
     config->writeEntry("CanResume", canResume);
-    config->writeEntry("TotalSize", totalSize);
-    config->writeEntry("ProcessedSize", processedSize);
+    config->writeEntry("TotalSize", totalSize );
+    config->writeEntry("ProcessedSize", processedSize );
     config->writeEntry("ScheduledTime", startTime);
     sDebugOut << endl;
 }
@@ -746,42 +830,35 @@ void Transfer::slotExecPause()
     sDebugOut << endl;
 }
 
-void Transfer::slotExecAbort(const QString & _msg)
+void Transfer::slotExecError()
 {
-    mode = MD_DELAYED;
+    sDebugIn << endl;
+
     status = ST_STOPPED;
-    slotSpeed(0);               //need???????
-    QString tmps;
+    mode = MD_SCHEDULED;
+    startTime=QDateTime::currentDateTime().addSecs(ksettings.reconnectTime * 60);
+    emit statusChanged(this, OP_SCHEDULED);
 
-    tmps = "<code><font color=\"red\"> <strong>" + _msg + "</font> </strong></code><br/>";
-
-    logMessage(tmps);
-
-    if (ksettings.b_reconnectOnError) {
-        retryCount++;
-        if (retryCount == ksettings.reconnectRetries) { // no more retries
-            if (retryCount > ksettings.reconnectRetries)
-                ksettings.reconnectRetries = retryCount;
-            status = ST_STOPPED;
-            mode = MD_DELAYED;
-        } else {
-            status = ST_STOPPED;
-            mode = MD_SCHEDULED;
-            startTime = QDateTime::currentDateTime().addSecs(ksettings.reconnectTime * 60);
-            logMessage(i18n("Attempt number %1").arg(retryCount));
-        }
-    } else {                    // if reconnecting is not enabled - simply set to delayed
-        status = ST_STOPPED;
-        mode = MD_DELAYED;
-    }
-
-    emit statusChanged(this, OP_ABORTED);
+    sDebugOut << endl;
 }
 
+void Transfer::slotExecBroken()
+{
+    sDebugIn << endl;
+
+    status = ST_STOPPED;
+    mode = MD_QUEUED;
+    emit statusChanged(this, OP_QUEUED);
+
+    sDebugOut << endl;
+}
+
+
 void Transfer::slotExecRemove()
 {
     sDebugIn << endl;
 
+    m_pSlave->wait();
     emit statusChanged(this, OP_REMOVED);
     sDebugOut << endl;
 }
@@ -797,6 +874,25 @@ void Transfer::slotExecResume()
 void Transfer::slotExecConnected()
 {
     sDebugIn << endl;
+    if (mode == MD_NEW)
+    {
+        if (ksettings.b_offline)// when we're offline and arrive here, then the file is in cache
+            return;             // Slave::slotResult will be called immediately, so we do nothing here
+        status = ST_STOPPED;
+        m_pSlave->Op(Slave::KILL);
+        if (ksettings.b_addQueued)
+        {
+            mode = MD_QUEUED;
+            emit statusChanged(this, OP_QUEUED);
+        }
+        else
+        {
+            mode = MD_DELAYED;
+            emit statusChanged(this, OP_DELAYED);
+        }
+        return;
+    }
+    
     status = ST_RUNNING;
     emit statusChanged(this, OP_CONNECTED);
     sDebugOut << endl;
@@ -816,7 +912,7 @@ void Transfer::slotCanResume(bool _bCanResume)
         setText(view->lv_resume, i18n("No"));
     }
 
-    dlgIndividual->setCanResume(canResume);
+    //dlgIndividual->setCanResume(canResume);
 
     sDebugOut << endl;
 }
@@ -861,7 +957,7 @@ void Transfer::slotStartTime(const QDateTime & _startTime)
 /** return true if the dlgIndividual is Visible */
 bool Transfer::isVisible() const
 {
-    return dlgIndividual->isVisible();
+    return dlgIndividual ? dlgIndividual->isVisible() : false;
 }
 
 bool Transfer::keepDialogOpen() const
@@ -872,8 +968,43 @@ bool Transfer::keepDialogOpen() const
 void Transfer::maybeShow()
 {
     if ( ksettings.b_showIndividual && getStatus() != Transfer::ST_FINISHED )
-        dlgIndividual->show();
+    {
+        if(dlgIndividual)
+            dlgIndividual->show();
+    }
 }
 
+bool Transfer::retryOnError()
+{
+    return (ksettings.b_reconnectOnError && (retryCount < ksettings.reconnectRetries));
+}
+
+bool Transfer::retryOnBroken()
+{
+    return (ksettings.b_reconnectOnBroken && (retryCount < ksettings.reconnectRetries));
+}
+
+void Transfer::checkCache()
+{
+    assert (mode == MD_NEW);
+
+    if (src.protocol()=="http")
+    {
+        status = ST_TRYING;
+        m_pSlave->Op(Slave::RETR_CACHE);
+    }
+    else
+        NotInCache();
+}
+
+void Transfer::NotInCache()
+{
+    logMessage(i18n("checking if file is in cache...no"));
+    if (ksettings.b_addQueued)
+        mode = MD_QUEUED;
+    else
+        mode = MD_DELAYED;
+    status = ST_STOPPED;
+}
 #include "transfer.moc"
 
