@@ -2,7 +2,7 @@
 *                                transferlist.cpp
 *                             -------------------
 *
-*    Revision     : $Id: transferlist.cpp,v 1.26 2004/07/04 18:38:27 binner Exp $
+*    Revision     : $Id: transferlist.cpp 388130 2005-02-10 19:58:58Z ratz $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -196,17 +196,17 @@ bool TransferList::updateStatus(int counter)
 }
 
 
-bool TransferList::isQueueEmpty()
+bool TransferList::areTransfersQueuedOrScheduled()
 {
     TransferIterator it(this);
 
-    if (childCount() <= 0)
-        return true;
-    else
-        for (; it.current(); ++it)
-            if (it.current()->getMode() == Transfer::MD_NONE)
+    if (childCount() > 0) {
+        for (; it.current(); ++it) {
+            if ((it.current()->getMode() == Transfer::MD_QUEUED)|| \
+                (it.current()->getMode() == Transfer::MD_SCHEDULED))
                 return true;
-
+        }
+    }
     return false;
 }
 
@@ -229,7 +229,7 @@ void TransferList::readTransfers(const KURL& file)
 {
     QString tmpFile;
 
-    if (KIO::NetAccess::download(file, tmpFile)) {
+    if (KIO::NetAccess::download(file, tmpFile, (QWidget*)parent())) {
         KSimpleConfig config(tmpFile);
 
         config.setGroup("Common");
