@@ -15,78 +15,55 @@
     *************************************************************************
 */
 
-#ifndef __CHATVIEW_H__
-#define __CHATVIEW_H__
-
-#include <qptrdict.h>
-#include <qvaluelist.h>
-#include <qpair.h>
-#include <ktextedit.h>
-
-#include <kopetecontact.h>
-#include <kdockwidget.h>
-#include <klistview.h>
-#include <dom/html_element.h>
+#ifndef CHATVIEW_H
+#define CHATVIEW_H
 
 #include "kopeteview.h"
+#include "kopeteviewplugin.h"
+#include <kdockwidget.h>
+#include <ktextedit.h> // for covariant return type of editWidget
+#include <qptrdict.h>
 
-class QPixmap;
-class KopeteTabWidget;
 class QTimer;
 
-class KHTMLPart;
-class KHTMLView;
-class KRootPixmap;
-class KRichTextEditPart;
+class ChatTextEditPart;
+class ChatMembersListWidget;
+class ChatMessagePart;
 
 class KopeteChatWindow;
+
 class KTabWidget;
-class KopeteRichTextEditPart;
-class KopeteMessageManager;
-class KCompletion;
-class KURL;
 
 class KopeteChatViewPrivate;
+class ChatWindowPlugin;
 
-using namespace DOM;
-
-typedef QPtrList<KopeteContact> KopeteContactPtrList;
-
-namespace KParts { struct URLArgs; class Part; }
-
-class KopeteContactLVI : public QObject, public KListViewItem
+namespace KParts
 {
-	Q_OBJECT
+    class Part;
+}
 
-public:
-	KopeteContactLVI( KopeteView *view, const KopeteContact *contact, KListView *parent );
-	const KopeteContact *contact() const { return m_contact; }
-	virtual QString key( int column, bool /*ascending*/ ) const;
-private:
-	KopeteContact *m_contact;
-	KListView *m_parentView;
-	KopeteView *m_view;
-
-private slots:
-	void slotPropertyChanged( KopeteContact *contact, const QString &key, const QVariant &oldValue, const QVariant &newValue  );
-	void slotStatusChanged( KopeteContact *c, const KopeteOnlineStatus &status, const KopeteOnlineStatus & );
-	void slotExecute( QListViewItem* );
-};
+namespace Kopete
+{
+	class Contact;
+	class ChatSession;
+}
 
 /**
  * @author Olivier Goffart
  */
 class ChatView : public KDockMainWindow, public KopeteView
 {
-	friend class KopeteChatViewTip;
-
 	Q_OBJECT
 public:
-	ChatView( KopeteMessageManager *manager, const char *name = 0 );
+	ChatView( Kopete::ChatSession *manager, ChatWindowPlugin *parent, const char *name = 0 );
 	~ChatView();
 
+	ChatMembersListWidget *membersList() const { return m_membersList; }
+	ChatMessagePart *messagePart() const { return m_messagePart; }
+	ChatTextEditPart *editPart() const { return m_editPart; }
+
 	/**
-	 * Adds text into the edit area. Used when you select an emotiocon
+	 * Adds text into the edit area. Used when you select an emoticon
 	 * @param text The text to be inserted
 	 */
 	void addText( const QString &text );
@@ -97,25 +74,21 @@ public:
 	void saveOptions();
 
 	/**
-	 * Sets the text to be displayed on the status label
-	 * @param text The text to be displayed
-	 */
-	void setStatus( const QString &text );
-
-	/**
-	 * Tells this view if it is the active view
+	 * Tells this view it is the active view
 	 */
 	void setActive( bool value );
 
 	/**
 	 * Clears the chat buffer
+	 *
+	 * Reimplemented from KopeteView
 	 */
 	virtual void clear();
 
 	/**
 	 * Sets the text to be displayed on tab label and window caption
 	 */
-	virtual void setCaption( const QString &text, bool modified );
+	void setCaption( const QString &text, bool modified );
 
 	/**
 	 * Changes the pointer to the chat widnow. Used to re-parent the view
@@ -123,11 +96,22 @@ public:
 	 */
 	void setMainWindow( KopeteChatWindow* parent );
 
+	/**
+	 * Returns the message currently in the edit area
+	 * Reimplemented from KopeteView
+	 * @return The Kopete::Message object for the message
+	 *
+	 * Reimplemented from KopeteView
+	 */
+	virtual Kopete::Message currentMessage();
+
 	/**
 	 * Sets the current message in the chat window
 	 * @param parent The new chat window
+	 *
+	 * Reimplemented from KopeteView
 	 */
-	virtual void setCurrentMessage( const KopeteMessage &newMessage );
+	virtual void setCurrentMessage( const Kopete::Message &newMessage );
 
 	void setTabBar( KTabWidget *tabBar );
 
@@ -143,12 +127,6 @@ public:
 	 */
 	void toggleMembersVisibility();
 
-	/**
-	 * Returns the message currently in the edit area
-	 * @return The message
-	 */
-	virtual KopeteMessage currentMessage();
-
 	/**
 	 * Returns the chat window this view is in
 	 * @return The chat window
@@ -165,52 +143,37 @@ public:
 	 * Returns whether or not the chat member list is visible
 	 * @return Is the chat member list visible?
 	 */
-	const bool visibleMembersList() { return visibleMembers; }
+	bool visibleMembersList();
 
-	/**
-	 * Returns the HTML contents of the KHTML widget
-	 * @return The contents of the view
-	 */
-	const QString viewsText();
-
-	QString &status() { return m_status; }
+	const QString &statusText();
 
 	bool docked() { return ( m_tabBar != 0L ); }
 
-	QString &caption() { return m_captionText; }
+	QString &caption() const;
 
-	bool sendInProgress() { return m_sendInProgress; }
+	bool sendInProgress();
 
-	void historyUp();
-
-	void historyDown();
-
-	virtual void raise(bool activate=false);
+	/** Reimplemented from KopeteView **/
+	virtual void raise( bool activate=false );
 
+	/** Reimplemented from KopeteView **/
 	virtual void makeVisible();
 
+	/** Reimplemented from KopeteView **/
 	virtual bool isVisible();
 
-	virtual QTextEdit *editWidget() { return static_cast<QTextEdit*>( m_edit ); }
-	virtual QWidget *mainWidget() { return this; }
+	/** Reimplemented from KopeteView **/
+	virtual QWidget *mainWidget();
 
-	/**
-	 * Returns the HTML contents of the KHTML widget
-	 * @return The contents of the view
-	 */
-	void nickComplete();
+	KTextEdit *editWidget();
 
-	void setStylesheet( const QString &style  );
-
-	/**
-	 * Can we send messages now?
-	 */
 	bool canSend();
 
-	/**
-	 * Is the user typing right now?
-	 */
-	bool isTyping();
+	/** Reimplimented from KopeteView **/
+	virtual void registerContextMenuHandler( QObject *target, const char* slot );
+
+	/** Reimplimented from KopeteView **/
+	virtual void registerTooltipHandler( QObject *target, const char* slot );
 
 public slots:
 	/**
@@ -230,18 +193,7 @@ public slots:
 	 */
 	void paste();
 
-	void print();
-
-	void save();
-
-	/**
-	 * Selects all text in the chat view
-	 */
-	void selectAll();
-
-	void pageUp();
-
-	void pageDown();
+	void nickComplete();
 
 	/**
 	 * Sets the foreground color of the entry area, and outgoing messages
@@ -256,10 +208,15 @@ public slots:
 	 */
 	void setFont( const QFont &newFont );
 
-	/*
+	/**
 	 * show a Font dialog and set the font selected by the user
 	 */
-	void setFont( );
+	void setFont();
+
+	/**
+	 * Get the font used in the format toolbar for Rich Text formatting
+	 */
+	QFont font();
 
 	/**
 	 * Sets the background color of the entry area, and outgoing messages
@@ -273,17 +230,11 @@ public slots:
 	 */
 	virtual void sendMessage();
 
-	/**
-	 * Appends a message to the chat view display area
-	 * @param message The message to be appended
-	 */
-	void addChatMessage( KopeteMessage &message );
-
 	/**
 	 * Called when a message is received from someone
 	 * @param message The message received
 	 */
-	virtual void appendMessage( KopeteMessage &message );
+	virtual void appendMessage( Kopete::Message &message );
 
 	/**
 	 * Called when a typing event is received from a contact
@@ -291,26 +242,27 @@ public slots:
 	 * @param contact The contact who is / isn't typing
 	 * @param typing If the contact is typing now
 	 */
-	void remoteTyping( const KopeteContact *contact, bool typing );
+	void remoteTyping( const Kopete::Contact *contact, bool typing );
 
+	/**
+	 * Sets the text to be displayed on the status label
+	 * @param text The text to be displayed
+	 */
+	void setStatusText( const QString &text );
+
+	/** Reimplemented from KopeteView **/
 	virtual void messageSentSuccessfully();
 
 	virtual bool closeView( bool force = false );
 
-	KParts::Part *part() const { return (KParts::Part*)( editpart ); }
+	KParts::Part *part() const;
 
 signals:
 	/**
-	 * Emits when a message is sent
+	 * Emitted when a message is sent
 	 * @param message The message sent
 	 */
-	void messageSent( KopeteMessage & );
-
-	/**
-	 * Emits every 4 seconds while the user is typing
-	 * @param bool if the user is typing right now
-	 */
-	void typing( bool );
+	void messageSent( Kopete::Message & );
 
 	void messageSuccess( ChatView* );
 
@@ -321,16 +273,16 @@ signals:
 
 	void closing( KopeteView* );
 
-	void activated( KopeteView * );
+	void activated( KopeteView* );
 
 	void captionChanged( bool active );
 
-	void updateStatusIcon( const ChatView * );
+	void updateStatusIcon( const ChatView* );
 
 	/**
 	 * Our send-button-enabled flag has changed
 	 */
-	void canSendChanged();
+	void canSendChanged(bool);
 
 	/**
 	 * Emitted when we re-parent ourselves with a new window
@@ -338,138 +290,80 @@ signals:
 	void windowCreated();
 
 private slots:
-	void slotOpenURLRequest( const KURL &url, const KParts::URLArgs &args );
-	void slotContactsContextMenu( KListView*, QListViewItem *item, const QPoint &point );
-	void slotRepeatTimer();
 	void slotRemoteTypingTimeout();
-	void slotScrollView();
-	void slotAppearanceChanged();
-	void slotPropertyChanged( KopeteContact *contact, const QString &key, const QVariant &oldValue, const QVariant &newValue  );
+	void slotPropertyChanged( Kopete::Contact *contact, const QString &key, const QVariant &oldValue, const QVariant &newValue  );
 
 	/**
-	 * Called when a contact is added to the KMM instance (A new person joins the chat).
+	 * Called when a contact is added to the chat session.
 	 * Adds this contact to the typingMap and the contact list view
 	 * @param c The contact that joined the chat
 	 * @param suppress mean that no notifications are showed
 	 */
-	void slotContactAdded( const KopeteContact *c, bool surpress );
+	void slotContactAdded( const Kopete::Contact *c, bool suppress );
 
 	/**
-	 * Called when a contact is removed from the KMM instance (A person left the chat).
-	 * Removes this contact from typingMap and the contact list view
+	 * Called when a contact is removed from the chat session. Updates the tab state and status icon,
+	 * displays a notification message and performs some cleanup.
 	 * @param c The contact left the chat
 	 * @param reason is the reason the contact left
 	 * @param format The format of the reason message
+	 * @param suppressNotification mean that no notifications are showed
 	 */
-	void slotContactRemoved( const KopeteContact *c, const QString& reason, KopeteMessage::MessageFormat format );
+	void slotContactRemoved( const Kopete::Contact *c, const QString& reason, Kopete::Message::MessageFormat format, bool suppressNotification=false );
 
 	/**
-	 * Called when a contact changes status, updates the contact list view and
+	 * Called when a contact changes status, updates the display name, status icon and tab bar state.
+	 * If the user isn't changing to/from an Unknown status, will also display a message in the chatwindow.
 	 * @param contact The contact who changed status
 	 * @param status The new status of the contact
+	 * @param oldstatus The former status of the contact
 	 */
-	void slotContactStatusChanged( KopeteContact *contact, const KopeteOnlineStatus &status, const KopeteOnlineStatus &oldstatus );
+	void slotContactStatusChanged( Kopete::Contact *contact, const Kopete::OnlineStatus &status, const Kopete::OnlineStatus &oldstatus );
 
 	/**
 	 * Called when the chat's display name is changed
 	 */
 	void slotChatDisplayNameChanged();
 
-	/**
-	 * Called when text is changed in the edit area
-	 */
-	void slotTextChanged();
-
-	void slotStopTimer();
-
-	/**
-	 * Called when KopetePrefs are saved
-	 */
-	void slotTransparencyChanged();
 	void slotMarkMessageRead();
 
-	/**
-	 * Sets the background of the widget
-	 * @param pm The new background image
-	 */
-	void slotUpdateBackground( const QPixmap &pm );
-
-	void slotScrollingTo( int x, int y);
-
-	void slotRefreshNodes();
-
-	void slotRefreshView();
-
-	void slotTransformComplete( const QVariant &result );
-
-	void slotRightClick( const QString &, const QPoint &point );
-
-	void slotCopyURL();
-
 	void slotToggleRtfToolbar( bool enabled );
 
+	void editPartTextChanged();
+
+protected:
+	virtual void dragEnterEvent ( QDragEnterEvent * );
+	virtual void dropEvent ( QDropEvent * );
+
 private:
-	enum KopeteTabState { Normal , Highlighted , Changed , Typing , Message , Undefined };
-	enum MembersListPolicy { Smart = 0, Visible = 1, Hidden = 2 };
-
-	typedef QMap<unsigned long,KopeteMessage> MessageMap;
-
-	QPtrDict<QTimer> m_remoteTypingMap;
-	KHTMLPart *chatView;
-	KHTMLView *htmlWidget;
-	bool scrollPressed;
-	MembersListPolicy membersStatus;
-	QStringList historyList;
-	int historyPos;
-	bool bgChanged;
-	QString unreadMessageFrom;
-	QMap<const KopeteContact *, KopeteContactLVI *> memberContactMap;
-	KTextEdit* m_edit;
-	KListView *membersList;
-	bool transparencyEnabled;
-	bool bgOverride;
-	bool fgOverride;
-	bool rtfOverride;
-	bool isActive;
-	bool m_sendInProgress;
-	bool visibleMembers;
-	unsigned long messageId;
-	QString m_lastMatch;
-	QString backgroundFile;
-	QString m_status;
-//	QPixmap m_icon;
-//	QPixmap m_iconLight;
-	KCompletion *mComplete;
-	HTMLElement activeElement;
-
-	KopeteTabState m_tabState;
-	KRootPixmap *root;
-	KDockWidget *viewDock;
-	KDockWidget *membersDock;
-	KDockWidget *editDock;
-	KTabWidget *m_tabBar;
-	KopeteRichTextEditPart *editpart;
-
-	KAction *copyAction;
-	KAction  *saveAction;
-	KAction *printAction;
-	KAction *closeAction;
-	KAction *copyURLAction;
-
-	// These control the position and visibility of the chat member list
-	KDockWidget::DockPosition membersDockPosition;
-
+	// widget stuff
 	KopeteChatWindow *m_mainWindow;
+	KTabWidget *m_tabBar;
 
-	QTimer *m_typingRepeatTimer;
-	QTimer *m_typingStopTimer;
+	KDockWidget *viewDock;
+	ChatMessagePart *m_messagePart;
 
-	/**
-	 * Holds the string to be displayed on the tabs and window title
-	 */
-	QString m_captionText;
+	KDockWidget *membersDock;
+	ChatMembersListWidget *m_membersList;
 
-	void setTabState( KopeteTabState state = Undefined);
+	KDockWidget *editDock;
+	ChatTextEditPart *m_editPart;
+
+	// the state of our tab
+	enum KopeteTabState { Normal, Highlighted, Changed, Typing, Message, Undefined };
+	KopeteTabState m_tabState;
+
+	// position and visibility of the chat member list
+	KDockWidget::DockPosition membersDockPosition;
+	enum MembersListPolicy { Smart = 0, Visible = 1, Hidden = 2 };
+	MembersListPolicy membersStatus;
+
+	// miscellany
+	QPtrDict<QTimer> m_remoteTypingMap;
+	QString unreadMessageFrom;
+	QString m_status;
+
+	void setTabState( KopeteTabState state = Undefined );
 
 	/**
 	 * Creates the members list widget
@@ -481,25 +375,21 @@ private:
 	 */
 	void readOptions();
 
-	/**
-	 * Refreshes the cuat view. Used to update the background.
-	 */
-	void refreshView();
-
-	KopeteMessage messageFromNode( Node &n );
-	void sendInternalMessage(const QString &msg, KopeteMessage::MessageFormat format = KopeteMessage::PlainText );
-
-	const QString styleHTML() const;
-
-	const QString addNickLinks( const QString &html ) const;
-
-	KopeteContact *contactFromNode( const DOM::Node &n ) const;
-
-	MessageMap messageMap;
+	void sendInternalMessage( const QString &msg, Kopete::Message::MessageFormat format = Kopete::Message::PlainText );
 
 	KopeteChatViewPrivate *d;
 };
 
+/**
+ * This is the class that makes the chatwindow a plugin
+ */
+class ChatWindowPlugin : public Kopete::ViewPlugin
+{
+	public:
+		ChatWindowPlugin(QObject *parent, const char *name, const QStringList &args);
+		KopeteView* createView( Kopete::ChatSession *manager );
+};
+
 #endif
 
 // vim: set noet ts=4 sts=4 sw=4:
