@@ -24,13 +24,9 @@
 #include "kopetecontact.h"
 #include "kdeversion.h"
 
-class KopeteMessage;
-class KopeteMessageManager;
 class KAction;
 class KToggleAction;
 class KActionMenu;
-class KopeteContact;
-class KopeteProtocol;
 class KTempFile;
 class QPixmap;
 class QTabWidget;
@@ -46,7 +42,14 @@ class KopeteView;
 class KSelectAction;
 class ChatView;
 
-typedef QPtrList<KopeteContact>  KopeteContactPtrList;
+namespace Kopete
+{
+class Message;
+class ChatSession;
+class Contact;
+class Protocol;
+typedef QPtrList<Contact>  ContactPtrList;
+}
 
 class KopeteChatWindow : public KParts::MainWindow
 {
@@ -62,11 +65,9 @@ public:
 	 * @return A KopeteChatWindow suitable for docking a ChatView into. Guaranteed
 	 *  to be a valid pointer.
 	 */
-	static KopeteChatWindow *window( KopeteMessageManager *manager );
+	static KopeteChatWindow *window( Kopete::ChatSession *manager );
 	~KopeteChatWindow();
 
-	KopeteMessage currentMessage();
-
 	/**
 	 * Attach an unattached chatview to this window
 	 * @param chat The chat view to attach
@@ -93,12 +94,19 @@ public:
 	void updateMembersActions();
 	void setStatus( const QString & );
 
+	/** 
+	 * Reimplemented from KMainWindow - asks each ChatView in the window if it is ok to close the window 
+	 * @return true if no ChatView objects to closing.
+	 */
+	virtual bool queryClose();
+	virtual bool queryExit();
+
 	KTempFile *backgroundFile;
 	QPtrList<ChatView> chatViewList;
 
 private:
 	// All KopeteChatWindows are created by the findWindow function
-	KopeteChatWindow(QWidget *parent = 0, const char* name = "KopeteChatWindow" );
+	KopeteChatWindow( QWidget *parent = 0, const char* name = "KopeteChatWindow" );
 
 	/**
 	 * The window list has changed:
@@ -118,14 +126,11 @@ private:
 
 	ChatView *m_activeView;
 	ChatView *m_popupView;
-	bool widgetSet;
-	bool tabsEnabled;
-	const KopeteContact *m_us;
+	bool m_alwaysShowTabs;
 	bool updateBg;
 	KTabWidget *m_tabBar;
 	KPushButton *m_button_send;
 	KSqueezedTextLabel *m_status_text;
-	QVBox *vBox;
 	QVBoxLayout *mainLayout;
 	QFrame *mainArea;
 	QLabel *anim;
@@ -138,7 +143,7 @@ private:
 	KAction *nickComplete;
 
 #if !KDE_IS_VERSION( 3, 1, 90 )
-  KToggleAction *mStatusbarAction;
+	KToggleAction *mStatusbarAction;
 #endif
 
 	KAction *tabLeft;
@@ -158,10 +163,10 @@ private:
 	QString statusMsg;
 
 signals:
-	void closing(KopeteChatWindow*);
+	void closing( KopeteChatWindow* );
 
 public slots:
-	void slotSmileyActivated(const QString &);
+	void slotSmileyActivated( const QString & );
 	void setActiveView( QWidget *active );
 	void updateBackground( const QPixmap &pm );
 
@@ -182,6 +187,8 @@ private slots:
 
 	void slotHistoryUp();
 	void slotHistoryDown();
+	void slotPageUp();
+	void slotPageDown();
 
 	void slotSendMessage();
 	void slotChatSave();
@@ -213,8 +220,7 @@ private slots:
 
 protected:
 	virtual void closeEvent( QCloseEvent *e );
-	virtual void windowActivationChange(bool);
-	virtual bool eventFilter( QObject *o, QEvent *e );
+	virtual void windowActivationChange( bool );
 };
 
 #endif
