@@ -19,11 +19,17 @@
 
 #include "kopeteemailwindow.h"
 
-#include <qclipboard.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qtimer.h>
-#include <qvbox.h>
+#include "chatmessagepart.h"
+#include "chattexteditpart.h"
+#include "kopetecontact.h"
+#include "kopetemetacontact.h"
+#include "kopeteemoticonaction.h"
+#include "kopetemessagemanager.h"
+#include "kopeteplugin.h"
+#include "kopetepluginmanager.h"
+#include "kopeteprefs.h"
+#include "kopetestdaction.h"
+#include "kopeteviewmanager.h"
 
 #include <kaction.h>
 #include <kapplication.h>
@@ -35,7 +41,6 @@
 #include <kedittoolbar.h>
 #include <kfontdialog.h>
 #include <kglobalsettings.h>
-#include <khtml_part.h>
 #include <khtmlview.h>
 #include <kiconloader.h>
 #include <kkeydialog.h>
@@ -47,59 +52,54 @@
 #include <kpushbutton.h>
 #include <ktextedit.h>
 #include <kwin.h>
+#include <kgenericfactory.h>
 
-#include "kopetecontact.h"
-#include "kopetemetacontact.h"
-#include "kopeteemoticonaction.h"
-#include "kopetemessagemanager.h"
-#include "kopeteplugin.h"
-#include "kopetepluginmanager.h"
-#include "kopeteprefs.h"
-#include "kopetexsl.h"
+#include <qlabel.h>
+#include <qlayout.h>
+#include <qtimer.h>
+#include <qvbox.h>
 
-#if !KDE_IS_VERSION(3, 1, 90)
-#include "loadmovie.h"
-#endif
+typedef KGenericFactory<EmailWindowPlugin> EmailWindowPluginFactory;
+K_EXPORT_COMPONENT_FACTORY( kopete_emailwindow, EmailWindowPluginFactory( "kopete_emailwindow" )  )
 
-class KopeteEmailWindowPrivate
+EmailWindowPlugin::EmailWindowPlugin(QObject *parent, const char *name, const QStringList &) :
+	Kopete::ViewPlugin( EmailWindowPluginFactory::instance(), parent, name )
+{}
+
+KopeteView* EmailWindowPlugin::createView( Kopete::ChatSession *manager )
+{
+	//TODO: foreignMessage, how will we do this cleanly?
+	return (KopeteView*)new KopeteEmailWindow(manager,this, false);
+}
+
+class KopeteEmailWindow::Private
 {
 public:
-	QValueList<KopeteMessage> messageQueue;
-	bool blnShowingMessage;
+	QValueList<Kopete::Message> messageQueue;
+	bool showingMessage;
 	bool sendInProgress;
 	bool visible;
 	uint queuePosition;
-	QColor fgColor;
-	QColor bgColor;
-	QFont font;
 	KPushButton *btnReplySend;
 	KPushButton *btnReadNext;
 	KPushButton *btnReadPrev;
-	QTextEdit *txtEntry;
 	QSplitter *split;
-	KHTMLView *htmlView;
-	KHTMLPart *htmlPart;
+	ChatMessagePart *messagePart;
 	KopeteEmailWindow::WindowMode mode;
 	KAction *chatSend;
 	QLabel *anim;
 	QMovie animIcon;
 	QPixmap normalIcon;
 	QString unreadMessageFrom;
-	KParts::Part *editpart;
+	ChatTextEditPart *editPart;
 
 	KActionMenu *actionActionMenu;
 	KopeteEmoticonAction *actionSmileyMenu;
-
-	KopeteXSLT *xsltParser;
 };
 
-KopeteEmailWindow::KopeteEmailWindow( KopeteMessageManager *manager, bool foreignMessage )
-:  KParts::MainWindow( ), KopeteView( manager )
+KopeteEmailWindow::KopeteEmailWindow( Kopete::ChatSession *manager, EmailWindowPlugin *parent, bool foreignMessage )
+	:  KParts::MainWindow( ), KopeteView( manager, parent ), d( new Private )
 {
-	d = new KopeteEmailWindowPrivate;
-
-	d->xsltParser = new KopeteXSLT( KopetePrefs::prefs()->styleContents(), this );
-
 	QVBox *v = new QVBox( this );
 	setCentralWidget( v );
 
@@ -108,55 +108,43 @@ KopeteEmailWindow::KopeteEmailWindow( KopeteMessageManager *manager, bool foreig
 	d->split = new QSplitter( v );
 	d->split->setOrientation( QSplitter::Vertical );
 
-	d->htmlPart = new KHTMLPart( d->split );
+	d->messagePart = new ChatMessagePart( manager, d->split, "messagePart" );
 
-	//Security settings, we don't need this stuff
-	d->htmlPart->setJScriptEnabled( false ) ;
-	d->htmlPart->setJavaEnabled( false );
-	d->htmlPart->setPluginsEnabled( false );
-	d->htmlPart->setMetaRefreshEnabled( false );
+	// FIXME: should this be in ChatView too? maybe move to ChatMessagePart?
+	d->messagePart->view()->setMarginWidth( 4 );
+	d->messagePart->view()->setMarginHeight( 4 );
+	d->messagePart->view()->setMinimumSize( QSize( 75, 20 ) );
 
-	d->htmlView = d->htmlPart->view();
-	d->htmlView->setMarginWidth( 4 );
-	d->htmlView->setMarginHeight( 4 );
-	d->htmlView->setMinimumSize( QSize( 75, 20 ) );
-	connect ( d->htmlPart->browserExtension(), SIGNAL( openURLRequestDelayed( const KURL &, const KParts::URLArgs & ) ),
-		SLOT( slotOpenURLRequest( const KURL &, const KParts::URLArgs & ) ) );
-	d->htmlView->setFocusPolicy( NoFocus );
+	d->editPart = new ChatTextEditPart( manager, d->split, "editPart" );
 
-	d->editpart = 0L;
-	if(KopetePrefs::prefs()->richText())
-	{
-		KLibFactory *factory = KLibLoader::self()->factory("libkrichtexteditpart");
-		if ( factory )
-		{
-			d->editpart = dynamic_cast<KParts::Part*> (factory->create( d->split, "krichtexteditpart", "KParts::ReadWritePart" ) );
-		}
-	}
+	/*
+	FIXME: dude, wtf?
+	QDomDocument doc = d->editPart->domDocument();
+	QDomNode menu = doc.documentElement().firstChild();
+	menu.removeChild( menu.firstChild() ); // Remove File
+	menu.removeChild( menu.firstChild() ); // Remove Edit
+	menu.removeChild( menu.firstChild() ); // Remove View
+	menu.removeChild( menu.lastChild() ); //Remove Help
 
-	if ( d->editpart )
-	{
-		QDomDocument doc = d->editpart->domDocument();
-		QDomNode menu = doc.documentElement().firstChild();
-		menu.removeChild( menu.firstChild() ); // Remove File
-		menu.removeChild( menu.firstChild() ); // Remove Edit
-		menu.removeChild( menu.firstChild() ); // Remove View
-		menu.removeChild( menu.lastChild() ); //Remove Help
+	doc.documentElement().removeChild( doc.documentElement().childNodes().item(1) ); //Remove MainToolbar
+	doc.documentElement().removeChild( doc.documentElement().lastChild() ); // Remove Edit popup
+	*/
+	connect( d->editPart, SIGNAL( messageSent( Kopete::Message & ) ),
+	         this, SIGNAL( messageSent( Kopete::Message & ) ) );
+	connect( d->editPart, SIGNAL( canSendChanged( bool ) ),
+	         this, SLOT( slotUpdateReplySend() ) );
+	connect( d->editPart, SIGNAL( typing(bool) ),
+		 manager, SIGNAL( typing(bool) ) );
 
-		doc.documentElement().removeChild( doc.documentElement().childNodes().item(1) ); //Remove MainToolbar
-		doc.documentElement().removeChild( doc.documentElement().lastChild() ); // Remove Edit popup
-		d->txtEntry = static_cast<KTextEdit*>( d->editpart->widget() );
-	}
-	else
-	{
-		d->txtEntry = new KTextEdit( d->split );
-	}
-
-	d->txtEntry->setMinimumSize( QSize( 75, 20 ) );
-	d->txtEntry->setWordWrap( QTextEdit::WidgetWidth );
-	d->txtEntry->setTextFormat( Qt::PlainText );
-	d->txtEntry->setWrapPolicy( QTextEdit::AtWhiteSpace );
-	connect( d->txtEntry, SIGNAL( textChanged()), this, SLOT( slotTextChanged() ) );
+	//Connections to the manager and the ViewManager that every view should have
+	connect( this, SIGNAL( closing( KopeteView * ) ),
+		 KopeteViewManager::viewManager(), SLOT( slotViewDestroyed( KopeteView * ) ) );
+	connect( this, SIGNAL( activated( KopeteView * ) ),
+		 KopeteViewManager::viewManager(), SLOT( slotViewActivated( KopeteView * ) ) );
+	connect( this, SIGNAL( messageSent(Kopete::Message &) ),
+		 manager, SLOT( sendMessage(Kopete::Message &) ) );
+	connect( manager, SIGNAL( messageSuccess() ),
+		 this, SLOT( messageSentSuccessfully() ));
 
 	QWidget *containerWidget = new QWidget( v );
 	containerWidget->setSizePolicy( QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum) );
@@ -174,14 +162,14 @@ KopeteEmailWindow::KopeteEmailWindow( KopeteMessageManager *manager, bool foreig
 	h->addWidget( d->btnReadNext, 0, Qt::AlignRight | Qt::AlignVCenter );
 
 	d->btnReplySend = new KPushButton( containerWidget );
-	connect( d->btnReplySend, SIGNAL( pressed() ), this, SLOT( slotReplySendClicked() ) );
+	connect( d->btnReplySend, SIGNAL( pressed() ), this, SLOT( slotReplySend() ) );
 	h->addWidget( d->btnReplySend, 0, Qt::AlignRight | Qt::AlignVCenter );
 
 	initActions();
 	setWFlags(Qt::WDestructiveClose);
 
-	d->blnShowingMessage = false;
-	
+	d->showingMessage = false;
+
 	if( foreignMessage )
 		toggleMode( Read );
 	else
@@ -190,19 +178,6 @@ KopeteEmailWindow::KopeteEmailWindow( KopeteMessageManager *manager, bool foreig
 	KConfig *config = KGlobal::config();
 	applyMainWindowSettings( config, QString::fromLatin1( "KopeteEmailWindow" )  );
 
-	config->setGroup( QString::fromLatin1("KopeteEmailWindowSettings") );
-
-	QFont tmpFont = KGlobalSettings::generalFont();
-	slotSetFont( config->readFontEntry( QString::fromLatin1("Font"), &tmpFont) );
-
-	QColor tmpColor = KGlobalSettings::textColor();
-	slotSetFgColor( config->readColorEntry ( QString::fromLatin1("TextColor"), &tmpColor ) );
-
-	tmpColor = KGlobalSettings::baseColor();
-	slotSetBgColor( config->readColorEntry ( QString::fromLatin1("BackgroundColor"), &tmpColor) );
-
-	connect( KopetePrefs::prefs(), SIGNAL(messageAppearanceChanged()), this, SLOT( slotRefreshAppearance() ) );
-
 	d->sendInProgress = false;
 
 	toolBar()->alignItemRight( 99 );
@@ -212,27 +187,16 @@ KopeteEmailWindow::KopeteEmailWindow( KopeteMessageManager *manager, bool foreig
 
 	setCaption( manager->displayName() );
 
-	m_type = KopeteMessage::Email;
-
-	d->txtEntry->installEventFilter( this );
-	KCursor::setAutoHideCursor( d->txtEntry, true, true );
+	slotUpdateReplySend();
 }
 
 KopeteEmailWindow::~KopeteEmailWindow()
 {
 	emit( closing( this ) );
 
+	// saves menubar, toolbar and statusbar setting
 	KConfig *config = KGlobal::config();
-
-	// saves menubar,toolbar and statusbar setting
 	saveMainWindowSettings( config, QString::fromLatin1( "KopeteEmailWindow" ) );
-
-	config->setGroup( QString::fromLatin1("KopeteEmailWindowSettings") );
-
-	config->writeEntry( QString::fromLatin1( "Font" ), d->font );
-	config->writeEntry( QString::fromLatin1( "TextColor" ), d->fgColor );
-	config->writeEntry( QString::fromLatin1( "BackgroundColor" ), d->bgColor );
-
 	config->sync();
 
 	delete d;
@@ -243,92 +207,52 @@ void KopeteEmailWindow::initActions(void)
 	KActionCollection *coll = actionCollection();
 
 	d->chatSend = new KAction( i18n( "&Send Message" ), QString::fromLatin1( "mail_send" ), 0,
-		this, SLOT( sendMessage() ), coll, "chat_send" );
+		this, SLOT( slotReplySend() ), coll, "chat_send" );
 	//Default to 'Return' for sending messages
 	d->chatSend->setShortcut( QKeySequence( Key_Return ) );
-	d->chatSend->setEnabled( false );
 
 	KStdAction::quit ( this, SLOT( slotCloseView() ), coll );
 
-	KStdAction::cut( d->txtEntry, SLOT( cut() ), coll );
+	KStdAction::cut( d->editPart->widget(), SLOT( cut() ), coll );
 	KStdAction::copy( this, SLOT(slotCopy()), coll);
-	KStdAction::paste( d->txtEntry, SLOT( paste() ), coll );
+	KStdAction::paste( d->editPart->widget(), SLOT( paste() ), coll );
 
 	new KAction( i18n( "&Set Font..." ), QString::fromLatin1( "charset" ), 0,
-		this, SLOT( slotSetFont() ), coll, "format_font" );
+	             d->editPart, SLOT( setFont() ), coll, "format_font" );
 	new KAction( i18n( "Set Text &Color..." ), QString::fromLatin1( "pencil" ), 0,
-		this, SLOT( slotSetFgColor() ), coll, "format_color" );
+	             d->editPart, SLOT( setFgColor() ), coll, "format_color" );
 	new KAction( i18n( "Set &Background Color..." ), QString::fromLatin1( "fill" ), 0,
-		this, SLOT( slotSetBgColor() ), coll, "format_bgcolor" );
+	             d->editPart, SLOT( setBgColor() ), coll, "format_bgcolor" );
 
-/*
-	// FIXME: This code was marked as KDE < 3.1 specific. Can we remove it?
-	//        Commented out for now, see if (and if so, where) it breaks - Martijn
 	KStdAction::showMenubar( this, SLOT( slotViewMenuBar() ), coll );
-	KStdAction::showToolbar( this, SLOT( slotViewToolBar() ), coll );
-*/
+	setStandardToolBarMenuEnabled( true );
 
 	d->actionSmileyMenu = new KopeteEmoticonAction( coll, "format_smiley" );
 	d->actionSmileyMenu->setDelayed( false );
 	connect(d->actionSmileyMenu, SIGNAL(activated(const QString &)), this, SLOT(slotSmileyActivated(const QString &)));
 
 	// add configure key bindings menu item
-	KStdAction::keyBindings(this, SLOT(slotConfKeys()), coll);
-	KStdAction::configureToolbars(this, SLOT(slotConfToolbar()), coll);
-
+	KStdAction::keyBindings( guiFactory(), SLOT( configureShortcuts() ), coll );
+	KStdAction::configureToolbars(this, SLOT( slotConfToolbar() ), coll);
+	//FIXME: no longer works?
+	KopeteStdAction::preferences( coll , "settings_prefs" );
 
 	// The animated toolbarbutton
 	d->normalIcon = QPixmap( BarIcon( QString::fromLatin1( "kopete" ) ) );
-#if KDE_IS_VERSION(3, 1, 90)
 	d->animIcon = KGlobal::iconLoader()->loadMovie( QString::fromLatin1( "newmessage" ), KIcon::Toolbar);
-#else
-	d->animIcon = KopeteCompat::loadMovie( QString::fromLatin1( "newmessage" ), KIcon::Toolbar);
-#endif
 	d->animIcon.pause();
 
 	d->anim = new QLabel( this, "kde toolbar widget" );
-	d->anim->setMargin(5);
+	d->anim->setMargin( 5 );
 	d->anim->setPixmap( d->normalIcon );
-	//toolBar()->insertWidget( 99, d->anim->width(), d->anim );
-	new KWidgetAction( d->anim , i18n("Toolbar Animation") , 0, 0 , 0 , coll , "toolbar_animation");
+	new KWidgetAction( d->anim, i18n("Toolbar Animation"), 0, 0, 0, coll, "toolbar_animation" );
 
-	setXMLFile( QString::fromLatin1( "kopetechatwindow.rc" ) );
-	createGUI( d->editpart );
+	setXMLFile( QString::fromLatin1( "kopeteemailwindow.rc" ) );
+	createGUI( d->editPart );
 	//createGUI( QString::fromLatin1( "kopeteemailwindow.rc" ) );
 	guiFactory()->addClient(m_manager);
 }
 
-bool KopeteEmailWindow::eventFilter( QObject *o, QEvent *e )
-{
-	if ( o->inherits( "KTextEdit" ) )
-		KCursor::autoHideEventFilter( o, e );
-
-	if( e->type() == QEvent::KeyPress )
-	{
-		QKeyEvent *event = static_cast<QKeyEvent*>( e );
-		KKey key( event );
-
-		// NOTE:
-		// shortcut.contains( key ) doesn't work. It was the old way we used to do it, but it is incorrect
-		// because if you have a multi-key shortcut then pressing any of the keys in
-		// that shortcut individually causes the shortcut to be activated.
-
-		if( d->chatSend->isEnabled() )
-		{
-			for( uint i = 0; i < d->chatSend->shortcut().count(); i++ )
-			{
-				if( key == d->chatSend->shortcut().seq(i).key(0) )
-				{
-					sendMessage();
-					return true;
-				}
-			}
-		}
-	}
-
-	return false;
-}
-
 void KopeteEmailWindow::closeEvent( QCloseEvent *e )
 {
 	// DO NOT call base class's closeEvent - see comment in KopeteApplication constructor for reason
@@ -340,14 +264,6 @@ void KopeteEmailWindow::closeEvent( QCloseEvent *e )
 	e->accept();
 }
 
-void KopeteEmailWindow::slotViewToolBar()
-{
-	if(toolBar()->isVisible())
-		toolBar()->hide();
-	else
-		toolBar()->show();
-}
-
 void KopeteEmailWindow::slotViewMenuBar()
 {
 	if( !menuBar()->isHidden() )
@@ -359,101 +275,41 @@ void KopeteEmailWindow::slotViewMenuBar()
 void KopeteEmailWindow::slotSmileyActivated(const QString &sm )
 {
 	if ( !sm.isNull() )
-		d->txtEntry->insert( sm );
-}
-
-void KopeteEmailWindow::slotConfKeys()
-{
-	KKeyDialog::configure(actionCollection(), this, true);
+		d->editPart->addText( sm );
 }
 
 void KopeteEmailWindow::slotConfToolbar()
 {
-	saveMainWindowSettings(KGlobal::config(), QString::fromLatin1( "KopeteChatWindow" ));
-	KEditToolbar *dlg = new KEditToolbar(actionCollection(), QString::fromLatin1("kopetechatwindow.rc") );
+	saveMainWindowSettings(KGlobal::config(), QString::fromLatin1( "KopeteEmailWindow" ));
+	KEditToolbar *dlg = new KEditToolbar(actionCollection(), QString::fromLatin1("kopeteemailwindow.rc") );
 	if (dlg->exec())
 	{
-		createGUI( d->editpart );
-		applyMainWindowSettings(KGlobal::config(), QString::fromLatin1( "KopeteChatWindow" ));
+		createGUI( d->editPart );
+		applyMainWindowSettings(KGlobal::config(), QString::fromLatin1( "KopeteEmailWindow" ));
 	}
 	delete dlg;
 }
 
-
-void KopeteEmailWindow::slotSetFont()
-{
-	KFontDialog::getFont( d->font, false, this );
-	d->txtEntry->setFont( d->font );
-}
-
-void KopeteEmailWindow::slotSetFont( const QFont &newFont )
-{
-	d->font = newFont;
-	d->txtEntry->setFont( d->font );
-}
-
-void KopeteEmailWindow::slotSetFgColor( const QColor &newColor )
-{
-	if( newColor == QColor() )
-		KColorDialog::getColor( d->fgColor, this );
-	else
-		d->fgColor = newColor;
-
-	QPalette pal = d->txtEntry->palette();
-	pal.setColor( QPalette::Active, QColorGroup::Text, d->fgColor );
-	pal.setColor( QPalette::Inactive, QColorGroup::Text, d->fgColor );
-
-	// unsetPalette() so that color changes in kcontrol are honoured
-	// if we ever have a subclass of KTextEdit, reimplement setPalette()
-	// and check it there.
-	if ( pal == QApplication::palette( d->txtEntry ) )
-		d->txtEntry->unsetPalette();
-	else
-		d->txtEntry->setPalette( pal );
-}
-
-void KopeteEmailWindow::slotSetBgColor( const QColor &newColor )
-{
-	if( newColor == QColor() )
-		KColorDialog::getColor( d->bgColor, this );
-	else
-		d->bgColor = newColor;
-
-	QPalette pal = d->txtEntry->palette();
-	pal.setColor( QPalette::Active,   QColorGroup::Base, d->bgColor );
-	pal.setColor( QPalette::Inactive, QColorGroup::Base, d->bgColor );
-	pal.setColor( QPalette::Disabled, QColorGroup::Base, d->bgColor );
-
-	// unsetPalette() so that color changes in kcontrol are honoured
-	// if we ever have a subclass of KTextEdit, reimplement setPalette()
-	// and check it there.
-	if ( pal == QApplication::palette( d->txtEntry ) )
-		d->txtEntry->unsetPalette();
-	else
-		d->txtEntry->setPalette( pal );
-}
-
 void KopeteEmailWindow::slotCopy()
 {
 //	kdDebug(14010) << k_funcinfo << endl;
 
-	if ( d->htmlPart->hasSelection() )
-		QApplication::clipboard()->setText( d->htmlPart->selectedText() );
+	if ( d->messagePart->hasSelection() )
+		d->messagePart->copy();
 	else
-		d->txtEntry->copy();
+		d->editPart->widget()->copy();
 }
 
-
-void KopeteEmailWindow::appendMessage(KopeteMessage &message)
+void KopeteEmailWindow::appendMessage(Kopete::Message &message)
 {
-	if( message.from() != m_manager->user() )
+	if( message.from() != m_manager->myself() )
 	{
 		if( d->mode == Send )
 			toggleMode( Reply );
 
 		d->messageQueue.append( message );
 
-		if( !d->blnShowingMessage )
+		if( !d->showingMessage )
 			slotReadNext();
 		else
 		{
@@ -461,7 +317,7 @@ void KopeteEmailWindow::appendMessage(KopeteMessage &message)
 			updateNextButton();
 		}
 
-		d->unreadMessageFrom = message.from()->metaContact() ? 
+		d->unreadMessageFrom = message.from()->metaContact() ?
 			message.from()->metaContact()->displayName() : message.from()->contactId();
 		QTimer::singleShot( 1000, this, SLOT(slotMarkMessageRead()) );
 	}
@@ -491,21 +347,23 @@ void KopeteEmailWindow::updateNextButton()
 	d->btnReadNext->setText( i18n( "(%1) Next >>" ).arg( d->messageQueue.count() - d->queuePosition ) );
 }
 
-void KopeteEmailWindow::slotTextChanged()
+void KopeteEmailWindow::slotUpdateReplySend()
 {
-	bool canSend = !d->txtEntry->text().isEmpty();
-	if( d->mode != Read )
-	{
-		d->btnReplySend->setEnabled( canSend );
-		d->chatSend->setEnabled( canSend );
-	}
+	bool canSend;
+	if( d->mode == Read )
+		canSend = true;
+	else
+		canSend = d->editPart->canSend();
+
+	d->btnReplySend->setEnabled( canSend );
+	d->chatSend->setEnabled( canSend );
 }
 
 void KopeteEmailWindow::slotReadNext()
 {
 //	kdDebug(14010) << k_funcinfo << endl;
 
-	d->blnShowingMessage = true;
+	d->showingMessage = true;
 
 	d->queuePosition++;
 
@@ -518,7 +376,7 @@ void KopeteEmailWindow::slotReadPrev()
 {
 //	kdDebug(14010) << k_funcinfo << endl;
 
-	d->blnShowingMessage = true;
+	d->showingMessage = true;
 
 	d->queuePosition--;
 
@@ -527,42 +385,21 @@ void KopeteEmailWindow::slotReadPrev()
 	updateNextButton();
 }
 
-void KopeteEmailWindow::slotRefreshAppearance()
+void KopeteEmailWindow::writeMessage( Kopete::Message &msg )
 {
-	KopeteMessage m = currentMessage();
-	writeMessage( m );
-}
-
-void KopeteEmailWindow::writeMessage( KopeteMessage &msg )
-{
-	QString dir = ( QApplication::reverseLayout() ? QString::fromLatin1("rtl") : QString::fromLatin1("ltr") );
-	d->htmlPart->begin();
-	//FIXME: this should use multi-argument version of .arg!
-	d->htmlPart->write( QString::fromLatin1( "<html><head><style>body {font-family:%1; font-size:%2pt; color:%3} td {font-family:%4; font-size:%5pt; color:%6}</style></head>" )
-		.arg( KopetePrefs::prefs()->fontFace().family() )
-		.arg( KopetePrefs::prefs()->fontFace().pointSize() )
-		.arg( KopetePrefs::prefs()->textColor().name() )
-		.arg( KopetePrefs::prefs()->fontFace().family() )
-		.arg( KopetePrefs::prefs()->fontFace().pointSize() )
-		.arg( KopetePrefs::prefs()->textColor().name() ) );
-	d->htmlPart->write( QString::fromLatin1( "<body style=\"background-repeat:no-repeat; background-attachment:fixed\" bgcolor=\"%1\" vlink=\"%2\" link=\"%3\" %4>%5</body></html>" )
-		.arg( KopetePrefs::prefs()->bgColor().name() )
-		.arg( KopetePrefs::prefs()->linkColor().name() )
-		.arg( KopetePrefs::prefs()->linkColor().name() )
-		.arg( dir )
-		.arg( d->xsltParser->transform( msg.asXML().toString() ) ) );
-	d->htmlPart->end();
+	d->messagePart->clear();
+	d->messagePart->appendMessage( msg );
 }
 
 void KopeteEmailWindow::sendMessage()
 {
+	if ( !d->editPart->canSend() )
+		return;
 	d->sendInProgress = true;
 	d->anim->setMovie( d->animIcon );
 	d->animIcon.unpause();
-	d->btnReplySend->setEnabled( false );
-	d->txtEntry->setEnabled( false );
-	KopeteMessage sentMessage = currentMessage();
-	emit messageSent( sentMessage );
+	d->editPart->widget()->setEnabled( false );
+	d->editPart->sendMessage();
 }
 
 void KopeteEmailWindow::messageSentSuccessfully()
@@ -613,8 +450,7 @@ bool KopeteEmailWindow::closeView( bool force )
 	}
 	else
 	{
-		d->txtEntry->setEnabled( true );
-		d->txtEntry->setText( QString::null );
+		d->editPart->widget()->setEnabled( true );
 	}
 
 	return false;
@@ -628,37 +464,36 @@ void KopeteEmailWindow::toggleMode( WindowMode newMode )
 	{
 		case Send:
 			d->btnReplySend->setText( i18n( "Send" ) );
-			slotTextChanged();
-			d->txtEntry->show();
-			d->htmlView->hide();
+			d->editPart->widget()->show();
+			d->messagePart->view()->hide();
 			d->btnReadNext->hide();
 			d->btnReadPrev->hide();
 			break;
 		case Read:
 			d->btnReplySend->setText( i18n( "Reply" ) );
-			d->btnReplySend->setEnabled( true );
-			d->txtEntry->hide();
-			d->htmlView->show();
+			d->editPart->widget()->hide();
+			d->messagePart->view()->show();
 			d->btnReadNext->show();
 			d->btnReadPrev->show();
 			break;
 		case Reply:
 			QValueList<int> splitPercent;
+			// FIXME: should be saved and restored
 			splitPercent.append(50);
 			splitPercent.append(50);
 			d->btnReplySend->setText( i18n( "Send" ) );
-			slotTextChanged();
-			d->txtEntry->show();
-			d->htmlView->show();
+			d->editPart->widget()->show();
+			d->messagePart->view()->show();
 			d->btnReadNext->show();
 			d->btnReadPrev->show();
 			d->split->setSizes( splitPercent );
-			d->txtEntry->setFocus();
+			d->editPart->widget()->setFocus();
 			break;
 	}
+	slotUpdateReplySend();
 }
 
-void KopeteEmailWindow::slotReplySendClicked()
+void KopeteEmailWindow::slotReplySend()
 {
 	if( d->mode == Read )
 		toggleMode( Reply );
@@ -670,10 +505,10 @@ void KopeteEmailWindow::slotReplySendClicked()
 void KopeteEmailWindow::raise(bool activate)
 {
 	makeVisible();
-	
+
 	if ( !KWin::windowInfo( winId(), NET::WMDesktop ).onAllDesktops() )
-	KWin::setOnDesktop( winId(), KWin::currentDesktop() );
-	
+		KWin::setOnDesktop( winId(), KWin::currentDesktop() );
+
 	KMainWindow::raise();
 
 	/* Removed Nov 2003
@@ -687,11 +522,7 @@ void KopeteEmailWindow::raise(bool activate)
 
 	//Will not activate window if user was typing
 	if(activate)
-#if KDE_VERSION < KDE_MAKE_VERSION( 3, 1, 90 )
-		KWin::setActiveWindow( winId() );
-#else
 		KWin::activateWindow( winId() );
-#endif
 }
 
 void KopeteEmailWindow::windowActivationChange( bool )
@@ -712,37 +543,14 @@ bool KopeteEmailWindow::isVisible()
 	return d->visible;
 }
 
-KopeteMessage KopeteEmailWindow::currentMessage()
+Kopete::Message KopeteEmailWindow::currentMessage()
 {
-	KopeteMessage currentMsg = KopeteMessage( m_manager->user(), m_manager->members(), d->txtEntry->text(),
-		KopeteMessage::Outbound, d->editpart ? KopeteMessage::RichText : KopeteMessage::PlainText );
-
-	currentMsg.setFont( d->font );
-	currentMsg.setBg( d->bgColor );
-	currentMsg.setFg( d->fgColor );
-
-	return currentMsg;
+	return d->editPart->contents();
 }
 
-void KopeteEmailWindow::setCurrentMessage( const KopeteMessage &newMessage )
+void KopeteEmailWindow::setCurrentMessage( const Kopete::Message &newMessage )
 {
-	d->txtEntry->setText( newMessage.plainBody() );
-}
-
-void KopeteEmailWindow::slotOpenURLRequest(const KURL &url, const KParts::URLArgs & /* args */ )
-{
-	kdDebug(14010) << k_funcinfo << "url=" << url.url() << endl;
-
-	// FIXME: Doesn't KRun do the mime type check automagically for us? - Martijn
-	if( url.protocol() == QString::fromLatin1( "mailto" ) )
-		kapp->invokeMailer( url );
-	else
-		kapp->invokeBrowser( url.url() );
-}
-
-QTextEdit * KopeteEmailWindow::editWidget()
-{
-	return d->txtEntry;
+	d->editPart->setContents( newMessage );
 }
 
 void KopeteEmailWindow::slotCloseView()
