@@ -51,21 +51,23 @@
 #include <kmessagebox.h>
 #include <kpushbutton.h>
 #include <kstandarddirs.h>
-#include <klibloader.h>
-#include <ktrader.h>
 #include <ktextedit.h>
 #include <kurlrequesterdlg.h>
+#include <krun.h>
+#include <kdirwatch.h>
 
 #include <ktexteditor/highlightinginterface.h>
 #include <ktexteditor/editinterface.h>
 #include <ktexteditor/document.h>
 #include <ktexteditor/view.h>
 
-#include "kopeteprefs.h"
-#include "kopetemessage.h"
-#include "styleeditdialog.h"
-#include "kopetexsl.h"
+// Things we fake to get the message preview to work
+#include "kopetemetacontact.h"
 #include "kopetecontact.h"
+#include "kopetemessage.h"
+
+#include "kopeteprefs.h"
+#include "kopetexsl.h"
 #include "kopeteemoticons.h"
 #include "kopeteglobal.h"
 
@@ -77,7 +79,7 @@ K_EXPORT_COMPONENT_FACTORY( kcm_kopete_appearanceconfig, KopeteAppearanceConfigF
 class KopeteAppearanceConfigPrivate
 {
 public:
-	KopeteXSLT *xsltParser;
+	Kopete::XSLT *xsltParser;
 };
 
 AppearanceConfig::AppearanceConfig(QWidget *parent, const char* /*name*/, const QStringList &args )
@@ -87,7 +89,7 @@ AppearanceConfig::AppearanceConfig(QWidget *parent, const char* /*name*/, const
 
 	d = new KopeteAppearanceConfigPrivate;
 
-	d->xsltParser = new KopeteXSLT( KopetePrefs::prefs()->styleContents(), this );
+	d->xsltParser = new Kopete::XSLT( KopetePrefs::prefs()->styleContents(), this );
 
 	(new QVBoxLayout(this))->setAutoAdd(true);
 	mAppearanceTabCtl = new QTabWidget(this, "mAppearanceTabCtl");
@@ -145,6 +147,10 @@ AppearanceConfig::AppearanceConfig(QWidget *parent, const char* /*name*/, const
 
 	mAppearanceTabCtl->addTab( mPrfsChatWindow, i18n("Chat Window") );
 
+
+	connect( KDirWatch::self() , SIGNAL(dirty(const QString&)) , this, SLOT( slotStyleModified( const QString &) ) );
+
+
 	// "Contact List" TAB =======================================================
 	mPrfsContactList = new AppearanceConfig_ContactList(mAppearanceTabCtl);
 	connect(mPrfsContactList->mTreeContactList, SIGNAL(toggled(bool)),
@@ -163,6 +169,10 @@ AppearanceConfig::AppearanceConfig(QWidget *parent, const char* /*name*/, const
 		this, SLOT(emitChanged()));
 	connect(mPrfsContactList->mFoldVisibility, SIGNAL(toggled(bool)),
 		this, SLOT(emitChanged()));
+	connect(mPrfsContactList->mAutoHide, SIGNAL(toggled(bool)),
+		this, SLOT(emitChanged()));
+	connect(mPrfsContactList->mAutoHideTimeout, SIGNAL(valueChanged(int)),
+		this, SLOT(emitChanged()));
 
 	// don't enable the checkbox if XRender is not available
 	#ifdef HAVE_XRENDER
@@ -211,7 +221,7 @@ AppearanceConfig::AppearanceConfig(QWidget *parent, const char* /*name*/, const
 
 	// ==========================================================================
 
-	errorAlert = false;
+
 	styleChanged = false;
 	slotTransparencyChanged(mPrfsChatWindow->mTransparencyEnabled->isChecked());
 
@@ -237,8 +247,9 @@ void AppearanceConfig::save()
 	p->setTransparencyColor( mPrfsChatWindow->mTransparencyTintColor->color() );
 	p->setTransparencyEnabled( mPrfsChatWindow->mTransparencyEnabled->isChecked() );
 	p->setTransparencyValue( mPrfsChatWindow->mTransparencyValue->value() );
-	if( styleChanged || p->styleSheet() != itemMap[ mPrfsChatWindow->styleList->selectedItem() ] )
-		p->setStyleSheet( itemMap[ mPrfsChatWindow->styleList->selectedItem() ] );
+	if( styleChanged || p->styleSheet() != mPrfsChatWindow->styleList->selectedItem()->text() )
+		p->setStyleSheet(  mPrfsChatWindow->styleList->selectedItem()->text() );
+	kdDebug(14000) << k_funcinfo << p->styleSheet()  << mPrfsChatWindow->styleList->selectedItem()->text() << endl;
 
 	// "Contact List" TAB =======================================================
 	p->setTreeView(mPrfsContactList->mTreeContactList->isChecked());
@@ -262,20 +273,23 @@ void AppearanceConfig::save()
 	p->setContactListCustomSmallFont(mPrfsColors->mSmallFont->font());
 	p->setContactListCustomNormalFont(mPrfsColors->mNormalFont->font());
 	p->setContactListGroupNameColor(mPrfsColors->mGroupNameColor->color());
+	p->setContactListAutoHide(mPrfsContactList->mAutoHide->isChecked());
+	p->setContactListAutoHideTimeout(mPrfsContactList->mAutoHideTimeout->value());
 
 	p->setBgOverride( mPrfsColors->mBgOverride->isChecked() );
 	p->setFgOverride( mPrfsColors->mFgOverride->isChecked() );
 	p->setRtfOverride( mPrfsColors->mRtfOverride->isChecked() );
 
 	p->save();
-	errorAlert = false;
 	styleChanged = false;
 }
 
 void AppearanceConfig::load()
 {
-	if( errorAlert )
-		return;
+	//we will change the state of somme controls, which will call some signals.
+	//so to don't refresh everything several times, we memorize we are loading.
+	loading=true;
+
 //	kdDebug(14000) << k_funcinfo << "called" << endl;
 	KopetePrefs *p = KopetePrefs::prefs();
 
@@ -297,7 +311,8 @@ void AppearanceConfig::load()
 		QFileInfo fi( *it );
 		QString fileName = fi.fileName().section( '.', 0, 0 );
 		mPrfsChatWindow->styleList->insertItem( fileName, 0 );
-		itemMap.insert( mPrfsChatWindow->styleList->firstItem(), fileName );
+		itemMap.insert( mPrfsChatWindow->styleList->firstItem(), *it );
+		KDirWatch::self()->addFile(*it);
 
 		if ( fileName == p->styleSheet() )
 			mPrfsChatWindow->styleList->setSelected( mPrfsChatWindow->styleList->firstItem(), true );
@@ -316,6 +331,8 @@ void AppearanceConfig::load()
 	mPrfsContactList->mFadeVisibility->setChecked( false );
 #endif
 	mPrfsContactList->mFoldVisibility->setChecked( p->contactListFolding() );
+	mPrfsContactList->mAutoHide->setChecked( p->contactListAutoHide() );
+	mPrfsContactList->mAutoHideTimeout->setValue( p->contactListAutoHideTimeout() );
 
 	// "Colors & Fonts" TAB =====================================================
 	mPrfsColors->foregroundColor->setColor(p->highlightForeground());
@@ -334,6 +351,9 @@ void AppearanceConfig::load()
 	mPrfsColors->mBgOverride->setChecked( p->bgOverride() );
 	mPrfsColors->mFgOverride->setChecked( p->fgOverride() );
 	mPrfsColors->mRtfOverride->setChecked( p->rtfOverride() );
+
+	loading=false;
+	slotUpdatePreview();
 }
 
 void AppearanceConfig::updateEmoticonlist()
@@ -343,7 +363,7 @@ void AppearanceConfig::updateEmoticonlist()
 
 	mPrfsEmoticons->icon_theme_list->clear(); // Wipe out old list
 	// Get a list of directories in our icon theme dir
-	QStringList themeDirs = KGlobal::dirs()->findDirs("data", "kopete/pics/emoticons");
+	QStringList themeDirs = KGlobal::dirs()->findDirs("emoticons", "");
 	// loop adding themes from all dirs into theme-list
 	for(unsigned int x = 0;x < themeDirs.count();x++)
 	{
@@ -356,8 +376,8 @@ void AppearanceConfig::updateEmoticonlist()
 			// We don't care for '.' and '..'
 			if ( themeQDir[y] != "." && themeQDir[y] != ".." )
 			{
-				// Add ourselves to the list, using our directory name
-				QPixmap previewPixmap = QPixmap(locate("data", "kopete/pics/emoticons/"+themeQDir[y]+"/smile.png"));
+				// Add ourselves to the list, using our directory name  FIXME:  use the first emoticon of the theme.
+				QPixmap previewPixmap = QPixmap(locate("emoticons", themeQDir[y]+"/smile.png"));
 				mPrfsEmoticons->icon_theme_list->insertItem(previewPixmap,themeQDir[y]);
 			}
 		}
@@ -372,7 +392,7 @@ void AppearanceConfig::updateEmoticonlist()
 		mPrfsEmoticons->icon_theme_list->setCurrentItem( 0 );
 }
 
-void AppearanceConfig::slotUseEmoticonsChanged( bool b )
+void AppearanceConfig::slotUseEmoticonsChanged( bool  )
 {
 	emitChanged();
 }
@@ -380,12 +400,11 @@ void AppearanceConfig::slotUseEmoticonsChanged( bool b )
 void AppearanceConfig::slotSelectedEmoticonsThemeChanged()
 {
 	QString themeName = mPrfsEmoticons->icon_theme_list->currentText();
-	QFileInfo fileInf(KGlobal::dirs()->findResource("data",
-		"kopete/pics/emoticons/"+themeName+"/"));
+	QFileInfo fileInf(KGlobal::dirs()->findResource("emoticons", themeName+"/"));
 	mPrfsEmoticons->btnRemoveTheme->setEnabled( fileInf.isWritable() );
 
-	KopeteEmoticons emoticons( themeName );
-	QStringList smileys = emoticons.picList();
+	Kopete::Emoticons emoticons( themeName );
+	QStringList smileys = emoticons.emoticonAndPicList().values();
 	QString newContentText = "<qt>";
 
 	for(QStringList::Iterator it = smileys.begin(); it != smileys.end(); ++it )
@@ -420,41 +439,20 @@ void AppearanceConfig::slotChangeFont()
 
 void AppearanceConfig::slotAddStyle()
 {
-	editedItem = 0L;
-	styleEditor = new StyleEditDialog(0L,"style", true);
-	(new QHBoxLayout( styleEditor->editFrame ))->setAutoAdd( true );
-	KTrader::OfferList offers = KTrader::self()->query( "KTextEditor/Document" );
-	KService::Ptr service = *offers.begin();
-	KLibFactory *factory = KLibLoader::self()->factory( service->library().latin1() );
-	editDocument = static_cast<KTextEditor::Document *>( factory->create( styleEditor->editFrame, 0, "KTextEditor::Document" ) );
+    QString styleName=KInputDialog::getText( i18n("Add Styles - Kopete") , i18n("Enter the name for the new style you want to add:") ,
+				QString::null, 0L, this) ;
+	if(styleName.isEmpty())
+		return;
 
-	if(!editDocument)
-		return; //TODO: show an error if the plugin can't be loaded
-
-	// FIXME: Can someone explain me why editDocument has no parent?
-	// Is it a problem in Kate? in the KLibrary system? This is a workaround
-	// for that. That also solves a crash while closing Kopete
-	connect(styleEditor, SIGNAL(destroyed()), editDocument, SLOT(deleteLater()) );
-	// Explanation of the crash (Bug 67494) :
-	// There is a static deleter in the Kate KPart to free some classes. This
-	// one also deletes some Highlight object. And there is another staticDeleter
-	// in Kopete to free the LibLoader, which will free the Kate Library, which
-	// will delete Kate's Document, which will deref some Highlight object
-	// ***BOOM***  (Highlight objects are already deleted)
-	// So this is maybe a problem in Kate. But if we delete object before closing
-	// Kopete, when they are not useful anymore, no problem
-
-	editDocument->createView( styleEditor->editFrame, 0 )->setSizePolicy( QSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding) );
-	KTextEditor::editInterface( editDocument )->setText( QString::fromLatin1(
-		"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
-		"<xsl:stylesheet version=\"1.0\" xmlns:xsl=\"http://www.w3.org/1999/XSL/Transform\">\n"
-		"<xsl:output method=\"html\"/>\n"
-		"<xsl:template match=\"message\">\n\n\n\n</xsl:template>\n</xsl:stylesheet>" ) );
-	updateHighlight();
-	styleEditor->show();
-	connect( styleEditor->buttonOk, SIGNAL(clicked()), this, SLOT(slotStyleSaved()) );
-	connect( styleEditor->buttonCancel, SIGNAL(clicked()), styleEditor, SLOT(deleteLater()) );
-	currentStyle = QString::null; //force to update preview;
+	if( addStyle( styleName ,
+			"<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
+			"<xsl:stylesheet version=\"1.0\" xmlns:xsl=\"http://www.w3.org/1999/XSL/Transform\">\n"
+			"<xsl:output method=\"html\"/>\n"
+			"<xsl:template match=\"message\">\n\n\n\n</xsl:template>\n</xsl:stylesheet>"  ) );
+	{
+		KRun::runURL( KURL(locateLocal("appdata", QString::fromLatin1("styles/%1.xsl").arg( styleName ) )) , "text/plain");
+		currentStyle = QString::null; //force to update preview;
+	}
 }
 
 void AppearanceConfig::updateHighlight()
@@ -474,8 +472,7 @@ void AppearanceConfig::updateHighlight()
 
 void AppearanceConfig::slotStyleSelected()
 {
-	QString styleName = itemMap[mPrfsChatWindow->styleList->selectedItem()];
-	QString filePath = locateLocal("appdata", QString::fromLatin1("styles/%1.xsl").arg( styleName ) );
+	QString filePath = itemMap[mPrfsChatWindow->styleList->selectedItem()];
 	QFileInfo fi( filePath );
 	if(fi.isWritable())
 	{
@@ -502,7 +499,7 @@ void AppearanceConfig::slotImportStyle()
 		if ( KIO::NetAccess::download( chosenStyle, stylePath, this ) )
 		{
 			QString styleSheet = fileContents( stylePath );
-			if ( KopeteXSLT( styleSheet ).isValid() )
+			if ( Kopete::XSLT( styleSheet ).isValid() )
 			{
 				QFileInfo fi( stylePath );
 				addStyle( fi.fileName().section( '.', 0, 0 ), styleSheet );
@@ -533,7 +530,7 @@ void AppearanceConfig::slotCopyStyle()
 
 		if ( !styleName.isEmpty() )
 		{
-			QString stylePath = locate("appdata", QString::fromLatin1("styles/%1.xsl").arg(itemMap[ copiedItem ]) );
+			QString stylePath = itemMap[ copiedItem ];
 			addStyle( styleName, fileContents( stylePath ) );
 		}
 	}
@@ -547,14 +544,10 @@ void AppearanceConfig::slotCopyStyle()
 
 void AppearanceConfig::slotEditStyle()
 {
-	slotAddStyle();
 	editedItem = mPrfsChatWindow->styleList->selectedItem();
-	QString stylePath = locate("appdata", QString::fromLatin1("styles/%1.xsl").arg(itemMap[ editedItem ]) );
-	QString model = fileContents( stylePath );
-	KTextEditor::editInterface( editDocument )->setText( model );
-	updateHighlight();
-	styleEditor->styleName->setText( editedItem->text() );
-	emitChanged();
+	QString stylePath = itemMap[ editedItem ];
+
+	KRun::runURL(stylePath, "text/plain");
 }
 
 void AppearanceConfig::slotDeleteStyle()
@@ -580,24 +573,25 @@ void AppearanceConfig::slotDeleteStyle()
 	emitChanged();
 }
 
-void AppearanceConfig::slotStyleSaved()
+void AppearanceConfig::slotStyleModified(const QString &filename)
 {
-	if( addStyle( styleEditor->styleName->text(), KTextEditor::editInterface( editDocument )->text() ) )
+	editedItem = mPrfsChatWindow->styleList->selectedItem();
+	QString stylePath = itemMap[ editedItem ];
+
+	if(filename == stylePath)
 	{
-		styleEditor->deleteLater();
+		currentStyle=QString::null;  //force to relead the preview
+		slotUpdatePreview();
+
 		emitChanged();
 	}
-	else //The style has not been saved for a reason or another - don't loose it
-		styleEditor->show();
 }
 
 bool AppearanceConfig::addStyle( const QString &styleName, const QString &styleSheet )
 {
 	bool newStyleName = !mPrfsChatWindow->styleList->findItem( styleName );
-	bool editExistingStyle = (mPrfsChatWindow->styleList->selectedItem() &&
-				 mPrfsChatWindow->styleList->selectedItem()->text()==styleName);
 
-	if ( newStyleName || editExistingStyle )
+	if ( newStyleName )
 	{
 		QString filePath = locateLocal("appdata", QString::fromLatin1("styles/%1.xsl").arg( styleName ) );
 		QFile out( filePath );
@@ -607,10 +601,12 @@ bool AppearanceConfig::addStyle( const QString &styleName, const QString &styleS
 			stream << styleSheet;
 			out.close();
 
+			KDirWatch::self()->addFile(filePath);
+
 			if ( newStyleName )
 			{
 				mPrfsChatWindow->styleList->insertItem( styleName, 0 );
-				itemMap.insert( mPrfsChatWindow->styleList->firstItem(), styleName );
+				itemMap.insert( mPrfsChatWindow->styleList->firstItem(), filePath );
 				mPrfsChatWindow->styleList->setSelected( mPrfsChatWindow->styleList->firstItem(), true );
 				mPrfsChatWindow->styleList->sort();
 			}
@@ -634,28 +630,47 @@ bool AppearanceConfig::addStyle( const QString &styleName, const QString &styleS
 	return false;
 }
 
-//reimplement KopeteContact and his abstract method
-class TestContact : public KopeteContact
+// Reimplement Kopete::Contact and its abstract method
+class FakeContact : public Kopete::Contact
 {
 public:
-	TestContact (  const QString &id  ) : KopeteContact ( (KopeteAccount*)0L, id, 0L ) {}
-	virtual KopeteMessageManager* manager(bool) { return 0L; }
+	FakeContact ( const QString &id, Kopete::MetaContact *mc ) : Kopete::Contact( 0, id, mc ) {}
+	virtual Kopete::ChatSession *manager(Kopete::Contact::CanCreateFlags /*c*/) { return 0L; }
+	virtual void slotUserInfo() {};
 };
 
+static QString sampleConversationXML()
+{
+	//Kopete::MetaContact jackMC;
+	FakeContact myself( i18n( "Myself" ), 0 );
+	FakeContact jack( i18n( "Jack" ), /*&jackMC*/ 0 );
+
+	Kopete::Message msgIn  ( &jack,   &myself, i18n( "Hello, this is an incoming message :-)" ), Kopete::Message::Inbound );
+	Kopete::Message msgOut ( &myself, &jack,   i18n( "Ok, this is an outgoing message" ), Kopete::Message::Outbound );
+	Kopete::Message msgCol ( &jack,   &myself, i18n( "Here is an incoming colored message" ), Kopete::Message::Inbound );
+	msgCol.setFg( QColor( "DodgerBlue" ) );
+	msgCol.setBg( QColor( "LightSteelBlue" ) );
+	Kopete::Message msgInt ( &jack,   &myself, i18n( "This is an internal message" ), Kopete::Message::Internal );
+	Kopete::Message msgAct ( &jack,   &myself, i18n( "performed an action" ), Kopete::Message::Inbound,
+				  Kopete::Message::PlainText, QString::null, Kopete::Message::TypeAction );
+	Kopete::Message msgHigh( &jack,   &myself, i18n( "This is a highlighted message" ), Kopete::Message::Inbound );
+	msgHigh.setImportance( Kopete::Message::Highlight );
+	Kopete::Message msgBye ( &myself, &jack,   i18n( "Bye" ), Kopete::Message::Outbound );
+
+	return QString::fromLatin1( "<document>" ) + msgIn.asXML().toString() + msgOut.asXML().toString()
+	       + msgCol.asXML().toString() + msgInt.asXML().toString() + msgAct.asXML().toString()
+	       + msgHigh.asXML().toString() + msgBye.asXML().toString() + QString::fromLatin1( "</document>" );
+}
+
 void AppearanceConfig::slotUpdatePreview()
 {
+	if(loading)
+		return;
+
 	QListBoxItem *style = mPrfsChatWindow->styleList->selectedItem();
-	if( style && itemMap[ style ] != currentStyle )
+	if( style && style->text() != currentStyle )
 	{
-		KopeteContact *myself = new TestContact( i18n( "Myself" ) );
-		KopeteContact *jack = new TestContact( i18n( "Jack" ) );
-
-		KopeteMessage msgIn(  jack,   myself, i18n( "Hello, this is an incoming message :-)" ), KopeteMessage::Inbound );
-		KopeteMessage msgOut( myself, jack,   i18n( "Ok, this is an outgoing message" ), KopeteMessage::Outbound );
-		KopeteMessage msgInt( jack,   myself, i18n( "This is an internal message" ), KopeteMessage::Internal );
-		KopeteMessage msgAct( jack,   myself, i18n( "performed an action" ), KopeteMessage::Action );
-		//KopeteMessage msgHigh( jack, myself, i18n( "This is a highlighted message" ), KopeteMessage::Inbound );
-
+		//FIXME: should be using a ChatMessagePart
 		preview->begin();
 		preview->write( QString::fromLatin1(
 			"<html><head><style>"
@@ -670,28 +685,12 @@ void AppearanceConfig::slotUpdatePreview()
 			.arg( mPrfsColors->bgColor->color().name() ).arg( mPrfsColors->linkColor->color().name() )
 			.arg( mPrfsColors->linkColor->color().name() ) );
 
-		// Parsing a XSLT message is incredibly slow! that's why I commented out some preview messages
-		QString stylePath = locate("appdata", QString::fromLatin1("styles/%1.xsl").arg(itemMap[ style ]) );
+		QString stylePath = itemMap[ style ];
 		d->xsltParser->setXSLT( fileContents(stylePath) );
-		preview->write( d->xsltParser->transform( msgIn.asXML().toString() ) );
-		preview->write( d->xsltParser->transform( msgOut.asXML().toString() ) );
-		msgIn.setFg( QColor( "DodgerBlue" ) );
-		msgIn.setBg( QColor( "LightSteelBlue" ) );
-		msgIn.setBody( i18n( "Here is an incoming colored message" ) );
-		preview->write( d->xsltParser->transform( msgIn.asXML().toString() ) );
-		preview->write( d->xsltParser->transform( msgInt.asXML().toString() ) );
-		preview->write( d->xsltParser->transform( msgAct.asXML().toString() ) );
-		//msgHigh.setImportance( KopeteMessage::Highlight );
-		//preview->write( d->xsltParser->transform( msgHigh.asXML().toString() ) ) ;
-		msgOut.setBody( i18n( "Bye" ) );
-		preview->write( d->xsltParser->transform( msgOut.asXML().toString() ) );
-
+		preview->write( d->xsltParser->transform( sampleConversationXML() ) );
 		preview->write( QString::fromLatin1( "</body></html>" ) );
 		preview->end();
 
-		delete myself;
-		delete jack;
-
 		emitChanged();
 	}
 }
@@ -748,11 +747,11 @@ void AppearanceConfig::removeSelectedTheme()
 			"This will delete the files installed by this theme.</qt>").
 		arg(themeName);
 
-	int res = KMessageBox::questionYesNo(this, question, i18n("Confirmation"));
-	if (res!=KMessageBox::Yes)
+        int res = KMessageBox::warningContinueCancel(this, question, i18n("Confirmation"),KStdGuiItem::del());
+	if (res!=KMessageBox::Continue)
 		return;
 
-	KURL themeUrl(KGlobal::dirs()->findResource("data", "kopete/pics/emoticons/"+themeName+"/"));
+	KURL themeUrl(KGlobal::dirs()->findResource("emoticons", themeName+"/"));
 	KIO::NetAccess::del(themeUrl, this);
 
 	updateEmoticonlist();
