@@ -27,7 +27,6 @@ class QCheckBox;
 class KListBox;
 class KTextEdit;
 class KHTMLPart;
-class KopeteContact;
 class StyleEditDialog;
 class QListBoxItem;
 
@@ -44,7 +43,6 @@ namespace KTextEditor
 	class Document;
 }
 
-typedef QPtrList<KopeteContact> KopeteContactPtrList;
 typedef QMap<QString,QString> KopeteChatStyleMap;
 
 /**
@@ -73,7 +71,7 @@ private slots:
 	void slotDeleteStyle();
 	void slotImportStyle();
 	void slotCopyStyle();
-	void slotStyleSaved();
+	void slotStyleModified(const QString &);
 	void slotStyleSelected();
 	void slotEditTooltips();
 	void emitChanged();
@@ -104,7 +102,7 @@ private:
 	QListBoxItem *editedItem;
 	QMap<QListBoxItem*,QString> itemMap;
 	QString currentStyle;
-	bool errorAlert;
+	bool loading;
 	bool styleChanged;
 
 	KopeteAppearanceConfigPrivate *d;
