@@ -1,7 +1,7 @@
 /*
     behaviorconfig.cpp  -  Kopete Look Feel Config
 
-    Kopete    (c) 2002-2003 by the Kopete developers  <kopete-devel@kde.org>
+    Kopete    (c) 2002-2005 by the Kopete developers  <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -19,10 +19,13 @@
 
 #include <qcheckbox.h>
 #include <qlayout.h>
+#include <qlabel.h>
 #include <qhbuttongroup.h>
 #include <qspinbox.h>
+#include <qcombobox.h>
 
 #include <kdebug.h>
+#include <kplugininfo.h>
 #include <klocale.h>
 #include <kpushbutton.h>
 #include <kgenericfactory.h>
@@ -32,6 +35,7 @@
 #include "kopeteprefs.h"
 #include "kopeteaway.h"
 #include "kopeteawayconfigbase.h"
+#include "kopetepluginmanager.h"
 
 #include <qtabwidget.h>
 
@@ -59,6 +63,8 @@ BehaviorConfig::BehaviorConfig(QWidget *parent, const char * /* name */, const Q
 	mPrfsChat = new BehaviorConfig_Chat(mBehaviorTabCtl);
 	mBehaviorTabCtl->addTab(mPrfsChat, i18n("&Chat"));
 
+	Kopete::PluginManager *pluginManager = Kopete::PluginManager::self();
+	viewPlugins = pluginManager->availablePlugins("Views");
 
 	load();
 
@@ -73,8 +79,13 @@ BehaviorConfig::BehaviorConfig(QWidget *parent, const char * /* name */, const Q
 	connect(mPrfsGeneral->mTrayflashNotifyChk, SIGNAL(toggled(bool)),
 		this, SLOT(slotSettingsChanged(bool)));
 	connect(mPrfsGeneral->mSoundIfAwayChk, SIGNAL(toggled(bool)),
+			this, SLOT(slotSettingsChanged(bool)));
+	connect(mPrfsGeneral->mEventIfActive, SIGNAL(toggled(bool)),
+			this, SLOT(slotSettingsChanged(bool)));
+	connect(mPrfsGeneral->mAutoConnect, SIGNAL(toggled(bool)),
 		this, SLOT(slotSettingsChanged(bool)));
 
+
 	// "Chat" TAB ===============================================================
 	connect( mPrfsChat->cb_RaiseMsgWindowChk, SIGNAL(toggled(bool)),
 		this, SLOT(slotSettingsChanged(bool)));
@@ -88,6 +99,14 @@ BehaviorConfig::BehaviorConfig(QWidget *parent, const char * /* name */, const Q
 		this, SLOT(slotValueChanged(int)));
 	connect( mPrfsChat->mChatViewBufferSize, SIGNAL(valueChanged(int)),
 		this, SLOT(slotValueChanged(int)));
+	connect( mPrfsChat->truncateContactNameEnabled, SIGNAL(toggled(bool)),
+		this, SLOT(slotSettingsChanged(bool)));
+	connect( mPrfsChat->mMaxContactNameLength, SIGNAL(valueChanged(int)),
+		this, SLOT(slotValueChanged(int)));
+	connect( mPrfsChat->viewPlugin, SIGNAL(activated(int)),
+		 this, SLOT(slotValueChanged(int)));
+	connect( mPrfsChat->viewPlugin, SIGNAL(activated(int)),
+		 this, SLOT(slotUpdatePluginLabel(int)));
 
 	// "Away" TAB ===============================================================
 	connect( mAwayConfigUI->mAutoAwayTimeout, SIGNAL(valueChanged(int)),
@@ -103,6 +122,7 @@ void BehaviorConfig::save()
 //	kdDebug(14000) << k_funcinfo << "called." << endl;
 
 	KopetePrefs *p = KopetePrefs::prefs();
+	KConfig *config = KGlobal::config();
 
 	// "General" TAB ============================================================
 	p->setShowTray(mPrfsGeneral->mShowTrayChk->isChecked());
@@ -111,11 +131,13 @@ void BehaviorConfig::save()
 	p->setTrayflashNotify(mPrfsGeneral->mTrayflashNotifyChk->isChecked());
 	p->setBalloonNotify(mPrfsGeneral->mBalloonNotifyChk->isChecked());
 	p->setSoundIfAway(mPrfsGeneral->mSoundIfAwayChk->isChecked());
+	p->setAutoConnect(mPrfsGeneral->mAutoConnect->isChecked());
+	config->setGroup("General");
+	config->writeEntry("EventIfActive", mPrfsGeneral->mEventIfActive->isChecked());
 
 	// "Away" TAB ===============================================================
 	p->setRememberedMessages( mAwayConfigUI->rememberedMessages->value() );
 
-	KConfig *config = KGlobal::config();
 	config->setGroup("AutoAway");
 	config->writeEntry("Timeout", mAwayConfigUI->mAutoAwayTimeout->value() * 60);
 	config->writeEntry("GoAvailable", mAwayConfigUI->mGoAvailable->isChecked());
@@ -127,10 +149,14 @@ void BehaviorConfig::save()
 	p->setShowEvents(mPrfsChat->cb_ShowEventsChk->isChecked());
 	p->setHighlightEnabled(mPrfsChat->highlightEnabled->isChecked());
 	p->setChatWindowPolicy(mPrfsChat->chatWindowGroup->id(
-			mPrfsChat->chatWindowGroup->selected()));
-	p->setInterfacePreference(static_cast<KopetePrefs::ChatWindowPref>
-		(mPrfsChat->interfaceGroup->id(mPrfsChat->interfaceGroup->selected())) );
+		mPrfsChat->chatWindowGroup->selected())
+	);
+
+	p->setInterfacePreference( viewPlugins[mPrfsChat->viewPlugin->currentItem()]->pluginName() );
+
 	p->setChatViewBufferSize(mPrfsChat->mChatViewBufferSize->value());
+	p->setTruncateContactNames(mPrfsChat->truncateContactNameEnabled->isChecked());
+	p->setMaxContactNameLength(mPrfsChat->mMaxContactNameLength->value());
 
 	p->save();
 	emit changed(false);
@@ -140,7 +166,7 @@ void BehaviorConfig::load()
 {
 //	kdDebug(14000) << k_funcinfo << "called" << endl;
 	KopetePrefs *p = KopetePrefs::prefs();
-
+	KConfig *config = KGlobal::config();
 
 	// "General" TAB ============================================================
 	mPrfsGeneral->mShowTrayChk->setChecked( p->showTray() );
@@ -149,10 +175,12 @@ void BehaviorConfig::load()
 	mPrfsGeneral->mTrayflashNotifyChk->setChecked ( p->trayflashNotify() );
 	mPrfsGeneral->mBalloonNotifyChk->setChecked ( p->balloonNotify() );
 	mPrfsGeneral->mSoundIfAwayChk->setChecked( p->soundIfAway() );
+	mPrfsGeneral->mAutoConnect->setChecked( p->autoConnect() );
 	slotShowTrayChanged( mPrfsGeneral->mShowTrayChk->isChecked() );
+	config->setGroup("General");
+	mPrfsGeneral->mEventIfActive->setChecked(config->readBoolEntry("EventIfActive", true));
 
 	// "Away" TAB ===============================================================
-	KConfig *config = KGlobal::config();
 	config->setGroup("AutoAway");
 	mAwayConfigUI->mAutoAwayTimeout->setValue(config->readNumEntry("Timeout", 600)/60);
 	mAwayConfigUI->mGoAvailable->setChecked(config->readBoolEntry("GoAvailable", true));
@@ -164,12 +192,27 @@ void BehaviorConfig::load()
 	mPrfsChat->cb_ShowEventsChk->setChecked(p->showEvents());
 	mPrfsChat->highlightEnabled->setChecked(p->highlightEnabled());
 	mPrfsChat->chatWindowGroup->setButton(p->chatWindowPolicy());
-	mPrfsChat->interfaceGroup->setButton(p->interfacePreference());
 	mPrfsChat->mChatViewBufferSize->setValue(p->chatViewBufferSize());
+	mPrfsChat->truncateContactNameEnabled->setChecked(p->truncateContactNames());
+	mPrfsChat->mMaxContactNameLength->setValue(p->maxConactNameLength());
 
-	//TODO: make the whole thing working correctly insteads of this ugly hack...
-	// emit changed(false);
-	// emit changed(true);
+
+	mPrfsChat->viewPlugin->clear();
+	int selectedIdx = 0, i = 0;
+	for(  QValueList<KPluginInfo*>::iterator it = viewPlugins.begin(); it != viewPlugins.end(); ++it )
+	{
+		if( (*it)->pluginName() == p->interfacePreference() )
+			selectedIdx = i;
+		mPrfsChat->viewPlugin->insertItem( (*it)->name(), i++ );
+	}
+
+	mPrfsChat->viewPlugin->setCurrentItem(selectedIdx);
+	slotUpdatePluginLabel(selectedIdx);
+}
+
+void BehaviorConfig::slotUpdatePluginLabel(int)
+{
+	mPrfsChat->viewPluginLabel->setText( viewPlugins[ mPrfsChat->viewPlugin->currentItem() ]->comment() );
 }
 
 void BehaviorConfig::slotShowTrayChanged(bool check)
