@@ -21,6 +21,7 @@
 #include <klocale.h>
 #include <kiconloader.h>
 #include <kdebug.h>
+#include <kapplication.h>
 
 #include "kopetecontactlistview.h"
 #include "kopetegroupviewitem.h"
@@ -66,14 +67,14 @@ private:
 } // END namespace UI
 } // END namespace Kopete
 
-KopeteGroupViewItem::KopeteGroupViewItem( KopeteGroup *group_, QListView *parent, const char *name )
+KopeteGroupViewItem::KopeteGroupViewItem( Kopete::Group *group_, QListView *parent, const char *name )
 : Kopete::UI::ListView::Item( parent, group_, name )
 {
 	m_group = group_;
 	initLVI();
 }
 
-KopeteGroupViewItem::KopeteGroupViewItem( KopeteGroup *group_, QListViewItem *parent, const char *name )
+KopeteGroupViewItem::KopeteGroupViewItem( Kopete::Group *group_, QListViewItem *parent, const char *name )
  : Kopete::UI::ListView::Item( parent, group_, name )
 {
 	m_group = group_;
@@ -101,11 +102,12 @@ void KopeteGroupViewItem::initLVI()
 	d->name->setToolTipSource( d->toolTipSource.get() );
 	d->count->setToolTipSource( d->toolTipSource.get() );
 
-	connect( m_group, SIGNAL( renamed( KopeteGroup*, const QString& ) ),
+	connect( m_group, SIGNAL( displayNameChanged( Kopete::Group*, const QString& ) ),
 		this, SLOT( refreshDisplayName() ) );
 
 	connect( KopetePrefs::prefs(), SIGNAL( contactListAppearanceChanged() ),
 		SLOT( slotConfigChanged() ) );
+	connect( kapp, SIGNAL( appearanceChanged() ),  SLOT( slotConfigChanged() ) );
 
 	connect( m_group, SIGNAL( iconAppearanceChanged() ), SLOT( updateIcon() ) );
 
@@ -113,7 +115,7 @@ void KopeteGroupViewItem::initLVI()
 	slotConfigChanged();
 }
 
-KopeteGroup* KopeteGroupViewItem::group() const
+Kopete::Group* KopeteGroupViewItem::group() const
 {
 	return m_group;
 }
@@ -176,12 +178,12 @@ QString KopeteGroupViewItem::key( int, bool ) const
 {
 	//Groups are placed after topLevel contact.
 	//Exepted Temporary group which is the first group
-	if ( group()->type() != KopeteGroup::Normal )
+	if ( group()->type() != Kopete::Group::Normal )
 		return "0" + d->name->text();
 	return "M" + d->name->text();
 }
 
-void KopeteGroupViewItem::startRename( int col )
+void KopeteGroupViewItem::startRename( int /*col*/ )
 {
 	//kdDebug(14000) << k_funcinfo << endl;
 	KListViewItem::startRename( 0 );
@@ -234,8 +236,8 @@ void KopeteGroupViewItem::updateIcon()
 	// TODO: clever caching
 	if ( isOpen() )
 	{
-		if ( group()->useCustomIcon() && !group()->icon( KopetePluginDataObject::Open ).isEmpty() )
-			open = SmallIcon( group()->icon( KopetePluginDataObject::Open ) );
+		if ( group()->useCustomIcon() && !group()->icon( Kopete::ContactListElement::Open ).isEmpty() )
+			open = SmallIcon( group()->icon( Kopete::ContactListElement::Open ) );
 		else
 			open = SmallIcon( KOPETE_GROUP_DEFAULT_OPEN_ICON );
 
@@ -243,8 +245,8 @@ void KopeteGroupViewItem::updateIcon()
 	}
 	else
 	{
-		if ( group()->useCustomIcon() && !group()->icon( KopetePluginDataObject::Closed ).isEmpty() )
-			closed = SmallIcon( group()->icon( KopetePluginDataObject::Closed ) );
+		if ( group()->useCustomIcon() && !group()->icon( Kopete::ContactListElement::Closed ).isEmpty() )
+			closed = SmallIcon( group()->icon( Kopete::ContactListElement::Closed ) );
 		else
 			closed = SmallIcon( KOPETE_GROUP_DEFAULT_CLOSED_ICON );
 
@@ -263,7 +265,16 @@ QString KopeteGroupViewItem::text( int column ) const
 void KopeteGroupViewItem::setText( int column, const QString &text )
 {
 	if ( column == 0 )
+	{
+		KopeteContactListView *lv = dynamic_cast<KopeteContactListView *>( listView() );
+		if ( lv )
+		{
+			KopeteContactListView::UndoItem *u=new KopeteContactListView::UndoItem(KopeteContactListView::UndoItem::GroupRename, 0L, m_group);
+			u->args << m_group->displayName();
+			lv->insertUndoItem(u);
+		}
 		group()->setDisplayName( text );
+	}
 	else
 		KListViewItem::setText( column, text );
 }
