@@ -3,9 +3,11 @@
 
     Kopete Contactlist Properties GUI for Groups and MetaContacts
 
-    Copyright (c) 2002-2003 by Stefan Gehn            <metz AT gehn.net>
-	Copyright (c) 2004      by Will Stephenson <lists@stevello.free-online.co.uk>
-    Kopete    (c) 2002-2003 by the Kopete developers  <kopete-devel@kde.org>
+    Copyright (c) 2002-2003 by Stefan Gehn <metz AT gehn.net>
+    Copyright (c) 2004 by Will Stephenson <lists@stevello.free-online.co.uk>
+    Copyright (c) 2004 by Duncan Mac-Vicar P. <duncan@kde.org>
+    
+    Kopete    (c) 2002-2005 by the Kopete developers  <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -27,10 +29,12 @@
 #include <qlayout.h>
 #include <qpushbutton.h>
 #include <qtabwidget.h>
+#include <qcombobox.h>
 
 #include <kdialogbase.h>
 #include <kfiledialog.h>
 #include <kicondialog.h>
+#include <kmessagebox.h>
 #include <kurlrequester.h>
 #include <kabc/addresseedialog.h>
 #include <kabc/stdaddressbook.h>
@@ -38,12 +42,17 @@
 #include <kstandarddirs.h>
 #include <kurlrequester.h>
 
+#include "kabcpersistence.h"
 #include "kopeteaddrbookexport.h"
+#include "kopetecontact.h"
 #include "kopetegroup.h"
 #include "kopetegroupviewitem.h"
 #include "kopetemetacontact.h"
 #include "kopetenotifyclient.h"
 #include "kopetemetacontactlvi.h"
+#include "kopeteaccount.h"
+#include "kopeteprotocol.h"
+#include "linkaddressbookui.h"
 
 #include "customnotificationprops.h"
 #include "customnotifications.h"
@@ -71,14 +80,14 @@ KopeteGVIProps::KopeteGVIProps(KopeteGroupViewItem *gvi, QWidget *parent, const
 	mainWidget->edtDisplayName->setText( item->group()->displayName() );
 	mainWidget->chkUseCustomIcons->setChecked( item->group()->useCustomIcon() );
 
-	QString openName = item->group()->icon( KopetePluginDataObject::Open );
+	QString openName = item->group()->icon( Kopete::ContactListElement::Open );
 	if(openName.isEmpty())
 		openName = KOPETE_GROUP_DEFAULT_OPEN_ICON;
-	QString closeName = item->group()->icon( KopetePluginDataObject::Closed );
+	QString closeName = item->group()->icon( Kopete::ContactListElement::Closed );
 	if(closeName.isEmpty())
 		closeName = KOPETE_GROUP_DEFAULT_CLOSED_ICON;
 	mainWidget->icnbOpen->setIcon( openName );
-    mainWidget->icnbClosed->setIcon( closeName );
+	mainWidget->icnbClosed->setIcon( closeName );
 
 	connect( this, SIGNAL(okClicked()), this, SLOT( slotOkClicked() ) );
 	connect( mainWidget->chkUseCustomIcons, SIGNAL( toggled( bool ) ),
@@ -108,10 +117,10 @@ void KopeteGVIProps::slotOkClicked()
 	if( m_dirty )
 	{
 		item->group()->setIcon( mainWidget->icnbOpen->icon(),
-			 KopetePluginDataObject::Open );
+			 Kopete::ContactListElement::Open );
 
 		item->group()->setIcon( mainWidget->icnbClosed->icon(),
-			KopetePluginDataObject::Closed );
+			Kopete::ContactListElement::Closed );
 	}
 	
 	mNotificationProps->storeCurrentCustoms();
@@ -136,6 +145,7 @@ void KopeteGVIProps::slotIconChanged()
 KopeteMetaLVIProps::KopeteMetaLVIProps(KopeteMetaContactLVI *lvi, QWidget *parent, const char *name)
 : KDialogBase(parent, name, true, i18n("Properties of Meta Contact %1").arg(lvi->metaContact()->displayName()), Ok|Cancel, Ok, false)
 {
+	m_countPhotoCapable = 0;
 	mainWidget = new KopeteMetaLVIPropsWidget( this, "mainWidget" );
 	mainWidget->icnbOffline->setIconSize( KIcon::SizeSmall );
 	mainWidget->icnbOnline->setIconSize( KIcon::SizeSmall );
@@ -158,24 +168,78 @@ KopeteMetaLVIProps::KopeteMetaLVIProps(KopeteMetaContactLVI *lvi, QWidget *paren
 	item = lvi;
 
 	mainWidget->edtDisplayName->setText( item->metaContact()->displayName() );
-	mainWidget->chkTrackChildDisplayName->setChecked( item->metaContact()->trackChildNameChanges() );
-	mainWidget->chkTrackChildDisplayName->setEnabled( item->metaContact()->contacts().count() == 1 );
+	mainWidget->chkTrackChildDisplayName->setChecked( item->metaContact()->nameSource() != 0 );
+	mainWidget->chkTrackChildPhoto->setChecked( item->metaContact()->photoSource() != 0 );
+	mainWidget->chkTrackChildDisplayName->setEnabled( item->metaContact()->contacts().count() > 0 );
+	mainWidget->chkTrackChildPhoto->setEnabled( item->metaContact()->contacts().count() > 0 );
+	mainWidget->chkSyncPhoto->setEnabled( mainWidget->chkTrackChildPhoto->isEnabled() );
+	mainWidget->chkSyncPhoto->setChecked( item->metaContact()->isPhotoSyncedWithKABC() );
+	mainWidget->cmbAccount->setEnabled( mainWidget->chkTrackChildDisplayName->isChecked() );
+	
+	slotSetNameComboEnabled(mainWidget->chkTrackChildDisplayName->isChecked());
+	slotSetPhotoComboEnabled(mainWidget->chkTrackChildPhoto->isChecked());
+	
+	Kopete::Contact* trackingName = item->metaContact()->nameSource();
+	QPtrList< Kopete::Contact > cList = item->metaContact()->contacts();
+	QPtrListIterator<Kopete::Contact> it( cList );
+	for( ; it.current(); ++it )
+	{
+		QString acct = it.current()->property( Kopete::Global::Properties::self()->nickName() ).value().toString() + " <" + it.current()->contactId() + ">";
+		QPixmap acctIcon = it.current()->account()->accountIcon();
+		mainWidget->cmbAccount->insertItem( acctIcon, acct );
+		
+		// Select this item if it's the one we're tracking.
+		if( it.current() == trackingName )
+		{
+			mainWidget->cmbAccount->setCurrentItem( mainWidget->cmbAccount->count() - 1 );
+		}
+	}
 
+	m_withPhotoContacts.clear();
+	Kopete::Contact* trackingPhoto = item->metaContact()->photoSource();
+	QPtrListIterator<Kopete::Contact> itp( cList );
+	for( ; itp.current(); ++itp )
+	{
+		Kopete::Contact *citem = itp.current();
+		if ( citem->hasProperty( Kopete::Global::Properties::self()->photo().key() ) )
+		{
+			m_countPhotoCapable++;
+			QString acct = citem->property( Kopete::Global::Properties::self()->nickName() ).value().toString() + " <" + citem->contactId() + ">";
+			QPixmap acctIcon = citem->account()->accountIcon();
+			mainWidget->cmbAccountPhoto->insertItem( acctIcon, acct );
+			
+			// Select this item if it's the one we're tracking.
+			if( citem == trackingPhoto )
+			{
+				mainWidget->cmbAccountPhoto->setCurrentItem( mainWidget->cmbAccountPhoto->count() - 1 );
+			}
+			m_withPhotoContacts.insert(mainWidget->cmbAccountPhoto->count() - 1  , citem );
+		}
+	}
+
+	if ( ! m_countPhotoCapable )
+	{
+		slotSetPhotoComboEnabled(false);
+		mainWidget->chkTrackChildPhoto->setEnabled(false);
+		mainWidget->chkSyncPhoto->setEnabled(false);
+		mainWidget->cmbAccountPhoto->insertItem(i18n("No contacts with photo support"));
+	}
+	
 	mainWidget->chkUseCustomIcons->setChecked( item->metaContact()->useCustomIcon() );
 
-	QString offlineName = item->metaContact()->icon( KopetePluginDataObject::Offline );
+	QString offlineName = item->metaContact()->icon( Kopete::ContactListElement::Offline );
 	if(offlineName.isEmpty())
 		offlineName = QString::fromLatin1(MC_OFF); // Default
 
-	QString onlineName = item->metaContact()->icon( KopetePluginDataObject::Online );
+	QString onlineName = item->metaContact()->icon( Kopete::ContactListElement::Online );
 	if(onlineName.isEmpty())
 		onlineName = QString::fromLatin1(MC_ON); // Default
 
-	QString awayName = item->metaContact()->icon( KopetePluginDataObject::Away );
+	QString awayName = item->metaContact()->icon( Kopete::ContactListElement::Away );
 	if(awayName.isEmpty())
 		awayName = QString::fromLatin1(MC_AW); // Default
 
-	QString unknownName = item->metaContact()->icon( KopetePluginDataObject::Unknown );
+	QString unknownName = item->metaContact()->icon( Kopete::ContactListElement::Unknown );
 	if(unknownName.isEmpty())
 		unknownName = QString::fromLatin1(MC_UNK); // Default
 
@@ -188,22 +252,25 @@ KopeteMetaLVIProps::KopeteMetaLVIProps(KopeteMetaContactLVI *lvi, QWidget *paren
 
 	mExport = 0L;
 
-	
 	if ( !kabcUid.isEmpty() )
 	{
-		KABC::AddressBook *ab = KABC::StdAddressBook::self();
-		KABC::StdAddressBook::setAutomaticSave( false );
+		KABC::AddressBook *ab = Kopete::KABCPersistence::self()->addressBook();
 		KABC::Addressee a = ab->findByUid( kabcUid );
-		mainWidget->edtAddressee->setText( a.realName() );
-		mainWidget->btnSelectAddressee->setEnabled( true );
-		mainWidget->btnMerge->setEnabled( true );
-		mainWidget->edtAddressee->setEnabled( true );
-		mainWidget->lblAddressee->setEnabled( true );
-		mainWidget->chkHasAddressbookEntry->setChecked( true );
-		mExport = new KopeteAddressBookExport( this, item->metaContact() );
-		
-		mSound = a.sound();
-		mFromKABC->setEnabled( !( mSound.isIntern() || mSound.url().isEmpty() ) );
+
+		if(!a.isEmpty())
+		{
+			mainWidget->edtAddressee->setText( a.realName() );
+			mainWidget->btnSelectAddressee->setEnabled( true );
+			mainWidget->btnImportKABC->setEnabled( true );
+			mainWidget->btnExportKABC->setEnabled( true );
+			mainWidget->edtAddressee->setEnabled( true );
+			mainWidget->lblAddressee->setEnabled( true );
+			mainWidget->chkHasAddressbookEntry->setChecked( true );
+			mExport = new KopeteAddressBookExport( this, item->metaContact() );
+			
+			mSound = a.sound();
+			mFromKABC->setEnabled( !( mSound.isIntern() || mSound.url().isEmpty() ) );
+		}
 	}
 	
 	connect( this, SIGNAL(okClicked()), this, SLOT( slotOkClicked() ) );
@@ -213,12 +280,17 @@ KopeteMetaLVIProps::KopeteMetaLVIProps(KopeteMetaContactLVI *lvi, QWidget *paren
 		this, SLOT( slotHasAddressbookEntryToggled( bool ) ) );
 	connect( mainWidget->btnSelectAddressee, SIGNAL( clicked() ),
 		this, SLOT( slotSelectAddresseeClicked() ) );
-	connect( mainWidget->btnMerge, SIGNAL( clicked() ),
-		this, SLOT( slotMergeClicked() ) );
+	connect( mainWidget->btnImportKABC, SIGNAL( clicked() ),
+		this, SLOT( slotImportClicked() ) );
+	connect( mainWidget->btnExportKABC, SIGNAL( clicked() ),
+					 this, SLOT( slotExportClicked() ) );
 	connect( mFromKABC, SIGNAL( clicked() ),
 		this, SLOT( slotFromKABCClicked() ) );
-    connect( mNotificationProps->widget()->customSound, SIGNAL( openFileDialog( KURLRequester * )),
+	connect( mNotificationProps->widget()->customSound, SIGNAL( openFileDialog( KURLRequester * )),
              SLOT( slotOpenSoundDialog( KURLRequester * )));
+
+	connect( mainWidget->chkTrackChildPhoto, SIGNAL(toggled(bool)), SLOT(slotSetPhotoComboEnabled(bool)));
+	connect( mainWidget->chkTrackChildDisplayName, SIGNAL(toggled(bool)), SLOT(slotSetNameComboEnabled(bool)));
 	slotUseCustomIconsToggled( mainWidget->chkUseCustomIcons->isChecked() );
 }
 
@@ -226,14 +298,45 @@ KopeteMetaLVIProps::~KopeteMetaLVIProps()
 {
 }
 
+void KopeteMetaLVIProps::slotSetPhotoComboEnabled( bool on )
+{
+	mainWidget->cmbAccountPhoto->setEnabled(on);
+	mainWidget->chkSyncPhoto->setEnabled(on);
+	mainWidget->lblPhotoAccount->setEnabled(on);
+}
+
+void KopeteMetaLVIProps::slotSetNameComboEnabled( bool on )
+{
+	mainWidget->cmbAccount->setEnabled(on);
+	mainWidget->lblAccountName->setEnabled(on);
+}
+
 void KopeteMetaLVIProps::slotOkClicked()
 {
 	if( mainWidget->edtDisplayName->text() != item->metaContact()->displayName() )
 	{
 		item->metaContact()->setDisplayName( mainWidget->edtDisplayName->text() );
 	}
-	item->metaContact()->setTrackChildNameChanges( mainWidget->chkTrackChildDisplayName->isChecked() );
-
+	
+	// set name source
+	if ( mainWidget->chkTrackChildDisplayName->isChecked() )
+		item->metaContact()->setNameSource( item->metaContact()->contacts().at( mainWidget->cmbAccount->currentItem() ) );
+	else
+		item->metaContact()->setNameSource( 0L );
+	
+	// set photo source
+	if ( mainWidget->chkTrackChildPhoto->isChecked() )
+	{
+		item->metaContact()->setPhotoSource( m_withPhotoContacts[ mainWidget->cmbAccountPhoto->currentItem() ] );
+		item->metaContact()->setPhotoSyncedWithKABC( mainWidget->chkSyncPhoto->isChecked() );
+	}
+	else
+	{
+		item->metaContact()->setPhotoSource( 0L );
+		item->metaContact()->setPhotoSyncedWithKABC(false);
+	}
+	
+	
 	item->metaContact()->setUseCustomIcon(
 		mainWidget->chkUseCustomIcons->isChecked() );
 
@@ -245,16 +348,16 @@ void KopeteMetaLVIProps::slotOkClicked()
 		mainWidget->icnbUnknown->icon() != MC_UNK )
 	{
 		item->metaContact()->setIcon( mainWidget->icnbOffline->icon(),
-			 KopetePluginDataObject::Offline );
+			 Kopete::ContactListElement::Offline );
 
 		item->metaContact()->setIcon( mainWidget->icnbOnline->icon(),
-			KopetePluginDataObject::Online );
+			Kopete::ContactListElement::Online );
 
 		item->metaContact()->setIcon( mainWidget->icnbAway->icon(),
-			KopetePluginDataObject::Away );
+			Kopete::ContactListElement::Away );
 
 		item->metaContact()->setIcon( mainWidget->icnbUnknown->icon(),
-			KopetePluginDataObject::Unknown );
+			Kopete::ContactListElement::Unknown );
 	}
 	// if no kabc link, remove any existing link
 	if ( !mainWidget->chkHasAddressbookEntry->isChecked() )
@@ -282,38 +385,54 @@ void KopeteMetaLVIProps::slotHasAddressbookEntryToggled( bool on )
 	mainWidget->edtAddressee->setEnabled( on );
 	mainWidget->btnSelectAddressee->setEnabled( on );
 	if ( !on )
-		mainWidget->btnMerge->setEnabled( false );
+		mainWidget->btnImportKABC->setEnabled( false );
+		mainWidget->btnExportKABC->setEnabled( false );
 }
 
 void KopeteMetaLVIProps::slotSelectAddresseeClicked()
 {
-	 KABC::Addressee a = KABC::AddresseeDialog::getAddressee(this);
-	 if ( a.isEmpty() )
-	 {
-	 	mainWidget->edtAddressee->setText( QString::null ) ;
-		mainWidget->btnMerge->setEnabled( false );
+	LinkAddressbookUI dialog( item->metaContact(), this, "link_addr_book_dialog" );
+	if ( dialog.exec() == QDialog::Rejected )
+		return;
+	
+	KABC::Addressee a = dialog.addressee();
+	if ( a.isEmpty() )
+	{
+		mainWidget->edtAddressee->setText( QString::null ) ;
+		mainWidget->btnExportKABC->setEnabled( false );
+		mainWidget->btnImportKABC->setEnabled( false );
 		mFromKABC->setEnabled( false );
-	 }
-	 else
-	 {
+	}
+	else
+	{
 		mSound = a.sound();
 		mFromKABC->setEnabled( !( mSound.isIntern() || mSound.url().isEmpty() ) );
-	 	mainWidget->btnMerge->setEnabled( true );
+		mainWidget->btnExportKABC->setEnabled( true );
+		mainWidget->btnImportKABC->setEnabled( true );
 		// set the lineedit to the Addressee's name
 		mainWidget->edtAddressee->setText( a.realName() );
 		// set/update the MC's addressee uin field
 		item->metaContact()->setMetaContactId( a.uid() );
 		delete mExport;
 		mExport = new KopeteAddressBookExport( this, item->metaContact() );
-	 }
+	}
 }
 
-void KopeteMetaLVIProps::slotMergeClicked()
+void KopeteMetaLVIProps::slotExportClicked()
 {
 	if ( mExport->showDialog() == QDialog::Accepted )
 		mExport->exportData();
 }
 
+void KopeteMetaLVIProps::slotImportClicked()
+{
+	if ( Kopete::KABCPersistence::self()->syncWithKABC( item->metaContact() ) )
+		KMessageBox::queuedMessageBox( this, KMessageBox::Information,
+																	 i18n( "No contacts were imported from the address book." ),
+																	 i18n( "No Change" ) );
+}
+
+
 void KopeteMetaLVIProps::slotFromKABCClicked()
 {
 	 mNotificationProps->widget()->customSound->setURL( mSound.url() );
