@@ -18,14 +18,16 @@
     *************************************************************************
 */
 
-#include <qapplication.h>
 #include <qpainter.h>
 #include <qtimer.h>
 #include <qvariant.h>
+#include <qmime.h>
+#include <qstylesheet.h>
 
 #include "kopetenotifyclient.h"
 #include <kdebug.h>
 #include <kiconeffect.h>
+#include <kimageeffect.h>
 #include <kiconloader.h>
 #include <klocale.h>
 #include <kmessagebox.h>
@@ -33,6 +35,10 @@
 #include <kpopupmenu.h>
 #include <kglobal.h>
 #include <kconfig.h>
+#include <kapplication.h>
+
+#include <kabc/addressbook.h>
+#include <kabc/addressee.h>
 
 #include <kdeversion.h>
 #include <kinputdialog.h>
@@ -53,6 +59,8 @@
 #include "kopetestdaction.h"
 #include "systemtray.h"
 #include "kopeteglobal.h"
+#include "kopetecontact.h"
+#include "kabcpersistence.h"
 
 #include <memory>
 
@@ -65,20 +73,43 @@ namespace ListView {
 class MetaContactToolTipSource : public ToolTipSource
 {
 public:
-	MetaContactToolTipSource( KopeteMetaContact *mc )
+	MetaContactToolTipSource( MetaContact *mc )
 	 : metaContact( mc )
 	{
 	}
 	QString operator()( ComponentBase *, const QPoint &, QRect & )
 	{
-		QPtrList<KopeteContact> contacts = metaContact->contacts();
-		if( contacts.count() == 1 )
-			return contacts.first()->toolTip();
 
-		// We are over a metacontact with > 1 child contacts, and not over a specific contact
-		// Iterate through children and display a summary tooltip
-		QString toolTip = QString::fromLatin1("<qt><table>");
-		for(KopeteContact *c = contacts.first(); c; c = contacts.next())
+		// We begin with the meta contact display name at the top of the tooltip
+		QString toolTip = QString::fromLatin1("<qt><table cellpadding=\"0\" cellspacing=\"1\">");
+		
+        toolTip += QString::fromLatin1("<tr><td>");
+
+		if ( ! metaContact->photo().isNull() )
+        {
+			QString photoName = QString::fromLatin1("kopete-metacontact-photo:%1").arg( KURL::encode_string( metaContact->metaContactId() ));
+			//QMimeSourceFactory::defaultFactory()->setImage( "contactimg", metaContact->photo() );
+			toolTip += QString::fromLatin1("<img src=\"%1\">").arg( photoName );
+        }
+        else
+        {
+			kdDebug( 14010 ) << k_funcinfo << "null picture" << endl; 
+        }
+		
+		toolTip += QString::fromLatin1("</td><td>");
+		toolTip += QString::fromLatin1("<b><font size=\"+1\">%1</font></b><br><br>").arg(metaContact->displayName());
+		
+		QPtrList<Contact> contacts = metaContact->contacts();		
+		if ( contacts.count() == 1 )
+		{
+			return toolTip + contacts.first()->toolTip() + QString::fromLatin1("</td></tr></table></qt>");
+		}
+
+		toolTip += QString::fromLatin1("<table>");
+
+        // We are over a metacontact with > 1 child contacts, and not over a specific contact
+        // Iterate through children and display a summary tooltip
+        for(Contact *c = contacts.first(); c; c = contacts.next())
 		{
 			QString iconName = QString::fromLatin1("kopete-contact-icon:%1:%2:%3")
 			.arg( KURL::encode_string( c->protocol()->pluginId() ),
@@ -87,14 +118,14 @@ public:
 				);
 
 			toolTip += i18n("<tr><td>STATUS ICON <b>PROTOCOL NAME</b> (ACCOUNT NAME)</td><td>STATUS DESCRIPTION</td></tr>",
-								"<tr><td><img src=\"%1\">&nbsp;<b>%2</b>&nbsp;(%3)</td><td align=\"right\">%4</td></tr>")
+							"<tr><td><img src=\"%1\">&nbsp;<nobr><b>%2</b></nobr>&nbsp;<nobr>(%3)</nobr></td><td align=\"right\"><nobr>%4</nobr></td></tr>")
 						.arg( iconName, c->property(Kopete::Global::Properties::self()->nickName()).value().toString() , c->contactId(), c->onlineStatus().description() );
 		}
 
-		return toolTip + QString::fromLatin1("</table></qt>");
+		return toolTip + QString::fromLatin1("</table></td></tr></table></qt>");
 	}
 private:
-	KopeteMetaContact *metaContact;
+	MetaContact *metaContact;
 };
 
 } // END namespace ListView
@@ -104,36 +135,42 @@ private:
 class KopeteMetaContactLVI::Private
 {
 public:
-	Private() : metaContactIcon( 0 ), nameText( 0 ), extraText( 0 ), contactIconBox( 0 ),
-	            buddyIcon( 0 ), currentMode( -1 ) {}
+	Private() : metaContactIcon( 0L ), nameText( 0L ), extraText( 0L ), contactIconBox( 0L ),
+	            metaContactPhoto( 0L ), currentMode( -1 ) {}
+	ListView::ImageComponent *metaContactPhoto;
 	ListView::ImageComponent *metaContactIcon;
 	ListView::TextComponent *nameText;
 	ListView::TextComponent *extraText;
 	ListView::BoxComponent *contactIconBox;
 	ListView::BoxComponent *spacerBox;
-	ListView::ImageComponent *buddyIcon;
 	std::auto_ptr<ListView::ToolTipSource> toolTipSource;
+	// metacontact icon size
 	int iconSize;
+	// protocol icon size
+	int contactIconSize;
+	// metacontact photo size
+	int photoSize;
 	int currentMode;
 
-	QPtrList<KopeteEvent> events;
+	QPtrList<Kopete::MessageEvent> events;
 };
 
 class ContactComponent : public ListView::ImageComponent
 {
-	KopeteContact *mContact;
+	Kopete::Contact *mContact;
+	int mIconSize;
 public:
-	ContactComponent( ListView::ComponentBase *parent, KopeteContact *contact )
+	ContactComponent( ListView::ComponentBase *parent, Kopete::Contact *contact, int iconSize)
 	 : ListView::ImageComponent( parent )
-	 , mContact( contact )
+	 , mContact( contact ), mIconSize( iconSize )
 	{
 		updatePixmap();
 	}
 	void updatePixmap()
 	{
-		setPixmap( contact()->onlineStatus().iconFor( contact(), 12 ) );
+		setPixmap( contact()->onlineStatus().iconFor( contact(), mIconSize ) );
 	}
-	KopeteContact *contact()
+	Kopete::Contact *contact()
 	{
 		return mContact;
 	}
@@ -156,7 +193,7 @@ public:
 	}
 };
 
-KopeteMetaContactLVI::KopeteMetaContactLVI( KopeteMetaContact *contact, KopeteGroupViewItem *parent )
+KopeteMetaContactLVI::KopeteMetaContactLVI( Kopete::MetaContact *contact, KopeteGroupViewItem *parent )
 : ListView::Item( parent, contact, "MetaContactLVI" )
 //: QObject( contact, "MetaContactLVI" ), KListViewItem( parent )
 {
@@ -169,7 +206,7 @@ KopeteMetaContactLVI::KopeteMetaContactLVI( KopeteMetaContact *contact, KopeteGr
 	parent->refreshDisplayName();
 }
 
-KopeteMetaContactLVI::KopeteMetaContactLVI( KopeteMetaContact *contact, QListViewItem *parent )
+KopeteMetaContactLVI::KopeteMetaContactLVI( Kopete::MetaContact *contact, QListViewItem *parent )
 : ListView::Item( parent, contact, "MetaContactLVI" )
 //: QObject( contact, "MetaContactLVI" ), KListViewItem( parent )
 {
@@ -182,7 +219,7 @@ KopeteMetaContactLVI::KopeteMetaContactLVI( KopeteMetaContact *contact, QListVie
 	initLVI();
 }
 
-KopeteMetaContactLVI::KopeteMetaContactLVI( KopeteMetaContact *contact, QListView *parent )
+KopeteMetaContactLVI::KopeteMetaContactLVI( Kopete::MetaContact *contact, QListView *parent )
 : ListView::Item( parent, contact, "MetaContactLVI" )
 //: QObject( contact, "MetaContactLVI" ), KListViewItem( parent )
 {
@@ -198,25 +235,32 @@ KopeteMetaContactLVI::KopeteMetaContactLVI( KopeteMetaContact *contact, QListVie
 void KopeteMetaContactLVI::initLVI()
 {
 	d = new Private;
+	  
 	d->toolTipSource.reset( new ListView::MetaContactToolTipSource( m_metaContact ) );
 
 	m_oldStatus = m_metaContact->status();
 	m_oldStatusIcon = m_metaContact->statusIcon();
-
+	
 	connect( m_metaContact, SIGNAL( displayNameChanged( const QString &, const QString & ) ),
 		SLOT( slotDisplayNameChanged() ) );
+	
+	connect( m_metaContact, SIGNAL( photoChanged() ),
+		SLOT( slotPhotoChanged() ) );
+		
+	connect( m_metaContact, SIGNAL( onlineStatusChanged( Kopete::MetaContact *, Kopete::OnlineStatus::StatusType ) ),
+		SLOT( slotPhotoChanged() ) );
 
-	connect( m_metaContact, SIGNAL( onlineStatusChanged( KopeteMetaContact *, KopeteOnlineStatus::OnlineStatus ) ),
+	connect( m_metaContact, SIGNAL( onlineStatusChanged( Kopete::MetaContact *, Kopete::OnlineStatus::StatusType ) ),
 		SLOT( slotUpdateMetaContact() ) );
 
-	connect( m_metaContact, SIGNAL( contactStatusChanged( KopeteContact *, const KopeteOnlineStatus & ) ),
-		SLOT( slotContactStatusChanged( KopeteContact * ) ) );
+	connect( m_metaContact, SIGNAL( contactStatusChanged( Kopete::Contact *, const Kopete::OnlineStatus & ) ),
+		SLOT( slotContactStatusChanged( Kopete::Contact * ) ) );
 
-	connect( m_metaContact, SIGNAL( contactAdded( KopeteContact * ) ),
-		SLOT( slotContactAdded( KopeteContact * ) ) );
+	connect( m_metaContact, SIGNAL( contactAdded( Kopete::Contact * ) ),
+		SLOT( slotContactAdded( Kopete::Contact * ) ) );
 
-	connect( m_metaContact, SIGNAL( contactRemoved( KopeteContact * ) ),
-		SLOT( slotContactRemoved( KopeteContact * ) ) );
+	connect( m_metaContact, SIGNAL( contactRemoved( Kopete::Contact * ) ),
+		SLOT( slotContactRemoved( Kopete::Contact * ) ) );
 
 	connect( m_metaContact, SIGNAL( iconAppearanceChanged() ),
 		SLOT( slotUpdateMetaContact() ) );
@@ -224,12 +268,14 @@ void KopeteMetaContactLVI::initLVI()
 	connect( m_metaContact, SIGNAL( useCustomIconChanged( bool ) ),
 		SLOT( slotUpdateMetaContact() ) );
 
-	connect( m_metaContact, SIGNAL( contactIdleStateChanged( KopeteContact * ) ),
-		SLOT( slotIdleStateChanged( KopeteContact * ) ) );
+	connect( m_metaContact, SIGNAL( contactIdleStateChanged( Kopete::Contact * ) ),
+		SLOT( slotIdleStateChanged( Kopete::Contact * ) ) );
 
 	connect( KopetePrefs::prefs(), SIGNAL( contactListAppearanceChanged() ),
 		SLOT( slotConfigChanged() ) );
 
+	connect( kapp, SIGNAL( appearanceChanged() ),  SLOT( slotConfigChanged() ) );
+
 	mBlinkTimer = new QTimer( this, "mBlinkTimer" );
 	connect( mBlinkTimer, SIGNAL( timeout() ), SLOT( slotBlink() ) );
 	mIsBlinkIcon = false;
@@ -285,22 +331,36 @@ void KopeteMetaContactLVI::movedToDifferentGroup()
 
 void KopeteMetaContactLVI::rename( const QString& newName )
 {
+	KopeteContactListView *lv = dynamic_cast<KopeteContactListView *>( listView() );
+	if ( lv )
+	{
+		KopeteContactListView::UndoItem *u=new KopeteContactListView::UndoItem(KopeteContactListView::UndoItem::MetaContactRename, m_metaContact);
+		if ( m_metaContact->nameSource() == 0 )
+			u->args << m_metaContact->displayName();
+		else
+		{
+			Kopete::Contact* c = m_metaContact->nameSource();
+			u->args << c->contactId() << c->protocol()->pluginId() << c->account()->accountId();
+		}
+		lv->insertUndoItem(u);
+	}
+	
 	if ( newName.isEmpty() )
 	{
 		// Reset the last display name
 		slotDisplayNameChanged();
-		m_metaContact->setTrackChildNameChanges( true );
+		m_metaContact->setNameSource( m_metaContact->contacts().first() );
 	}
 	else // user changed name manually, disable tracking of contact nickname and update displayname
 	{
-		m_metaContact->setTrackChildNameChanges( false );
+		m_metaContact->setNameSource( 0 );
 		m_metaContact->setDisplayName( newName );
 	}
 
-	kdDebug( 14000 ) << k_funcinfo << "newName=" << newName << ", TrackChildNameChanges=" << m_metaContact->trackChildNameChanges() << endl;
+	kdDebug( 14000 ) << k_funcinfo << "newName=" << newName << endl;
 }
 
-void KopeteMetaContactLVI::slotContactStatusChanged( KopeteContact *c )
+void KopeteMetaContactLVI::slotContactStatusChanged( Kopete::Contact *c )
 {
 	updateContactIcon( c );
 
@@ -308,7 +368,7 @@ void KopeteMetaContactLVI::slotContactStatusChanged( KopeteContact *c )
 	// multiple times if the user is in multiple groups - Jason
 
 	// comparing the status of the previous and new preferred contact is the determining factor in deciding to notify
-	KopeteOnlineStatus newStatus;
+	Kopete::OnlineStatus newStatus;
 	if ( m_metaContact->preferredContact() )
 		newStatus = m_metaContact->preferredContact()->onlineStatus();
 	else
@@ -319,40 +379,50 @@ void KopeteMetaContactLVI::slotContactStatusChanged( KopeteContact *c )
 
 	// ensure we are not suppressing notifications, because connecting or disconnected
 	if ( !(c->account()->suppressStatusNotification()
-		 || ( c->account()->myself()->onlineStatus().status() == KopeteOnlineStatus::Connecting )
+		 || ( c->account()->myself()->onlineStatus().status() == Kopete::OnlineStatus::Connecting )
 		 || !c->account()->isConnected() ) )
 	{
 		if ( !c->account()->isAway() || KopetePrefs::prefs()->soundIfAway() )
 		{
 			int winId = KopeteSystemTray::systemTray() ? KopeteSystemTray::systemTray()->winId() : 0;
 
-			//QString text = i18n( "%2 is now %1." ).arg( m_metaContact->statusString(), m_metaContact->displayName() );
-			QString text = i18n( "%2 is now %1." ).arg( c->onlineStatus().description(), m_metaContact->displayName() );
+			QString text;
+			if(!m_metaContact->photo().isNull())
+			{
+				text= i18n("<qt><table cellpadding=\"0\" cellspacing=\"0\"><tr><td><img src=\"kopete-metacontact-photo:%1\"></td><td>%2 is now %3</td></tr></table></qt>")
+						.arg( KURL::encode_string( m_metaContact->metaContactId()) ,  QStyleSheet::escape(m_metaContact->displayName()) , QStyleSheet::escape(c->onlineStatus().description())  );
+			}
+			else
+			{
+				//QString text = i18n( "%2 is now %1." ).arg( m_metaContact->statusString(), m_metaContact->displayName() );
+				text = i18n( "%2 is now %1." ).arg( c->onlineStatus().description(), m_metaContact->displayName() );
+			}
 
+			
 			// figure out what's happened
 			enum ChangeType { noChange, noEvent, signedIn, changedStatus, signedOut };
 			ChangeType t = noChange;
 			//kdDebug( 14000 ) << k_funcinfo << m_metaContact->displayName() <<
 			//" - Old MC Status: " << m_oldStatus.status() << ", New MC Status: " << newStatus.status() << endl;
 			// first, exclude changes due to blocking or subscription changes at the protocol level
-			if ( ( m_oldStatus.status() == KopeteOnlineStatus::Unknown
-						|| newStatus.status() == KopeteOnlineStatus::Unknown ) )
+			if ( ( m_oldStatus.status() == Kopete::OnlineStatus::Unknown
+						|| newStatus.status() == Kopete::OnlineStatus::Unknown ) )
 				t = noEvent;	// This means the contact's changed from or to unknown - due to a protocol state change, not a contact state change
 			else	// we're dealing with a genuine contact state change
 			{
-				if ( m_oldStatus.status() == KopeteOnlineStatus::Offline )
+				if ( m_oldStatus.status() == Kopete::OnlineStatus::Offline )
 				{
-					if ( newStatus.status() != KopeteOnlineStatus::Offline )
+					if ( newStatus.status() != Kopete::OnlineStatus::Offline )
 					{
 						//kdDebug( 14000 ) << "signed in" << endl;
 						t = signedIn;	// contact has gone from offline to something else, it's a sign-in
 					}
 				}
-				else if ( m_oldStatus.status() == KopeteOnlineStatus::Online
-						  || m_oldStatus.status() == KopeteOnlineStatus::Away
-						  || m_oldStatus.status() == KopeteOnlineStatus::Invisible)
+				else if ( m_oldStatus.status() == Kopete::OnlineStatus::Online
+						  || m_oldStatus.status() == Kopete::OnlineStatus::Away
+						  || m_oldStatus.status() == Kopete::OnlineStatus::Invisible)
 				{
-					if ( newStatus.status() == KopeteOnlineStatus::Offline )
+					if ( newStatus.status() == Kopete::OnlineStatus::Offline )
 					{
 						//kdDebug( 14000 ) << "signed OUT" << endl;
 						t = signedOut;	// contact has gone from an online state to an offline state, it's a sign out
@@ -396,7 +466,7 @@ void KopeteMetaContactLVI::slotContactStatusChanged( KopeteContact *c )
 		if ( !mBlinkTimer->isActive() && ( m_metaContact->statusIcon() != m_oldStatusIcon ) )
 		{
 			mIsBlinkIcon = false;
-			m_blinkLeft = 5;
+			m_blinkLeft = 9;
 			mBlinkTimer->start( 400, false );
 		}
 	}
@@ -433,13 +503,69 @@ void KopeteMetaContactLVI::execute() const
 
 void KopeteMetaContactLVI::slotDisplayNameChanged()
 {
-	d->nameText->setText( m_metaContact->displayName() );
+	if ( d->nameText )
+	{
+		d->nameText->setText( m_metaContact->displayName() );
+	
+		// delay the sort if we can
+		if ( ListView::ListView *lv = dynamic_cast<ListView::ListView *>( listView() ) )
+			lv->delayedSort();
+		else
+			listView()->sort();
+	}
+}
 
-	// delay the sort if we can
-	if ( ListView::ListView *lv = dynamic_cast<ListView::ListView *>( listView() ) )
-		lv->delayedSort();
-	else
-		listView()->sort();
+void KopeteMetaContactLVI::slotPhotoChanged()
+{
+	if ( d->metaContactPhoto )
+	{
+		QPixmap photoPixmap;
+		//QPixmap defaultIcon( KGlobal::iconLoader()->loadIcon( "vcard", KIcon::Desktop ) );
+		QImage photoImg = m_metaContact->photo();
+		if ( !photoImg.isNull() && (photoImg.width() > 0) &&  (photoImg.height() > 0) )
+		{
+			int photoSize = d->photoSize;
+			
+			if ( photoImg.width() > photoImg.height() )
+			{
+				photoImg = photoImg.smoothScale( photoSize, photoSize * photoImg.height() / photoImg.width() ) ;
+			}
+			else
+			{
+				photoImg = photoImg.smoothScale( photoSize *  photoImg.width() / photoImg.height() , photoSize );
+			}
+			
+			KImageEffect *effect = 0L;
+			switch ( m_metaContact->status() )
+			{
+				case Kopete::OnlineStatus::Away:
+					effect = new KImageEffect();
+					effect->fade(photoImg, 0.5, Qt::white);
+				break;
+				case Kopete::OnlineStatus::Offline:
+					effect = new KImageEffect();
+					effect->fade(photoImg, 0.4, Qt::white);
+					effect->toGray(photoImg);
+				break;
+				case Kopete::OnlineStatus::Unknown:
+					effect = new KImageEffect();
+					effect->fade(photoImg, 0.8, Qt::white);
+			}
+			delete effect;
+			photoPixmap = photoImg;
+			QPainter p(&photoPixmap);
+			p.setPen(Qt::black);
+			p.drawLine(0, 0, photoPixmap.width()-1, 0);
+			p.drawLine(0, photoPixmap.height()-1, photoPixmap.width()-1, photoPixmap.height()-1);
+			p.drawLine(0, 0, 0, photoPixmap.height()-1);
+			p.drawLine(photoPixmap.width()-1, 0, photoPixmap.width()-1, photoPixmap.height()-1);
+		}
+		else
+		{
+			photoPixmap=SmallIcon(m_metaContact->statusIcon(), d->photoSize);
+		}
+		d->metaContactPhoto->setPixmap( photoPixmap, false);
+	}
 }
 
 /*
@@ -453,7 +579,7 @@ void KopeteMetaContactLVI::slotRemoveThisUser()
 		arg( m_metaContact->displayName() ), i18n( "Remove Contact" ), KGuiItem(i18n("Remove"),"editdelete") )
 		== KMessageBox::Continue )
 	{
-		KopeteContactList::contactList()->removeMetaContact( m_metaContact );
+		Kopete::ContactList::self()->removeMetaContact( m_metaContact );
 	}
 }
 
@@ -466,7 +592,7 @@ void KopeteMetaContactLVI::slotRemoveFromGroup()
 }
 */
 
-void KopeteMetaContactLVI::startRename( int col )
+void KopeteMetaContactLVI::startRename( int /*col*/ )
 {
 	KListViewItem::startRename( 0 );
 }
@@ -491,12 +617,12 @@ void KopeteMetaContactLVI::slotMoveToGroup()
 		if ( m_actionMove->currentItem() == 0 )
 		{
 			// we are moving to top-level
-			if ( group() != KopeteGroup::toplevel )
-				m_metaContact->moveToGroup( group(), KopeteGroup::toplevel );
+			if ( group() != Kopete::Group::toplevel )
+				m_metaContact->moveToGroup( group(), Kopete::Group::toplevel );
 		}
 		else
 		{
-			KopeteGroup *to = KopeteContactList::contactList()->getGroup( m_actionMove->currentText() );
+			Kopete::Group *to = Kopete::ContactList::self()->getGroup( m_actionMove->currentText() );
 			if ( !m_metaContact->groups().contains( to ) )
 				m_metaContact->moveToGroup( group(), to );
 		}
@@ -511,11 +637,11 @@ void KopeteMetaContactLVI::slotAddToGroup()
 		if ( m_actionCopy->currentItem() == 0 )
 		{
 			// we are adding to top-level
-			m_metaContact->addToGroup( KopeteGroup::toplevel );
+			m_metaContact->addToGroup( Kopete::Group::toplevel );
 		}
 		else
 		{
-			m_metaContact->addToGroup( KopeteContactList::contactList()->getGroup( m_actionCopy->currentText() ) );
+			m_metaContact->addToGroup( Kopete::ContactList::self()->getGroup( m_actionCopy->currentText() ) );
 		}
 	}
 }
@@ -531,7 +657,7 @@ void KopeteMetaContactLVI::slotAddToNewGroup()
 		i18n( "New Group" ), i18n( "Please enter the name for the new group:" ) );
 
 	if ( !groupName.isEmpty() )
-		m_metaContact->addToGroup( KopeteContactList::contactList()->getGroup( groupName ) );
+		m_metaContact->addToGroup( Kopete::ContactList::self()->findGroup( groupName ) );
 }
 
 void KopeteMetaContactLVI::slotConfigChanged()
@@ -573,9 +699,16 @@ void KopeteMetaContactLVI::setDisplayMode( int mode )
 	// empty...
 	while ( component( 0 ) )
 		delete component( 0 );
-	d->extraText = 0;
-	d->buddyIcon = 0;
+	
+	d->nameText = 0L;
+	d->metaContactPhoto = 0L;
+	d->extraText = 0L;
+	d->metaContactIcon = 0L;
 	d->iconSize = IconSize( KIcon::Small );
+	d->contactIconSize = 12;
+	d->photoSize = 48;
+
+	disconnect( Kopete::KABCPersistence::self()->addressBook() , 0 , this , 0);
 
 	// generate our contents
 	using namespace ListView;
@@ -592,12 +725,16 @@ void KopeteMetaContactLVI::setDisplayMode( int mode )
 		Component *box = new BoxComponent( vbox, BoxComponent::Horizontal );
 		d->contactIconBox = new BoxComponent( box, BoxComponent::Horizontal );
 
-		new HSpacerComponent( hbox );
-		d->buddyIcon = new ImageComponent( hbox );
 		d->iconSize = IconSize( KIcon::Toolbar );
 	}
-	else if( mode == KopetePrefs::Yagami )             // just for Yagami :)
+	else if( mode == KopetePrefs::Yagami )             // Style with metacontact photo
 	{
+		d->contactIconSize = IconSize( KIcon::Small );
+		Component *imageBox = new BoxComponent( hbox, BoxComponent::Vertical );
+		new VSpacerComponent( imageBox );
+		// include borders in size
+		d->metaContactPhoto = new ImageComponent( imageBox, d->photoSize + 2 , d->photoSize + 2 );
+		new VSpacerComponent( imageBox );
 		Component *vbox = new BoxComponent( hbox, BoxComponent::Vertical );
 		d->nameText = new TextComponent( vbox );
 		d->extraText = new TextComponent( vbox );
@@ -605,10 +742,11 @@ void KopeteMetaContactLVI::setDisplayMode( int mode )
 		Component *box = new BoxComponent( vbox, BoxComponent::Horizontal );
 		d->contactIconBox = new BoxComponent( box, BoxComponent::Horizontal );
 
-		new HSpacerComponent( hbox );
-		d->buddyIcon = new ImageComponent( hbox );
-		d->iconSize = IconSize( KIcon::Toolbar );
-		d->metaContactIcon = new ImageComponent( hbox );
+		if(!metaContact()->photoSource() && !Kopete::KABCPersistence::self()->addressBook()->findByUid( metaContact()->metaContactId() ).isEmpty()   )
+		{	//if the photo is the one of the kaddressbook,  track every change in the adressbook, it might be the photo of our contact.
+			connect( Kopete::KABCPersistence::self()->addressBook() , SIGNAL(addressBookChanged (AddressBook *) ) ,
+					 this , SLOT(slotPhotoChanged()));
+		}
 	}
 	else if( mode == KopetePrefs::RightAligned )       // old right-aligned contact
 	{
@@ -628,13 +766,15 @@ void KopeteMetaContactLVI::setDisplayMode( int mode )
 	setMetaContactToolTipSourceForComponent( d->metaContactIcon );
 	setMetaContactToolTipSourceForComponent( d->nameText );
 	setMetaContactToolTipSourceForComponent( d->extraText );
-
+	setMetaContactToolTipSourceForComponent( d->metaContactPhoto );
+	
 	// update the display name
 	slotDisplayNameChanged();
-
+	slotPhotoChanged();
+	
 	// finally, re-add all contacts so their icons appear. remove them first for consistency.
-	QPtrList<KopeteContact> contacts = m_metaContact->contacts();
-	for ( QPtrListIterator<KopeteContact> it( contacts ); it.current(); ++it )
+	QPtrList<Kopete::Contact> contacts = m_metaContact->contacts();
+	for ( QPtrListIterator<Kopete::Contact> it( contacts ); it.current(); ++it )
 	{
 		slotContactRemoved( *it );
 		slotContactAdded( *it );
@@ -651,7 +791,7 @@ void KopeteMetaContactLVI::updateVisibility()
 		setTargetVisibility( true );
 }
 
-void KopeteMetaContactLVI::slotContactPropertyChanged( KopeteContact *,
+void KopeteMetaContactLVI::slotContactPropertyChanged( Kopete::Contact *contact,
 	const QString &key, const QVariant &old, const QVariant &newVal )
 {
 	if ( key == QString::fromLatin1("awayMessage") && d->extraText && old != newVal )
@@ -661,13 +801,17 @@ void KopeteMetaContactLVI::slotContactPropertyChanged( KopeteContact *,
 		else
 			d->extraText->setText( newVal.toString() );
 	}
+	else if ( key == QString::fromLatin1("photo") && m_metaContact->photoSource() == contact )
+	{
+		slotPhotoChanged();
+	}
 }
 
-void KopeteMetaContactLVI::slotContactAdded( KopeteContact *c )
+void KopeteMetaContactLVI::slotContactAdded( Kopete::Contact *c )
 {
-	connect( c, SIGNAL( propertyChanged( KopeteContact *, const QString &,
+	connect( c, SIGNAL( propertyChanged( Kopete::Contact *, const QString &,
 			const QVariant &, const QVariant & ) ),
-		this, SLOT( slotContactPropertyChanged( KopeteContact *, const QString &,
+		this, SLOT( slotContactPropertyChanged( Kopete::Contact *, const QString &,
 			const QVariant &, const QVariant & ) ) );
 	connect( c->account() , SIGNAL( colorChanged(const QColor& ) ) , this, SLOT( updateContactIcons() ) );
 
@@ -677,11 +821,11 @@ void KopeteMetaContactLVI::slotContactAdded( KopeteContact *c )
 		QVariant(), c->property( QString::fromLatin1("awayMessage") ).value() );
 }
 
-void KopeteMetaContactLVI::slotContactRemoved( KopeteContact *c )
+void KopeteMetaContactLVI::slotContactRemoved( Kopete::Contact *c )
 {
-	disconnect( c, SIGNAL( propertyChanged( KopeteContact *, const QString &,
+	disconnect( c, SIGNAL( propertyChanged( Kopete::Contact *, const QString &,
 			const QVariant &, const QVariant & ) ),
-		this, SLOT( slotContactPropertyChanged( KopeteContact *,
+		this, SLOT( slotContactPropertyChanged( Kopete::Contact *,
 			const QString &, const QVariant &, const QVariant & ) ) );
 	disconnect( c->account() , SIGNAL( colorChanged(const QColor& ) ) , this, SLOT( updateContactIcons() ) );
 
@@ -695,12 +839,12 @@ void KopeteMetaContactLVI::slotContactRemoved( KopeteContact *c )
 void KopeteMetaContactLVI::updateContactIcons()
 {
 	// show offline contacts setting may have changed
-	QPtrList<KopeteContact> contacts = m_metaContact->contacts();
-	for ( QPtrListIterator<KopeteContact> it( contacts ); it.current(); ++it )
+	QPtrList<Kopete::Contact> contacts = m_metaContact->contacts();
+	for ( QPtrListIterator<Kopete::Contact> it( contacts ); it.current(); ++it )
 		updateContactIcon( *it );
 }
 
-void KopeteMetaContactLVI::updateContactIcon( KopeteContact *c )
+void KopeteMetaContactLVI::updateContactIcon( Kopete::Contact *c )
 {
 	KGlobal::config()->setGroup( QString::fromLatin1("ContactList") );
 	bool bHideOffline = KGlobal::config()->readBoolEntry(
@@ -711,21 +855,21 @@ void KopeteMetaContactLVI::updateContactIcon( KopeteContact *c )
 	ContactComponent *comp = contactComponent( c );
 	bool bShow = !bHideOffline || c->isOnline();
 	if ( bShow && !comp )
-		(void)new ContactComponent( d->contactIconBox, c );
+		(void)new ContactComponent( d->contactIconBox, c, d->contactIconSize );
 	else if ( !bShow && comp )
 		delete comp;
 	else if ( comp )
 		comp->updatePixmap();
 }
 
-KopeteContact *KopeteMetaContactLVI::contactForPoint( const QPoint &p ) const
+Kopete::Contact *KopeteMetaContactLVI::contactForPoint( const QPoint &p ) const
 {
 	if ( ContactComponent *comp = dynamic_cast<ContactComponent*>( d->contactIconBox->componentAt( p ) ) )
 		return comp->contact();
 	return 0L;
 }
 
-ContactComponent *KopeteMetaContactLVI::contactComponent( const KopeteContact *c ) const
+ContactComponent *KopeteMetaContactLVI::contactComponent( const Kopete::Contact *c ) const
 {
 	for ( uint n = 0; n < d->contactIconBox->components(); ++n )
 	{
@@ -738,19 +882,19 @@ ContactComponent *KopeteMetaContactLVI::contactComponent( const KopeteContact *c
 	return 0;
 }
 
-QRect KopeteMetaContactLVI::contactRect( const KopeteContact *c ) const
+QRect KopeteMetaContactLVI::contactRect( const Kopete::Contact *c ) const
 {
 	if ( ListView::Component *comp = contactComponent( c ) )
 		return comp->rect();
 	return QRect();
 }
 
-KopeteGroup *KopeteMetaContactLVI::group()
+Kopete::Group *KopeteMetaContactLVI::group()
 {
-	if ( m_parentGroup && m_parentGroup->group() != KopeteGroup::topLevel() )
+	if ( m_parentGroup && m_parentGroup->group() != Kopete::Group::topLevel() )
 		return m_parentGroup->group();
 	else
-		return KopeteGroup::topLevel();
+		return Kopete::Group::topLevel();
 }
 
 QString KopeteMetaContactLVI::key( int, bool ) const
@@ -758,16 +902,16 @@ QString KopeteMetaContactLVI::key( int, bool ) const
 	char importanceChar;
 	switch ( m_metaContact->status() )
 	{
-	case KopeteOnlineStatus::Online:
+	case Kopete::OnlineStatus::Online:
 		importanceChar = 'A';
 		break;
-	case KopeteOnlineStatus::Away:
+	case Kopete::OnlineStatus::Away:
 		importanceChar = 'B';
 		break;
-	case KopeteOnlineStatus::Offline:
+	case Kopete::OnlineStatus::Offline:
 		importanceChar = 'C';
 		break;
-	case KopeteOnlineStatus::Unknown:
+	case Kopete::OnlineStatus::Unknown:
 	default:
 		importanceChar = 'D';
 	}
@@ -788,13 +932,13 @@ bool KopeteMetaContactLVI::isGrouped() const
 	if ( !m_parentGroup || !m_parentGroup->group() )
 		return false;
 
-	if ( m_parentGroup->group() == KopeteGroup::temporary() && !KopetePrefs::prefs()->sortByGroup() )
+	if ( m_parentGroup->group() == Kopete::Group::temporary() && !KopetePrefs::prefs()->sortByGroup() )
 		return false;
 
 	return true;
 }
 
-void KopeteMetaContactLVI::slotIdleStateChanged( KopeteContact *c )
+void KopeteMetaContactLVI::slotIdleStateChanged( Kopete::Contact *c )
 {
 	QPixmap icon = SmallIcon( m_metaContact->statusIcon(), d->iconSize );
 	if ( KopetePrefs::prefs()->greyIdleMetaContacts() && ( m_metaContact->idleTime() >= 10 * 60 ) )
@@ -812,6 +956,7 @@ void KopeteMetaContactLVI::slotIdleStateChanged( KopeteContact *c )
 			d->extraText->setDefaultColor();
 	}
 
+	if(d->metaContactIcon)
 	d->metaContactIcon->setPixmap( icon );
 	// we only need to update the contact icon if one was supplied;
 	// if none was supplied, we only need to update the MC appearance
@@ -821,12 +966,12 @@ void KopeteMetaContactLVI::slotIdleStateChanged( KopeteContact *c )
 		return;
 }
 
-void KopeteMetaContactLVI::catchEvent( KopeteEvent *event )
+void KopeteMetaContactLVI::catchEvent( Kopete::MessageEvent *event )
 {
 	d->events.append( event );
 
-	connect( event, SIGNAL( done( KopeteEvent* ) ),
-	         this, SLOT( slotEventDone( KopeteEvent * ) ) );
+	connect( event, SIGNAL( done( Kopete::MessageEvent* ) ),
+	         this, SLOT( slotEventDone( Kopete::MessageEvent * ) ) );
 
 	if ( mBlinkTimer->isActive() )
 		mBlinkTimer->stop();
@@ -844,7 +989,8 @@ void KopeteMetaContactLVI::slotBlink()
 	bool haveEvent = !d->events.isEmpty();
 	if ( mIsBlinkIcon )
 	{
-		d->metaContactIcon->setPixmap( SmallIcon( m_metaContact->statusIcon(), d->iconSize ) );
+		if(d->metaContactIcon)
+			d->metaContactIcon->setPixmap( SmallIcon( m_metaContact->statusIcon(), d->iconSize ) );
 		if ( !haveEvent && m_blinkLeft <= 0 )
 		{
 			mBlinkTimer->stop();
@@ -856,11 +1002,13 @@ void KopeteMetaContactLVI::slotBlink()
 	{
 		if ( haveEvent )
 		{
-			d->metaContactIcon->setPixmap( SmallIcon( "newmsg", d->iconSize ) );
+			if(d->metaContactIcon)
+				d->metaContactIcon->setPixmap( SmallIcon( "newmsg", d->iconSize ) );
 		}
 		else
 		{
-			d->metaContactIcon->setPixmap( SmallIcon( m_oldStatusIcon, d->iconSize ) );
+			if(d->metaContactIcon)
+				d->metaContactIcon->setPixmap( SmallIcon( m_oldStatusIcon, d->iconSize ) );
 			m_blinkLeft--;
 		}
 	}
@@ -868,7 +1016,7 @@ void KopeteMetaContactLVI::slotBlink()
 	mIsBlinkIcon = !mIsBlinkIcon;
 }
 
-void KopeteMetaContactLVI::slotEventDone( KopeteEvent *event )
+void KopeteMetaContactLVI::slotEventDone( Kopete::MessageEvent *event )
 {
 	d->events.remove( event );
 
@@ -881,8 +1029,9 @@ void KopeteMetaContactLVI::slotEventDone( KopeteEvent *event )
 			//the visibility has not been correctly updated. so do it now
 			updateVisibility();
 		}
-	
-		d->metaContactIcon->setPixmap( SmallIcon( m_metaContact->statusIcon(), d->iconSize ) );
+
+		if(d->metaContactIcon)
+			d->metaContactIcon->setPixmap( SmallIcon( m_metaContact->statusIcon(), d->iconSize ) );
 		mIsBlinkIcon = false;
 	}
 }
