@@ -25,6 +25,7 @@
 #include <kmainwindow.h>
 
 class QHBox;
+class QTimer;
 
 class KAction;
 class KActionMenu;
@@ -33,16 +34,20 @@ class KGlobalAccel;
 class KSelectAction;
 class KToggleAction;
 
-class KopeteAccount;
 class KopeteAccountStatusBarIcon;
-class KopeteContact;
 class KopeteContactListView;
-class KopeteAwayAction;
-class KopetePlugin;
 class KopetePluginConfig;
-class KopeteProtocol;
 class KopeteSystemTray;
 
+namespace Kopete
+{
+class AwayAction;
+class Account;
+class Contact;
+class Plugin;
+class Protocol;
+}
+
 /**
  * @author Duncan Mac-Vicar P. <duncan@kde.org>
  */
@@ -56,6 +61,8 @@ public:
 
 protected:
 	virtual void closeEvent( QCloseEvent *ev );
+	virtual void leaveEvent( QEvent* ev );
+	virtual void showEvent( QShowEvent* ev );
 
 private slots:
 	void showMenubar();
@@ -63,14 +70,26 @@ private slots:
 	void slotToggleShowOffliners();
 	void slotToggleShowEmptyGroups();
 	void slotConfigChanged();
-	void slotConfKeys();
 	void slotConfNotifications();
 	void slotConfToolbar();
 	void slotUpdateToolbar();
 	void slotConfigurePlugins();
 	void slotConfGlobalKeys();
 	void slotShowHide();
-
+	
+	/**
+	 * Checks if the mousecursor is in the contact list.
+	 * If not, the window will be hidden.
+	 */
+	void slotAutoHide();
+	
+	/**
+	 * This slot will apply settings that change the 
+	 * contactlist's appearance. Only autohiding is 
+	 * handled here at the moment
+	 */
+	void slotContactListAppearanceChanged();
+	
 	/**
 	 * This slot will show an away dialog and then
 	 * set all the protocols to away
@@ -82,24 +101,24 @@ private slots:
 	 * Get a notification when a plugin is loaded, so we can merge
 	 * XMLGUI cruft
 	 */
-	void slotPluginLoaded( KopetePlugin *p );
+	void slotPluginLoaded( Kopete::Plugin *p );
 
 	/**
 	 * Get a notification when an account is created, so we can add a status bar
 	 * icon
 	 */
-	void slotAccountRegistered( KopeteAccount *a );
+	void slotAccountRegistered( Kopete::Account *a );
 
 	/**
 	 * Cleanup the status bar icon when the account is destroyed
 	 */
-	void slotAccountUnregistered( KopeteAccount *a);
+	void slotAccountUnregistered( const Kopete::Account *a);
 
 	/**
 	 * The status icon got changed, update it.
 	 * @param contact The account's contact that changed.
 	 */
-	void slotAccountStatusIconChanged( KopeteContact * contact);
+	void slotAccountStatusIconChanged( Kopete::Contact * contact);
 
 	/**
 	 * The status icon of some account changed. Must be sent by the account in question.
@@ -109,13 +128,12 @@ private slots:
 	/**
 	 * Show a context menu for a protocol
 	 */
-	void slotProtocolStatusIconRightClicked( KopeteProtocol *proto,
-		const QPoint &p );
+//	void slotProtocolStatusIconRightClicked( Kopete::Protocol *proto, const QPoint &p );
 
 	/**
 	 * Show a context menu for an account
 	 */
-	void slotAccountStatusIconRightClicked( KopeteAccount *a,
+	void slotAccountStatusIconRightClicked( Kopete::Account *a,
 		const QPoint &p );
 
 	void slotTrayAboutToShowMenu(KPopupMenu *);
@@ -125,6 +143,11 @@ private slots:
 	 */
 	void showAddContactDialog();
 
+	/** 
+	 * Show the Export Contacts wizards
+	 */
+	void showExportDialog();
+
 	/**
 	 * Enable the Connect All and Disconnect All buttons here
 	 * along with connecting the accountRegistered and accountUnregistered
@@ -138,13 +161,14 @@ public:
 	// Some Actions
 	KAction* actionAddContact;
 
-	KActionMenu* actionConnectionMenu;
-	KAction* actionConnect;
+	//KActionMenu* actionConnectionMenu;
+	//KAction* actionConnect;
 	KAction* actionDisconnect;
+	KAction* actionExportContacts;
 
 	KActionMenu* actionAwayMenu;
 	KActionMenu* actionDockMenu;
-	KopeteAwayAction* selectAway;
+	Kopete::AwayAction* selectAway;
 	KAction* actionSetAvailable;
 
 	KAction* actionPrefs;
@@ -164,7 +188,10 @@ private:
 	void saveOptions();
 	
 	void makeTrayToolTip();
+	void startAutoHideTimer();
 
+	virtual bool queryClose();
+	virtual bool queryExit();
 private:
 	int docked;
 	bool hidden;
@@ -172,6 +199,9 @@ private:
 	QPoint position;
 	QHBox *m_statusBarWidget;
 	KopeteSystemTray *m_tray;
+	bool m_autoHide;
+	unsigned int m_autoHideTimeout;
+	QTimer* m_autoHideTimer;
 
 	KopetePluginConfig *m_pluginConfig;
 
