@@ -3,7 +3,7 @@
 
     Copyright (c) 2003     Jason Keirstead   <jason@keirstead.org>
 
-    Kopete    (c) 2002-2003 by the Kopete developers  <kopete-devel@kde.org>
+    Kopete    (c) 2002-2005 by the Kopete developers  <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -22,12 +22,25 @@
 
 #include "kopeteawayaction.h"
 #include "kopeteaway.h"
+#include "kopeteonlinestatus.h"
 
-KopeteAwayAction::KopeteAwayAction(const QString &text, const QIconSet &pix, const KShortcut &cut,
-	const QObject *receiver, const char *slot, QObject *parent, const char *name ) :
-	KSelectAction(text, pix, cut, parent, name )
+
+namespace Kopete {
+
+class AwayAction::Private
 {
-	QObject::connect( KopeteAway::getInstance(), SIGNAL( messagesChanged() ),
+public:
+	Private(const OnlineStatus& s) : reasonCount(0) , status(s) {};
+	int reasonCount;
+	OnlineStatus status;
+};
+
+
+AwayAction::AwayAction(const QString &text, const QIconSet &pix, const KShortcut &cut,
+	const QObject *receiver, const char *slot, QObject *parent, const char *name )
+	: KSelectAction(text, pix, cut, parent, name ) , d(new Private( OnlineStatus() ) )
+{
+	QObject::connect( Kopete::Away::getInstance(), SIGNAL( messagesChanged() ),
 		this, SLOT( slotAwayChanged() ) );
 
 	QObject::connect( this, SIGNAL( awayMessageSelected( const QString & ) ),
@@ -36,28 +49,42 @@ KopeteAwayAction::KopeteAwayAction(const QString &text, const QIconSet &pix, con
 	QObject::connect( this, SIGNAL( activated( int ) ),
 		this, SLOT( slotSelectAway( int ) ) );
 
-	reasonCount = 0;
+	slotAwayChanged();
+}
+
+AwayAction::AwayAction( const OnlineStatus& status, const QString &text, const QIconSet &pix, const KShortcut &cut,
+					   const QObject *receiver, const char *slot, QObject *parent, const char *name )
+	: KSelectAction(text, pix, cut, parent, name ) , d(new Private( status ) )
+{
+	QObject::connect( Kopete::Away::getInstance(), SIGNAL( messagesChanged() ),
+					  this, SLOT( slotAwayChanged() ) );
+
+	QObject::connect( this, SIGNAL( awayMessageSelected( const Kopete::OnlineStatus &, const QString & ) ),
+					  receiver, slot );
+
+	QObject::connect( this, SIGNAL( activated( int ) ),
+					  this, SLOT( slotSelectAway( int ) ) );
 
 	slotAwayChanged();
 }
 
-void KopeteAwayAction::slotAwayChanged()
+void AwayAction::slotAwayChanged()
 {
-	QStringList awayMessages = KopeteAway::getInstance()->getMessages();
+	QStringList awayMessages = Kopete::Away::getInstance()->getMessages();
 	for( QStringList::iterator it = awayMessages.begin(); it != awayMessages.end(); ++it )
 	{
 		(*it) = KStringHandler::rsqueeze( *it );
 	}
 
-	reasonCount = awayMessages.count();
+	d->reasonCount = awayMessages.count();
 	awayMessages.append( i18n( "New Message..." ) );
 	setItems( awayMessages );
 	setCurrentItem( -1 );
 }
 
-void KopeteAwayAction::slotSelectAway( int index )
+void AwayAction::slotSelectAway( int index )
 {
-	KopeteAway *mAway = KopeteAway::getInstance();
+	Kopete::Away *mAway = Kopete::Away::getInstance();
 	QString awayReason;
 
 	// Index == -1 means this is a result of Global Away all.
@@ -65,7 +92,7 @@ void KopeteAwayAction::slotSelectAway( int index )
 	if( index == -1 )
 		index = 0;
 	
-	if( index < reasonCount )
+	if( index < d->reasonCount )
 	{
 		awayReason = mAway->getMessage( index );
 	}
@@ -77,15 +104,18 @@ void KopeteAwayAction::slotSelectAway( int index )
 			);
 
 		if( !awayReason.isEmpty() )
-			KopeteAway::getInstance()->addMessage( awayReason );
+			Kopete::Away::getInstance()->addMessage( awayReason );
 	}
 
 	if( !awayReason.isEmpty() )
 	{
-		emit( awayMessageSelected( awayReason ) );
-		setCurrentItem( -1 );
+		emit awayMessageSelected( awayReason ) ;
+		emit awayMessageSelected( d->status, awayReason );
 	}
+	setCurrentItem( -1 );
 }
 
+} //END namespace Kopete
+
 #include "kopeteawayaction.moc"
 
