@@ -22,16 +22,22 @@
 #include <kactionclasses.h>
 #include <kaction.h>
 
+#include <kopete_export.h>
+
+namespace Kopete
+{
+
+class OnlineStatus;
+
 /**
- * @class KopeteAwayAction
+ * @class Kopete::AwayAction
  *
- * KopeteAwayAction is a KAction that lets you select an away message
+ * Kopete::AwayAction is a KAction that lets you select an away message
  * from the list of predefined away messages, or enter a custom one.
  *
  * @author Jason Keirstead   <jason@keirstead.org>
  */
-
-class KopeteAwayAction : public KSelectAction
+class KOPETE_EXPORT AwayAction : public KSelectAction
 {
 	Q_OBJECT
 	public:
@@ -40,9 +46,20 @@ class KopeteAwayAction : public KSelectAction
 		 * @p text, @p pix, @p cut, @p receiver, @p slot, @p parent and
 		 * @p name are all handled by KSelectAction.
 		 **/
-		KopeteAwayAction(const QString &text, const QIconSet &pix,
-			const KShortcut &cut, const QObject *receiver, const char *slot,
-			QObject *parent, const char *name = 0);
+		AwayAction(const QString &text, const QIconSet &pix,
+				   const KShortcut &cut, const QObject *receiver, const char *slot,
+				   QObject *parent, const char *name = 0);
+
+		/**
+		 * Constructor
+		 * @param status the OnlineStatus that appears in the signal
+		 * @param slot must have the following signature:  ( const OnlineStatus &, const QString & )
+		 * @p text, @p pix, @p cut, @p receiver, @p slot, @p parent and
+		 * @p name are all handled by KSelectAction.
+		 **/
+		AwayAction(const OnlineStatus &status, const QString &text, const QIconSet &pix,
+				   const KShortcut &cut, const QObject *receiver, const char *slot,
+				   QObject *parent, const char *name = 0);
 
 	signals:
 		/**
@@ -50,12 +67,20 @@ class KopeteAwayAction : public KSelectAction
 		*/
 		void awayMessageSelected( const QString & );
 
+		 /**
+		  * same as above, but with the saved status
+		  */
+		void awayMessageSelected( const Kopete::OnlineStatus& , const QString & );
+
 	private slots:
 		void slotAwayChanged();
 		void slotSelectAway( int index );
 
 	private:
-		int reasonCount;
+		class Private;
+		Private *d;
 };
 
+}
+
 #endif
