@@ -1,9 +1,9 @@
 /*
     kopetecontact.cpp - Kopete Contact
 
-    Copyright (c) 2002      by Duncan Mac-Vicar Prett <duncan@kde.org>
+    Copyright (c) 2002-2004 by Duncan Mac-Vicar Prett <duncan@kde.org>
     Copyright (c) 2002-2003 by Martijn Klingens       <klingens@kde.org>
-    Copyright (c) 2002-2004 by Olivier Goffart        <ogoffart@tiscalinet.be>
+    Copyright (c) 2002-2004 by Olivier Goffart        <ogoffart @tiscalinet.be>
 
     Kopete    (c) 2002-2004 by the Kopete developers  <kopete-devel@kde.org>
 
@@ -26,6 +26,7 @@
 #include <kdeversion.h>
 #include <kinputdialog.h>
 
+#include <kabcpersistence.h>
 #include <kdialogbase.h>
 #include <klocale.h>
 #include <kpopupmenu.h>
@@ -34,39 +35,34 @@
 #include "kopetecontactlist.h"
 #include "kopeteglobal.h"
 #include "kopeteuiglobal.h"
-#include "kopeteprefs.h"
 #include "kopeteprotocol.h"
 #include "kopeteaccount.h"
 #include "kopetestdaction.h"
 #include "kopetemessagemanager.h"
 #include "kopeteview.h"
 #include "kopetemetacontact.h"
+#include "kopeteprefs.h"
 
 //For the moving to another metacontact dialog
 #include <qlabel.h>
+#include <qimage.h>
 #include <qmime.h>
 #include <qvbox.h>
 #include <klistview.h>
 #include <qcheckbox.h>
 #include <qwhatsthis.h>
 
-struct KopeteContactPrivate
+namespace Kopete {
+
+struct Contact::Private
 {
 public:
 	bool fileCapable;
 
-	KopeteOnlineStatus onlineStatus;
-	KopeteAccount *account;
+	OnlineStatus onlineStatus;
+	Account *account;
 
-	KopeteMetaContact *metaContact;
-
-	KAction *actionSendMessage;
-	KAction *actionChat;
-	KAction *actionDeleteContact;
-	KAction *actionChangeMetaContact;
-	KAction *actionUserInfo;
-	KAction *actionSendFile;
-	KAction *actionAddContact;
+	MetaContact *metaContact;
 
 	QString contactId;
 	QString icon;
@@ -75,101 +71,78 @@ public:
 	unsigned long int idleTime;
 
 	Kopete::ContactProperty::Map properties;
+
 };
 
-KopeteContact::KopeteContact( KopeteAccount *account, const QString &contactId,
-	KopeteMetaContact *parent, const QString &icon )
+Contact::Contact( Account *account, const QString &contactId,
+	MetaContact *parent, const QString &icon )
 	: QObject( parent )
 {
-	d = new KopeteContactPrivate;
+	d = new Private;
 
 	//kdDebug( 14010 ) << k_funcinfo << "Creating contact with id " << contactId << endl;
 
 	d->contactId = contactId;
-
 	d->metaContact = parent;
 	d->fileCapable = false;
 	d->account = account;
 	d->idleTime = 0;
+	d->icon = icon;
 
 	if ( account )
 		account->registerContact( this );
 
-	d->icon = icon;
-
-	// Need to check this because myself() has no parent
+	// Need to check this because myself() may have no parent
 	if( parent )
 	{
-		connect( parent, SIGNAL( aboutToSave( KopeteMetaContact * ) ),
-			protocol(), SLOT( slotMetaContactAboutToSave( KopeteMetaContact * ) ) );
+		connect( parent, SIGNAL( aboutToSave( Kopete::MetaContact * ) ),
+			protocol(), SLOT( slotMetaContactAboutToSave( Kopete::MetaContact * ) ) );
 
 		parent->addContact( this );
 	}
+
+	connect( account, SIGNAL( isConnectedChanged() ), SLOT( slotAccountIsConnectedChanged() ) );
 }
 
-KopeteContact::~KopeteContact()
+Contact::~Contact()
 {
 	//kdDebug(14010) << k_funcinfo << endl;
 	emit( contactDestroyed( this ) );
-	d->metaContact = 0L;
 	delete d;
 }
 
 
-void KopeteContact::rename( const QString &name )
+
+OnlineStatus Contact::onlineStatus() const
 {
-	QString nick = property( Kopete::Global::Properties::self()->nickName() ).value().toString();
-	if( name == nick )
-		return;
- 
-	setProperty( Kopete::Global::Properties::self()->nickName(), name );
+	if ( this == account()->myself() || account()->isConnected() )
+		return d->onlineStatus;
+	else
+		return protocol()->accountOfflineStatus();
 }
 
-void KopeteContact::setDisplayName( const QString &name )
-{
-	QString nick = property( Kopete::Global::Properties::self()->nickName() ).value().toString();
-	if( name == nick )
-		return;
- 
-	setProperty( Kopete::Global::Properties::self()->nickName(), name );
-}
-
-QString KopeteContact::displayName() const
-{
-	QString nick = property( Kopete::Global::Properties::self()->nickName() ).value().toString();
-	if( !nick.isEmpty() )
-		return nick;
-		
-	return d->contactId;
-}
-
-const KopeteOnlineStatus& KopeteContact::onlineStatus() const
-{
-	return d->onlineStatus;
-}
-
-void KopeteContact::setOnlineStatus( const KopeteOnlineStatus &status )
+void Contact::setOnlineStatus( const OnlineStatus &status )
 {
 	if( status == d->onlineStatus )
 		return;
 
-	KopeteOnlineStatus oldStatus = d->onlineStatus;
+	OnlineStatus oldStatus = d->onlineStatus;
 	d->onlineStatus = status;
 
 	Kopete::Global::Properties *globalProps = Kopete::Global::Properties::self();
 
 	// Contact changed from Offline to another status
-	if( oldStatus.status() == KopeteOnlineStatus::Offline &&
-		status.status() != KopeteOnlineStatus::Offline )
+	if( oldStatus.status() == OnlineStatus::Offline &&
+		status.status() != OnlineStatus::Offline )
 	{
 		setProperty( globalProps->onlineSince(), QDateTime::currentDateTime() );
 		/*kdDebug(14010) << k_funcinfo << "REMOVING lastSeen property for " <<
 			d->displayName << endl;*/
 		removeProperty( globalProps->lastSeen() );
 	}
-	else if( oldStatus.status() != KopeteOnlineStatus::Offline &&
-		oldStatus.status() != KopeteOnlineStatus::Unknown &&
-		status.status() == KopeteOnlineStatus::Offline ) // Contact went back offline
+	else if( oldStatus.status() != OnlineStatus::Offline &&
+		oldStatus.status() != OnlineStatus::Unknown &&
+		status.status() == OnlineStatus::Offline ) // Contact went back offline
 	{
 		removeProperty( globalProps->onlineSince() );
 		/*kdDebug(14010) << k_funcinfo << "SETTING lastSeen property for " <<
@@ -177,131 +150,137 @@ void KopeteContact::setOnlineStatus( const KopeteOnlineStatus &status )
 		setProperty( globalProps->lastSeen(), QDateTime::currentDateTime() );
 	}
 
-	emit onlineStatusChanged( this, status, oldStatus );
+	if ( this == account()->myself() || account()->isConnected() )
+		emit onlineStatusChanged( this, status, oldStatus );
 }
 
-void KopeteContact::sendFile( const KURL &, const QString &, uint )
+void Contact::slotAccountIsConnectedChanged()
+{
+	if ( this == account()->myself() )
+		return;
+
+	if ( account()->isConnected() )
+		emit onlineStatusChanged( this, d->onlineStatus, protocol()->accountOfflineStatus() );
+	else
+		emit onlineStatusChanged( this, protocol()->accountOfflineStatus(), d->onlineStatus );
+}
+
+
+void Contact::sendFile( const KURL &, const QString &, uint )
 {
 	kdWarning( 14010 ) << k_funcinfo << "Plugin "
 		<< protocol()->pluginId() << " has enabled file sending, "
 		<< "but didn't implement it!" << endl;
 }
 
-void KopeteContact::slotAddContact()
+void Contact::slotAddContact()
 {
 	if( metaContact() )
 	{
 		metaContact()->setTemporary( false );
-		KopeteContactList::contactList()->addMetaContact( metaContact() );
+		ContactList::self()->addMetaContact( metaContact() );
 	}
 }
 
-KPopupMenu* KopeteContact::popupMenu( KopeteMessageManager *manager )
+KPopupMenu* Contact::popupMenu( ChatSession *manager )
 {
 	// FIXME:
-	// This should perhaps be KActionCollection * KopeteContact::contactActions()
+	// This should perhaps be KActionCollection * Contact::contactActions()
 	// to avoid passing around KPopupMenu's (Jason)
 	//
-	// KActionCollections are bad for popup menus because they are unordered.
-	// in fact, I think customContextMenuActions should be remade into a popupmenu,
-	// or a QPtrList<KAction>, or something that has a notion of order, because
-	// currently the customContextMenuActions do not return in the order they are
-	// added, which makes for a mess when you want certain things at the top and
-	// others later on.
 
 	// Build the menu
 	KPopupMenu *menu = new KPopupMenu();
 
-	// Initialize the context menu
-	d->actionChat        = KopeteStdAction::chat( this,        SLOT( startChat() ),             menu, "actionChat" );
-	d->actionSendFile    = KopeteStdAction::sendFile( this,    SLOT( sendFile() ),              menu, "actionSendFile" );
-	d->actionUserInfo    = KopeteStdAction::contactInfo( this, SLOT( slotUserInfo() ),          menu, "actionUserInfo" );
-	d->actionSendMessage = KopeteStdAction::sendMessage( this, SLOT( sendMessage() ),           menu, "actionSendMessage" );
-	d->actionDeleteContact = KopeteStdAction::deleteContact( this, SLOT( slotDeleteContact() ), menu, "actionDeleteContact" );
-	d->actionChangeMetaContact = KopeteStdAction::changeMetaContact( this, SLOT( slotChangeMetaContact() ), menu, "actionChangeMetaContact" );
-	d->actionAddContact = new KAction( i18n( "&Add to Your Contact List" ), QString::fromLatin1( "bookmark_add" ), 0,
-		this, SLOT( slotAddContact() ), menu, "actionAddContact" );
-
-	// FIXME: After KDE 3.2 we should make isReachable do the isConnected call so it can be removed here - Martijn
-	bool reach = isReachable() && d->account->isConnected(); // save calling a method several times
-	d->actionChat->setEnabled( reach );
-	d->actionSendFile->setEnabled( reach && d->fileCapable );
-	d->actionSendMessage->setEnabled( reach );
-
+	// insert title
 	QString titleText;
-
 	QString nick = property( Kopete::Global::Properties::self()->nickName() ).value().toString();
 	if( nick.isEmpty() )
-		titleText = QString::fromLatin1( "%1 (%2)" ).arg( contactId(), d->onlineStatus.description() );
+		titleText = QString::fromLatin1( "%1 (%2)" ).arg( contactId(), onlineStatus().description() );
 	else
-		titleText = QString::fromLatin1( "%1 <%2> (%3)" ).arg( nick, contactId(), d->onlineStatus.description() );
-
+		titleText = QString::fromLatin1( "%1 <%2> (%3)" ).arg( nick, contactId(), onlineStatus().description() );
 	menu->insertTitle( titleText );
 
-	if( metaContact() && metaContact()->isTemporary() )
+	if( metaContact() && metaContact()->isTemporary() && contactId() != account()->myself()->contactId() )
 	{
-		d->actionAddContact->plug( menu );
+		KAction *actionAddContact = new KAction( i18n( "&Add to Your Contact List" ), QString::fromLatin1( "bookmark_add" ),
+		                                         0, this, SLOT( slotAddContact() ), menu, "actionAddContact" );
+		actionAddContact->plug( menu );
 		menu->insertSeparator();
 	}
 
-	d->actionSendMessage->plug( menu );
-	d->actionChat->plug( menu );
-	d->actionSendFile->plug( menu );
+	// FIXME: After KDE 3.2 we should make isReachable do the isConnected call so it can be removed here - Martijn
+	bool reach = account()->isConnected() && isReachable();
+	bool myself = (this == account()->myself());
+
+	KAction *actionSendMessage = KopeteStdAction::sendMessage( this, SLOT( sendMessage() ), menu, "actionSendMessage" );
+	actionSendMessage->setEnabled( reach && !myself );
+	actionSendMessage->plug( menu );
+
+	KAction *actionChat = KopeteStdAction::chat( this, SLOT( startChat() ), menu, "actionChat" );
+	actionChat->setEnabled( reach && !myself );
+	actionChat->plug( menu );
+
+	KAction *actionSendFile = KopeteStdAction::sendFile( this, SLOT( sendFile() ), menu, "actionSendFile" );
+	actionSendFile->setEnabled( reach && d->fileCapable && !myself );
+	actionSendFile->plug( menu );
 
 	// Protocol specific options will go below this separator
 	// through the use of the customContextMenuActions() function
 
 	// Get the custom actions from the protocols ( pure virtual function )
 	QPtrList<KAction> *customActions = customContextMenuActions( manager );
-	if( customActions )
+	if( customActions && !customActions->isEmpty() )
 	{
-		if ( !customActions->isEmpty() )
-		{
-			menu->insertSeparator();
+		menu->insertSeparator();
 
-			for( KAction *a = customActions->first(); a; a = customActions->next() )
-				a->plug( menu );
-		}
+		for( KAction *a = customActions->first(); a; a = customActions->next() )
+			a->plug( menu );
 	}
-
 	delete customActions;
 
 	menu->insertSeparator();
-	if( metaContact() && !metaContact()->isTemporary() )
-		d->actionChangeMetaContact->plug( menu );
-
-	d->actionUserInfo->plug( menu );
 
 	if( metaContact() && !metaContact()->isTemporary() )
-	{
-		d->actionDeleteContact->plug( menu );
-	}
+		KopeteStdAction::changeMetaContact( this, SLOT( changeMetaContact() ), menu, "actionChangeMetaContact" )->plug( menu );
+
+	KopeteStdAction::contactInfo( this, SLOT( slotUserInfo() ), menu, "actionUserInfo" )->plug( menu );
+
+#if 0 //this is not fully implemented yet (and doesn't work).  disable for now   - Olivier 2005-01-11
+	if ( account()->isBlocked( d->contactId ) )
+		KopeteStdAction::unblockContact( this, SLOT( slotUnblock() ), menu, "actionUnblockContact" )->plug( menu );
+	else
+		KopeteStdAction::blockContact( this, SLOT( slotBlock() ), menu, "actionBlockContact" )->plug( menu );
+#endif
+
+	if( metaContact() && !metaContact()->isTemporary() )
+		KopeteStdAction::deleteContact( this, SLOT( slotDelete() ), menu, "actionDeleteContact" )->plug( menu );
 
 	return menu;
 }
 
-void KopeteContact::slotChangeMetaContact()
+void Contact::changeMetaContact()
 {
 	KDialogBase *moveDialog = new KDialogBase( Kopete::UI::Global::mainWidget(), "moveDialog", true, i18n( "Move Contact" ),
 		KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, true );
 
 	QVBox *w = new QVBox( moveDialog );
 	w->setSpacing( 8 );
-	new QLabel( i18n( "Select the meta contact to which you want to move this contact" ), w );
+        new QLabel( i18n( "Select the meta contact to which you want to move this contact:" ), w );
 	KListView *selectMetaContactListBox = new KListView ( w, "selectMetaContactListBox" );
 	selectMetaContactListBox->addColumn( i18n( "Display Name" ) );
 	selectMetaContactListBox->addColumn( i18n( "Contact IDs" ) );
 
-	QMap<QListViewItem*,KopeteMetaContact*> map;
-	QPtrList<KopeteMetaContact> metaContacts = KopeteContactList::contactList()->metaContacts();
-	for( KopeteMetaContact *mc = metaContacts.first(); mc ; mc = metaContacts.next() )
+	QMap<QListViewItem*,MetaContact*> map;
+	QPtrList<MetaContact> metaContacts = ContactList::self()->metaContacts();
+	for( MetaContact *mc = metaContacts.first(); mc ; mc = metaContacts.next() )
 	{
 		if( !mc->isTemporary() && mc != metaContact() )
 		{
 			QString t;
 			bool f=true;
-			QPtrList<KopeteContact> contacts = mc->contacts();
-			for( KopeteContact *c = contacts.first(); c ; c = contacts.next() )
+			QPtrList<Contact> contacts = mc->contacts();
+			for( Contact *c = contacts.first(); c ; c = contacts.next() )
 			{
 				if( !f )
 					t += QString::fromLatin1( " ; " );
@@ -323,11 +302,11 @@ void KopeteContact::slotChangeMetaContact()
 	moveDialog->setMainWidget( w );
 	if( moveDialog->exec() == QDialog::Accepted )
 	{
-		KopeteMetaContact *mc = map[selectMetaContactListBox->currentItem()];
+		Kopete::MetaContact *mc = map[selectMetaContactListBox->currentItem()];
 		if(chkCreateNew->isChecked())
 		{
-			mc=new KopeteMetaContact();
-			KopeteContactList::contactList()->addMetaContact(mc);
+			mc=new Kopete::MetaContact();
+			Kopete::ContactList::self()->addMetaContact(mc);
 		}
 		if( mc )
 		{
@@ -338,16 +317,16 @@ void KopeteContact::slotChangeMetaContact()
 	moveDialog->deleteLater();
 }
 
-void KopeteContact::setMetaContact( KopeteMetaContact *m )
+void Contact::setMetaContact( MetaContact *m )
 {
-	KopeteMetaContact *old = d->metaContact;
+	MetaContact *old = d->metaContact;
 	if(old==m) //that make no sens
 		return;
 
 	if( old )
 	{
 		int result=KMessageBox::No;
-		if( old->isTemporary() ) 
+		if( old->isTemporary() )
 			result=KMessageBox::Yes;
 		else if( old->contacts().count()==1 )
 		{ //only one contact, including this one, that mean the contact will be empty efter the move
@@ -355,21 +334,17 @@ void KopeteContact::setMetaContact( KopeteMetaContact *m )
 				"`%3' will be empty afterwards. Do you want to delete this contact?" )
 					.arg(contactId(), m ? m->displayName() : QString::null, old->displayName())
 				, i18n( "Move Contact" ), i18n( "&Delete" ) , i18n( "&Keep" ) , QString::fromLatin1("delete_old_contact_when_move") );
-
 			if(result==KMessageBox::Cancel)
 				return;
 		}
-
-		old->removeKABC();
 		old->removeContact( this );
-		disconnect( old, SIGNAL( aboutToSave( KopeteMetaContact * ) ),
-			protocol(), SLOT( slotMetaContactAboutToSave( KopeteMetaContact * ) ) );
-		old->updateKABC();
+		disconnect( old, SIGNAL( aboutToSave( Kopete::MetaContact * ) ),
+			protocol(), SLOT( slotMetaContactAboutToSave( Kopete::MetaContact * ) ) );
 
 		if(result==KMessageBox::Yes)
 		{
 			//remove the old metacontact.  (this delete the MC)
-			KopeteContactList::contactList()->removeMetaContact(old);
+			ContactList::self()->removeMetaContact(old);
 		}
 		else
 		{
@@ -385,21 +360,23 @@ void KopeteContact::setMetaContact( KopeteMetaContact *m )
 	{
 		m->addContact( this );
 		m->insertChild( this );
-
-		connect( d->metaContact, SIGNAL( aboutToSave( KopeteMetaContact * ) ),
-		protocol(), SLOT( slotMetaContactAboutToSave( KopeteMetaContact * ) ) );
-		m->updateKABC();
+		// it is necessary to call this write here, because MetaContact::addContact() does not differentiate
+		// between adding completely new contacts (which should be written to kabc) and restoring upon restart
+		// (where no write is needed).
+		KABCPersistence::self()->write( m );
+		connect( d->metaContact, SIGNAL( aboutToSave( Kopete::MetaContact * ) ),
+		protocol(), SLOT( slotMetaContactAboutToSave( Kopete::MetaContact * ) ) );
 	}
-	syncGroups();
+	sync();
 }
 
-void KopeteContact::serialize( QMap<QString, QString> &/*serializedData*/,
+void Contact::serialize( QMap<QString, QString> &/*serializedData*/,
 	QMap<QString, QString> & /* addressBookData */ )
 {
 }
 
 
-void KopeteContact::serializeProperties(QMap<QString, QString> &serializedData)
+void Contact::serializeProperties(QMap<QString, QString> &serializedData)
 {
 
 	Kopete::ContactProperty::Map::ConstIterator it;// = d->properties.ConstIterator;
@@ -416,7 +393,7 @@ void KopeteContact::serializeProperties(QMap<QString, QString> &serializedData)
 	} // end for()
 } // end serializeProperties()
 
-void KopeteContact::deserializeProperties(
+void Contact::deserializeProperties(
 	QMap<QString, QString> &serializedData )
 {
 	QMap<QString, QString>::ConstIterator it;
@@ -456,42 +433,36 @@ void KopeteContact::deserializeProperties(
 }
 
 
-bool KopeteContact::isReachable()
+bool Contact::isReachable()
 {
 	// The default implementation returns false when offline and true
 	// otherwise. Subclass if you need more control over the process.
-	return onlineStatus().status() != KopeteOnlineStatus::Offline;
+	return onlineStatus().status() != OnlineStatus::Offline;
 }
 
-void KopeteContact::startChat()
+
+void Contact::startChat()
 {
-	KopeteView *v=manager(true)->view(true, KopeteMessage::Chat );
+	KopeteView *v=manager( CanCreate )->view(true, QString::fromLatin1("kopete_chatwindow") );
 	if(v)
 		v->raise(true);
 }
 
-void KopeteContact::sendMessage()
+void Contact::sendMessage()
 {
-	KopeteView *v=manager(true)->view(true, KopeteMessage::Email );
+	KopeteView *v=manager( CanCreate )->view(true, QString::fromLatin1("kopete_emailwindow") );
 	if(v)
 		v->raise(true);
 }
 
-void KopeteContact::execute()
+void Contact::execute()
 {
 	// FIXME: After KDE 3.2 remove the isConnected check and move it to isReachable - Martijn
 	if ( account()->isConnected() && isReachable() )
 	{
-		switch ( KopetePrefs::prefs()->interfacePreference() )
-		{
-			case KopetePrefs::EmailWindow:
-				sendMessage();
-				break;
-			case KopetePrefs::ChatWindow:
-			default:
-				startChat();
-				break;
-		}
+		KopeteView *v=manager( CanCreate )->view(true, KopetePrefs::prefs()->interfacePreference() );
+		if(v)
+			v->raise(true);
 	}
 	else
 	{
@@ -501,69 +472,96 @@ void KopeteContact::execute()
 	}
 }
 
-void KopeteContact::slotDeleteContact()
+void Contact::slotDelete()
+{
+	if ( KMessageBox::warningContinueCancel( Kopete::UI::Global::mainWidget(),
+		i18n( "Are you sure you want to remove the contact  '%1' from your contact list?" ).
+		arg( d->contactId ), i18n( "Remove Contact" ), KGuiItem(i18n("Remove"), QString::fromLatin1("editdelete") ) )
+		== KMessageBox::Continue )
+	{
+		deleteContact();
+	}
+}
+
+void Contact::deleteContact()
 {
 	// Default implementation simply deletes the contact
 	deleteLater();
 }
 
-void KopeteContact::slotUserInfo()
-{
-	// Default implementation does nothing
-}
 
-bool KopeteContact::isOnline() const
-{
-	return (d->onlineStatus.status() != KopeteOnlineStatus::Offline) &&
-		(d->onlineStatus.status() != KopeteOnlineStatus::Unknown);
-}
-
-KopeteMetaContact * KopeteContact::metaContact() const
+MetaContact * Contact::metaContact() const
 {
 	return d->metaContact;
 }
 
-QString KopeteContact::contactId() const
+QString Contact::contactId() const
 {
 	return d->contactId;
 }
 
-KopeteProtocol * KopeteContact::protocol() const
+Protocol * Contact::protocol() const
 {
 	return d->account ? d->account->protocol() : 0L;
 }
 
-KopeteAccount * KopeteContact::account() const
+Account * Contact::account() const
 {
 	return d->account;
 }
 
-QPtrList<KAction> *KopeteContact::customContextMenuActions()
+
+
+void Contact::sync(unsigned int)
+{
+	/* Default implementation does nothing */
+}
+
+QString& Contact::icon() const
+{
+	return d->icon;
+}
+
+void Contact::setIcon( const QString& icon )
+{
+	d->icon = icon;
+	return;
+}
+
+QPtrList<KAction> *Contact::customContextMenuActions()
 {
 	return 0L;
 }
 
-QPtrList<KAction> *KopeteContact::customContextMenuActions( KopeteMessageManager * /* manager */ )
+QPtrList<KAction> *Contact::customContextMenuActions( ChatSession * /* manager */ )
 {
 	return customContextMenuActions();
 }
 
-bool KopeteContact::isFileCapable() const
+
+bool Contact::isOnline() const
+{
+	return onlineStatus().isDefinitelyOnline();
+}
+
+
+bool Contact::isFileCapable() const
 {
 	return d->fileCapable;
 }
 
-void KopeteContact::setFileCapable( bool filecap )
+void Contact::setFileCapable( bool filecap )
 {
 	d->fileCapable = filecap;
 }
 
-bool KopeteContact::canAcceptFiles() const
+
+bool Contact::canAcceptFiles() const
 {
 	return isOnline() && d->fileCapable;
 }
 
-unsigned long int KopeteContact::idleTime() const
+unsigned long int Contact::idleTime() const
 {
 	if(d->idleTime==0)
 		return 0;
@@ -571,42 +569,28 @@ unsigned long int KopeteContact::idleTime() const
 	return d->idleTime+(d->idleTimer.elapsed()/1000);
 }
 
-void KopeteContact::setIdleTime( unsigned long int t )
+void Contact::setIdleTime( unsigned long int t )
 {
 	d->idleTime=t;
 	if(t > 0)
 		d->idleTimer.start();
+	//FIXME: if t == 0, idleTime() will now return garbage
 //	else
 //		d->idleTimer.stop();
 }
 
-void KopeteContact::syncGroups()
-{
-	/* Default implementation does nothing */
-}
 
-QString& KopeteContact::icon() const
-{
-	return d->icon;
-}
-
-void KopeteContact::setIcon( const QString& icon )
-{
-	d->icon = icon;
-	return;
-}
-
-QStringList KopeteContact::properties() const
+QStringList Contact::properties() const
 {
 	return d->properties.keys();
 }
 
-bool KopeteContact::hasProperty(const QString &key) const
+bool Contact::hasProperty(const QString &key) const
 {
 	return d->properties.contains(key);
 }
 
-const Kopete::ContactProperty &KopeteContact::property(const QString &key) const
+const ContactProperty &Contact::property(const QString &key) const
 {
 	if(hasProperty(key))
 		return d->properties[key];
@@ -614,7 +598,7 @@ const Kopete::ContactProperty &KopeteContact::property(const QString &key) const
 		return Kopete::ContactProperty::null;
 }
 
-const Kopete::ContactProperty &KopeteContact::property(
+const Kopete::ContactProperty &Contact::property(
 	const Kopete::ContactPropertyTmpl &tmpl) const
 {
 	if(hasProperty(tmpl.key()))
@@ -624,7 +608,7 @@ const Kopete::ContactProperty &KopeteContact::property(
 }
 
 
-void KopeteContact::setProperty(const Kopete::ContactPropertyTmpl &tmpl,
+void Contact::setProperty(const Kopete::ContactPropertyTmpl &tmpl,
 	const QVariant &value)
 {
 	if(tmpl.isNull() || tmpl.key().isEmpty())
@@ -649,7 +633,7 @@ void KopeteContact::setProperty(const Kopete::ContactPropertyTmpl &tmpl,
 	}
 }
 
-void KopeteContact::removeProperty(const Kopete::ContactPropertyTmpl &tmpl)
+void Contact::removeProperty(const Kopete::ContactPropertyTmpl &tmpl)
 {
 	if(!tmpl.isNull() && !tmpl.key().isEmpty())
 	{
@@ -661,7 +645,7 @@ void KopeteContact::removeProperty(const Kopete::ContactPropertyTmpl &tmpl)
 }
 
 
-QString KopeteContact::toolTip() const
+QString Contact::toolTip() const
 {
 	Kopete::ContactProperty p;
 	QString tip;
@@ -681,16 +665,16 @@ QString KopeteContact::toolTip() const
 	{
 		tip = i18n( "<b>DISPLAY NAME</b><br><img src=\"%2\">&nbsp;CONTACT STATUS",
 			"<b><nobr>%3</nobr></b><br><img src=\"%2\">&nbsp;%1" ).
-			arg( KopeteMessage::escape( onlineStatus().description() ), iconName,
-				KopeteMessage::escape( d->contactId ) );
+			arg( Kopete::Message::escape( onlineStatus().description() ), iconName,
+				Kopete::Message::escape( d->contactId ) );
 	}
 	else
 	{
 		tip = i18n( "<b>DISPLAY NAME</b> (CONTACT ID)<br><img src=\"%2\">&nbsp;CONTACT STATUS",
 			"<nobr><b>%4</b> (%3)</nobr><br><img src=\"%2\">&nbsp;%1" ).
-				arg( KopeteMessage::escape( onlineStatus().description() ), iconName,
-					KopeteMessage::escape( contactId() ),
-					KopeteMessage::escape( nick ) );
+				arg( Kopete::Message::escape( onlineStatus().description() ), iconName,
+					Kopete::Message::escape( contactId() ),
+					Kopete::Message::escape( nick ) );
 	}
 
 	// --------------------------------------------------------------------------
@@ -723,7 +707,7 @@ QString KopeteContact::toolTip() const
 			{
 				tip += i18n("<br><b>Home Page:</b>&nbsp;FORMATTED URL",
 					"<br><b>Home Page:</b>&nbsp;<a href=\"%1\"><nobr>%2</nobr></a>").
-					arg( KURL::encode_string( url ), KopeteMessage::escape( url ) );
+					arg( KURL::encode_string( url ), Kopete::Message::escape( url ) );
 			}
 		}
 		else if ((*it) == QString::fromLatin1("awayMessage"))
@@ -758,7 +742,7 @@ QString KopeteContact::toolTip() const
 						if( p.isRichText() )
 							valueText = val.toString();
 						else
-							valueText = KopeteMessage::escape( val.toString() );
+							valueText = Kopete::Message::escape( val.toString() );
 				}
 
 				tip += i18n("<br><b>PROPERTY LABEL:</b>&nbsp;PROPERTY VALUE",
@@ -771,8 +755,11 @@ QString KopeteContact::toolTip() const
 	return tip;
 }
 
-QString KopeteContact::formattedName() const
+QString Kopete::Contact::formattedName() const
 {
+	if( hasProperty(QString::fromLatin1("FormattedName")) )
+		return property(QString::fromLatin1("FormattedName")).value().toString();
+
 	QString ret;
 	Kopete::ContactProperty first, last;
 
@@ -799,7 +786,7 @@ QString KopeteContact::formattedName() const
 	return ret;
 }
 
-QString KopeteContact::formattedIdleTime() const
+QString Kopete::Contact::formattedIdleTime() const
 {
 	QString ret;
 	unsigned long int leftTime = idleTime();
@@ -841,5 +828,42 @@ QString KopeteContact::formattedIdleTime() const
 	return ret;
 }
 
+
+void Kopete::Contact::slotBlock()
+{
+	account()->block( d->contactId );
+}
+
+void Kopete::Contact::slotUnblock()
+{
+	account()->unblock( d->contactId );
+}
+
+void Kopete::Contact::setNickName( const QString &name )
+{
+	QString nick = property( Kopete::Global::Properties::self()->nickName() ).value().toString();
+	if( name == nick )
+		return;
+
+	setProperty( Kopete::Global::Properties::self()->nickName(), name );
+}
+
+QString Kopete::Contact::nickName() const
+{
+	QString nick = property( Kopete::Global::Properties::self()->nickName() ).value().toString();
+	if( !nick.isEmpty() )
+		return nick;
+
+	return contactId();
+}
+
+void Contact::virtual_hook( uint , void * )
+{ }
+
+
+} //END namespace Kopete
+
+
 #include "kopetecontact.moc"
-// vim: set noet ts=4 sts=4 sw=4:
+
+
