@@ -1,9 +1,9 @@
 /*
     kopetecontact.h - Kopete Contact
 
-    Copyright (c) 2002      by Duncan Mac-Vicar Prett <duncan@kde.org>
+    Copyright (c) 2002-2004 by Duncan Mac-Vicar Prett <duncan@kde.org>
     Copyright (c) 2002-2003 by Martijn Klingens       <klingens@kde.org>
-    Copyright (c) 2002-2003 by Olivier Goffart        <ogoffart@tiscalinet.be>
+    Copyright (c) 2002-2004 by Olivier Goffart        <ogoffart @ tiscalinet.be>
 
     Kopete    (c) 2002-2004 by the Kopete developers  <kopete-devel@kde.org>
 
@@ -21,54 +21,58 @@
 #define __KOPETECONTACT_H__
 
 #include <qobject.h>
-#include <qstringlist.h>
-#include <qvariant.h>
 #include <kurl.h>
-#include <qvaluelist.h>
+#include <kdemacros.h>
+#include "kopeteglobal.h"
 
-#include "kopetecontactproperty.h"
-
-struct KopeteContactPrivate;
+#include <kopete_export.h>
 
+class QImage;
 class KPopupMenu;
-class KURL;
 class KAction;
-class KopeteGroup;
-class KopeteMetaContact;
-class KopeteMessageManager;
-class KopeteOnlineStatus;
-class KopetePlugin;
-class KopeteProtocol;
-class KopeteAccount;
-typedef QPtrList<KopeteGroup> KopeteGroupList;
+
+namespace Kopete
+{
+
+class Group;
+class MetaContact;
+class ChatSession;
+class OnlineStatus;
+class Plugin;
+class Protocol;
+class Account;
+typedef QPtrList<Group> GroupList;
 
 /**
  * @author Duncan Mac-Vicar P. <duncan@kde.org>
  * @author Martijn Klingens <klingens@kde.org>
- * @author Olivier Goffart <ogoffart@tiscalinet.be>
+ * @author Olivier Goffart <ogoffart@ tiscalinet.be>
  *
  * This class abstracts a generic contact
  * Use it for inserting contacts in the contact list for example.
  */
-class KopeteContact : public QObject
+class KOPETE_EXPORT Contact : public QObject
 {
 	Q_OBJECT
 
-	//Q_PROPERTY( QString displayName READ displayName )
+	Q_ENUMS( CanCreateFlags )
 	Q_PROPERTY( QString formattedName READ formattedName )
 	Q_PROPERTY( QString formattedIdleTime READ formattedIdleTime )
 	Q_PROPERTY( bool isOnline READ isOnline )
-	Q_PROPERTY( bool isFileCapable READ isFileCapable )
+	Q_PROPERTY( bool fileCapable READ isFileCapable WRITE setFileCapable )
 	Q_PROPERTY( bool canAcceptFiles READ canAcceptFiles )
+	//Q_PROPERTY( bool isReachable READ isReachable )
 	Q_PROPERTY( QString contactId READ contactId )
-	Q_PROPERTY( QString icon READ icon )
+	Q_PROPERTY( QString icon READ icon WRITE setIcon )
 	Q_PROPERTY( QString toolTip READ toolTip )
+	Q_PROPERTY( QString nickName READ nickName WRITE setNickName )
+	//Q_PROPERTY( unsigned long idleTime READ idleTime WRITE setIdleTime )
 
 public:
 	/**
 	 * \brief Create new contact.
 	 *
-	 * <b>The parent KopeteMetaContact must not be NULL</b>
+	 * <b>The parent MetaContact must not be NULL</b>
 	 *
 	 * \note id is required to be unique per protocol and per account.
 	 * Across those boundaries ids may occur multiple times.
@@ -78,19 +82,66 @@ public:
 	 * this is undefined and may change at any time!
 	 *
 	 * @param account is the parent account. this constructor automatically register the contact to the account
-	 * @param id is the KopeteContact's unique Id (mostly the user's login)
-	 * @param parent is the parent @ref KopeteMetaContact this KopeteContact is part of
+	 * @param id is the Contact's unique Id (mostly the user's login)
+	 * @param parent is the parent @ref MetaContact this Contact is part of
 	 * @param icon is an optional icon
 	 */
-	KopeteContact( KopeteAccount *account, const QString &id, KopeteMetaContact *parent,
+	Contact( Account *account, const QString &id, MetaContact *parent,
 		const QString &icon = QString::null );
 
-	~KopeteContact();
+	~Contact();
 
 	/**
-	 * \brief Get whether this contact is online
-	 * @return true if the contact is online
-	 * @return false if the contact is not online
+	 * \brief Get the metacontact for this contact
+	 * @return The MetaContact object for this contact
+	 */
+	MetaContact *metaContact() const;
+
+
+	/**
+	 * \brief Get the unique id that identifies a contact.
+	 *
+	 * \note Id is required to be unique per protocol and per account.
+	 * Across those boundaries ids may occur multiple times.
+	 * The id is solely for comparing items safely (using pointers is
+	 * more crash-prone). DO NOT assume anything regarding the id's
+	 * value! Even if it may look like an ICQ UIN or an MSN passport,
+	 * this is undefined and may change at any time!
+	 *
+	 * @return The unique id of the contact
+	 */
+	QString contactId() const;
+
+	/**
+	 * \brief Get the protocol that the contact belongs to.
+	 *
+	 * simply return account()->protocol()
+	 *
+	 * @return the contact's protocol
+	 */
+	Protocol* protocol() const;
+
+	/**
+	 * \brief Get the account that this contact belongs to
+	 *
+	 * @return the Account object for this contact
+	 */
+	Account* account() const;
+
+	/**
+	 * \brief Move this contact to a new MetaContact.
+	 * This basically reparents the contact and updates the internal
+	 * data structures.
+	 * If the old contact is going to be empty, a question may ask to the user if it wants to delete the old contact.
+	 *
+	 * @param m The new MetaContact to move this contact to
+	 */
+	void setMetaContact(MetaContact *m);
+
+
+	/**
+	 * @brief Get whether this contact is online.
+	 * @return @c true if the contact is online, @c false otherwise.
 	 */
 	bool isOnline() const;
 
@@ -107,14 +158,10 @@ public:
 	//        isReachable() accessor that checks for account->isConnected()
 	//        and then calls a new virtual method that does the
 	//        protocol-specific work, like 'doIsUnreachable' or so - Martijn
+	//
+	//FIXME: Can this be made const please? - JK
 	virtual bool isReachable();
 
-	/**
-	 * \brief Get the metacontact for this contact
-	 * @return The KopeteMetaContact object for this contact
-	 */
-	KopeteMetaContact *metaContact() const;
-
 	/**
 	 * @brief Serialize the contact for storage in the contact list.
 	 *
@@ -129,11 +176,11 @@ public:
 	 * 'nothing to save'.
 	 *
 	 * The provided addressBookFields QMap contains the index field as
-	 * marked with @ref KopetePlugin::addAddressBookField() with the
+	 * marked with @ref Plugin::addAddressBookField() with the
 	 * contact id as value. If no index field is available the QMap is
 	 * simply passed as an empty map.
 	 *
-	 * @sa KopeteProtocol::deserializeContact
+	 * @sa Protocol::deserializeContact
 	 */
 	virtual void serialize( QMap<QString, QString> &serializedData, QMap<QString, QString> &addressBookData );
 
@@ -152,58 +199,16 @@ public:
 	 */
 	void deserializeProperties(QMap<QString, QString> &serializedData);
 
-	/**
-	 * \brief Get the current display name
-	 * @return The display name
-	 * @deprecated  Use the nickname property instead
-	 */
-	QString displayName() const KDE_DEPRECATED;
-
 	/**
 	 * @brief Get the online status of the contact
 	 * @return the online status of the contact
 	 */
-	const KopeteOnlineStatus& onlineStatus() const;
+	OnlineStatus onlineStatus() const;
 
 	/**
 	 * \brief Set the contact's online status
 	 */
-	void setOnlineStatus(const KopeteOnlineStatus &status);
-
-	/**
-	 * \brief Get the unique id that identifies a contact.
-	 *
-	 * \note Id is required to be unique per protocol and per account.
-	 * Across those boundaries ids may occur multiple times.
-	 * The id is solely for comparing items safely (using pointers is
-	 * more crash-prone). DO NOT assume anything regarding the id's
-	 * value! Even if it may look like an ICQ UIN or an MSN passport,
-	 * this is undefined and may change at any time!
-	 *
-	 * @return The unique id of the contact
-	 */
-	QString contactId() const;
-
-	/**
-	 * \brief Get the protocol that the contact belongs to.
-	 *
-	 * \note Id is required to be unique per protocol and per account.
-	 * Across those boundaries ids may occur multiple times.
-	 * The id is solely for comparing items safely (using pointers is
-	 * more crash-prone). DO NOT assume anything regarding the id's
-	 * value! Even if it may look like an ICQ UIN or an MSN passport,
-	 * this is undefined and may change at any time!
-	 *
-	 * @return the contact's protocol
-	 */
-	KopeteProtocol* protocol() const;
-
-	/**
-	 * \brief Get the account that this contact belongs to
-	 *
-	 * @return the KopeteAccount object for this contact
-	 */
-	KopeteAccount* account() const;
+	void setOnlineStatus(const OnlineStatus &status);
 
 	/**
 	 * \brief Get the set of custom menu items for this contact
@@ -215,9 +220,14 @@ public:
 	 * Actions should have the collection as parent.
 	 *
 	 * @return Collection of menu items to be show on the context menu
+	 * @todo if possible, try to use KXMLGUI
 	 */
 	virtual QPtrList<KAction> *customContextMenuActions();
-	virtual QPtrList<KAction> *customContextMenuActions( KopeteMessageManager *manager );
+
+	/**
+	 * @todo  What is this function for ?
+	 */
+	virtual QPtrList<KAction> *customContextMenuActions( ChatSession *manager );
 
 	/**
 	 * @brief Get the Context Menu for this contact
@@ -225,17 +235,7 @@ public:
 	 * This menu includes generic actions common to each protocol, and action defined in
 	 * @ref customContextMenuActions()
 	 */
-	KPopupMenu *popupMenu( KopeteMessageManager *manager = 0L );
-
-	/**
-	 * \brief Move this contact to a new MetaContact.
-	 * This basically reparents the contact and updates the internal
-	 * data structures.
-	 * If the old contact is going to be empty, a question may ask to the user if it wants to delete the old contact.
-	 *
-	 * @param m The new MetaContact to move this contact to
-	 */
-	void setMetaContact(KopeteMetaContact *m);
+	KPopupMenu *popupMenu( ChatSession *manager = 0L );
 
 	/**
 	 * \brief Get whether or not this contact is capable of file transfers
@@ -244,6 +244,8 @@ public:
 	 * \see setFileCapable()
 	 * \return true if the protocol for this contact is capable of file transfers
 	 * \return false if the protocol for this contact is not capable of file transfers
+	 *
+	 * @todo have a capabilioties. or move to protocol capabilities
 	 */
 	bool isFileCapable() const;
 
@@ -251,6 +253,7 @@ public:
 	 * \brief Set the file transfer capability of this contact
 	 *
 	 * \param filecap The new file transfer capability setting
+	 * @todo have a capabilioties. or move to protocol capabilities
 	 */
 	void setFileCapable( bool filecap );
 
@@ -261,19 +264,11 @@ public:
 	 * capable of sending files.
 	 * \see isReachable()
 	 * @return true if this contact is online and is capable of receiving files
-	 * \return false if this contact is not capable of receiving files
+	 * @todo have a capabilioties. or move to protocol capabilities
 	 */
 	bool canAcceptFiles() const;
 
-    /**
-	 * @brief Rename a contact's display name.
-	 *
-	 * The default implementation calls @ref setDisplayName() immediately.
-	 *
-	 * @deprecated if you want to rename the alias on the server, use syncGroups()
-	 */
-	virtual void rename( const QString &newName ) KDE_DEPRECATED;
-
+	enum CanCreateFlags {  CannotCreate=false , CanCreate=true  };
 
 	/**
 	 * Returns the primary message manager affiliated with this contact
@@ -286,18 +281,33 @@ public:
 	 * to any existing managers. Currently, this is only set to true when
 	 * a chat is initiated by the user by clicking the contact list.
 	 */
-	virtual KopeteMessageManager * manager( bool canCreate = false ) =0;
+	virtual ChatSession * manager( CanCreateFlags canCreate = CannotCreate ) =0;
 
 	/**
 	 * Returns the name of the icon to use for this contact
+	 *  If null, the protocol icon need to be used.
+	 * The icon is not colored, nor has the status icon overloaded
 	 */
-	virtual QString& icon() const;
+	QString& icon() const;
+
+	/**
+	 * @brief Change the icon to use for this contact
+	 * If you don't want to have the protocol icon as icon for this contact, you may set
+	 * another icon.  The icon doesn't need to be colored with the account icon as this operation
+	 * will be performed later.
+	 *
+	 * if you want to go back to the protocol icon, set a null string.
+	 */
+	void setIcon( const QString& icon );
 
 	/**
 	 * \brief Get the time (in seconds) this contact has been idle
 	 * It will return the time set in @ref setIdleTime() with an addition of the time
 	 * since you set this last time
 	 * @return time this contact has been idle for, in seconds
+	 //
+         // FIXME: Can we make this just 'unsigned long' ? QT Properties can't handle
+         // 'unsigned long int'
 	 */
 	virtual unsigned long int idleTime() const;
 
@@ -305,6 +315,9 @@ public:
 	 * \brief Set the current idle time in seconds.
 	 * Kopete will automatically calculate the time in @ref idleTime
 	 * except if you set 0.
+	 // 
+	 // FIXME: Can we make this just 'unsigned long' ? QT Properties can't handle
+	 // 'unsigned long int'
 	 */
 	void setIdleTime(unsigned long int);
 
@@ -345,6 +358,19 @@ public:
 	 **/
 	void setProperty(const Kopete::ContactPropertyTmpl &tmpl, const QVariant &value);
 
+        /**
+	 * \brief Convenience method to set the nickName property to the specified value
+	 * @param name The nickname to set
+	 */
+	void setNickName( const QString &name );
+
+	/**
+	 * \brief Convenience method to retrieve the nickName property.
+	 *
+	 * This method will return the contactId if there has been no nickName property set
+	 */
+	QString nickName() const;
+
 	/**
 	 * \brief Remove a property if it exists
 	 *
@@ -364,7 +390,7 @@ public:
 	 * if present.
 	 * Suitable for GUI display
 	 **/
-	virtual QString formattedName() const;
+	QString formattedName() const;
 
 	/**
 	 * Returns a formatted string of idleTime().
@@ -372,6 +398,14 @@ public:
 	 **/
 	QString formattedIdleTime() const;
 
+	/**
+	 * used in @ref sync()
+	 */
+	enum Changed{ MovedBetweenGroup = 0x01, ///< the contact has been moved between groups
+		      DisplayNameChanged = 0x02 ///< the displayname of the contact changed
+	};
+
+
 public slots:
 	/**
 	 * This should typically pop up a KopeteChatWindow
@@ -393,7 +427,29 @@ public slots:
 	 * is called by the KAction changeMetaContact that is part of the context
 	 * menu.
 	 */
-	void slotChangeMetaContact();
+	void changeMetaContact();
+
+	/**
+	 * Method to retrieve user information.  Should be implemented by
+	 * the protocols, and popup some sort of dialog box
+	 *
+	 * reimplement it to show the informlation
+	 * @todo rename and make it pure virtual
+	 */
+	virtual void slotUserInfo() {};
+
+	/**
+	 * @brief Syncronise the server and the metacontact.
+	 * Protocols with server-side contact lists can implement this to
+	 * sync the server groups with the metaContact groups. Or the server alias if any.
+	 *
+	 * This method is called every time the metacontact has been moved or renamed.
+	 *
+	 * default implementation does nothing
+	 *
+	 * @param changed is a bitmask of the @ref Changed enum which say why the call to this funtion is done.
+	 */
+	virtual void sync(unsigned int changed = 0xFF);
 
 	/**
 	 * Method to delete a contact from the contact list,
@@ -402,16 +458,10 @@ public slots:
 	 * (ie. messages to the server, etc)
 	 * the default implementation simply call deleteLater()
 	 */
-	virtual void slotDeleteContact();
+	virtual void deleteContact();
 
 	/**
-	 * Method to retrieve user information.  Should be implemented by
-	 * the protocols, and popup some sort of dialog box
-	 */
-	virtual void slotUserInfo();
-
-	/**
-	 * This is the KopeteContact level slot for sending files. It should be
+	 * This is the Contact level slot for sending files. It should be
 	 * implemented by all contacts which have the setFileCapable() flag set to
 	 * true. If the function is called through the GUI, no parameters are sent
 	 * and they take on default values (the file is chosen with a file open dialog)
@@ -424,34 +474,7 @@ public slots:
 	 *                file size (such as over  asocket
 	 */
 	virtual void sendFile( const KURL &sourceURL = KURL(),
-		const QString &fileName = QString::null, uint fileSize = 0L );
-
-	/**
-	 * @brief Syncronise the server and the metacontact.
-	 * Protocols with server-side contact lists can implement this to
-	 * sync the server groups with the metaContact groups. Or the server alias if any.
-	 *
-	 * This method is called every time the metacontact has been moved or renamed.
-	 *
-	 * default implementation does nothing
-	 *
-	 * @todo rename it to syncronise since it's not anymore only for groups.
-	 */
-	virtual void syncGroups();
-
-	/**
-	 * Change the icon to use for this contact
-	 */
-	void setIcon( const QString& icon );
-
-protected:
-	/**
-	 * Sets the display name, for the contact.
-	 * this is what is shown in the contact list.
-	 * @param name Then new display name
-	 * @deprecated use the nickname property
-	 */
-	void setDisplayName( const QString &name ) KDE_DEPRECATED;
+			       const QString &fileName = QString::null, uint fileSize = 0L );
 
 private slots:
 
@@ -460,29 +483,49 @@ private slots:
 	 */
 	void slotAddContact();
 
+	/**
+	 * slot called when the action "delete" is called.
+	 */
+	void slotDelete();
+
+	/**
+	 * slot called when the action "block" is called.
+	 */
+	void slotBlock();
+
+	/**
+	 * slot called when the action "unblock" is called.
+	 */
+	void slotUnblock();
+
+	/**
+	 * The account's isConnected has changed.
+	 */
+	void slotAccountIsConnectedChanged();
+
 signals:
 	/**
 	 * The contact's online status changed
 	 */
-	void onlineStatusChanged( KopeteContact *contact,
-		const KopeteOnlineStatus &status, const KopeteOnlineStatus &oldStatus );
+	void onlineStatusChanged( Kopete::Contact *contact,
+		const Kopete::OnlineStatus &status, const Kopete::OnlineStatus &oldStatus );
 
 	/**
 	 * The contact is about to be destroyed.
 	 * Called when entering the destructor. Useful for cleanup, since
 	 * metaContact() is still accessible at this point.
 	 *
-	 * @warning this signal is emit in the KopeteContact destructor, so all
+	 * @warning this signal is emit in the Contact destructor, so all
 	 * virtual method are not available
 	 */
-	void contactDestroyed( KopeteContact *contact );
+	void contactDestroyed( Kopete::Contact *contact );
 
 	/**
 	 * The contact's idle state changed.
 	 * You need to emit this signal to update the view.
 	 * That mean when activity has been noticed
 	 */
-	void idleStateChanged( KopeteContact *contact );
+	void idleStateChanged( Kopete::Contact *contact );
 
 	/**
 	 * One of the contact's properties has changed.
@@ -491,13 +534,57 @@ signals:
 	 * @param oldValue the value before the change, or an invalid QVariant if the property is new
 	 * @param newValue the value after the change, or an invalid QVariant if the property was removed
 	 */
-	void propertyChanged( KopeteContact *contact, const QString &key,
+	void propertyChanged( Kopete::Contact *contact, const QString &key,
 		const QVariant &oldValue, const QVariant &newValue );
 
+protected:
+	virtual void virtual_hook(uint id, void *data);
+
 private:
-	KopeteContactPrivate *d;
+	class Private;
+	Private *d;
+
+
+
+public:
+
+//MOC_SKIP_BEGIN//
+//(moc doesn't like the KDE_DEPRECATED macro)
+
+	/**
+	 * @todo remove
+	 * @deprecated  Use setNickName, or set the nickName property
+	 */
+	KDE_DEPRECATED void rename( const QString &name )
+	{
+		setNickName( name );
+	}
+
+	/**
+	 * @todo remove
+	 * @deprecated  Use setNickName, or set the nickName property
+	 */
+	KDE_DEPRECATED void setDisplayName( const QString &name )
+	{
+		setNickName( name );
+	}
+
+	/**
+	 * @todo remove
+	 * @deprecated  Use nickName, or get the nickName property
+	 */
+	KDE_DEPRECATED QString displayName() const
+	{
+		return nickName();
+	}
+
+//MOC_SKIP_END//
+
 };
 
+
+} //END namespace Kopete
+
 #endif
 
 // vim: set noet ts=4 sts=4 sw=4:
