@@ -16,24 +16,38 @@
     *************************************************************************
 */
 
-#ifndef __KOPETECONTACTLIST_H__
-#define __KOPETECONTACTLIST_H__
+#ifndef KOPETECONTACTLIST_H__
+#define KOPETECONTACTLIST_H__
 
 #include <qobject.h>
 #include <qptrlist.h>
 
-//#include <kurl.h>
-class KURL;
+#include <kopete_export.h>
 
+class KURL;
 class QDomDocument;
-class KopeteMetaContact;
-class KopeteGroup;
-class KopeteContact;
+
+
+namespace Kopete 
+{
+
+class MetaContact;
+class Group;
+class Contact;
+
 
 /**
+ * @brief manage contacts and metacontact
+ *
+ * The contactList is a singleton you can uses with @ref ContactList::self()
+ *
+ * it let you get a list of metacontact with @ref metaContacts()
+ * Only metacontact which are on the contactlist are returned.
+ *
  * @author Martijn Klingens <klingens@kde.org>
+ * @author Olivier Goffart <ogoffart @tiscalinet.be>
  */
-class KopeteContactList : public QObject
+class KOPETE_EXPORT ContactList : public QObject
 {
 	Q_OBJECT
 
@@ -42,188 +56,113 @@ public:
 	 * The contact list is a singleton object. Use this method to retrieve
 	 * the instance.
 	 */
-	static KopeteContactList *contactList();
-
-	~KopeteContactList();
-
-	/**
-	 * Find the meta contact that a given contact belongs to. If contact
-	 * is not found, null is returned.
-	 * For now, just compare the ID field.
-	 *
-	 * NOTE: Even though the new contact list generally doesn't require this
-	 *       method, it's not completely obsolete either, because protocols
-	 *       with server-side contact lists ( MSN, Jabber, etc. ) may detect
-	 *       new contacts having been added upon reconnect.
-	 */
-	KopeteMetaContact *findContact( const QString &protocolId,
-		const QString &accountId, const QString &contactId );
-
-
-	/**
-	 * Return the metacontact referenced by the given id
-	 */
-	KopeteMetaContact *metaContact( const QString &metaContactId ) const;
-
-	/**
-	 * Return all meta contacts
-	 */
-	QStringList contacts() const;
-
-	/**
-	 * Return all meta contacts that are reachable
-	 */
-	QStringList reachableContacts() const;
-
-	/**
-	 * Return all contacts that are online
-	 */
-	QPtrList<KopeteContact> onlineContacts() const;
-
-	/**
-	 * Overloaded method of @ref onlineContacts() that only returns
-	 * the online contacts for a single protocol
-	 */
-	QPtrList<KopeteContact> onlineContacts( const QString &protocolId ) const;
-
-	/**
-	 * Return all meta contacts that are online
-	 */
-	QPtrList<KopeteMetaContact> onlineMetaContacts() const;
-
-	/**
-	 * Overloaded method of @ref onlineMetaContacts() that only returns
-	 * the online meta contacts for a single protocol
-	 */
-	QPtrList<KopeteMetaContact> onlineMetaContacts( const QString &protocolId ) const;
-
-	/**
-	 * Returns all contacts which can accept file transfers
-	 */
-	QStringList fileTransferContacts() const;
-
-	QStringList contactFileProtocols( const QString &displayName);
-
-	/**
-	 * Return all meta contacts with their current status
-	 *
-	 * FIXME: Do we *need* this one? Sounds error prone to me, because
-	 * nicknames can contain parentheses too. - Martijn
-	 */
-	QStringList contactStatuses() const;
-
-	/**
-	 * Return all available groups
-	 */
-	QPtrList<KopeteGroup> groups() const;
+	static ContactList *self();
+	~ContactList();
 
 	/**
+	 * @brief return a list of all metacontact of the contactlist
 	 * Retrieve the list of all available meta contacts.
 	 * The returned QPtrList is not the internally used variable, so changes
 	 * to it won't propagate into the actual contact list. This can be
 	 * useful if you need a subset of the contact list, because you can
 	 * simply filter the result set as you wish without worrying about
 	 * side effects.
-	 * The contained KopeteMetaContacts are obviously _not_ duplicates, so
+	 * The contained MetaContacts are obviously _not_ duplicates, so
 	 * changing those *will* have the expected result :-)
 	 */
-	QPtrList<KopeteMetaContact> metaContacts() const;
+	QPtrList<MetaContact> metaContacts() const;
+	
+	/**
+	 * @return all groups
+	 */
+	QPtrList<Group> groups() const;
 
 	/**
-	 * Get a group.
-	 * If a group already exists with the given name and the given type, the existing group will be returned.
- 	 * Otherwise, a new group will be created.
-	 * @param displayName is the display name to search
-	 * @param type is the KopeteGroup::GroupType to search, the default value is Kopetegroup::Normal
+	 * Return the metacontact referenced by the given id. is none is found, return 0L
+	 * @sa MetaContact::metaContactId()
 	 */
-	KopeteGroup * getGroup( const QString &displayName, int type = 0/*KopeteGroup::Normal*/ );
+	MetaContact *metaContact( const QString &metaContactId ) const;
 
 	/**
 	 * return the group with the given unique id. if none is found return 0L
 	 */
-	KopeteGroup * getGroup(unsigned int groupId);
+	Group * group(unsigned int groupId) const;
+	
+	
+	/**
+	 * @brief find a contact in the contactlist.
+	 * Browse in each metacontact of the list to find the contact with the given ID.
+	 * @param protocolId the @ref Plugin::pluginId() of the protocol ("MSNProtocol")
+	 * @param accountId the @ref Account::accountId()
+	 * @param contactId the @ref Contact::contactId()
+	 * @return the contact with the parameters, or 0L if not found.
+	 */
+	Contact *findContact( const QString &protocolId, const QString &accountId, const QString &contactId ) const;
 
 	/**
 	 * Find a contact by display name. Returns the first match.
 	 */
-	KopeteMetaContact *findContactByDisplayName( const QString &displayName );
+	MetaContact *findMetaContactByDisplayName( const QString &displayName ) const;
 
 	/**
 	 * Find a meta contact by its contact id. Returns the first match.
 	 */
-	KopeteMetaContact *findMetaContactByContactId( const QString &contactId );
+	MetaContact *findMetaContactByContactId( const QString &contactId ) const;
+
+	/**
+	 * @brief find a group with his displayName
+	 * If a group already exists with the given name and the given type, the existing group will be returned.
+ 	 * Otherwise, a new group will be created.
+	 * @param displayName is the display name to search
+	 * @param type is the @ref Group::GroupType to search, the default value is group::Normal
+	 * @return always a valid Group
+	 */
+	Group * findGroup( const QString &displayName, int type = 0/*Group::Normal*/ );
 
 	/**
 	 * return the list of metacontact actually selected in the contactlist UI
 	 */
-	QPtrList<KopeteMetaContact> selectedMetaContacts() const;
+	QPtrList<MetaContact> selectedMetaContacts() const;
 
 	/**
 	 * return the list of groups actualy selected in the contactlist UI
 	 */
-	QPtrList<KopeteGroup> selectedGroups() const ;
+	QPtrList<Group> selectedGroups() const ;
 	
 public slots:
 
 	/**
 	 * Add the metacontact into the contact list
 	 * When calling this method, the contact has to be already placed in the correct group.
-	 * If the contact is not in a  group, it will be added to the top-level group
+	 * If the contact is not in a  group, it will be added to the top-level group.
+	 * It is also better if the MetaContact could also be completely created, i.e: all contacts already in it
 	 */
-	void addMetaContact( KopeteMetaContact *c );
+	void addMetaContact( Kopete::MetaContact *c );
 
 	/**
 	 * Remove a metacontact from the contactlist.
 	 * This method delete itself the metacontact.
 	 */
-	void removeMetaContact( KopeteMetaContact *contact );
+	void removeMetaContact( Kopete::MetaContact *contact );
 
 	/**
 	 * Add a group
+	 * each group must be added on the list after his creation.
 	 */
-	void addGroup(KopeteGroup *);
+	void addGroup(Kopete::Group *);
 
 	/**
 	 * Remove a group
 	 * this method delete the group
 	 */
-	void removeGroup(KopeteGroup *);
-
-	/**
-	 * Exposed via DCOP in kopeteiface
-	 * Used to send a file to a MetaContact using the highest ranked protocol
-	 *
-	 * FIXME: We need to change this to use a unique ID instead of the displayName
-	 *
-	 * @param displayName Metacontact to send file to
-	 * @param sourceURL The file we are sending
-	 * @param altFileName (Optional) An alternate filename for the file we are sending
-	 * @param fileSize (Optional) The size of the file
-	 */
-	void sendFile(const QString &displayName, const KURL &sourceURL,
-		const QString &altFileName = QString::null, const long unsigned int fileSize = 0L);
-
-	/**
-	 * Open a chat to a contact, and optionally set some initial text
-	 */
-	void messageContact( const QString &displayName, const QString &messageText = QString::null );
+	void removeGroup(Kopete::Group *);
 
 	/**
 	 * Set which items are selected in the ContactList GUI.
 	 * This method has to be called by the contactlist UI side.
 	 * it stores the selected items, and emits signals
 	 */
-	 void setSelectedItems(QPtrList<KopeteMetaContact> metaContacts , QPtrList<KopeteGroup> groups);
-
-	/**
-	 * @internal
-	 * Load the contact list
-	 *
-	 * FIXME: Use a better way, without exposing the XML backend, though.
-	 */
-	void load();
-
-	void save();
+	 void setSelectedItems(QPtrList<MetaContact> metaContacts , QPtrList<Group> groups);
 
 signals:
 	/**
@@ -231,33 +170,36 @@ signals:
 	 * ( like the listview widgets ) can connect to this signal to receive
 	 * the newly added contacts.
 	 */
-	void metaContactAdded( KopeteMetaContact *mc );
+	void metaContactAdded( Kopete::MetaContact *mc );
+	
 	/**
-	 * a metacontact has just been removed
+	 * A metacontact has just been removed.  and will be soon deleted
 	 */
-	void metaContactDeleted( KopeteMetaContact *mc );
+	void metaContactRemoved( Kopete::MetaContact *mc );
 
 	/**
 	 * A group has just been added
 	 */
-	void groupAdded( KopeteGroup * );
+	void groupAdded( Kopete::Group * );
+	
 	/**
 	 * A group has just been removed
 	 */
-	void groupRemoved( KopeteGroup * );
+	void groupRemoved( Kopete::Group * );
+	
 	/**
 	 * A group has just been renamed
 	 */
-	void groupRenamed(KopeteGroup *, const QString & oldname);
+	void groupRenamed(Kopete::Group *, const QString & oldname);
 
 	/**
 	 * A contact has been added to a group
 	 */
-	void metaContactAddedToGroup( KopeteMetaContact *mc, KopeteGroup *to );
+	void metaContactAddedToGroup( Kopete::MetaContact *mc, Kopete::Group *to );
 	/**
 	 * A contact has been removed from a group
 	 */
-	void metaContactRemovedFromGroup( KopeteMetaContact *mc, KopeteGroup *from );
+	void metaContactRemovedFromGroup( Kopete::MetaContact *mc, Kopete::Group *from );
 
 	/**
 	 * This signal is emit when the selection has changed, it is emitted after the following slot
@@ -280,6 +222,106 @@ private slots:
 	 * Called on contactlist load or when KABC has changed, to check if we need to update our contactlist from there.
 	 */
 	void slotKABCChanged();
+private:
+	
+	/**
+	 * Convert the contact list from an older version
+	 */
+	void convertContactList( const QString &fileName, uint fromVersion, uint toVersion );
+	
+	
+	/**
+	 * Private constructor: we are a singleton
+	 */
+	ContactList();
+	
+	static ContactList *s_self;
+	class Private;
+	Private *d;
+	
+
+public: //TODO I think all theses method should be moved to the decop interface.
+	/**
+	 * Return all meta contacts
+	 */
+	QStringList contacts() const;
+
+	/**
+	 * Return all meta contacts that are reachable
+	 */
+	QStringList reachableContacts() const;
+
+	/**
+	 * Return all contacts that are online
+	 */
+	QPtrList<Contact> onlineContacts() const;
+
+	/**
+	 * Overloaded method of @ref onlineContacts() that only returns
+	 * the online contacts for a single protocol
+	 */
+	QPtrList<Contact> onlineContacts( const QString &protocolId ) const;
+
+	/**
+	 * Return all meta contacts that are online
+	 */
+	QPtrList<MetaContact> onlineMetaContacts() const;
+
+	/**
+	 * Overloaded method of @ref onlineMetaContacts() that only returns
+	 * the online meta contacts for a single protocol
+	 */
+	QPtrList<MetaContact> onlineMetaContacts( const QString &protocolId ) const;
+
+	/**
+	 * Returns all contacts which can accept file transfers
+	 */
+	QStringList fileTransferContacts() const;
+
+	QStringList contactFileProtocols( const QString &displayName);
+
+	/**
+	 * Return all meta contacts with their current status
+	 *
+	 * FIXME: Do we *need* this one? Sounds error prone to me, because
+	 * nicknames can contain parentheses too. - Martijn
+	 */
+	QStringList contactStatuses() const;
+	
+	
+	/**
+	 * Exposed via DCOP in kopeteiface
+	 * Used to send a file to a MetaContact using the highest ranked protocol
+	 *
+	 * FIXME: We need to change this to use a unique ID instead of the displayName
+	 *
+	 * @param displayName Metacontact to send file to
+	 * @param sourceURL The file we are sending
+	 * @param altFileName (Optional) An alternate filename for the file we are sending
+	 * @param fileSize (Optional) The size of the file
+	 */
+	void sendFile(const QString &displayName, const KURL &sourceURL,
+		const QString &altFileName = QString::null, const long unsigned int fileSize = 0L);
+
+	/**
+	 * Open a chat to a contact, and optionally set some initial text
+	 */
+	void messageContact( const QString &displayName, const QString &messageText = QString::null );
+
+	
+	
+
+public slots:
+	/**
+	 * @internal
+	 * Load the contact list
+	 *
+	 * FIXME: Use a better way, without exposing the XML backend, though.
+	 */
+	void load();
+
+	void save();
+	
 private:
 	/**
 	 * Return a XML representation of the contact list
@@ -295,27 +337,13 @@ private:
 	 * Save the contact list to XML file
 	 */
 	void saveXML();
-
-	/**
-	 * Private constructor: we are a singleton
-	 */
-	KopeteContactList();
-
-	/**
-	 * Our contact list instance
-	 */
-	static KopeteContactList *s_contactList;
-
-	/**
-	 * Convert the contact list from an older version
-	 */
-	void convertContactList( const QString &fileName, uint fromVersion, uint toVersion );
-
-	class KopeteContactListPrivate;
-	KopeteContactListPrivate *d;
+	
+	
 };
 
+} //END namespace Kopete
+
+
 #endif
 
-// vim: set noet ts=4 sts=4 sw=4:
 
