@@ -1,10 +1,10 @@
 /*
     kopetegroup.cpp - Kopete (Meta)Contact Group
 
-    Copyright (c) 2002-2003 by Olivier Goffart       <ogoffart@tiscalinet.be>
+    Copyright (c) 2002-2004 by Olivier Goffart       <ogoffart@ tiscalinet.be>
     Copyright (c) 2003      by Martijn Klingens      <klingens@kde.org>
 
-    Kopete    (c) 2002-2003 by the Kopete developers <kopete-devel@kde.org>
+    Kopete    (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -20,14 +20,18 @@
 
 #include "kopetecontactlist.h"
 #include "kopetemetacontact.h"
+#include "kopetecontact.h"
+#include "kopetemessagemanager.h"
 
 #include <klocale.h>
 
-struct KopeteGroupPrivate
+namespace Kopete {
+
+class Group::Private
 {
+public:
 	QString displayName;
-	QString internalName;
-	KopeteGroup::GroupType type;
+	Group::GroupType type;
 	bool expanded;
 	uint groupId;
 
@@ -35,78 +39,57 @@ struct KopeteGroupPrivate
 	static uint uniqueGroupId;
 };
 
-KopeteGroup *KopeteGroup::s_topLevel  = 0L;
-KopeteGroup *KopeteGroup::s_temporary = 0L;
-
-KopeteGroup * KopeteGroup::topLevel()
+Group *Group::s_topLevel  = 0L;
+Group *Group::s_temporary = 0L;
+Group * Group::topLevel()
 {
-	// Do not translate the internal name, it's not shown in the GUI
 	if ( !s_topLevel )
-		s_topLevel = new KopeteGroup( i18n( "Top Level" ),
-				QString::fromLatin1( "Top-Level" ), 
-				KopeteGroup::TopLevel );
+		s_topLevel = new Group( i18n( "Top Level" ), Group::TopLevel );
 
 	return s_topLevel;
 }
 
-KopeteGroup * KopeteGroup::temporary()
+Group * Group::temporary()
 {
-	// Do not translate the internal name, it's not shown in the GUI
 	if ( !s_temporary )
-		s_temporary = new KopeteGroup( i18n( "Not in your contact list" ),
-				 QString::fromLatin1( "Temporary" ), 
-				 KopeteGroup::Temporary );
+		s_temporary = new Group( i18n( "Not in your contact list" ), Group::Temporary );
 
 	return s_temporary;
 }
 
-uint KopeteGroupPrivate::uniqueGroupId = 0;
+uint Group::Private::uniqueGroupId = 0;
 
-KopeteGroup::KopeteGroup( const QString &_name, GroupType _type )
-: KopetePluginDataObject( KopeteContactList::contactList() )
+Group::Group( const QString &_name, GroupType _type )
+	: ContactListElement( ContactList::self() )
 {
-	d = new KopeteGroupPrivate;
+	d = new Private;
 	d->displayName = _name;
-	d->internalName = _name;
 	d->type = _type;
 	d->expanded = true;
 	d->groupId = 0;
 }
 
-KopeteGroup::KopeteGroup()
-: KopetePluginDataObject( KopeteContactList::contactList() )
+Group::Group()
+	: ContactListElement( ContactList::self() )
 {
-	d = new KopeteGroupPrivate;
+	d = new Private;
 	d->expanded = true;
 	d->type = Normal;
-	d->displayName = QString::null;
-	d->internalName = QString::null;
 	d->groupId = 0;
 }
 
-KopeteGroup::KopeteGroup( const QString &_displayName, const QString &_internalName, GroupType _type )
+Group::~Group()
 {
-	d = new KopeteGroupPrivate;
-	d->displayName = _displayName;
-	d->internalName = _internalName;
-	d->type = _type;
-	d->expanded = true;
-	d->groupId = 0;
-}
-
-KopeteGroup::~KopeteGroup()
-{
-	if ( d->type == TopLevel )
-		s_topLevel = 0L;
-	if ( d->type == Temporary )
-		s_temporary = 0L;
-
+	if(d->type == TopLevel)
+		s_topLevel=0L;
+	if(d->type == Temporary)
+		s_temporary=0L;
 	delete d;
 }
 
-QPtrList<KopeteMetaContact> KopeteGroup::members() const
+QPtrList<MetaContact> Group::members() const
 {
-	QPtrList<KopeteMetaContact> members = KopeteContactList::contactList()->metaContacts();
+	QPtrList<MetaContact> members = ContactList::self()->metaContacts();
 	// members is a *copy* of the meta contacts, so using first(), next() and remove() is fine.
 	for( members.first(); members.current(); )
 	{
@@ -118,7 +101,7 @@ QPtrList<KopeteMetaContact> KopeteGroup::members() const
 	return members;
 }
 
-const QDomElement KopeteGroup::toXML()
+const QDomElement Group::toXML()
 {
 	QDomDocument group;
 	group.appendChild( group.createElement( QString::fromLatin1( "kopete-group" ) ) );
@@ -146,19 +129,19 @@ const QDomElement KopeteGroup::toXML()
 	group.documentElement().appendChild( displayName );
 
 	// Store other plugin data
-	QValueList<QDomElement> pluginData = KopetePluginDataObject::toXML();
+	QValueList<QDomElement> pluginData = ContactListElement::toXML();
 	for ( QValueList<QDomElement>::Iterator it = pluginData.begin(); it != pluginData.end(); ++it )
 		group.documentElement().appendChild( group.importNode( *it, true ) );
 
 	// Store custom notification data
-	QDomElement notifyData = KopeteNotifyDataObject::notifyDataToXML();
+	QDomElement notifyData = Kopete::NotifyDataObject::notifyDataToXML();
 	if ( notifyData.hasChildNodes() )
 		group.documentElement().appendChild( group.importNode( notifyData, true ) );
 
 	return group.documentElement();
 }
 
-bool KopeteGroup::fromXML( const QDomElement &data )
+bool Group::fromXML( const QDomElement &data )
 {
 	QString strGroupId = data.attribute( QString::fromLatin1( "groupId" ) );
 	if ( !strGroupId.isEmpty() )
@@ -209,11 +192,11 @@ bool KopeteGroup::fromXML( const QDomElement &data )
 		}
 		else if( groupElement.tagName() == QString::fromLatin1( "custom-notifications" ) )
 		{
-			KopeteNotifyDataObject::notifyDataFromXML( groupElement );
+			Kopete::NotifyDataObject::notifyDataFromXML( groupElement );
 		}
 		else
 		{
-			KopetePluginDataObject::fromXML( groupElement );
+			Kopete::ContactListElement::fromXML( groupElement );
 		}
 
 		groupData = groupData.nextSibling();
@@ -240,42 +223,42 @@ bool KopeteGroup::fromXML( const QDomElement &data )
 	return ( d->type == Normal );
 }
 
-void KopeteGroup::setDisplayName( const QString &s )
+void Group::setDisplayName( const QString &s )
 {
 	if ( d->displayName != s )
 	{
 		QString oldname = d->displayName;
 		d->displayName = s;
-		emit renamed( this, oldname );
+		emit displayNameChanged( this, oldname );
 	}
 }
 
-QString KopeteGroup::displayName() const
+QString Group::displayName() const
 {
 	return d->displayName;
 }
 
-KopeteGroup::GroupType KopeteGroup::type() const
+Group::GroupType Group::type() const
 {
 	return d->type;
 }
 
-void KopeteGroup::setType( GroupType t )
+void Group::setType( GroupType t )
 {
 	d->type = t;
 }
 
-void KopeteGroup::setExpanded( bool isExpanded )
+void Group::setExpanded( bool isExpanded )
 {
 	d->expanded = isExpanded;
 }
 
-bool KopeteGroup::isExpanded() const
+bool Group::isExpanded() const
 {
 	return d->expanded;
 }
 
-uint KopeteGroup::groupId() const
+uint Group::groupId() const
 {
 	if ( d->groupId == 0 )
 		d->groupId = ++d->uniqueGroupId;
@@ -283,12 +266,61 @@ uint KopeteGroup::groupId() const
 	return d->groupId;
 }
 
-QString KopeteGroup::internalName() const
+
+void Group::sendMessage()
 {
-	return d->internalName;
+	QPtrList<Kopete::MetaContact> list = onlineMembers();
+	Kopete::MetaContact *mc = list.first();
+	Kopete::Contact *c;
+	
+	if(!mc)
+		return;
+	c = mc->preferredContact();
+	c->sendMessage();
+	if( c->manager( Contact::CanCreate ) )
+	{
+		connect( c->manager(), SIGNAL( messageSent( Kopete::Message&, Kopete::ChatSession* ) ), this, SLOT( sendMessage( Kopete::Message& ) ));
+	}
 }
 
+void Group::sendMessage( Message& msg )
+{
+	QPtrList<MetaContact> list = onlineMembers();
+	Kopete::MetaContact *mc = list.first();
+	Kopete::Contact *c = msg.to().first();
+	
+	if(!mc)
+		return;
+	list.remove( msg.to().first()->metaContact() );
+	for( mc = list.first(); mc; mc = list.next() )
+	{
+		if( mc->preferredContact()->manager( Contact::CanCreate ) )
+		{
+			mc->preferredContact()->manager( )->sendMessage( msg );
+		}
+	}
+	if( c->manager( Contact::CannotCreate ) )
+	{
+		disconnect( c->manager(), SIGNAL( messageSent( Kopete::Message&, Kopete::ChatSession* ) ), this, SLOT( sendMessage( Kopete::Message& ) ) );
+	}
+}
+
+QPtrList<MetaContact> Group::onlineMembers() const
+{
+	QPtrList<MetaContact> list = members();
+	
+	for( list.first(); list.current(); )
+		if( list.current()->isReachable() )
+			list.next();
+		else
+			list.remove();
+	return list;
+}
+
+} //END namespace Kopete 
+
+
 #include "kopetegroup.moc"
 
-// vim: set noet ts=4 sts=4 sw=4:
+
 
