@@ -26,31 +26,34 @@
 #include "kopetemessagemanager.h"
 #include "kopetemessage.h"
 
-class KopeteMessageManager;
-class KopeteMessage;
-class KopeteContact;
-class KopeteProtocol;
-class KopeteEvent;
+#include <kopete_export.h>
+
 class KopeteView;
 
-typedef QPtrList<KopeteContact>        KopeteContactPtrList;
-typedef QValueList<KopeteMessage>      KopeteMessageList;
-typedef QIntDict<KopeteMessageManager> KopeteMessageManagerDict;
+namespace Kopete
+{
+
+class Contact;
+class Protocol;
+class MessageEvent;
+
+typedef QPtrList<Contact>        ContactPtrList;
+typedef QValueList<Message>      MessageList;
 
 /**
  * @author Duncan Mac-Vicar Prett <duncan@kde.org>
  *
- * KopeteMessageManagerFactory is responsible for creating and tracking KopeteMessageManager
+ * Kopete::ChatSessionManager is responsible for creating and tracking Kopete::ChatSession
  * instances for each chat.
  */
-class KopeteMessageManagerFactory : public QObject
+class KOPETE_EXPORT ChatSessionManager : public QObject
 {
 	Q_OBJECT
 
 public:
-	static KopeteMessageManagerFactory* factory();
+	static ChatSessionManager* self();
 
-	~KopeteMessageManagerFactory();
+	~ChatSessionManager();
 
 	/**
 	 * Create a new chat session. Provided is the initial list of contacts in
@@ -59,54 +62,47 @@ public:
 	 * @param user The local user in the session.
 	 * @param chatContacts The list of contacts taking part in the chat.
 	 * @param protocol The protocol that the chat is using.
-	 * @return A pointer to a new or reused KopeteMessageManager.
+	 * @return A pointer to a new or reused Kopete::ChatSession.
 	 */
-	KopeteMessageManager* create( const KopeteContact *user,
-		KopeteContactPtrList chatContacts, KopeteProtocol *protocol);
+	Kopete::ChatSession* create( const Kopete::Contact *user,
+		Kopete::ContactPtrList chatContacts, Kopete::Protocol *protocol);
 
 	/**
 	 * Find a chat session, if one exists, that matches the given list of contacts.
 	 * @param user The local user in the session.
 	 * @param chatContacts The list of contacts taking part in the chat.
 	 * @param protocol The protocol that the chat is using.
-	 * @return A pointer to an existing KopeteMessageManager, or 0L if none was found.
+	 * @return A pointer to an existing Kopete::ChatSession, or 0L if none was found.
 	 */
-	KopeteMessageManager* findKopeteMessageManager( const KopeteContact *user,
-		KopeteContactPtrList chatContacts, KopeteProtocol *protocol);
+	Kopete::ChatSession* findChatSession( const Kopete::Contact *user,
+		Kopete::ContactPtrList chatContacts, Kopete::Protocol *protocol);
 
 	/**
-	 * Registers a KopeteMessageManager (or subclass thereof) with the KopeteMessageManagerFactory
+	 * Registers a Kopete::ChatSession (or subclass thereof) with the Kopete::ChatSessionManager
 	 */
-	void addKopeteMessageManager(KopeteMessageManager *);
-
-	/**
-	 * Find the idth KopeteMessageManager that the factory knows of.
-	 * @param id The number of the desired KopeteMessageManager.
-	 * @return A pointer to the KopeteMessageManager, or 0 if it was not found.
-	 */
-	KopeteMessageManager *findKopeteMessageManager( int id );
+	void registerChatSession(Kopete::ChatSession *);
 
 	/**
 	 * Get a list of all open sessions.
 	 */
-	const KopeteMessageManagerDict& sessions();
+	QValueList<ChatSession*> sessions();
 
 	/**
 	 * @internal
 	 * called by the kmm itself when it gets deleted
 	 */
-	void removeSession( KopeteMessageManager *session );
+	void removeSession( Kopete::ChatSession *session );
 
 	/**
 	 * create a new view for the manager.
 	 * only the manager should call this function
 	 */
-	KopeteView *createView( KopeteMessageManager * , KopeteMessage::MessageType type );
+	KopeteView *createView( Kopete::ChatSession * , const QString &requestedPlugin = QString::null );
 
 	/**
 	 * Post a new event. this will emit the @ref newEvent signal
 	 */
-	void postNewEvent(KopeteEvent*);
+	void postNewEvent(Kopete::MessageEvent*);
 
 	/**
 	 * Returns the current active Kopete view
@@ -122,14 +118,14 @@ signals:
 	 * Plugins may connect to this signal to change
 	 * the message contents before it's going to be displayed.
 	 */
-	void aboutToDisplay( KopeteMessage& message );
+	void aboutToDisplay( Kopete::Message& message );
 
 	/**
 	 * Plugins may connect to this signal
 	 * to manipulate the contents of the
 	 * message that is being sent.
 	 */
-	void aboutToSend( KopeteMessage& message );
+	void aboutToSend( Kopete::Message& message );
 
 	/**
 	 * Plugins may connect to this signal
@@ -138,7 +134,7 @@ signals:
 	 *
 	 * This signal is emitted before @ref aboutToDisplay()
 	 */
-	void aboutToReceive( KopeteMessage& message );
+	void aboutToReceive( Kopete::Message& message );
 
 	/**
 	 * A new view has been created
@@ -158,49 +154,38 @@ signals:
 	/**
 	 * a new KMM has been created
 	 */
-	void messageManagerCreated( KopeteMessageManager *);
-
-	/*
-	 * Request the creation of a new view
-	 */
-	void requestView(KopeteView*& , KopeteMessageManager * , KopeteMessage::MessageType type );
+	void chatSessionCreated( Kopete::ChatSession *);
 
 	/**
 	 * the message is ready to be displayed
 	 */
-	void display( KopeteMessage& message, KopeteMessageManager * );
+	void display( Kopete::Message& message, Kopete::ChatSession * );
 
 	/**
 	 * A new event has been posted.
 	 */
-	void newEvent(KopeteEvent *);
+	void newEvent(Kopete::MessageEvent *);
 
 	/**
 	 * The global shortcut for sending message has been used
 	 */
 	void readMessage();
 
-	/**
-	 * Emit this signal to obtain the avtive view from the
-	 * KopeteViewManager
-	 *
-	 * FIXME: This is realy dumb API
-	 */
-	 void getActiveView( KopeteView *& );
-
 public slots:
 	void slotReadMessage();
 
 private:
-	KopeteMessageManagerFactory( QObject* parent = 0, const char* name = 0 );
+	ChatSessionManager( QObject* parent = 0, const char* name = 0 );
 
-	int mId;
-	KopeteMessageManagerDict mSessionDict;
+	class Private;
+	Private *d;
 
-	static KopeteMessageManagerFactory *s_factory;
+	static ChatSessionManager *s_self;
 
 };
 
+}
+
 #endif
 
 // vim: set noet ts=4 sts=4 sw=4:
