@@ -68,6 +68,8 @@ void KopetePrefs::load()
 	mRichText = config->readBoolEntry("RichText editor", false);
 	mChatWShowSend = config->readBoolEntry("Show Chatwindow Send Button", true);
 	mRememberedMessages = config->readNumEntry("Remembered Messages", 5);
+	mTruncateContactNames = config->readBoolEntry("TruncateContactNames", false);
+	mMaxContactNameLength = config->readNumEntry("MaxContactNameLength", 20);
 
 	mTransparencyColor = config->readColorEntry("ChatView Transparency Tint Color", &Qt::white);
 	mChatViewBufferSize = config->readNumEntry("ChatView BufferSize", 250);
@@ -80,7 +82,7 @@ void KopetePrefs::load()
 	mBgOverride = config->readBoolEntry("ChatView Override Background", false);
 	mFgOverride = config->readBoolEntry("ChatView Override Foreground", false);
 	mRtfOverride = config->readBoolEntry("ChatView Override RTF", false);
-	mInterfacePreference = (ChatWindowPref)config->readNumEntry("Interface Preference", ChatWindow);
+	mInterfacePreference = config->readEntry("View Plugin", QString::fromLatin1("kopete_chatwindow") );
 	tmpColor = KGlobalSettings::textColor();
 	mTextColor = config->readColorEntry("Text Color", &tmpColor );
 	tmpColor = KGlobalSettings::baseColor();
@@ -135,10 +137,13 @@ void KopetePrefs::load()
 	mContactListAnimation = config->readBoolEntry("AnimateChanges", true);
 	mContactListFading = config->readBoolEntry("FadeItems", true);
 	mContactListFolding = config->readBoolEntry("FoldItems", true);
+	mContactListAutoHide = config->readBoolEntry("AutoHide", false);
+	mContactListAutoHideTimeout = config->readUnsignedNumEntry("AutoHideTimeout", 30);
 
 	// Load the reconnection setting
 	config->setGroup("General");
 	mReconnectOnDisconnect = config->readBoolEntry("ReconnectOnDisconnect", true);
+	mAutoConnect = config->readBoolEntry("AutoConnect", false);
 
 	// Nothing has changed yet
 	mWindowAppearanceChanged = false;
@@ -185,8 +190,10 @@ void KopetePrefs::save()
 	config->writeEntry("Idle Contact Color", mIdleContactColor);
 	config->writeEntry("RichText editor", mRichText);
 	config->writeEntry("Show Chatwindow Send Button", mChatWShowSend);
+	config->writeEntry("TruncateContactNames", mTruncateContactNames);
+	config->writeEntry("MaxContactNameLength", mMaxContactNameLength);
 
-	config->writeEntry("Interface Preference", mInterfacePreference);
+	config->writeEntry("View Plugin", mInterfacePreference);
 
 	config->writeEntry("Show Systemtray", mShowTray);
 	config->writeEntry("Stylesheet", mStyleSheet);
@@ -204,10 +211,13 @@ void KopetePrefs::save()
 	config->writeEntry("AnimateChanges", mContactListAnimation);
 	config->writeEntry("FadeItems", mContactListFading);
 	config->writeEntry("FoldItems", mContactListFolding);
+	config->writeEntry("AutoHide", mContactListAutoHide);
+	config->writeEntry("AutoHideTimeout", mContactListAutoHideTimeout);
 
 	//Save the reconnection setting
 	config->setGroup("General");
 	config->writeEntry("ReconnectOnDisconnect", mReconnectOnDisconnect);
+	config->writeEntry("AutoConnect", mAutoConnect);
 
 	config->sync();
 	emit saved();
@@ -370,7 +380,17 @@ void KopetePrefs::setChatWindowPolicy(int value)
 	mChatWindowPolicy = value;
 }
 
-void KopetePrefs::setInterfacePreference(ChatWindowPref value)
+void KopetePrefs::setTruncateContactNames( bool value )
+{
+	mTruncateContactNames = value;
+}
+
+void KopetePrefs::setMaxContactNameLength( int value )
+{
+	mMaxContactNameLength = value;
+}
+
+void KopetePrefs::setInterfacePreference(const QString &value)
 {
 	mInterfacePreference = value;
 }
@@ -412,7 +432,7 @@ void KopetePrefs::setHighlightEnabled(bool value)
 
 void KopetePrefs::setTransparencyValue(int value)
 {
-	if( value != mTransparencyValue ) mWindowAppearanceChanged = true;
+	if( value != mTransparencyValue ) mTransparencyChanged = true;
 	mTransparencyValue = value;
 }
 
@@ -535,9 +555,28 @@ void KopetePrefs::setContactListFolding( bool n )
 	mContactListFolding = n;
 }
 
+void KopetePrefs::setContactListAutoHide( bool n )
+{
+	if( n != mContactListAutoHide ) mContactListAppearanceChanged = true;
+	mContactListAutoHide = n;
+}
+
+void KopetePrefs::setContactListAutoHideTimeout( unsigned int n )
+{
+	if( n != mContactListAutoHideTimeout ) mContactListAppearanceChanged = true;
+	mContactListAutoHideTimeout = n;
+}
+
 void KopetePrefs::setReconnectOnDisconnect( bool newSetting )
 {
 	mReconnectOnDisconnect = newSetting;
 }
+
+
+void KopetePrefs::setAutoConnect(bool b)
+{
+	mAutoConnect=b;
+}
+
 #include "kopeteprefs.moc"
 // vim: set noet ts=4 sts=4 sw=4:
