@@ -22,9 +22,11 @@
 #include <qcolor.h>
 #include <qfont.h>
 
+#include <kopete_export.h>
+
 class KConfig;
 
-class KopetePrefs : public QObject
+class KOPETE_EXPORT KopetePrefs : public QObject
 {
 	Q_OBJECT
 	// here so we can use Qt to translate enums<-->strings
@@ -81,11 +83,11 @@ public:
 	bool fgOverride() const { return mFgOverride; }
 	bool rtfOverride() const { return mRtfOverride; }
 
-	enum ChatWindowPref { EmailWindow=0, ChatWindow };
-	ChatWindowPref interfacePreference() const { return mInterfacePreference; }
+	QString interfacePreference() const { return mInterfacePreference; }
 	bool showTray() const { return mShowTray; }
 	bool richText() const { return mRichText; }
 	bool chatWShowSend() const { return mChatWShowSend; }
+	bool autoConnect() const { return mAutoConnect; }
 
 	int chatWindowPolicy() const { return mChatWindowPolicy; }
 	QString styleSheet() const { return mStyleSheet; }
@@ -106,9 +108,14 @@ public:
 	bool contactListAnimation() const { return mContactListAnimation; }
 	bool contactListFading() const { return mContactListFading; }
 	bool contactListFolding() const { return mContactListFolding; }
+	bool contactListAutoHide() const { return mContactListAutoHide; }
+	unsigned int contactListAutoHideTimeout() const { return mContactListAutoHideTimeout; }
 
 	bool reconnectOnDisconnect() const { return mReconnectOnDisconnect; }
 
+	bool truncateContactNames() const { return mTruncateContactNames; }
+	int maxConactNameLength() const { return mMaxContactNameLength; }
+
 	void setIconTheme(const QString &value);
 	void setUseEmoticons(bool value);
 	void setShowOffline(bool value);
@@ -136,7 +143,7 @@ public:
 	void setBgOverride(bool);
 	void setFgOverride(bool);
 	void setRtfOverride(bool);
-	void setInterfacePreference(ChatWindowPref);
+	void setInterfacePreference(const QString &viewPlugin);
 	void setTextColor(const QColor &);
 	void setBgColor(const QColor &);
 	void setLinkColor(const QColor &);
@@ -155,7 +162,12 @@ public:
 	void setContactListAnimation( bool );
 	void setContactListFading( bool );
 	void setContactListFolding( bool );
+	void setContactListAutoHide( bool );
+	void setContactListAutoHideTimeout( unsigned int );
 	void setReconnectOnDisconnect( bool newSetting );
+	void setTruncateContactNames( bool );
+	void setMaxContactNameLength( int );
+	void setAutoConnect( bool );
 
 signals:
 	/**
@@ -202,7 +214,7 @@ private:
 	bool mTransparencyEnabled;
 	int mTransparencyValue;
 	int mRememberedMessages;
-	ChatWindowPref mInterfacePreference;
+	QString mInterfacePreference;
 	QColor mTransparencyColor;
 	int mChatViewBufferSize;
 	QColor mHighlightBackground;
@@ -222,9 +234,13 @@ private:
 	bool mMessageAppearanceChanged;
 	bool mContactListAppearanceChanged;
 	bool mChatWShowSend;
+	bool mAutoConnect;
 
 	int mChatWindowPolicy;
 
+	bool mTruncateContactNames;
+	int mMaxContactNameLength;
+
 	bool mRichText;
 	QString mStyleSheet;
 	QString mStyleContents;
@@ -240,6 +256,8 @@ private:
 	bool mContactListAnimation;
 	bool mContactListFading;
 	bool mContactListFolding;
+	bool mContactListAutoHide;
+	unsigned int mContactListAutoHideTimeout;
 
 	bool mReconnectOnDisconnect;
 
