@@ -59,12 +59,12 @@ static TestSet knownGood =
 	{ "<img src=\"...\" title=\":-)\" />", "<img src=\"...\" title=\":-)\" />" },
 	{ "End of sentence:p", "End of sentence<img align=\"center\" width=\"20\" height=\"20\" src=\"tongue.png\" title=\":p\"/>" },
 	{ "http://www.kde.org", "http://www.kde.org" },
+	{ "&gt;:-)", "<img align=\"center\" width=\"20\" height=\"20\" src=\"devil.png\" title=\"&gt;:-)\"/>" },
 	{ NULL, NULL }
 };
 
 static TestSet knownBroken =
 {
-	{ "&gt;:-)", "<img align=\"center\" width=\"20\" height=\"20\" src=\"devil.png\" title=\"&gt;:-)\"/>" },
 	{ ":))", ":))" },
 	{ "In a sentence:practical example", "In a sentence:practical example" },
 	{ "Bla (&nbsp;)", "Bla (&nbsp;)" },
@@ -76,6 +76,7 @@ static TestSet knownBroken =
 	{ "a non-breaking space (&nbsp;) character", "a non-breaking space (&nbsp;) character" },
 	{ "-+-[-:-(-:-)-:-]-+-", "-+-[-:-(-:-)-:-]-+-" },
 	{ "::shrugs::", "::shrugs::" },
+	{ ":Ptesting:P", ":Ptesting:P" },
 	{ NULL, NULL }
 };
 
@@ -85,7 +86,7 @@ void runTests( QString description, TestSet tests )
 	// Use the KMess-Cartoon theme because it has a smiley for the troublesome ':/' pattern, which
 	// also exists in http:// URIs. (Default doesn't have such a smiley, making it useless for
 	// the test.)
-	QString path = KGlobal::dirs()->findResource( "data", "kopete/pics/emoticons/KMess-Cartoon/smile.png" ).replace( "smile.png", QString::null );
+	QString path = KGlobal::dirs()->findResource( "emoticons", "KMess-Cartoon/smile.png" ).replace( "smile.png", QString::null );
 
 	_out << endl;
 	_out << "* Running test set '" << description << "'" << endl;
@@ -93,7 +94,7 @@ void runTests( QString description, TestSet tests )
 	uint i = 0;
 	while ( tests[ i ][ 0 ] && tests[ i ][ 1 ] )
 	{
-		QString result = KopeteEmoticons::parseEmoticons( tests[ i ][ 0 ] ).replace( path, QString::null );
+		QString result = Kopete::Emoticons::parseEmoticons( tests[ i ][ 0 ] ).replace( path, QString::null );
 
 		if ( result == tests[ i ][ 1 ] )
 		{
