@@ -1,7 +1,7 @@
 /*
     kopetefileconfirmdialog.cpp
 
-    Copyright (c) 2003      by Olivier Goffart       <ogoffart@tiscalinet.be>
+    Copyright (c) 2003-2004 by Olivier Goffart       <ogoffart@tiscalinet.be>
 
     Kopete    (c) 2002-2003 by the Kopete developers <kopete-devel@kde.org>
 
@@ -22,14 +22,16 @@
 #include <klocale.h>
 #include <kfiledialog.h>
 #include <kpushbutton.h>
+#include <kmessagebox.h>
 
 //#include "kopetetransfermanager.h"
 #include "fileconfirmbase.h"
 #include "kopetefileconfirmdialog.h"
 
 #include "kopetemetacontact.h"
+#include "kopetecontact.h"
 
-KopeteFileConfirmDialog::KopeteFileConfirmDialog(const KopeteFileTransferInfo &info,const QString& description,QWidget *parent, const char *name )
+KopeteFileConfirmDialog::KopeteFileConfirmDialog(const Kopete::FileTransferInfo &info,const QString& description,QWidget *parent, const char *name )
 : KDialogBase( parent, name, true, i18n( "A User Would Like to Send You a File" ),
 	KDialogBase::User1 | KDialogBase::User2, KDialogBase::User1, true, i18n( "&Refuse" ), i18n( "&Accept" ) ),
 	m_info( info )
@@ -70,7 +72,7 @@ void KopeteFileConfirmDialog::slotUser2()
 {
 	m_emited=true;
 	KURL url(m_view->m_saveto->text());
-	if(url.isValid())
+	if(url.isValid() && url.isLocalFile() )
 	{
 		const QString directory=url.directory();
 		if(!directory.isEmpty())
@@ -78,9 +80,20 @@ void KopeteFileConfirmDialog::slotUser2()
 			KGlobal::config()->setGroup("File Transfer");
 			KGlobal::config()->writeEntry("defaultPath" , directory );
 		}
-	} 
-	emit accepted(m_info,m_view->m_saveto->text());
-	close();
+		
+		if(QFile(m_view->m_saveto->text()).exists())
+		{
+			int ret=KMessageBox::warningContinueCancel(this,  i18n("The file '%1' already exists.\nDo you want to overwrite it ?").arg(m_view->m_saveto->text()) ,
+					 i18n("Overwrite File") , KStdGuiItem::save());
+			if(ret==KMessageBox::Cancel)
+				return;
+		}
+	 
+		emit accepted(m_info,m_view->m_saveto->text());
+		close();
+	}
+	else
+		KMessageBox::queuedMessageBox (this, KMessageBox::Sorry, i18n("You must provide a valid local filename") );
 }
 
 void KopeteFileConfirmDialog::slotUser1()
