@@ -32,52 +32,7 @@
 
 #include "kopetecontactlist.h"
 #include "kopetegroup.h"
-
-KopeteGroupListAction::KopeteGroupListAction( const QString &text, const QString &pix, const KShortcut &cut, const QObject *receiver,
-	const char *slot, QObject *parent, const char *name )
-: KListAction( text, pix, cut, parent, name )
-{
-	connect( this, SIGNAL( activated() ), receiver, slot );
-
-	connect( KopeteContactList::contactList(), SIGNAL( groupAdded( KopeteGroup * ) ), this, SLOT( slotUpdateList() ) );
-	connect( KopeteContactList::contactList(), SIGNAL( groupRemoved( KopeteGroup * ) ), this, SLOT( slotUpdateList() ) );
-	slotUpdateList();
-}
-
-KopeteGroupListAction::~KopeteGroupListAction()
-{
-}
-
-void KopeteGroupListAction::slotUpdateList()
-{
-	QStringList groupList;
-
-	// Add groups to our list
-	KopeteGroupList groups = KopeteContactList::contactList()->groups();
-	for ( KopeteGroup *it = groups.first(); it; it = groups.next() )
-	{
-		// FIXME: I think handling the i18n for temporary and top level
-		//        groups belongs in KopeteGroup instead.
-		//        It's now duplicated in KopeteGroupListAction and
-		//        KopeteGroupViewItem already - Martijn
-		QString displayName;
-		switch ( it->type() )
-		{
-		case KopeteGroup::Temporary:
-			// Moving to temporary makes no sense, skip the group
-			continue;
-		case KopeteGroup::TopLevel:
-			displayName = i18n( "(Top-Level)" );
-			break;
-		default:
-			displayName = it->displayName();
-			break;
-		}
-		groupList.append( displayName );
-	}
-
-	setItems( groupList );
-}
+#include "kopeteuiglobal.h"
 
 KSettings::Dialog *KopetePreferencesAction::s_settingsDialog = 0L;
 
@@ -101,11 +56,11 @@ void KopetePreferencesAction::slotShowPreferences()
 {
 	// FIXME: Use static deleter - Martijn
 	if ( !s_settingsDialog )
-		s_settingsDialog = new KSettings::Dialog( KSettings::Dialog::Static, qApp->mainWidget() );
+		s_settingsDialog = new KSettings::Dialog( KSettings::Dialog::Static, Kopete::UI::Global::mainWidget() );
 	s_settingsDialog->show();
-	
+
 	s_settingsDialog->dialog()->raise();
-	
+
 #if KDE_IS_VERSION( 3, 1, 90 )
 	KWin::activateWindow( s_settingsDialog->dialog()->winId() );
 #endif
@@ -123,7 +78,7 @@ KAction * KopeteStdAction::chat( const QObject *recvr, const char *slot, QObject
 
 KAction * KopeteStdAction::sendMessage( const QObject *recvr, const char *slot, QObject *parent, const char *name )
 {
-	return new KAction( i18n( "&Send Message..." ), QString::fromLatin1( "mail_generic" ), 0, recvr, slot, parent, name );
+	return new KAction( i18n( "&Send Single Message..." ), QString::fromLatin1( "mail_generic" ), 0, recvr, slot, parent, name );
 }
 
 KAction * KopeteStdAction::contactInfo( const QObject *recvr, const char *slot, QObject *parent, const char *name )
@@ -151,19 +106,9 @@ KAction * KopeteStdAction::changeMetaContact( const QObject *recvr, const char *
 	return new KAction( i18n( "Cha&nge Meta Contact..." ), QString::fromLatin1( "move" ), 0, recvr, slot, parent, name );
 }
 
-KListAction * KopeteStdAction::moveContact( const QObject *recvr, const char *slot, QObject *parent, const char *name )
-{
-	return new KopeteGroupListAction( i18n( "&Move To" ), QString::fromLatin1( "editcut" ), 0, recvr, slot, parent, name );
-}
-
-KListAction * KopeteStdAction::copyContact( const QObject *recvr, const char *slot, QObject *parent, const char *name )
-{
-	return new KopeteGroupListAction( i18n( "Cop&y To" ), QString::fromLatin1( "editcopy" ), 0, recvr, slot, parent, name );
-}
-
 KAction * KopeteStdAction::deleteContact( const QObject *recvr, const char *slot, QObject *parent, const char *name )
 {
-	return new KAction( i18n( "&Delete Contact..." ), QString::fromLatin1( "edittrash" ), 0, recvr, slot, parent, name );
+	return new KAction( i18n( "&Delete Contact" ), QString::fromLatin1( "editdelete" ), Qt::Key_Delete, recvr, slot, parent, name );
 }
 
 KAction * KopeteStdAction::changeAlias( const QObject *recvr, const char *slot, QObject *parent, const char *name )
@@ -171,6 +116,16 @@ KAction * KopeteStdAction::changeAlias( const QObject *recvr, const char *slot,
 	return new KAction( i18n( "Change A&lias..." ), QString::fromLatin1( "signature" ), 0, recvr, slot, parent, name );
 }
 
+KAction * KopeteStdAction::blockContact( const QObject *recvr, const char *slot, QObject* parent, const char *name )
+{
+	return new KAction( i18n( "&Block Contact" ), QString::fromLatin1( "player_pause" ), 0, recvr, slot, parent, name );
+}
+
+KAction * KopeteStdAction::unblockContact( const QObject *recvr, const char *slot, QObject* parent, const char *name )
+{
+	return new KAction( i18n( "Un&block Contact" ), QString::fromLatin1( "player_play" ), 0, recvr, slot, parent, name );
+}
+
 #include "kopetestdaction.moc"
 
 // vim: set noet ts=4 sts=4 sw=4:
