@@ -17,38 +17,33 @@
 
 #include "kopeteview.h"
 
-KopeteView::KopeteView( KopeteMessageManager *manager )
+KopeteView::KopeteView( Kopete::ChatSession *manager, Kopete::ViewPlugin *plugin )
+    : m_manager(manager), m_plugin(plugin)
 {
-	m_manager = manager;
 }
 
-KopeteMessageManager *KopeteView::msgManager()
+Kopete::ChatSession *KopeteView::msgManager() const
 {
 	return m_manager;
 }
 
-const KopeteMessageManager *KopeteView::msgManager() const
-{
-	return m_manager;
-}
-
-KopeteMessage::MessageType KopeteView::viewType()
-{
-	return m_type;
-}
-
 void KopeteView::clear()
 {
 	//Do nothing
 }
 
-void KopeteView::appendMessages(QValueList<KopeteMessage> msgs)
+void KopeteView::appendMessages(QValueList<Kopete::Message> msgs)
 {
-	QValueList<KopeteMessage>::iterator it;
-    for ( it = msgs.begin(); it != msgs.end(); ++it )
+	QValueList<Kopete::Message>::iterator it;
+	for ( it = msgs.begin(); it != msgs.end(); ++it )
 	{
 		appendMessage(*it);
 	}
 
 }
 
+Kopete::ViewPlugin *KopeteView::plugin()
+{
+	return m_plugin;
+}
+
