@@ -29,15 +29,15 @@ K_EXPORT_COMPONENT_FACTORY( kopete_autoreplace, AutoReplacePluginFactory( "kopet
 AutoReplacePlugin * AutoReplacePlugin::pluginStatic_ = 0L;
 
 AutoReplacePlugin::AutoReplacePlugin( QObject *parent, const char * name, const QStringList & )
-: KopetePlugin( AutoReplacePluginFactory::instance(), parent, name )
+: Kopete::Plugin( AutoReplacePluginFactory::instance(), parent, name )
 {
 	if( !pluginStatic_ )
 		pluginStatic_ = this;
 
 	m_prefs = new AutoReplaceConfig;
 
-	connect( KopeteMessageManagerFactory::factory(), SIGNAL( aboutToSend( KopeteMessage & ) ),
-		this, SLOT( slotAboutToSend( KopeteMessage & ) ) );
+	connect( Kopete::ChatSessionManager::self(), SIGNAL( aboutToSend( Kopete::Message & ) ),
+		this, SLOT( slotAboutToSend( Kopete::Message & ) ) );
 
 	connect( this, SIGNAL( settingsChanged() ), this, SLOT( slotSettingsChanged() ) );
 }
@@ -59,32 +59,37 @@ void AutoReplacePlugin::slotSettingsChanged()
 	m_prefs->load();
 }
 
-void AutoReplacePlugin::slotAboutToSend( KopeteMessage &msg )
+void AutoReplacePlugin::slotAboutToSend( Kopete::Message &msg )
 {
-	if ( ( msg.direction() == KopeteMessage::Outbound && m_prefs->autoReplaceOutgoing() ) ||
-		( msg.direction() == KopeteMessage::Inbound && m_prefs->autoReplaceIncoming() ) )
+	if ( ( msg.direction() == Kopete::Message::Outbound && m_prefs->autoReplaceOutgoing() ) ||
+		( msg.direction() == Kopete::Message::Inbound && m_prefs->autoReplaceIncoming() ) )
 	{
 		QString replaced_message = msg.plainBody();
 		AutoReplaceConfig::WordsToReplace map = m_prefs->map();
 
 		// replaces all matched words --> try to find a more 'economic' way
 		// "\\b(%1)\\b" doesn't work when substituting /me.
-		QString match = "(^| |\\.|\\;|\\,|\\:)(%1)($| |\\.|\\;|\\,|\\:)";
+		QString match = "(^|\\s|\\.|\\;|\\,|\\:)(%1)(\\b)";
 		AutoReplaceConfig::WordsToReplace::Iterator it;
+		bool isReplaced=false;
 		for ( it = map.begin(); it != map.end(); ++it )
 		{
 			QRegExp re( match.arg( QRegExp::escape( it.key() ) ) );
-			re.search( replaced_message );
-			QString before = re.cap(1);
-			QString after = re.cap(3);
-			replaced_message.replace( re, before + map.find( it.key() ).data() + after );
+			if( re.search( replaced_message ) != -1 )
+			{
+				QString before = re.cap(1);
+				QString after = re.cap(3);
+				replaced_message.replace( re, before + map.find( it.key() ).data() + after );
+				isReplaced=true;
+			}
 		}
 
 		// the message is now the one with replaced words
-		msg.setBody( replaced_message, KopeteMessage::PlainText );
+		if(isReplaced)
+			msg.setBody( replaced_message, Kopete::Message::PlainText );
 	}
 
-	if( msg.direction() == KopeteMessage::Outbound )
+	if( msg.direction() == Kopete::Message::Outbound )
 	{
 		if ( m_prefs->dotEndSentence() )
 		{
@@ -94,7 +99,7 @@ void AutoReplacePlugin::slotAboutToSend( KopeteMessage &msg )
 			// replaced_message.replace(QRegExp( "([\\w])$" ), "\\1." );
 			
 			// the message is now the one with replaced words
-			msg.setBody( replaced_message, KopeteMessage::PlainText );
+			msg.setBody( replaced_message, Kopete::Message::PlainText );
 		}
 
 		if( m_prefs->capitalizeBeginningSentence() )
@@ -105,7 +110,7 @@ void AutoReplacePlugin::slotAboutToSend( KopeteMessage &msg )
 			replaced_message[ 0 ] = replaced_message.at( 0 ).upper();
 			
 			// the message is now the one with replaced words
-			msg.setBody( replaced_message, KopeteMessage::PlainText );
+			msg.setBody( replaced_message, Kopete::Message::PlainText );
 		}
 	}
 }
