@@ -34,13 +34,13 @@ class NowListeningGUIClient : public QObject , public KXMLGUIClient
 {
 Q_OBJECT
 	public:
-		NowListeningGUIClient( KopeteMessageManager *parent );
+		NowListeningGUIClient( Kopete::ChatSession *parent );
 		virtual ~NowListeningGUIClient() {}
 	protected slots:
 		void slotAdvertToCurrentChat();
 
 	private:
-		KopeteMessageManager* m_msgManager;
+		Kopete::ChatSession* m_msgManager;
 };
 
 #endif
