@@ -28,6 +28,8 @@
 #include "config.h"
 #include "kopetemessagemanagerfactory.h"
 #include "kopetemetacontact.h"
+#include "kopetecontact.h"
+#include "kopetecommandhandler.h"
 #include "nowlisteningconfig.h"
 #include "nowlisteningplugin.h"
 #include "nlmediaplayer.h"
@@ -46,7 +48,7 @@ typedef KGenericFactory<NowListeningPlugin> NowListeningPluginFactory;
 K_EXPORT_COMPONENT_FACTORY( kopete_nowlistening, NowListeningPluginFactory( "kopete_nowlistening" )  )
 
 NowListeningPlugin::NowListeningPlugin( QObject *parent, const char* name, const QStringList& /*args*/ )
-: KopetePlugin( NowListeningPluginFactory::instance(), parent, name )
+: Kopete::Plugin( NowListeningPluginFactory::instance(), parent, name )
 {
 	if ( pluginStatic_ )
 		kdDebug( 14307 )<<"####"<<"Now Listening already initialized"<<endl;
@@ -58,20 +60,18 @@ NowListeningPlugin::NowListeningPlugin( QObject *parent, const char* name, const
 	m_actionCollection = 0L;
 	m_actionWantsAdvert = 0L;
 	m_currentMetaContact = 0L;
-	m_currentMessageManager = 0L;
+	m_currentChatSession = 0L;
 
 	// initialise preferences
 	m_config = new NowListeningConfig;
 
-	connect( KopeteMessageManagerFactory::factory(), SIGNAL(
-			messageManagerCreated( KopeteMessageManager * )) , SLOT( slotNewKMM(
-			KopeteMessageManager * ) ) );
+	connect( Kopete::ChatSessionManager::self(), SIGNAL(
+			chatSessionCreated( Kopete::ChatSession * )) , SLOT( slotNewKMM(
+			Kopete::ChatSession * ) ) );
 
-	QIntDict<KopeteMessageManager> sessions =
-			KopeteMessageManagerFactory::factory()->sessions();
-	QIntDictIterator<KopeteMessageManager> it( sessions );
-	for ( ; it.current() ; ++it )
-		slotNewKMM( it.current() );
+	QValueList<Kopete::ChatSession*> sessions = Kopete::ChatSessionManager::self()->sessions();
+	for (QValueListIterator<Kopete::ChatSession*> it= sessions.begin(); it!=sessions.end() ; ++it)
+	  slotNewKMM( *it );
 
 	// get a pointer to the dcop client
 	m_client = kapp->dcopClient(); //new DCOPClient();
@@ -90,10 +90,14 @@ NowListeningPlugin::NowListeningPlugin( QObject *parent, const char* name, const
 #endif
 
 	// watch for '/media' getting typed
-	connect(  KopeteMessageManagerFactory::factory(),
-			SIGNAL( aboutToSend( KopeteMessage & ) ),
-			SLOT( slotOutgoingMessage( KopeteMessage & ) ) );
-			
+	Kopete::CommandHandler::commandHandler()->registerCommand(
+		this,
+		"media",
+		SLOT( slotMediaCommand( const QString &, Kopete::ChatSession * ) ),
+		i18n("USAGE: /media - Displays information on current song"),
+		0
+	);
+
 	connect ( this , SIGNAL( settingsChanged() ) , this , SLOT( slotSettingsChanged() ) );
 }
 
@@ -107,7 +111,7 @@ NowListeningPlugin::~NowListeningPlugin()
 	pluginStatic_ = 0L;
 }
 
-void NowListeningPlugin::slotNewKMM(KopeteMessageManager *KMM)
+void NowListeningPlugin::slotNewKMM(Kopete::ChatSession *KMM)
 {
 	new NowListeningGUIClient( KMM );
 }
@@ -117,30 +121,25 @@ NowListeningPlugin* NowListeningPlugin::plugin()
 	return pluginStatic_ ;
 }
 
-void NowListeningPlugin::slotOutgoingMessage( KopeteMessage& msg )
+void NowListeningPlugin::slotMediaCommand( const QString &args, Kopete::ChatSession *theChat )
 {
-	QString originalBody = msg.plainBody();
-	// look for messages that we've generated and ignore them
-	if ( !originalBody.startsWith( m_config->header() ) )
+	QString advert = allPlayerAdvert();
+	if ( advert.isEmpty() )
 	{
-		// look for the string '/media'
-		if ( originalBody.startsWith( "/media" ) )
-		{
-			QString advert = allPlayerAdvert();
-			if ( advert.isEmpty() )
-			{
-				// Catch no players/no track playing message case:
-				// Since we can't stop a message send in a plugin, add some message text to
-				// prevent us sending an empty message
-				advert = i18n("Message from Kopete user to another user; used when sending media information even though there are no songs playing or no media players running", "Now Listening for Kopete - it would tell you what I am listening to, if I was listening to something on a supported media player.");
-			}
-			// replace it with media advert
-			QString newBody = advert + originalBody.right(
-					originalBody.length() - 6 );
-			msg.setBody( newBody, KopeteMessage::RichText );
-		}
-		return;
+		// Catch no players/no track playing message case:
+		// Since we can't stop a message send in a plugin, add some message text to
+		// prevent us sending an empty message
+		advert = i18n("Message from Kopete user to another user; used when sending media information even though there are no songs playing or no media players running", "Now Listening for Kopete - it would tell you what I am listening to, if I was listening to something on a supported media player.");
 	}
+	
+	Kopete::Message msg( theChat->myself(),
+			theChat->members(),
+			advert + " " + args,
+			Kopete::Message::Outbound,
+			Kopete::Message::RichText
+	);
+	
+	theChat->sendMessage( msg );
 }
 
 QString NowListeningPlugin::allPlayerAdvert() const
@@ -251,24 +250,24 @@ QString NowListeningPlugin::substDepthFirst( NLMediaPlayer *player,
 		return in;
 }
 
-void NowListeningPlugin::advertiseToChat( KopeteMessageManager *theChat, QString message )
+void NowListeningPlugin::advertiseToChat( Kopete::ChatSession *theChat, QString message )
 {
-	KopeteContactPtrList pl = theChat->members();
+	Kopete::ContactPtrList pl = theChat->members();
 
 	// get on with it
 	kdDebug(14307) << k_funcinfo <<
 		( pl.isEmpty() ? "has no " : "has " ) << "interested recipients: " << endl;
-	for ( pl.first(); pl.current(); pl.next() )
-		kdDebug(14307) << "NowListeningPlugin::advertiseNewTracks() " << pl.current()->displayName() << endl;
+/*	for ( pl.first(); pl.current(); pl.next() )
+		kdDebug(14307) << "NowListeningPlugin::advertiseNewTracks() " << pl.current()->displayName() << endl; */
 	// if no-one in this KMM wants to be advertised to, don't send
 	// any message
 	if ( pl.isEmpty() )
 		return;
-	KopeteMessage msg( theChat->user(),
+	Kopete::Message msg( theChat->myself(),
 			pl,
 			message,
-			KopeteMessage::Outbound,
-			KopeteMessage::RichText );
+			Kopete::Message::Outbound,
+			Kopete::Message::RichText );
 	theChat->sendMessage( msg );
 }
 
