@@ -24,6 +24,7 @@
 #include "kopeteplugin.h"
 #include <qptrlist.h>
 
+namespace Kopete { class ChatSession; }
 
 class QTimer;
 class DCOPClient;
@@ -35,7 +36,7 @@ class NLMediaPlayer;
 /**
  * @author Will Stephenson
  */
-class NowListeningPlugin : public KopetePlugin
+class NowListeningPlugin : public Kopete::Plugin
 {
 	Q_OBJECT
 
@@ -47,10 +48,7 @@ friend class NowListeningGUIClient;
 		static NowListeningPlugin* plugin();
 
 	public slots:
-		/**
-		 * Perform any string substitution needed on outgoing messages
-		 */
-		void slotOutgoingMessage( KopeteMessage& msg );
+	  	void slotMediaCommand( const QString &, Kopete::ChatSession *theChat );
 
 	protected:
 		/**
@@ -68,13 +66,13 @@ friend class NowListeningGUIClient;
 		/**
 		 * Sends a message to a single chat
 		 */
-		void advertiseToChat( KopeteMessageManager* theChat, QString message );
+		void advertiseToChat( Kopete::ChatSession* theChat, QString message );
 
 	protected slots:
 		/**
 		 * Reacts to a new chat starting and adds actions to its GUI
 		 */
-		void slotNewKMM( KopeteMessageManager* );
+		void slotNewKMM( Kopete::ChatSession* );
 		
 		/**
 		 * Reacts to the plugin's settings changed signal, originating from the KCModule dispatcher
@@ -90,9 +88,9 @@ friend class NowListeningGUIClient;
 		DCOPClient *m_client;
 		// Support GUI actions
 		KActionCollection *m_actionCollection;
-		KopeteMessageManager *m_currentMessageManager;
+		Kopete::ChatSession *m_currentChatSession;
 		KToggleAction *m_actionWantsAdvert;
-		KopeteMetaContact *m_currentMetaContact;
+		Kopete::MetaContact *m_currentMetaContact;
 
 		static NowListeningPlugin* pluginStatic_;
 };
