@@ -1,4 +1,4 @@
-/* $Id: pubdir50.c 358826 2004-10-29 17:58:47Z gj $ */
+/* $Id: pubdir50.c 436359 2005-07-19 15:34:38Z gj $ */
 
 /*
  *  (C) Copyright 2003 Wojtek Kaniewski <wojtekka@irc.pl>
@@ -12,10 +12,10 @@
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- *  02111-1307, USA.
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307,
+ *  USA.
  */
 
 #include <errno.h>
@@ -84,7 +84,7 @@ int gg_pubdir50_add_n(gg_pubdir50_t req, int num, const char *field, const char
 
 		return 0;
 	}
-
+		
 	if (!(dupfield = strdup(field))) {
 		gg_debug(GG_DEBUG_MISC, "// gg_pubdir50_add_n() out of memory\n");
 		free(dupvalue);
@@ -139,7 +139,7 @@ int gg_pubdir50_add(gg_pubdir50_t req, const char *field, const char *value)
 int gg_pubdir50_seq_set(gg_pubdir50_t req, uint32_t seq)
 {
 	gg_debug(GG_DEBUG_FUNCTION, "** gg_pubdir50_seq_set(%p, %d);\n", req, seq);
-
+	
 	if (!req) {
 		gg_debug(GG_DEBUG_MISC, "// gg_pubdir50_seq_set() invalid arguments\n");
 		errno = EFAULT;
@@ -164,7 +164,7 @@ void gg_pubdir50_free(gg_pubdir50_t s)
 
 	if (!s)
 		return;
-
+	
 	for (i = 0; i < s->entries_count; i++) {
 		free(s->entries[i].field);
 		free(s->entries[i].value);
@@ -192,7 +192,7 @@ uint32_t gg_pubdir50(struct gg_session *sess, gg_pubdir50_t req)
 	struct gg_pubdir50_request *r;
 
 	gg_debug(GG_DEBUG_FUNCTION, "** gg_pubdir50(%p, %p);\n", sess, req);
-
+	
 	if (!sess || !req) {
 		gg_debug(GG_DEBUG_MISC, "// gg_pubdir50() invalid arguments\n");
 		errno = EFAULT;
@@ -209,7 +209,7 @@ uint32_t gg_pubdir50(struct gg_session *sess, gg_pubdir50_t req)
 		/* wyszukiwanie bierze tylko pierwszy wpis */
 		if (req->entries[i].num)
 			continue;
-
+		
 		size += strlen(req->entries[i].field) + 1;
 		size += strlen(req->entries[i].value) + 1;
 	}
@@ -261,12 +261,12 @@ int gg_pubdir50_handle_reply(struct gg_event *e, const char *packet, int length)
 	struct gg_pubdir50_reply *r = (struct gg_pubdir50_reply*) packet;
 	gg_pubdir50_t res;
 	int num = 0;
-
+	
 	gg_debug(GG_DEBUG_FUNCTION, "** gg_pubdir50_handle_reply(%p, %p, %d);\n", e, packet, length);
 
 	if (!e || !packet) {
 		gg_debug(GG_DEBUG_MISC, "// gg_pubdir50_handle_reply() invalid arguments\n");
-		errno = EINVAL;
+		errno = EFAULT;
 		return -1;
 	}
 
@@ -318,7 +318,7 @@ int gg_pubdir50_handle_reply(struct gg_event *e, const char *packet, int length)
 		}
 
 		value = NULL;
-
+		
 		for (p = field; p < end; p++) {
 			/* jeli mamy koniec tekstu... */
 			if (!*p) {
@@ -333,7 +333,7 @@ int gg_pubdir50_handle_reply(struct gg_event *e, const char *packet, int length)
 					break;
 			}
 		}
-
+		
 		/* sprawdmy, czy pole nie wychodzi poza pakiet, eby nie
 		 * mie segfaultw, jeli serwer przestanie zakacza pakietw
 		 * przez \0 */
@@ -354,10 +354,10 @@ int gg_pubdir50_handle_reply(struct gg_event *e, const char *packet, int length)
 			if (gg_pubdir50_add_n(res, num, field, value) == -1)
 				goto failure;
 		}
-	}
+	}	
 
 	res->count = num + 1;
-
+	
 	return 0;
 
 failure:
