@@ -19,29 +19,35 @@
 #ifndef IRCACCOUNT_H
 #define IRCACCOUNT_H
 
-#include <qstring.h>
-#include <qstringlist.h>
+#include "ircprotocol.h"
+
+#include "kircengine.h"
+
+#include "kopetepasswordedaccount.h"
+
 #include <kdialogbase.h>
 
-#include "kopeteaccount.h"
-#include "ircprotocol.h"
+#include <qstring.h>
+#include <qstringlist.h>
+
+class ChannelList;
+class IRCChannelContact;
+class IRCContactManager;
+class IRCServerContact;
+class IRCProtocol;
+class IRCUserContact;
+
+namespace Kopete
+{
+class AwayAction;
+class Contact;
+class Message;
+class ChatSession;
+class MetaContact;
+}
 
 class KAction;
 class KActionMenu;
-class KopeteAwayAction;
-
-class KopeteMetaContact;
-class KopeteMessage;
-class KopeteContact;
-class KopeteMessageManager;
-
-class KIRC;
-class IRCProtocol;
-class IRCContactManager;
-class IRCChannelContact;
-class IRCServerContact;
-class IRCUserContact;
-class ChannelList;
 
 struct IRCHost
 {
@@ -58,12 +64,13 @@ struct IRCNetwork
 	QValueList<IRCHost*> hosts;
 };
 
-class ChannelListDialog : public KDialogBase
+class ChannelListDialog
+	: public KDialogBase
 {
 	Q_OBJECT
 
 	public:
-		ChannelListDialog( KIRC *engine, const QString &caption, QObject *target, const char* slotJoinChan );
+		ChannelListDialog(KIRC::Engine *engine, const QString &caption, QObject *target, const char* slotJoinChan);
 
 		void clear();
 
@@ -73,11 +80,12 @@ class ChannelListDialog : public KDialogBase
 		void slotChannelDoubleClicked( const QString & );
 
 	private:
-		KIRC *m_engine;
+		KIRC::Engine *m_engine;
 		ChannelList *m_list;
 };
 
-class IRCAccount:  public KopeteAccount
+class IRCAccount
+	: public Kopete::PasswordedAccount
 {
 	friend class IRCEditAccountWidget;
 	friend class IRCProtocolHandler;
@@ -85,6 +93,12 @@ class IRCAccount:  public KopeteAccount
 	Q_OBJECT
 
 public:
+	static const QString CONFIG_CODECMIB;
+	static const QString CONFIG_NETWORKNAME;
+	static const QString CONFIG_NICKNAME;
+	static const QString CONFIG_USERNAME;
+	static const QString CONFIG_REALNAME;
+
 	enum MessageType
 	{
 		ConnectReply = 1,
@@ -99,16 +113,27 @@ public:
 	{
 		ActiveWindow = 1,
 		ServerWindow = 2,
-		AnonymousWindow = 4,
-		KNotify = 8,
-		Ignore = 16
+		AnonymousWindow = 3,
+		KNotify = 4,
+		Ignore = 5
 	};
 
 	IRCAccount(IRCProtocol *p, const QString &accountid, const QString &autoConnect = QString::null);
 	~IRCAccount();
 
+	void setNickName( const QString & );
+
+	void setAutoShowServerWindow( bool show );
+
+	void setAltNick( const QString & );
+	const QString altNick() const;
+
+	void setUserName( const QString & );
 	const QString userName() const;
 
+	void setRealName( const QString & );
+	const QString realName() const;
+
 	const QStringList connectCommands() const;
 
 	void setConnectCommands( const QStringList & ) const;
@@ -119,22 +144,17 @@ public:
 
 	void setDefaultQuit( const QString & );
 
-	void setUserName( const QString & );
-
-	void setNickName( const QString & );
-
-	void setAltNick( const QString & );
-
 	void setCodec( QTextCodec *codec );
 
+	void setMessageDestinations( int serverNotices, int serverMessages,
+		int informationReplies, int errorMessages );
+
 	QTextCodec *codec() const;
 
 	const QString defaultPart() const;
 
 	const QString defaultQuit() const;
 
-	const QString altNick() const;
-
 	const QString networkName() const;
 
 	QMap< QString, QString > customCtcp() const;
@@ -151,23 +171,26 @@ public slots:
 
 	virtual bool isConnected();
 
+	/** Reimplemented from Kopete::Account */
+	void setOnlineStatus( const Kopete::OnlineStatus& status , const QString &reason = QString::null);
+
 	// Returns the KIRC engine instance
-	KIRC *engine() const { return m_engine; }
+	KIRC::Engine *engine() const { return m_engine; }
 
 	// Returns the IRCProtocol instance for contacts
 	IRCProtocol *protocol() const { return m_protocol; }
 
 	IRCContactManager *contactManager() const { return m_contactManager; }
 
-	// Returns the KopeteContact of the user
+	// Returns the Kopete::Contact of the user
 	IRCUserContact *mySelf() const;
 
-	// Returns the KopeteContact of the server of the user
+	// Returns the Kopete::Contact of the server of the user
 	IRCServerContact *myServer() const;
 
 	void successfullyChangedNick(const QString &, const QString &);
 
-	virtual void connect();
+	virtual void connectWithPassword( const QString & );
 	virtual void disconnect();
 
 	void quit( const QString &quitMessage = QString::null );
@@ -177,12 +200,11 @@ public slots:
 	void appendMessage( const QString &message, MessageType type = Default );
 
 protected:
-	virtual bool addContactToMetaContact( const QString &contactId, const QString &displayName, KopeteMetaContact *parentContact ) ;
-
-protected slots:
-	virtual void loaded();
+	virtual bool createContact( const QString &contactId, Kopete::MetaContact *parentContact ) ;
 
 private slots:
+	void engineStatusChanged(KIRC::Engine::Status newStatus);
+
 	void slotFailedServerPassword();
 	void slotGoAway( const QString &reason );
 	void slotJoinNamedChannel( const QString &channel );
@@ -190,25 +212,31 @@ private slots:
 	void slotShowServerWindow();
 	void slotNickInUse( const QString &nick );
 	void slotNickInUseAlert( const QString &nick );
-	void slotConnectedToServer();
-	void slotDisconnected();
 	void slotServerBusy();
+	void slotNoSuchNickname( const QString &nick );
 	void slotSearchChannels();
 	void slotNewCtcpReply(const QString &type, const QString &target, const QString &messageReceived);
 	void slotJoinedUnknownChannel( const QString &channel, const QString &nick );
+	void slotPerformOnConnectCommands();
 
 private:
-	KopeteMessageManager *m_manager;
+	Kopete::ChatSession *m_manager;
 	QString mNickName;
-	KopeteAwayAction *mAwayAction;
+	Kopete::AwayAction *mAwayAction;
 	bool triedAltNick;
+	bool autoShowServerWindow;
 	QString autoConnect;
 
-	KIRC *m_engine;
+	KIRC::Engine *m_engine;
 	IRCNetwork *m_network;
 	uint currentHost;
 	QTextCodec *mCodec;
 
+	MessageDestination m_serverNotices;
+	MessageDestination m_serverMessages;
+	MessageDestination m_informationReplies;
+	MessageDestination m_errorMessages;
+
 	ChannelListDialog *m_channelList;
 
 	IRCContactManager *m_contactManager;
