@@ -19,7 +19,7 @@
 #include <qobject.h>
 #include <kxmlguiclient.h>
 
-class KopeteMessageManager;
+namespace Kopete { class ChatSession; }
 class IRCContact;
 
 /**
@@ -29,7 +29,7 @@ class IRCGUIClient : public QObject , public KXMLGUIClient
 {
 	Q_OBJECT
 	public:
-		IRCGUIClient( KopeteMessageManager *parent = 0 );
+		IRCGUIClient( Kopete::ChatSession *parent = 0 );
 		~IRCGUIClient();
 	
 	private slots:
