@@ -18,11 +18,14 @@
 #ifndef IRCSERVERCONTACT_H
 #define IRCSERVERCONTACT_H
 
-#include <qvaluelist.h>
-#include <qstringlist.h>
+#include "irccontact.h"
+
+#include "kircengine.h"
 
 #include "kopetemessagemanagerfactory.h"
-#include "irccontact.h"
+
+#include <qvaluelist.h>
+#include <qstringlist.h>
 
 class KActionCollection;
 class KAction;
@@ -35,25 +38,26 @@ class IRCChannelContact;
 /**
  * @author Michel Hermier <michel.hermier@wanadoo.fr>
  *
- * This class is the @ref KopeteContact object representing IRC Servers.
+ * This class is the @ref Kopete::Contact object representing IRC Servers.
  * It is derrived from @ref IRCContact where much of its functionality is shared with @ref IRCChannelContact and @ref IRCUserContact.
  */
-class IRCServerContact : public IRCContact
+class IRCServerContact
+	: public IRCContact
 {
 	Q_OBJECT
 
 	public:
-		// This class provides a KopeteContact for each server of a given IRC connection.
-		IRCServerContact(IRCContactManager *, const QString &servername, KopeteMetaContact *mc);
+		// This class provides a Kopete::Contact for each server of a given IRC connection.
+		IRCServerContact(IRCContactManager *, const QString &servername, Kopete::MetaContact *mc);
 
 		virtual const QString caption() const;
 
-		virtual void appendMessage(KopeteMessage &);
+		virtual void appendMessage(Kopete::Message &);
                 void appendMessage( const QString &message );
 
 	protected slots:
-		void engineInternalError(KIRC::EngineError error, const KIRCMessage &ircmsg);
-		virtual void slotSendMsg(KopeteMessage &message, KopeteMessageManager *);
+		void engineInternalError(KIRC::Engine::Error error, KIRC::Message &ircmsg);
+		virtual void slotSendMsg(Kopete::Message &message, Kopete::ChatSession *);
 
 	private slots:
 		virtual void updateStatus();
@@ -67,7 +71,7 @@ class IRCServerContact : public IRCContact
 		void slotCannotSendToChannel( const QString &channel, const QString &msg );
 
 	private:
-		QValueList<KopeteMessage> mMsgBuffer;
+		QValueList<Kopete::Message> mMsgBuffer;
 };
 
 #endif
