@@ -18,7 +18,7 @@
 #ifndef KIRCMESSAGE_H
 #define KIRCMESSAGE_H
 
-#include "kircentity.h" // Don't remove this prefix should/could(MUST?) be returned as a KIRCEntity
+#include "kircentity.h"
 
 #include <kbufferedio.h>
 
@@ -28,47 +28,52 @@
 #include <qtextcodec.h>
 #include <qregexp.h>
 
+#include <kopetemessage.h>
+
 // Uncoment this if you want a really rfc compliant message handling.
 // This is due to some changes of the message encoding with 14 arguments.(not very frequent :)
 // #define _IRC_STRICTNESS_
 
-class KIRC;
+namespace KIRC
+{
 
-class KIRCMessage
+class Engine;
+
+class Message
 {
-friend class KIRC;
 public:
-	KIRCMessage();
-	KIRCMessage(const KIRCMessage &obj);
-	KIRCMessage(const KIRCMessage *obj);
+	Message();
+	Message(const KIRC::Message &obj);
+	Message(const KIRC::Message *obj);
 
-	~KIRCMessage();
+	~Message();
 
-	static void writeRawMessage(KIRC *engine, const QTextCodec *codec, const QString &str);
+	static void writeRawMessage(KIRC::Engine *engine, const QTextCodec *codec, const QString &str);
 
-	static void writeMessage(KIRC *engine, const QTextCodec *codec, const QString &str);
+	static void writeMessage(KIRC::Engine *engine, const QTextCodec *codec, const QString &str);
 
-	static void writeMessage(KIRC *engine, const QTextCodec *codec,
+	static void writeMessage(KIRC::Engine *engine, const QTextCodec *codec,
 		const QString &command, const QStringList &args, const QString &suffix);
 
-	static void writeCtcpMessage(KIRC *engine, const QTextCodec *codec,
+	static void writeCtcpMessage(KIRC::Engine *engine, const QTextCodec *codec,
 		const QString &command, const QString &to,
 		const QString &ctcpMessage);
 
-	static void writeCtcpMessage(KIRC *engine, const QTextCodec *codec,
+	static void writeCtcpMessage(KIRC::Engine *engine, const QTextCodec *codec,
 		const QString &command, const QString &to, const QString &suffix,
 		const QString &ctcpCommand, const QStringList &ctcpArgs = QStringList(), const QString &ctcpSuffix = QString::null );
 
 	inline const QString nickFromPrefix() const
-		{ return KIRCEntity::userNick(m_prefix); }
+	{ return Kopete::Message::unescape(KIRC::Entity::userNick(m_prefix)); }
 
 	QString toString() const;
 
 	bool isNumeric() const;
 	bool isValid() const;
 	void dump() const;
+	void decodeAgain( const QTextCodec *codec );
 
-	inline const QString &raw() const
+	inline const QCString &raw() const
 		{ return m_raw; }
 	inline const QString &prefix() const
 		{ return m_prefix; }
@@ -87,16 +92,16 @@ public:
 
 	inline bool hasCtcpMessage() const
 		{ return m_ctcpMessage!=0; }
-	inline const class KIRCMessage &ctcpMessage() const
+	inline class KIRC::Message &ctcpMessage() const
 		{ return *m_ctcpMessage; }
 
-	static KIRCMessage parse(KIRC *engine, const QTextCodec *codec, bool *parseSuccess=0);
+	static KIRC::Message parse(KIRC::Engine *engine, const QTextCodec *codec, bool *parseSuccess=0);
 
 private:
 	/**
 	 * Contains the low level dequoted message.
 	 */
-	QString m_raw;
+	QCString m_raw;
 
 	/**
 	 * Contains the completely dequoted prefix.
@@ -129,12 +134,12 @@ private:
 	static QString ctcpQuote(const QString &str);
 	static QString ctcpUnquote(const QString &str);
 
-	static bool extractCtcpCommand(QString &str, QString &ctcpline);
+	static bool extractCtcpCommand(QCString &str, QCString &ctcpline);
 
-	static bool matchForIRCRegExp(const QString &line, const QTextCodec *codec, KIRCMessage &message);
-	static bool matchForIRCRegExp(QRegExp &regexp, const QTextCodec *codec, const QString &line, KIRCMessage &message);
+	static bool matchForIRCRegExp(const QCString &line, const QTextCodec *codec, KIRC::Message &message);
+	static bool matchForIRCRegExp(QRegExp &regexp, const QTextCodec *codec, const QCString &line, KIRC::Message &message);
 
-	class KIRCMessage *m_ctcpMessage;
+	class KIRC::Message *m_ctcpMessage;
 
 	static QRegExp m_IRCCommandType1;
   #ifdef _IRC_STRICTNESS_
@@ -144,4 +149,6 @@ private:
 	static QRegExp m_IRCNumericCommand;
 };
 
+}
+
 #endif // KIRCMESSAGE_H
