@@ -409,7 +409,7 @@ void JabberAccount::connectWithPassword ( const QString &password )
 	 */
 	jabberClientConnector = new JabberConnector;
 	jabberClientConnector->setOptHostPort (server (), port ());
-	jabberClientConnector->setOptSSL(trySSL);
+	jabberClientConnector->setOptSSL ( trySSL );
 
 	/*
 	 * Setup authentication layer
@@ -423,6 +423,9 @@ void JabberAccount::connectWithPassword ( const QString &password )
 			using namespace XMPP;
 			QObject::connect(jabberTLSHandler, SIGNAL(tlsHandshaken()), this, SLOT(slotTLSHandshaken()));
 		}
+
+		QPtrList<QCA::Cert> certStore;
+		jabberTLS->setCertificateStore ( certStore );
 	}
 
 	/*
@@ -828,7 +831,7 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 	QString errorText;
 	QString errorCondition;
 
-	errorClass = Kopete::Account::Unknown;
+	errorClass = Kopete::Account::InvalidHost;
 
 	/*
 	 * Display error to user.
@@ -837,10 +840,12 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 	switch(streamError)
 	{
 		case XMPP::Stream::ErrParse:
+			errorClass = Kopete::Account::Unknown;
 			errorText = i18n("Malformed packet received.");
 			break;
 
 		case XMPP::Stream::ErrProtocol:
+			errorClass = Kopete::Account::Unknown;
 			errorText = i18n("There was an unrecoverable error in the protocol.");
 			break;
 
@@ -887,7 +892,6 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 			break;
 
 		case XMPP::ClientStream::ErrConnection:
-			errorClass = Kopete::Account::InvalidHost;
 			switch(connectorCode)
 			{
  				case KNetwork::KSocketBase::LookupFailure:
@@ -969,7 +973,6 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 			break;
 
 		case XMPP::ClientStream::ErrTLS:
-			errorClass = Kopete::Account::InvalidHost;
 			switch(streamCondition)
 			{
 				case XMPP::ClientStream::TLSStart:
@@ -987,7 +990,6 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 			break;
 
 		case XMPP::ClientStream::ErrAuth:
-			errorClass = Kopete::Account::InvalidHost;
 			switch(streamCondition)
 			{
 				case XMPP::ClientStream::GenericAuthError:
@@ -1032,7 +1034,6 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 			break;
 
 		case XMPP::ClientStream::ErrSecurityLayer:
-			errorClass = Kopete::Account::InvalidHost;
 			switch(streamCondition)
 			{
 				case XMPP::ClientStream::LayerTLS:
@@ -1050,7 +1051,6 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 			break;
 
 		case XMPP::ClientStream::ErrBind:
-			errorClass = Kopete::Account::InvalidHost;
 			switch(streamCondition)
 			{
 				case XMPP::ClientStream::BindNotAllowed:
@@ -1768,10 +1768,14 @@ void JabberAccount::slotGroupChatPresence (const XMPP::Jid & jid, const XMPP::St
 
 }
 
-void JabberAccount::slotGroupChatError (const XMPP::Jid & /*jid*/, int /*error*/, const QString & /*reason*/)
+void JabberAccount::slotGroupChatError (const XMPP::Jid &jid, int error, const QString &reason)
 {
-	/* FIXME: Present this to the user, damnit! */
-// 	kdDebug (JABBER_DEBUG_GLOBAL) << "[JabberAccount] Group chat error - room " << jid.userHost () << " had error " << error << " (" << reason << ")!" << endl;
+	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "Group chat error - room " << jid.full () << " had error " << error << " (" << reason << ")" << endl;
+
+	KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (),
+									KMessageBox::Error,
+									i18n ("An error occurred when trying to start a chat: %1").arg ( QString::number ( error ) ),
+									i18n ("Jabber Error") );
 }
 
 void JabberAccount::slotResourceAvailable (const XMPP::Jid & jid, const XMPP::Resource & resource)
