@@ -36,7 +36,7 @@ class JabberConnector;
 class JabberProtocol;
 class QString;
 class QStringList;
-class KopeteMetaContact;
+namespace Kopete { class MetaContact; }
 class KActionMenu;
 class JabberResourcePool;
 class JabberContact;
@@ -104,7 +104,7 @@ public:
 	/*
 	 * Handle stream errors. Displays a dialog and returns.
 	 */
-	static void handleStreamError (int streamError, int streamCondition, int connectorCode, QString server, KopeteAccount::DisconnectReason &errorClass);
+	static void handleStreamError (int streamError, int streamCondition, int connectorCode, QString server, Kopete::Account::DisconnectReason &errorClass);
 
 	/**
 	 * Return the current, shared S5B server instance.
@@ -133,7 +133,10 @@ public slots:
 	void disconnect ();
 
 	/* Disconnect with a reason */
-	void disconnect ( KopeteAccount::DisconnectReason reason );
+	void disconnect ( Kopete::Account::DisconnectReason reason );
+
+	/* Reimplemented from Kopete::Account */
+	void setOnlineStatus( const Kopete::OnlineStatus& status , const QString &reason = QString::null);
 
 protected:
 	/**
@@ -141,8 +144,8 @@ protected:
 	 *
 	 * You shouldn't ever call this method yourself, For adding contacts see @ref addContact()
 	 *
-	 * This method is called by @ref KopeteAccount::addContact() in this method, you should
-	 * simply create the new custom @ref KopeteContact in the given metacontact. You should
+	 * This method is called by @ref Kopete::Account::addContact() in this method, you should
+	 * simply create the new custom @ref Kopete::Contact in the given metacontact. You should
 	 * NOT add the contact to the server here as this method gets only called when synchronizing
 	 * the contact list on disk with the one in memory. As such, all created contacts from this
 	 * method should have the "dirty" flag set.
@@ -151,10 +154,9 @@ protected:
 	 * (updating the GUI, parenting to meta contact, etc.) is being taken care of.
 	 *
 	 * @param contactId The unique ID for this protocol
-	 * @param displayName The displayname of the contact (may equal userId for some protocols)
 	 * @param parentContact The metacontact to add this contact to
 	 */
-	virtual bool addContactToMetaContact (const QString & contactID, const QString & displayName, KopeteMetaContact * parentContact);
+	virtual bool createContact (const QString & contactID, Kopete::MetaContact * parentContact);
 
 private:
 	/* Psi backend for this account. */
@@ -247,7 +249,7 @@ private slots:
 	void slotGoXA ( const QString & );
 
 	/* Set global presence to "do not disturb". */
-	void slotGoDND ( const QString & );
+	void slotGoDND ( const Kopete::OnlineStatus&, const QString & );
 
 	/* Set global presence to "invisible", no reason. */
 	void slotGoInvisible ();
@@ -301,6 +303,12 @@ private slots:
 	 * Update penalty timer
 	 */
 	void slotUpdatePenaltyTime ();
+	
+public:
+	/*
+	 * this is only a temporary solution to don't have an infinite loop whensyncing the contactlist
+	 */
+	bool dontSync;
 
 };
 
