@@ -21,9 +21,9 @@
 #include "jabberbasecontact.h"
 #include "xmpp_vcard.h"
 
-#include "kopetemessagemanager.h" // needed for silly KopeteContactPtrList
+#include "kopetemessagemanager.h" // needed for silly Kopete::ContactPtrList
 
-class JabberMessageManager;
+class JabberChatSession;
 
 class JabberContact : public JabberBaseContact
 {
@@ -33,7 +33,7 @@ Q_OBJECT
 public:
 
 	JabberContact (const XMPP::RosterItem &rosterItem,
-				   JabberAccount *account, KopeteMetaContact * mc);
+				   JabberAccount *account, Kopete::MetaContact * mc);
 
 	/**
 	 * Create custom context menu items for the contact
@@ -41,11 +41,6 @@ public:
 	 */
 	QPtrList<KAction> *customContextMenuActions ();
 
-	/**
-	 * Start a rename request.
-	 */
-	void rename ( const QString &newName );
-
 	/**
 	 * Deal with an incoming message for this contact.
 	 */
@@ -57,7 +52,7 @@ public:
 	 * not suitable for groupchat, as it only looks for
 	 * managers with ourselves in the contact list.
 	 */
-	KopeteMessageManager *manager ( bool canCreate = false );
+	Kopete::ChatSession *manager ( Kopete::Contact::CanCreateFlags );
 	
 	/**
 	 * Reads a vCard object and updates the contact's
@@ -70,12 +65,12 @@ public slots:
 	/**
 	 * Remove this contact from the roster
 	 */
-	void slotDeleteContact ();
+	void deleteContact ();
 
 	/**
 	 * Sync Groups with server
 	 */
-	void syncGroups ();
+	void sync(unsigned int);
 
 	/**
 	 * This is the JabberContact level slot for sending files.
@@ -126,7 +121,7 @@ private slots:
 	*/
 	void slotSelectResource ();
 
-	void slotMessageManagerDeleted ( QObject *sender );
+	void slotChatSessionDeleted ( QObject *sender );
 	
 	/**
 	 * Check if cached vCard is recent.
@@ -157,7 +152,7 @@ private:
 	 * the manager. If a new manager is created, the given
 	 * resource is preselected.
 	 */
-	JabberMessageManager *manager ( const QString &resource, bool canCreate = false );
+	JabberChatSession *manager ( const QString &resource, Kopete::Contact::CanCreateFlags );
 
 	/**
 	 * Create a message manager for this contact.
@@ -165,7 +160,7 @@ private:
 	 * looks for a message manager with a given
 	 * list of contacts as members.
 	 */
-	JabberMessageManager *manager ( KopeteContactPtrList chatMembers, bool canCreate = false );
+	JabberChatSession *manager ( Kopete::ContactPtrList chatMembers, Kopete::Contact::CanCreateFlags );
 
 	/**
 	 * Sends subscription messages.
@@ -184,11 +179,11 @@ private:
 	 * with several resources of the same contact
 	 * at the same time. Note that this does *not*
 	 * apply to group chats, so this variable
-	 * only contains classes of type JabberMessageManager.
-	 * The casts in manager() and slotMessageManagerDeleted()
+	 * only contains classes of type JabberChatSession.
+	 * The casts in manager() and slotChatSessionDeleted()
 	 * are thus legal.
 	 */
-	QPtrList<JabberMessageManager> mManagers;
+	QPtrList<JabberChatSession> mManagers;
 
 	/**
 	 * Indicates whether the vCard is currently
