@@ -245,7 +245,7 @@ void dlgJabberVCard::slotSaveNickname ()
 	}
 	else
 	{
-		jc->rename ( m_mainWidget->leNick->text() );
+		jc->metaContact()->setNameSource ( jc );
 	}
 
 }
