@@ -63,6 +63,7 @@ JabberEditAccountWidget::JabberEditAccountWidget (JabberProtocol * proto, Jabber
 	connect (sbLocalPort, SIGNAL (valueChanged (int)), this, SLOT (configChanged ()));
 	connect (leProxyJID, SIGNAL (textChanged (const QString &)), this, SLOT (configChanged ()));
 
+	
 	if (account())
 	{
 		this->reopen ();
@@ -72,6 +73,9 @@ JabberEditAccountWidget::JabberEditAccountWidget (JabberProtocol * proto, Jabber
 	{
 		connect (btnRegister, SIGNAL (clicked ()), this, SLOT (registerClicked ()));
 	}
+	QWidget::setTabOrder( mID, mPass->mRemembered );
+	QWidget::setTabOrder( mPass->mRemembered, mPass->mPassword );
+	QWidget::setTabOrder( mPass->mPassword, cbAutoConnect );
 }
 
 JabberEditAccountWidget::~JabberEditAccountWidget ()
@@ -109,6 +113,7 @@ void JabberEditAccountWidget::reopen ()
 	if(cbCustomServer->isChecked ())
 	{
 		mServer->setEnabled(true);
+		mPort->setEnabled(true);
 	}
 	else
 	{
@@ -205,13 +210,17 @@ void JabberEditAccountWidget::updateServerField ()
 	if(!cbCustomServer->isChecked())
 	{
 		QString newServer = mID->text().section("@", 1);
-
+		mPort->setValue(5222);
+		// check if ssl is enabled and set the port correctly
+		sslToggled(cbUseSSL->isChecked());
 		mServer->setText(newServer);
 		mServer->setEnabled(false);
+		mPort->setEnabled(false);
 	}
 	else
 	{
 		mServer->setEnabled(true);
+		mPort->setEnabled(true);
 	}
 
 }
