@@ -23,18 +23,11 @@ public:
 	QLabel *noaddMsg2;
 	bool canadd;
 	virtual bool validateData();
-	virtual bool apply( KopeteAccount*, KopeteMetaContact* );
+	virtual bool apply( Kopete::Account*, Kopete::MetaContact* );
 
 };
 
-
 #endif
-/*
- * Local variables:
- * c-indentation-style: k&r
- * c-basic-offset: 8
- * indent-tabs-mode: t
- * End:
- */
+
 // vim: set noet ts=4 sts=4 sw=4:
 
