@@ -4,9 +4,9 @@
     Copyright (c) 2002      by Duncan Mac-Vicar Prett <duncan@kde.org>
     Copyright (c) 2002      by Ryan Cumming           <bodnar42@phalynx.dhs.org>
     Copyright (c) 2002-2003 by Martijn Klingens       <klingens@kde.org>
-    Copyright (c) 2002-2004 by Olivier Goffart        <ogoffart@tiscalinet.be>
+    Copyright (c) 2002-2005 by Olivier Goffart        <ogoffart at kde.org>
 
-    Kopete    (c) 2002-2003 by the Kopete developers  <kopete-devel@kde.org>
+    Kopete    (c) 2002-2005 by the Kopete developers  <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -28,9 +28,11 @@
 #include <kfiledialog.h>
 #include <klineedit.h>
 #include <klocale.h>
+#include <kstandarddirs.h>
 #include <kmessagebox.h>
 #include <krun.h>
 #include <ktempfile.h>
+#include <qregexp.h>
 
 #include "kopetecontactlist.h"
 #include "kopetemessagemanagerfactory.h"
@@ -44,12 +46,10 @@
 #include "msnnotifysocket.h"
 #include "msnaccount.h"
 
-MSNContact::MSNContact( KopeteAccount *account, const QString &id, KopeteMetaContact *parent )
-: KopeteContact( account, id, parent )
+MSNContact::MSNContact( Kopete::Account *account, const QString &id, Kopete::MetaContact *parent )
+: Kopete::Contact( account, id, parent )
 {
-	m_displayPicture = 0L;
-
-	//m_deleted = false;
+	m_deleted = false;
 	m_allowed = false;
 	m_blocked = false;
 	m_reversed = false;
@@ -78,7 +78,6 @@ MSNContact::MSNContact( KopeteAccount *account, const QString &id, KopeteMetaCon
 
 MSNContact::~MSNContact()
 {
-	delete m_displayPicture;
 }
 
 bool MSNContact::isReachable()
@@ -86,7 +85,7 @@ bool MSNContact::isReachable()
 	if ( account()->isConnected() && isOnline() && account()->myself()->onlineStatus() != MSNProtocol::protocol()->HDN )
 		return true;
 
-	MSNMessageManager *kmm=dynamic_cast<MSNMessageManager*>(manager(false));
+	MSNChatSession *kmm=dynamic_cast<MSNChatSession*>(manager(Kopete::Contact::CannotCreate));
 	if( kmm && kmm->service() )  //the chat socket is open.  than mean message will be sent
 		return true;
 
@@ -104,16 +103,16 @@ bool MSNContact::isReachable()
 	return true;
 }
 
-KopeteMessageManager *MSNContact::manager( bool canCreate )
+Kopete::ChatSession *MSNContact::manager( Kopete::Contact::CanCreateFlags canCreate )
 {
-	KopeteContactPtrList chatmembers;
+	Kopete::ContactPtrList chatmembers;
 	chatmembers.append(this);
 
-	KopeteMessageManager *_manager = KopeteMessageManagerFactory::factory()->findKopeteMessageManager(  account()->myself(), chatmembers, protocol() );
-	MSNMessageManager *manager = dynamic_cast<MSNMessageManager*>( _manager );
-	if(!manager &&  canCreate)
+	Kopete::ChatSession *_manager = Kopete::ChatSessionManager::self()->findChatSession(  account()->myself(), chatmembers, protocol() );
+	MSNChatSession *manager = dynamic_cast<MSNChatSession*>( _manager );
+	if(!manager &&  canCreate==Kopete::Contact::CanCreate)
 	{
-		manager = new MSNMessageManager( protocol(), account()->myself(), chatmembers  );
+		manager = new MSNChatSession( protocol(), account()->myself(), chatmembers  );
 		static_cast<MSNAccount*>( account() )->slotStartChatSession( contactId() );
 	}
 	return manager;
@@ -201,7 +200,7 @@ void MSNContact::slotUserInfoDialogReversedToggled()
 		const_cast<QCheckBox*>(cb)->setChecked(m_reversed);
 }
 
-void MSNContact::slotDeleteContact()
+void MSNContact::deleteContact()
 {
 	kdDebug( 14140 ) << k_funcinfo << endl;
 
@@ -215,7 +214,7 @@ void MSNContact::slotDeleteContact()
 			return;
 		}
 
-		for( QMap<uint, KopeteGroup*>::Iterator it = m_serverGroups.begin(); it != m_serverGroups.end(); ++it )
+		for( QMap<uint, Kopete::Group*>::Iterator it = m_serverGroups.begin(); it != m_serverGroups.end(); ++it )
 			notify->removeContact( contactId(), it.key(), MSNProtocol::FL );
 	}
 	else
@@ -237,7 +236,9 @@ void MSNContact::setBlocked( bool blocked )
 	{
 		m_blocked = blocked;
 		//update the status
-		setOnlineStatus(onlineStatus());
+		setOnlineStatus(m_currentStatus);
+		//m_currentStatus is used here.  previously it was  onlineStatus()  but this may cause problem when
+		// the account is offline because of the  Kopete::Contact::OnlineStatus()  account offline hack.
 	}
 }
 
@@ -261,6 +262,18 @@ void MSNContact::setReversed( bool reversed )
 	m_reversed= reversed;
 }
 
+bool MSNContact::isDeleted() const
+{
+	return m_deleted;
+}
+
+void MSNContact::setDeleted( bool deleted )
+{
+	m_deleted= deleted;
+}
+
+
+
 void MSNContact::setInfo(const  QString &type,const QString &data )
 {
 	if( type == "PHH" )
@@ -299,7 +312,7 @@ void MSNContact::serialize( QMap<QString, QString> &serializedData, QMap<QString
 	// Contact id and display name are already set for us, only add the rest
 	QString groups;
 	bool firstEntry = true;
-	for( QMap<uint, KopeteGroup *>::ConstIterator it = m_serverGroups.begin(); it != m_serverGroups.end(); ++it )
+	for( QMap<uint, Kopete::Group *>::ConstIterator it = m_serverGroups.begin(); it != m_serverGroups.end(); ++it )
 	{
 		if( !firstEntry )
 		{
@@ -322,6 +335,7 @@ void MSNContact::serialize( QMap<QString, QString> &serializedData, QMap<QString
 	serializedData[ "PHW" ]  = m_phoneWork;
 	serializedData[ "PHM" ]  = m_phoneMobile;
 	serializedData[ "lists" ] = lists;
+	serializedData[ "obj" ] = m_obj;
 }
 
 QString MSNContact::phoneHome(){ return m_phoneHome ;}
@@ -329,7 +343,7 @@ QString MSNContact::phoneWork(){ return m_phoneWork ;}
 QString MSNContact::phoneMobile(){ return m_phoneMobile ;}
 
 
-const QMap<uint, KopeteGroup*>  MSNContact::serverGroups() const
+const QMap<uint, Kopete::Group*>  MSNContact::serverGroups() const
 {
 	return m_serverGroups;
 }
@@ -339,8 +353,11 @@ void MSNContact::clearServerGroups()
 }
 
 
-void MSNContact::syncGroups( )
+void MSNContact::sync( unsigned int changed )
 {
+	if( !  (changed & Kopete::Contact::MovedBetweenGroup) )
+		return;  //we are only interested by a change in groups
+
 	if(!metaContact() || metaContact()->isTemporary() )
 		return;
 
@@ -355,21 +372,24 @@ void MSNContact::syncGroups( )
 		kdDebug( 14140 ) << k_funcinfo << " This contact is already moving. Abort sync    id: " << contactId() << endl;
 		return;
 	}
-
+	
 	MSNNotifySocket *notify = static_cast<MSNAccount*>( account() )->notifySocket();
 	if( !notify )
 	{
 		//We are not connected, we will doing it next connection.
 		//Force to reload the whole contactlist from server to suync groups when connecting
-		account()->setPluginData(protocol(),"serial", QString::null );
+		account()->configGroup()->writeEntry("serial", 0 );
 		return;
 	}
+	
+	if(m_deleted)  //the contact hasn't been synced from server yet.
+		return; 
 
 	unsigned int count=m_serverGroups.count();
 
 	//STEP ONE : add the contact to every kopetegroups where the MC is
-	QPtrList<KopeteGroup> groupList = metaContact()->groups();
-	for ( KopeteGroup *group = groupList.first(); group; group = groupList.next() )
+	QPtrList<Kopete::Group> groupList = metaContact()->groups();
+	for ( Kopete::Group *group = groupList.first(); group; group = groupList.next() )
 	{
 		//For each group, ensure it is on the MSN server
 		if( !group->pluginData( protocol() , account()->accountId() + " id" ).isEmpty() )
@@ -385,7 +405,7 @@ void MSNContact::syncGroups( )
 				group->setPluginData( protocol() , account()->accountId() + " displayName" , QString::null);
 				kdWarning( 14140 ) << k_funcinfo << " Group " << group->displayName() << " marked with id #" <<Gid << " does not seems to be anymore on the server" << endl;
 
-				if(!group->displayName().isEmpty() && group->type() == KopeteGroup::Normal) //not the top-level
+				if(!group->displayName().isEmpty() && group->type() == Kopete::Group::Normal) //not the top-level
 				{
 					//Create the group and add the contact
 					static_cast<MSNAccount*>( account() )->addGroup( group->displayName(),contactId() );
@@ -404,7 +424,7 @@ void MSNContact::syncGroups( )
 		}
 		else
 		{
-			if(!group->displayName().isEmpty() && group->type() == KopeteGroup::Normal) //not the top-level
+			if(!group->displayName().isEmpty() && group->type() == Kopete::Group::Normal) //not the top-level
 			{
 				//Create the group and add the contact
 				static_cast<MSNAccount*>( account() )->addGroup( group->displayName(),contactId() );
@@ -421,7 +441,7 @@ void MSNContact::syncGroups( )
 	
 	QValueList<int> removinglist; //contact is not in that group. on the server. we will remove them dirrectly after the loop
 	
-	for( QMap<uint, KopeteGroup*>::Iterator it = m_serverGroups.begin();(count > 1 && it != m_serverGroups.end()); ++it )
+	for( QMap<uint, Kopete::Group*>::Iterator it = m_serverGroups.begin();(count > 1 && it != m_serverGroups.end()); ++it )
 	{
 		if( !static_cast<MSNAccount*>( account() )->m_groupList.contains(it.key()) )
 		{ // ohoh!   something is corrupted on the contactlist.xml
@@ -437,7 +457,7 @@ void MSNContact::syncGroups( )
 			continue;
 		}
 
-		KopeteGroup *group=it.data();
+		Kopete::Group *group=it.data();
 		if(!group) //we can't trust the data of it()   see in MSNProtocol::deserializeContact why
 			group=static_cast<MSNAccount*>( account() )->m_groupList[it.key()];
 		if( !metaContact()->groups().contains(group) )
@@ -463,7 +483,7 @@ void MSNContact::syncGroups( )
 
 }
 
-void MSNContact::contactAddedToGroup( uint groupNumber, KopeteGroup *group )
+void MSNContact::contactAddedToGroup( uint groupNumber, Kopete::Group *group )
 {
 	m_serverGroups.insert( groupNumber, group );
 	m_moving=false;
@@ -518,60 +538,57 @@ void MSNContact::sendFile( const KURL &sourceURL, const QString &altFileName, ui
 	if ( !filePath.isEmpty() )
 	{
 		//Send the file
-		static_cast<MSNMessageManager*>( manager(true) )->sendFile( filePath, altFileName, fileSize );
+		static_cast<MSNChatSession*>( manager(Kopete::Contact::CanCreate) )->sendFile( filePath, altFileName, fileSize );
 
 	}
 }
 
-void MSNContact::setOnlineStatus(const KopeteOnlineStatus& status)
+void MSNContact::setOnlineStatus(const Kopete::OnlineStatus& status)
 {
 	if(isBlocked() && status.internalStatus() < 15)
 	{
-		KopeteContact::setOnlineStatus(KopeteOnlineStatus(status.status() , (status.weight()==0) ? 0 : (status.weight() -1)  ,
-			protocol() , status.internalStatus()+15 , QString::fromLatin1("msn_blocked"),
-			status.caption() ,  i18n("%1|Blocked").arg( status.description() ) ) );
+		Kopete::Contact::setOnlineStatus(Kopete::OnlineStatus(status.status() , (status.weight()==0) ? 0 : (status.weight() -1)  ,
+			protocol() , status.internalStatus()+15 , QString::fromLatin1("msn_blocked") ,  i18n("%1|Blocked").arg( status.description() ) ) );
+	}
+	else if(!isBlocked() && status.internalStatus() >= 15)
+	{	//the user is not blocked, but the status is blocked
+		switch(status.internalStatus()-15)
+		{
+			case 1:
+				Kopete::Contact::setOnlineStatus(MSNProtocol::protocol()->NLN);
+				break;
+			case 2:
+				Kopete::Contact::setOnlineStatus(MSNProtocol::protocol()->BSY);
+				break;
+			case 3:
+				Kopete::Contact::setOnlineStatus(MSNProtocol::protocol()->BRB);
+				break;
+			case 4:
+				Kopete::Contact::setOnlineStatus(MSNProtocol::protocol()->AWY);
+				break;
+			case 5:
+				Kopete::Contact::setOnlineStatus(MSNProtocol::protocol()->PHN);
+				break;
+			case 6:
+				Kopete::Contact::setOnlineStatus(MSNProtocol::protocol()->LUN);
+				break;
+			case 7:
+				Kopete::Contact::setOnlineStatus(MSNProtocol::protocol()->FLN);
+				break;
+			case 8:
+				Kopete::Contact::setOnlineStatus(MSNProtocol::protocol()->HDN);
+				break;
+			case 9:
+				Kopete::Contact::setOnlineStatus(MSNProtocol::protocol()->IDL);
+				break;
+			default:
+				Kopete::Contact::setOnlineStatus(MSNProtocol::protocol()->UNK);
+				break;
+		}
 	}
 	else
-	{
-		if(status.internalStatus() >= 15)
-		{	//the user is not blocked, but the status is blocked
-			switch(status.internalStatus()-15)
-			{
-				case 1:
-					KopeteContact::setOnlineStatus(MSNProtocol::protocol()->NLN);
-					break;
-				case 2:
-					KopeteContact::setOnlineStatus(MSNProtocol::protocol()->BSY);
-					break;
-				case 3:
-					KopeteContact::setOnlineStatus(MSNProtocol::protocol()->BRB);
-					break;
-				case 4:
-					KopeteContact::setOnlineStatus(MSNProtocol::protocol()->AWY);
-					break;
-				case 5:
-					KopeteContact::setOnlineStatus(MSNProtocol::protocol()->PHN);
-					break;
-				case 6:
-					KopeteContact::setOnlineStatus(MSNProtocol::protocol()->LUN);
-					break;
-				case 7:
-					KopeteContact::setOnlineStatus(MSNProtocol::protocol()->FLN);
-					break;
-				case 8:
-					KopeteContact::setOnlineStatus(MSNProtocol::protocol()->HDN);
-					break;
-				case 9:
-					KopeteContact::setOnlineStatus(MSNProtocol::protocol()->IDL);
-					break;
-				default:
-					KopeteContact::setOnlineStatus(MSNProtocol::protocol()->UNK);
-					break;
-			}
-		}
-		else
-			KopeteContact::setOnlineStatus(status);
-	}
+		Kopete::Contact::setOnlineStatus(status);
+	m_currentStatus=status;
 }
 
 void MSNContact::slotSendMail()
@@ -585,9 +602,24 @@ void MSNContact::slotSendMail()
 
 void MSNContact::setDisplayPicture(KTempFile *f)
 {
-	if(m_displayPicture && m_displayPicture!=f)
-		delete m_displayPicture;
-	m_displayPicture=f;
+	//copy the temp file somewere else.
+	// in a better world, the file could be dirrectly wrote at the correct location.
+	// but the custom emoticon code is to deeply merged in the display picture code while it could be separated.
+	QString newlocation=locateLocal( "appdata", "msnpictures/"+ contactId().lower().replace(QRegExp("[./~]"),"-")  +".png"  ) ;
+
+	KIO::Job *j=KIO::file_move( KURL::fromPathOrURL( f->name() ) , KURL::fromPathOrURL( newlocation ) , -1, true /*overwrite*/ , false /*resume*/ , false /*showProgressInfo*/ );
+	
+	f->setAutoDelete(false);
+	delete f;
+
+	//let the time to KIO to copy the file
+	connect(j, SIGNAL(result(KIO::Job *)) , this, SLOT(slotEmitDisplayPictureChanged() ));
+}
+
+void MSNContact::slotEmitDisplayPictureChanged()
+{
+	QString newlocation=locateLocal( "appdata", "msnpictures/"+ contactId().lower().replace(QRegExp("[./~]"),"-")  +".png"  ) ;
+	setProperty( Kopete::Global::Properties::self()->photo() , newlocation );
 	emit displayPictureChanged();
 }
 
@@ -597,9 +629,11 @@ void MSNContact::setObject(const QString &obj)
 		return;
 
 	m_obj=obj;
-	delete m_displayPicture;
-	m_displayPicture=0;
+
+	removeProperty( Kopete::Global::Properties::self()->photo()  ) ;
 	emit displayPictureChanged();
+
+//	manager(Kopete::Contact::CanCreate); //create the manager which will download the photo automatically.
 }
 
 #include "msncontact.moc"
