@@ -4,9 +4,9 @@
     Copyright (c) 2002      by Duncan Mac-Vicar Prett <duncan@kde.org>
     Copyright (c) 2002      by Ryan Cumming           <bodnar42@phalynx.dhs.org>
     Copyright (c) 2002      by Martijn Klingens       <klingens@kde.org>
-    Copyright (c) 2002-2004 by Olivier Goffart        <ogoffart@tiscalinet.be>
+    Copyright (c) 2002-2005 by Olivier Goffart        <ogoffart at kde.org>
 
-    Kopete    (c) 2002-2004 by the Kopete developers  <kopete-devel@kde.org>
+    Kopete    (c) 2002-2005 by the Kopete developers  <kopete-devel@kde.org>
 
 
     *************************************************************************
@@ -23,6 +23,7 @@
 #define MSNCONTACT_H
 
 #include "kopetecontact.h"
+#include "kopeteonlinestatus.h"
 
 #include <kurl.h>
 
@@ -31,20 +32,20 @@ class QListViewItem;
 class QPixmap;
 class QTimer;
 
-class MSNMessageManager;
+class MSNChatSession;
 class KAction;
 class KActionCollection;
 class KTempFile;
 
-class KopeteProtocol;
-class KopeteOnlineStatus;
+namespace Kopete { class Protocol; }
+namespace Kopete { class OnlineStatus; }
 
-class MSNContact : public KopeteContact
+class MSNContact : public Kopete::Contact
 {
 	Q_OBJECT
 
 public:
-	MSNContact( KopeteAccount *account, const QString &id, KopeteMetaContact *parent );
+	MSNContact( Kopete::Account *account, const QString &id, Kopete::MetaContact *parent );
 	~MSNContact();
 
 	/**
@@ -55,9 +56,10 @@ public:
 
 	/**
 	 * Indicate whether this contact is deleted
+	 *   (not on the serverside list)
 	 */
-/*	bool isDeleted() const;
-	void setDeleted( bool d );*/
+	bool isDeleted() const;
+	void setDeleted( bool d );
 
 	/**
 	 * Indicate whether this contact is allowed
@@ -79,7 +81,7 @@ public:
 	/**
 	 * The groups in which the user is located on the server.
 	 */
-	const QMap<uint, KopeteGroup *>  serverGroups() const;
+	const QMap<uint, Kopete::Group *>  serverGroups() const;
 	/**
 	 * clear that map
 	 */
@@ -93,7 +95,7 @@ public:
 	 * update the server group map
 	 */
 	void contactRemovedFromGroup( unsigned int group );
-	void contactAddedToGroup( uint groupNumber, KopeteGroup *group );
+	void contactAddedToGroup( uint groupNumber, Kopete::Group *group );
 
 	virtual void serialize( QMap<QString, QString> &serializedData, QMap<QString, QString> &addressBookData );
 
@@ -105,13 +107,13 @@ public:
 	/**
 	 * Returns the MSN Message Manager associated with this contact
 	 */
-	virtual KopeteMessageManager *manager( bool canCreate = false );
+	virtual Kopete::ChatSession *manager( Kopete::Contact::CanCreateFlags = Kopete::Contact::CannotCreate );
 
 
 	/**
 	 * Because blocked contact have a small auto-modified status
 	 */
-	void setOnlineStatus(const KopeteOnlineStatus&);
+	void setOnlineStatus(const Kopete::OnlineStatus&);
 
 	QString phoneHome();
 	QString phoneWork();
@@ -119,17 +121,18 @@ public:
 
 	void setObject(const QString &obj);
 	QString object() const { return m_obj; }
-	KTempFile *displayPicture() const { return m_displayPicture; }
 
 public slots:
 	virtual void slotUserInfo();
-	virtual void slotDeleteContact();
-	virtual void sendFile(const KURL &sourceURL, const QString &altFileName, uint fileSize);
+	virtual void deleteContact();
+	virtual void sendFile( const KURL &sourceURL = KURL(),
+						   const QString &fileName = QString::null, uint fileSize = 0L );
 
 	/**
 	 * Every time the kopete's contactlist is modified, we sync the serverlist with it
 	 */
-	virtual void syncGroups();
+	virtual void sync( unsigned int cvhanged= 0xff);
+
 
 	void setDisplayPicture(KTempFile *f) ;
 
@@ -140,6 +143,7 @@ private slots:
 	void slotBlockUser();
 	void slotShowProfile();
 	void slotSendMail();
+	void slotEmitDisplayPictureChanged();
 
 	/**
 	 * Workaround to make this checkboxe readonly
@@ -147,11 +151,11 @@ private slots:
 	void slotUserInfoDialogReversedToggled();
 
 private:
-	QMap<uint, KopeteGroup *> m_serverGroups;
+	QMap<uint, Kopete::Group *> m_serverGroups;
 
 	bool m_blocked;
 	bool m_allowed;
-//	bool m_deleted;
+	bool m_deleted;
 	bool m_reversed;
 
 	bool m_moving;
@@ -161,12 +165,20 @@ private:
 	QString m_phoneMobile;
 	bool m_phone_mob;
 
-	QString m_obj; //the MSNObject
-	KTempFile *m_displayPicture;
-	
 	KAction *actionBlock;
 	KAction *actionShowProfile;
 	KAction *actionSendMail;
+
+	QString m_obj; //the MSNObject
+
+	/**
+	 * keep the current status here.  (it's normally already in Kopete::Contact::d->onlineStatus)
+	 * This is a workaround to prevent problems with the account offline status.
+	 */
+	Kopete::OnlineStatus m_currentStatus;
+
+	//MSNProtocol::deserializeContact need to acess some contact insternals
+	friend class MSNProtocol;
 };
 
 #endif
