@@ -1,9 +1,9 @@
 /*
     msnmessagemanager.h - MSN Message Manager
 
-    Copyright (c) 2002-2004 by Olivier Goffart        <ogoffart@tiscalinet.be>
+    Copyright (c) 2002-2005 by Olivier Goffart        <ogoffart@tiscalinet.be>
 
-    Kopete    (c) 2002-2004 by the Kopete developers  <kopete-devel@kde.org>
+    Kopete    (c) 2002-2005 by the Kopete developers  <kopete-devel@kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -31,13 +31,13 @@ class QLabel;
 /**
  * @author Olivier Goffart
  */
-class MSNMessageManager : public KopeteMessageManager
+class KOPETE_EXPORT MSNChatSession : public Kopete::ChatSession
 {
 	Q_OBJECT
 
 public:
-	MSNMessageManager( KopeteProtocol *protocol, const KopeteContact *user, KopeteContactPtrList others, const char *name = 0 );
-	~MSNMessageManager();
+	MSNChatSession( Kopete::Protocol *protocol, const Kopete::Contact *user, Kopete::ContactPtrList others, const char *name = 0 );
+	~MSNChatSession();
 
 	void createChat( const QString &handle, const QString &address, const QString &auth, const QString &ID = QString::null );
 
@@ -50,6 +50,8 @@ public:
 	 * append an invitation in the invitation map, and send the first invitation message
 	 */
 	void initInvitation(MSNInvitation* invitation);
+	
+	virtual void inviteContact(const QString& );
 
 public slots:
 	void slotCloseSession();
@@ -59,14 +61,20 @@ public slots:
 
 	void slotRequestPicture();
 
+	/**
+	 * this is a reimplementation of ChatSesstion slot.
+	 * the original slot is not virtual, but that's not a problem because it's a slot.
+	 */
+	virtual void receivedTypingMsg( const QString &, bool );
+
 private slots:
-	void slotMessageSent( KopeteMessage &message, KopeteMessageManager *kmm );
-	void slotMessageReceived( KopeteMessage &message );
+	void slotMessageSent( Kopete::Message &message, Kopete::ChatSession *kmm );
+	void slotMessageReceived( Kopete::Message &message );
 
 	void slotUserJoined( const QString &handle, const QString &publicName, bool IRO );
 	void slotUserLeft( const QString &handle, const QString &reason );
 	void slotSwitchBoardClosed();
-	void slotInviteContact( KopeteContact *contact );
+	void slotInviteContact( Kopete::Contact *contact );
 	void slotAcknowledgement( unsigned int id, bool ack );
 	void slotInvitation( const QString &handle, const QString &msg );
 
@@ -87,15 +95,20 @@ private:
 	QPtrList<KAction> m_inviteactions;
 
 	//Messages sent before the ending of the connection are queued
-	QValueList<KopeteMessage> m_messagesQueue;
+	QValueList<Kopete::Message> m_messagesQueue;
 	void sendMessageQueue();
 
-	QMap<unsigned int, KopeteMessage> m_messagesSent;
+	QMap<unsigned int, Kopete::Message> m_messagesSent;
 
 	QMap<long unsigned int, MSNInvitation*> m_invitations;
 
 	QTime m_awayMessageTime;
 
+	/**
+	 * weither or not the "has opened a new chat" message need to be sent if the user is typing
+	 */
+	bool m_newSession;
+
 	QLabel *m_image;
 
 
@@ -103,7 +116,7 @@ signals:
 	/*
 	 * This signal is relayed to the protocol and after, to plugins
 	 */
-	void invitation(MSNInvitation*& invitation,  const QString &bodyMSG , long unsigned int cookie , MSNMessageManager* msnMM , MSNContact* c );
+	void invitation(MSNInvitation*& invitation,  const QString &bodyMSG , long unsigned int cookie , MSNChatSession* msnMM , MSNContact* c );
 };
 
 #endif
