@@ -29,7 +29,7 @@
 class MSNDispatchSocket;
 class MSNAccount;
 class KTempFile;
-class SslLoginHandler;
+class MSNSecureLoginHandler;
 
 #include <kio/job.h>
 
@@ -66,6 +66,8 @@ public:
 
 	bool badPassword() { return m_badPassword; }
 
+	QString localIP() { return m_localIP; }
+
 public slots:
 	void slotOpenInbox();
 
@@ -165,7 +167,8 @@ private:
 	QString m_kv;
 	QString m_sid;
 	QString m_loginTime;
-	SslLoginHandler *m_sslLoginHandler;
+	QString m_localIP;
+	MSNSecureLoginHandler *m_secureLoginHandler;
 
 	QTimer *m_keepaliveTimer;
 
