@@ -1,7 +1,7 @@
 /*
     msnp2p.h - msn p2p protocol
 
-    Copyright (c) 2003 by Olivier Goffart        <ogoffart@tiscalinet.be>
+    Copyright (c) 2003-2005 by Olivier Goffart        <ogoffart@ kde.org>
 
     *************************************************************************
     *                                                                       *
@@ -20,50 +20,48 @@
 #include <qstrlist.h>
 
 
-class KopeteTransfer;
-struct KopeteFileTransferInfo;
+namespace Kopete { class Transfer; }
+namespace Kopete { struct FileTransferInfo; }
 
 class KTempFile;
 class QFile;
+class MSNP2PDisplatcher;
 
 /**
  * @author Olivier Goffart
- *
- * This class help the MSNSwithboardSocket to handle the MSN-P2P messages
+ * base class for all MSNP2P* classes
  */
 class MSNP2P : public QObject
 {
-	Q_OBJECT
-
+   Q_OBJECT
 public:
-	MSNP2P(  QObject *parent=0L , const char *name=0L);
-	~MSNP2P();
 
-public slots:
-	/**
-	 * parse an incoming message
-	 */
-	void slotReadMessage( const QByteArray &msg );
+	struct MessageStruct
+	{
+		unsigned int dataMessageSize;
+		unsigned int totalSize;
+		unsigned int dataOffset;
+		QByteArray message;
+	};
 
-signals:
-	/**
-	 * should be connected to the MSNSwitchBoardSocket's sendCommand function
-	 */
-	void sendCommand( const QString &cmd, const QString &args = QString::null,
-		bool addId = true, const QByteArray &body = QByteArray() , bool binary=false );
 
-	void fileReceived( KTempFile * , const QString &msnObject );
-
-private:
+	MSNP2P( unsigned long int sessionID , MSNP2PDisplatcher *parent);
+	MSNP2P( QObject* parent=0L);
+	virtual ~MSNP2P();
 
 	enum MessageType { BYE, OK, DECLINE, ERROR, INVITE };
 
+	/**
+	 *  you should call the base when reimplementing
+	 * */
+	virtual void parseMessage(MessageStruct & );
+
 	/**
 	 * send the MSNSLP command in a msn p2p message
 	 * dataMessage cen be a QCString in case of text message
 	 */
 	void sendP2PMessage( const QByteArray& dataMessage );
-	
+
 	/**
 	 * make and send a P2P message.
 	 * @ref sendP2PMessage is used to send the message.
@@ -72,54 +70,42 @@ private:
 	 */
 	void makeMSNSLPMessage( MessageType type, QString content );
 
-
 	/**
 	 * send the ACK
 	 */
 	void sendP2PAck( const char * originalHeader) ;
 
-
-
-
-
-private slots:
-	void slotSendData();
-	void slotTransferAccepted(KopeteTransfer*, const QString& );
-	void slotFileTransferRefused( const KopeteFileTransferInfo & );
-	void slotKopeteTransferDestroyed();
-
-public slots:
 	/**
-	 * Load the dysplayImage.
+	 *
 	 */
-	void requestDisplayPicture( const QString &myHandle, const QString &msgHandle, QString msnObject);
+	virtual void error();
 
-	/**
-	 * Abort the current transfer.
-	 */
-	void abortCurrentTransfer();
 
-private:
-	//for the display image
-	KTempFile *m_file;
-	QFile *m_Sfile;
-	QFile *m_Rfile;
-	QString m_obj;
-	
 	unsigned long int m_msgIdentifier;
 	unsigned long int m_sessionId;
 	unsigned long int m_totalDataSize;
 	unsigned long int m_offset;
-	
+
+	/**
+	 * the footer
+	 * default: 0
+	 * we're transfered a file or a picture : \1
+	 * we're transfering an image: \3
+	 */
+	char m_footer;
+
 	QString m_CallID;
 	QString m_branch;
 
-
 	QString m_myHandle;
 	QString m_msgHandle;
-	KopeteTransfer *m_kopeteTransfer;
+
+	MSNP2PDisplatcher *m_parent;
 
 };
 
+
+
+
 #endif
 
