@@ -2,8 +2,8 @@
     msnswitchboardsocket.h - switch board connection socket
 
     Copyright (c) 2002      by Martijn Klingens       <klingens@kde.org>
-    Copyright (c) 2002-2003 by Olivier Goffart        <ogoffart@tiscalinet.be>
-    Kopete    (c) 2002-2003 by the Kopete developers  <kopete-devel@kde.org>
+    Copyright (c) 2002-2005 by Olivier Goffart        <ogoffart@ kde.org>
+    Kopete    (c) 2002-2005 by the Kopete developers  <kopete-devel@kde.org>
 
     Portions of this code are taken from KMerlin,
               (c) 2001 by Olaf Lueg              <olueg@olsd.de>
@@ -28,11 +28,11 @@
 
 #include "msnsocket.h"
 
-class KopeteMessage;
+namespace Kopete { class Message; }
 class MSNAccount;
 class QTimer;
 
-class MSNP2P;
+class MSNP2PDisplatcher;
 class KTempFile;
 
 class MSNSwitchBoardSocket : public MSNSocket
@@ -59,15 +59,19 @@ private:
 	QString m_ID;
 	QString m_auth;
 	QStringList m_chatMembers;
-
-	MSNP2P *m_p2p ;
+	
+	MSNP2PDisplatcher *m_p2p ;
 
 	//used for emoticons
-	QValueList<const KopeteMessage> m_msgQueue;
+	QValueList<const Kopete::Message> m_msgQueue;
 	unsigned  m_recvIcons;
 	QMap<QString , QPair<QString , KTempFile*> >  m_emoticons;
-	KopeteMessage &parseCustomEmoticons(KopeteMessage &msg);
+	Kopete::Message &parseCustomEmoticons(Kopete::Message &msg);
 	QTimer *m_emoticonTimer;
+	QPtrList<KTempFile> m_typewrited;
+
+	/** the number of chunk for currents messages */
+	unsigned int m_chunks;
 
 protected:
 	/**
@@ -92,7 +96,7 @@ public:
 	const QStringList &chatMembers() { return m_chatMembers; }
 
 	void userLeftChat( const QString &handle , const QString &reason );
-	int sendMsg( const KopeteMessage &msg );
+	int sendMsg( const Kopete::Message &msg );
 
 public slots:
 	void slotCloseSession();
@@ -114,7 +118,7 @@ private slots:
 	void cleanQueue();
 
 signals:
-	void msgReceived( KopeteMessage &msg );
+	void msgReceived( Kopete::Message &msg );
 	void receivedTypingMsg( const QString &contactId, bool isTyping );
 	void msgAcknowledgement(unsigned int, bool);
 	void userJoined(const QString& handle , const QString &publicName , bool IRO);
