@@ -56,7 +56,7 @@ class YahooAccount : public Kopete::PasswordedAccount
 public:
 
 	enum SignalConnectionType { MakeConnections, DeleteConnections };
-	
+
 	YahooAccount(YahooProtocol *parent,const QString& accountID, const char *name = 0L);
 	~YahooAccount();
 
@@ -100,7 +100,10 @@ public slots:
 	 * Disconnect from the Yahoo service
 	 */
 	virtual void disconnect();
-	
+
+	/** Reimplemented from Kopete::Account */
+	void setOnlineStatus( const Kopete::OnlineStatus&, const QString &reason = QString::null);
+
 
 signals:
 	/**
@@ -108,16 +111,11 @@ signals:
 	 */
 	void receivedTypingMsg(const QString &contactId, bool isTyping);
 
-	/**
-	 * Emitted when a reconnect is needed due to a bad password
-	 */
-	void needReconnect();
-
 protected:
 	/**
 	 * Adds our Yahoo contact to a metacontact
 	 */
-	virtual bool addContactToMetaContact(const QString &contactId, const QString &displayName, KopeteMetaContact *parentContact);
+	virtual bool createContact(const QString &contactId,  Kopete::MetaContact *parentContact);
 
 	/**
 	 * Gets the just-received message color
@@ -129,12 +127,10 @@ protected:
 	QString stripMsgColorCodes(const QString& msg);
 
 protected slots:
-	virtual void loaded();
-
 	void slotConnected();
 	void slotGoOnline();
 	void slotGoOffline();
-	
+
 	void slotGoStatus(int status, const QString &awayMessage = QString::null);
 	void slotLoginResponse(int succ, const QString &url);
 	void slotGotBuddies(const YList * buds);
@@ -176,12 +172,6 @@ private slots:
 	void slotGoStatus099() { theAwayDialog->show(99); } // Custom
 	void slotGoStatus999() { slotGoStatus(999); } // Idle
 
-	/**
-	 * Set an error flag so that the password box
-	 * is popped up again when the password is wrong
-	 */
-	void slotNeedReconnect();
-
 private:
 
 	/**
@@ -198,7 +188,7 @@ private:
 	/**
 	 * Conferences list, maped by room name (id)
 	 */
-	QMap<QString, YahooConferenceMessageManager *> m_conferences;
+	QMap<QString, YahooConferenceChatSession *> m_conferences;
 
 	bool theHaveContactList;	// Do we have the full server-side contact list yet?
 	int stateOnConnection;		// The state to change to on connection
@@ -213,7 +203,7 @@ private:
 	int m_currentMailCount;
 	YahooSession *m_session;	// Connection Object
 	YahooProtocol *m_protocol;	// The Protocol Object
-	
+
 
 	YahooAwayDialog *theAwayDialog;	// Our away message dialog
 };
