@@ -31,6 +31,7 @@
 #include <qwidgetstack.h>
 #include <qtimer.h>
 #include <qdir.h>
+#include <qlineedit.h>
 
 #include <kapplication.h>
 #include <kglobal.h>
@@ -49,6 +50,9 @@
 #include "StartingKPFDialog.h"
 #include "WebServerManager_stub.h"
 #include "WebServer_stub.h"
+#include "Help.h"
+
+#include <dnssd/servicebrowser.h>
 
 namespace KPF
 {
@@ -102,6 +106,7 @@ namespace KPF
       uint  listenPort;
       uint  bandwidthLimit;
 //      uint  connectionLimit;
+      QString serverName;
       bool  followSymlinks;
   };
 
@@ -116,6 +121,7 @@ namespace KPF
           sb_listenPort             (0L),
           sb_bandwidthLimit         (0L),
 //          sb_connectionLimit        (0L),
+	  le_serverName             (0L),
           cb_followSymlinks         (0L),
           cb_share                  (0L),
           stack                     (0L),
@@ -129,11 +135,13 @@ namespace KPF
       QLabel                * l_listenPort;
       QLabel                * l_bandwidthLimit;
 //      QLabel                * l_connectionLimit;
+      QLabel                * l_serverName;
       QLabel                * l_kpfStatus;
 
       QSpinBox              * sb_listenPort;
       QSpinBox              * sb_bandwidthLimit;
 //      QSpinBox              * sb_connectionLimit;
+      QLineEdit             * le_serverName;
 
       QCheckBox             * cb_followSymlinks;
       QCheckBox             * cb_share;
@@ -248,12 +256,19 @@ namespace KPF
     void
   PropertiesDialogPlugin::setControlsEnabled(bool b)
   {
+
+    bool canPublish = b && DNSSD::ServiceBrowser::isAvailable() == DNSSD::ServiceBrowser::Working;
+    
+    d->l_serverName->setEnabled(canPublish);
     d->l_listenPort       ->setEnabled(b);
     d->l_bandwidthLimit   ->setEnabled(b);
 //    d->l_connectionLimit  ->setEnabled(b);
+    d->l_serverName       ->setEnabled(canPublish);
+    
     d->sb_listenPort      ->setEnabled(b);
     d->sb_bandwidthLimit  ->setEnabled(b);
 //    d->sb_connectionLimit ->setEnabled(b);
+    d->le_serverName      ->setEnabled(canPublish);
     d->cb_followSymlinks  ->setEnabled(b);
   }
 
@@ -311,15 +326,21 @@ namespace KPF
     d->l_listenPort       = new QLabel(i18n("&Listen port:"),      w);
     d->l_bandwidthLimit   = new QLabel(i18n("&Bandwidth limit:"),  w);
 //    d->l_connectionLimit  = new QLabel(i18n("Connection &limit"), w);
+    d->l_serverName       = new QLabel(i18n("&Server name:"), w);
+    bool canPublish = DNSSD::ServiceBrowser::isAvailable() == DNSSD::ServiceBrowser::Working;
+    d->l_serverName->setEnabled(canPublish);
 
     d->sb_listenPort      = new QSpinBox(1000,  999999, 1, w);
     d->sb_bandwidthLimit  = new QSpinBox(1,     999999, 1, w);
 //    d->sb_connectionLimit = new QSpinBox(1,     9999,   1, w);
-
+    d->le_serverName      = new QLineEdit( w);
+    d->le_serverName->setEnabled(canPublish);
+    
     d->cb_followSymlinks  =
       new QCheckBox(i18n("&Follow symbolic links"), w);
 
     d->l_listenPort       ->setBuddy(d->sb_listenPort);
+    d->l_serverName       ->setBuddy(d->le_serverName);
     d->l_bandwidthLimit   ->setBuddy(d->sb_bandwidthLimit);
 //    d->l_connectionLimit  ->setBuddy(d->sb_connectionLimit);
 
@@ -344,6 +365,8 @@ namespace KPF
     l2->addWidget(d->sb_bandwidthLimit,  1, 1);
 //    l2->addWidget(d->l_connectionLimit,  2, 0);
 //    l2->addWidget(d->sb_connectionLimit, 2, 1);
+    l2->addWidget(d->l_serverName,       2, 0);
+    l2->addWidget(d->le_serverName,      2, 1);
 
     l0->addWidget(d->cb_followSymlinks);
 
@@ -418,6 +441,7 @@ namespace KPF
        " risk. Use only if you understand the issues involved."
        "</p>"
       );
+    QString serverNameHelp = KPF::HelpText::getServerNameHelp();
 
     QWhatsThis::add(d->cb_share,            shareHelp);
     QWhatsThis::add(d->l_listenPort,        listenPortHelp);
@@ -426,6 +450,8 @@ namespace KPF
     QWhatsThis::add(d->sb_bandwidthLimit,   bandwidthLimitHelp);
 //    QWhatsThis::add(d->l_connectionLimit,   connectionLimitHelp);
 //    QWhatsThis::add(d->sb_connectionLimit,  connectionLimitHelp);
+    QWhatsThis::add(d->l_serverName,        serverNameHelp);
+    QWhatsThis::add(d->le_serverName,       serverNameHelp);
     QWhatsThis::add(d->cb_followSymlinks,   followSymlinksHelp);
 
     connect(d->cb_share, SIGNAL(toggled(bool)), SLOT(slotSharingToggled(bool)));
@@ -461,6 +487,12 @@ namespace KPF
         SLOT(slotChanged())
       );
 #endif
+    connect
+      (
+        d->le_serverName,
+	SIGNAL(textChanged(const QString&)),
+	SLOT(slotChanged())
+      );
 
     connect
       (
@@ -573,6 +605,16 @@ namespace KPF
     }
 #endif
 
+    d->currentState.serverName = webServer.serverName();
+    if (DCOPStub::CallFailed == webServer.status())
+    {
+      // TODO: warn user ?
+      kpfDebug << "WebServer_stub call failed" << endl;
+      d->currentState.serverName = "";
+      return;
+    }
+  
+
     d->currentState.followSymlinks = webServer.followSymlinks();
 
     if (DCOPStub::CallFailed == webServer.status())
@@ -704,6 +746,8 @@ namespace KPF
        ||
 //       d->currentState.connectionLimit  != d->wantedState.connectionLimit
 //       ||
+       d->currentState.serverName       != d->wantedState.serverName
+       ||
        d->currentState.followSymlinks   != d->wantedState.followSymlinks
       )
     {
@@ -731,7 +775,8 @@ namespace KPF
              d->wantedState.listenPort,
              d->wantedState.bandwidthLimit,
              Config::DefaultConnectionLimit,//d->wantedState.connectionLimit,
-             d->wantedState.followSymlinks
+             d->wantedState.followSymlinks,
+	     d->wantedState.serverName
             );
 
           if (ref.isNull())
@@ -776,7 +821,8 @@ namespace KPF
              d->wantedState.listenPort,
              d->wantedState.bandwidthLimit,
              Config::DefaultConnectionLimit,//d->wantedState.connectionLimit,
-             d->wantedState.followSymlinks
+             d->wantedState.followSymlinks,
+	     d->wantedState.serverName
             );
 
           if (DCOPStub::CallFailed == webServer.status())
@@ -817,6 +863,7 @@ namespace KPF
     d->sb_listenPort      ->setValue    (d->currentState.listenPort);
     d->sb_bandwidthLimit  ->setValue    (d->currentState.bandwidthLimit);
 //    d->sb_connectionLimit ->setValue    (d->currentState.connectionLimit);
+    d->le_serverName      ->setText     (d->currentState.serverName);
     d->cb_followSymlinks  ->setChecked  (d->currentState.followSymlinks);
 
     setControlsEnabled(d->currentState.shared);
@@ -829,6 +876,7 @@ namespace KPF
     d->wantedState.listenPort       = d->sb_listenPort->value();
     d->wantedState.bandwidthLimit   = d->sb_bandwidthLimit->value();
 //    d->wantedState.connectionLimit  = d->sb_connectionLimit->value();
+    d->wantedState.serverName       = d->le_serverName->text();
     d->wantedState.followSymlinks   = d->cb_followSymlinks->isChecked();
   }
 
