@@ -407,124 +407,6 @@ namespace KPF
     return s;
   }
 
-    QString
-  unquote(const QString & quoted)
-  {
-    if (quoted.length() < 3)
-      return quoted;
-
-    QString unquoted;
-
-    uint i;
-    for (i = 0; i < quoted.length() - 2; ++i)
-    {
-      if ('%' == quoted[i])
-      {
-        // First character.
-
-        char hexChar = quoted[i + 1].lower().latin1();
-
-        char unquotedChar = '\0';
-
-        if (hexChar >= '0' && hexChar <= '9')
-        {
-          unquotedChar = 16 * (hexChar - '0');
-        }
-        else if (hexChar >= 'a' && hexChar <= 'f')
-        {
-          unquotedChar = 16 * (hexChar - 'a' + 10);
-        }
-        else
-        {
-          kpfDebug << "Bad hex encoding in quoted string" << endl;
-          unquotedChar = hexChar;
-        }
-
-        // Second character.
-
-        hexChar = quoted[i + 2].lower().latin1();
-
-        if (hexChar >= '0' && hexChar <= '9')
-        {
-          unquotedChar += hexChar - '0';
-        }
-        else if (hexChar >= 'a' && hexChar <= 'f')
-        {
-          unquotedChar += hexChar - 'a' + 10;
-        }
-        else
-        {
-          kpfDebug << "Bad hex encoding in quoted string" << endl;
-          unquotedChar = hexChar;
-        }
-
-        unquoted += unquotedChar;
-        
-        // Skip past the characters we just used.
-
-        i += 2;
-      }
-      else
-      {
-        unquoted += quoted[i];
-      }
-    }
-
-    for (; i < quoted.length(); ++i)
-    {
-      if ('%' == quoted[i])
-      {
-        kpfDebug << "Bogus % in quoted string" << endl;
-        //return QString::null;
-      }
-
-      unquoted += quoted[i];
-    }
-
-    return unquoted;
-  }
-
-    QString
-  quote(const QString & unquoted)
-  {
-    QString quoted;
-
-    for (uint i = 0; i < unquoted.length(); ++i)
-    {
-      char c = unquoted[i];
-
-      if (
-        (c >= 'a' && c <= 'z')
-        ||
-        (c >= 'A' && c <= 'Z')
-        ||
-        (c >= '0' && c <= '9')
-        ||
-        ('.' == c)
-        ||
-        (':' == c)
-        ||
-        ('_' == c)
-        ||
-        ('-' == c)
-        ||
-        ('/' == c)
-        ||
-        ('?' == c)
-        ||
-        ('+' == c)
-      )
-      {
-        quoted += c;
-      }
-      else
-      {
-        quoted += QString("%%1").arg(c, 0, 16);
-      }
-    }
-
-    return quoted;
-  }
 
 } // End namespace KPF
 
