@@ -1,7 +1,7 @@
 /*
  *              kPPP: A pppd Front End for the KDE project
  *
- * $Id: docking.cpp,v 1.29 2003/11/27 22:09:44 mlaurent Exp $
+ * $Id: docking.cpp 357713 2004-10-25 20:36:48Z bmeyer $
  *
  *              Copyright (C) 1997 Bernd Johannes Wuebben
  *                      wuebben@math.cornell.edu
@@ -76,7 +76,7 @@ void DockWidget::paintIcon (int status) {
 
   const QPixmap *pixmap;
 
-  if(this->isVisible()) {
+  if(isVisible()) {
     switch(status)
       {
       case PPPStats::BytesBoth:
