@@ -1,7 +1,7 @@
 /*
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: general.cpp 344419 2004-09-06 15:25:58Z mlaurent $
+ * $Id: general.cpp 430606 2005-07-01 22:34:39Z porten $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -403,7 +403,7 @@ ModemWidget::ModemWidget(QWidget *parent, bool isnewmodem, const char *name)
   }
 
   for(int i=0; i <= flowcontrol->count()-1; i++)
-    if(gpppdata.flowcontrol() == flowcontrol->text(i))
+    if(gpppdata.flowcontrol() == flowListItem[i])
       flowcontrol->setCurrentItem(i);
 
 	//set the modem speed
