@@ -1,7 +1,7 @@
 /* -*- C++ -*-
  *            kPPP: A pppd front end for the KDE project
  *
- * $Id: kpppconfig.h,v 1.29 2003/03/07 22:06:51 waba Exp $
+ * $Id: kpppconfig.h 311457 2004-05-14 16:57:06Z sgotti $
  *
  *            Copyright (C) 1997 Bernd Johannes Wuebben
  *                   wuebben@math.cornell.edu
@@ -79,6 +79,9 @@
 // Define the maximum number of accounts
 #define MAX_ACCOUNTS 100
 
+// Define the maximum number of modems
+#define MAX_MODEMS 100
+
 // Define the mamimum number of script entries
 #define MAX_SCRIPT_ENTRIES 20
 
@@ -129,4 +132,8 @@ extern const char * const kppp_syslog[];
 #define __xnet_connect connect
 #endif
 
+#define CBTYPE_NONE     0
+#define CBTYPE_ADMIN    1
+#define CBTYPE_USER     2
+
 #endif
