@@ -24,6 +24,15 @@ public:
     void saveConfig();
     void defaultConfig();
     void readConfig( const KSOServChan * = ksopts );
+
+signals:
+    void modified();
+
+public slots:
+    void deletePressedSL();
+    void addPressedSL();
+    void deletePressedCL();
+    void addPressedCL();
 };
 
 #endif
