@@ -7,6 +7,7 @@
 #include <qpopupmenu.h>
 #include <kwin.h>
 #include <kaccel.h>
+#include <kaction.h>
 #include <kapplication.h>
 #include <klocale.h>
 #include <kdebug.h>
@@ -40,7 +41,7 @@ void DisplayMgrMDI::newTopLevel( QWidget *w, bool show )
     if(w->inherits("KMainWindow")){
         KMainWindow *t = static_cast<KMainWindow *>(w);
 
-        QMenuData *cmenu = t->menuBar();
+        QMenuBar *cmenu = t->menuBar();
         if(cmenu){
             QPopupMenu *m = new QPopupMenu(t, QCString(t->name()) + "_popup_MDI");
             m->setCheckable(true);
@@ -56,6 +57,26 @@ void DisplayMgrMDI::newTopLevel( QWidget *w, bool show )
              */
             cmenu->insertItem(i18n("&Window"), m, DMM_MDI_ID, 4);
             cmenu->setAccel(Key_M, DMM_MDI_ID);
+
+            QPopupMenu *sm = new QPopupMenu(t, "settings" );
+	    
+	    KToggleAction *showmenu = KStdAction::showMenubar( 0, 0, t->actionCollection() );
+	    showmenu->plug( sm );
+	    connect( showmenu, SIGNAL(toggled(bool)), cmenu, SLOT(setShown(bool)) );
+
+	    KSelectAction *selectTabbar = new KSelectAction(i18n("&Tab Bar"), 0, this, "tabbar" );
+	    QStringList tabbaritems;
+	    tabbaritems << i18n("&Top") << i18n("&Bottom");
+	    selectTabbar->setItems(tabbaritems);
+	    selectTabbar->setCurrentItem(1);
+	    selectTabbar->plug( sm );
+	    connect( selectTabbar, SIGNAL(activated(int)), this, SLOT(setTabPosition(int)) );
+
+	    KToggleAction *showfull = KStdAction::fullScreen( 0, 0, t->actionCollection(), t );
+	    showfull->plug( sm );
+	    connect( showfull, SIGNAL(toggled(bool)), this, SLOT(setFullScreen(bool)) );
+
+	    cmenu->insertItem( i18n("&Settings"), sm, -1, 5 );
         }
     }
     topLevel()->show();
@@ -225,6 +246,28 @@ MDITopLevel *DisplayMgrMDI::topLevel()
     return m_topLevel;
 }
 
+void DisplayMgrMDI::setTabPosition( int idx ) {
+
+    switch ( idx ) {
+	case 0:
+	    m_topLevel->tabWidget()->setTabPosition(QTabWidget::Top);
+	    break;
+	case 1:
+	    m_topLevel->tabWidget()->setTabPosition(QTabWidget::Bottom);
+	    break;
+    }
+}
+
+
+void DisplayMgrMDI::setFullScreen( bool full ) {
+    if ( full )
+	m_topLevel->showFullScreen();
+    else
+	m_topLevel->showNormal();
+}
+
+
+
 void DisplayMgrMDI::moveWindowLeft() {
     moveWindow(-1);
 }
