@@ -11,7 +11,7 @@ public:
     }
   virtual ~KSircIODiscard();
 
-  virtual void sirc_receive(QString, bool broadcast);
+  virtual void sirc_receive(QCString, bool broadcast);
   virtual void control_message(int, QString);
 
 private:
