@@ -47,14 +47,8 @@
 #include <syslog.h>
 #include <netdb.h>
 
-#ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
-#ifdef TIME_WITH_SYS_TIME
 #include <time.h>
-#endif
-#else
-#include <time.h>
-#endif
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
