@@ -22,6 +22,10 @@
 
 #include <qcheckbox.h>
 #include <qlayout.h>
+#include <qlineedit.h>
+#include <qhbox.h>
+#include <qlabel.h>
+#include <qgroupbox.h>
 
 #include <klocale.h>
 #include <kdebug.h>
@@ -34,29 +38,27 @@ IOSlaveSettings::IOSlaveSettings(const QString& config, QWidget *parent)
    QVBoxLayout *layout = new QVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint());
    layout->setAutoAdd(true);
 
-/*   QLabel *desc=new QLabel(i18n("\nIf you select \"Check port\" the ioslave will check whether the host supports this service when\n"\
-                                "you open this host. Please note that paranoia people might consider even this an attack.\n"\
-                                "\"Provide without checking\" means that you will always see the links for the services no matter whether\n"\
-                                "they are actually offered by the host. \"Never provide\" means that you will never have the links to the\n"\
-                                "services. In these both cases you won't contact the host, so that nobody might ever consider you an attacker.\n"),this);*/
-   //m_fingerSettings=new PortSettingsBar(i18n("Finger service (port 79)"),this);
-   m_ftpSettings=new PortSettingsBar(i18n("Show FTP Service Links (TCP, port 21)"),this);
-   m_httpSettings=new PortSettingsBar(i18n("Show HTTP Service Links (TCP, port 80)"),this);
-   m_nfsSettings=new PortSettingsBar(i18n("Show NFS Service Links (TCP, port 2049)"),this);
-   m_smbSettings=new PortSettingsBar(i18n("Show SMB Service Links (TCP, port 139)"),this);
-   m_fishSettings=new PortSettingsBar(i18n("Show FISH (ssh) Service Links (TCP, port 22)"),this);
+   QGroupBox* group=new QGroupBox(1, Horizontal, i18n("Show links for the following services"), this);
+
+   m_ftpSettings=new PortSettingsBar(i18n("FTP (TCP, port 21): "), group);
+   m_httpSettings=new PortSettingsBar(i18n("HTTP (TCP, port 80): "),group);
+   m_nfsSettings=new PortSettingsBar(i18n("NFS (TCP, port 2049): "),group);
+   m_smbSettings=new PortSettingsBar(i18n("Windows shares (TCP, ports 445 and 139):"),group);
+   m_fishSettings=new PortSettingsBar(i18n("Secure Shell/Fish (TCP, port 22): "),group);
    m_shortHostnames = new QCheckBox(i18n("Show &short hostnames (without domain suffix)"),this);
-   m_rlanSidebar = new QCheckBox(i18n("Use &rlan:/ instead of lan:/ in Konqueror's navigation panel"),this);
+
+   QHBox *hbox=new QHBox(this);
+   QLabel *label=new QLabel(i18n("Default LISa server host: "), hbox);
+   m_defaultLisaHostLe=new QLineEdit(hbox);
+   label->setBuddy(m_defaultLisaHostLe);
 
    QWidget *w=new QWidget(this);
-//   layout->setStretchFactor(desc,0);
-   //layout->setStretchFactor(m_fingerSettings,0);
    layout->setStretchFactor(m_ftpSettings,0);
    layout->setStretchFactor(m_httpSettings,0);
    layout->setStretchFactor(m_nfsSettings,0);
    layout->setStretchFactor(m_smbSettings,0);
    layout->setStretchFactor(m_shortHostnames,0);
-   layout->setStretchFactor(m_rlanSidebar,0);
+   layout->setStretchFactor(hbox,0);
    layout->setStretchFactor(w,1);
 
    connect(m_ftpSettings,SIGNAL(changed()),this,SIGNAL(changed()));
@@ -65,26 +67,25 @@ IOSlaveSettings::IOSlaveSettings(const QString& config, QWidget *parent)
    connect(m_smbSettings,SIGNAL(changed()),this,SIGNAL(changed()));
    connect(m_fishSettings,SIGNAL(changed()),this,SIGNAL(changed()));
    connect(m_shortHostnames,SIGNAL(clicked()),this,SIGNAL(changed()));
-   connect(m_rlanSidebar,SIGNAL(clicked()),this,SIGNAL(changed()));
+   connect(m_defaultLisaHostLe, SIGNAL(textChanged(const QString&)),this,SIGNAL(changed()));
 }
 
 void IOSlaveSettings::load()
 {
    kdDebug()<<"IOSlaveSettings::load()"<<endl;
-   //m_fingerSettings->setChecked(m_config.readNumEntry("Support_Finger", PORTSETTINGS_CHECK));
    m_ftpSettings->setChecked(m_config.readNumEntry("Support_FTP", PORTSETTINGS_CHECK));
    m_httpSettings->setChecked(m_config.readNumEntry("Support_HTTP", PORTSETTINGS_CHECK));
    m_nfsSettings->setChecked(m_config.readNumEntry("Support_NFS", PORTSETTINGS_CHECK));
    m_smbSettings->setChecked(m_config.readNumEntry("Support_SMB", PORTSETTINGS_CHECK));
    m_fishSettings->setChecked(m_config.readNumEntry("Support_FISH", PORTSETTINGS_CHECK));
    m_shortHostnames->setChecked(m_config.readBoolEntry("ShowShortHostnames",false));
-   m_rlanSidebar->setChecked(m_config.readEntry("sidebarURL", "lan:/") == "rlan:/" ? true : false );
+//   m_rlanSidebar->setChecked(m_config.readEntry("sidebarURL", "lan:/") == "rlan:/" ? true : false );
+   m_defaultLisaHostLe->setText(m_config.readEntry("DefaultLisaHost", "localhost"));
 }
 
 void IOSlaveSettings::save()
 {
    kdDebug()<<"IOSlaveSettings::save()"<<endl;
-   //m_config.writeEntry("Support_Finger", m_fingerSettings->selected());
    m_config.writeEntry("AlreadyConfigured",true);
    m_config.writeEntry("Support_FTP", m_ftpSettings->selected());
    m_config.writeEntry("Support_HTTP", m_httpSettings->selected());
@@ -92,7 +93,8 @@ void IOSlaveSettings::save()
    m_config.writeEntry("Support_SMB", m_smbSettings->selected());
    m_config.writeEntry("Support_FISH", m_fishSettings->selected());
    m_config.writeEntry("ShowShortHostnames",m_shortHostnames->isChecked());
-   m_config.writeEntry("sidebarURL", m_rlanSidebar->isChecked() ? "rlan:/" : "lan:/");
+//   m_config.writeEntry("sidebarURL", m_rlanSidebar->isChecked() ? "rlan:/" : "lan:/");
+   m_config.writeEntry("DefaultLisaHost", m_defaultLisaHostLe->text());
 
    m_config.sync();
 }
