@@ -46,6 +46,7 @@ class ResLisaSettings:public KCModule
       void suggestSettings();
    protected:
       KConfig m_config;
+      KConfig m_kiolanConfig;
       QPushButton* m_advancedSettingsButton;
       QPushButton* m_suggestSettings;
       QCheckBox* m_useNmblookup;
@@ -58,6 +59,7 @@ class ResLisaSettings:public KCModule
       QSpinBox *m_updatePeriod;
       QCheckBox *m_deliverUnnamedHosts;
       QSpinBox *m_maxPingsAtOnce;
+      QCheckBox* m_rlanSidebar;
       KDialogBase* m_reslisaAdvancedDlg;
 };
 
