@@ -1,7 +1,7 @@
 /*
  * portsettingsbar.cpp
  *
- * Copyright (c) 2000 Alexander Neundorf <neundorf@kde.org>
+ * Copyright (c) 2000, 2005 Alexander Neundorf <neundorf@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,35 +21,30 @@
 #include "portsettingsbar.h"
 #include <klocale.h>
 
-PortSettingsBar::PortSettingsBar(const QString& title, QWidget *parent)
-:QHButtonGroup(title, parent)
-{
-   m_checkButton=new QRadioButton(i18n("Check availability"), this);
-   m_provideButton=new QRadioButton(i18n("Always"), this);
-   m_disableButton=new QRadioButton(i18n("Never"), this);
+#include <qlabel.h>
 
-   connect(m_checkButton,SIGNAL(clicked()),this,SIGNAL(changed()));
-   connect(m_provideButton,SIGNAL(clicked()),this,SIGNAL(changed()));
-   connect(m_disableButton,SIGNAL(clicked()),this,SIGNAL(changed()));
+PortSettingsBar::PortSettingsBar(const QString& title, QWidget *parent)
+:QHBox(parent)
+{
+   QLabel* label=new QLabel(title, this);
+   m_box=new QComboBox(this);
+   label->setBuddy(m_box);
+
+   m_box->insertItem(i18n("Check availability"));
+   m_box->insertItem(i18n("Always"));
+   m_box->insertItem(i18n("Never"));
+
+   connect(m_box,SIGNAL(activated()),this,SIGNAL(changed()));
 }
 
-int PortSettingsBar::selected()
+int PortSettingsBar::selected() const
 {
-   if (m_checkButton->isChecked())
-      return PORTSETTINGS_CHECK;
-   else if (m_provideButton->isChecked())
-      return PORTSETTINGS_PROVIDE;
-   return PORTSETTINGS_DISABLE;
+   return m_box->currentItem();
 }
 
 void PortSettingsBar::setChecked(int what)
 {
-   if (what==PORTSETTINGS_CHECK)
-      m_checkButton->setChecked(TRUE);
-   else if (what==PORTSETTINGS_PROVIDE)
-      m_provideButton->setChecked(TRUE);
-   else 
-      m_disableButton->setChecked(TRUE);
+   m_box->setCurrentItem(what);
 }
 
 #include "portsettingsbar.moc"
