@@ -1,7 +1,7 @@
 /*
  * portsettingsbar.h
  *
- * Copyright (c) 2000 Alexander Neundorf <neundorf@kde.org>
+ * Copyright (c) 2000, 2005 Alexander Neundorf <neundorf@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,27 +21,25 @@
 #ifndef PORTSETTINGSBAR_H
 #define PORTSETTINGSBAR_H
 
-#include <qradiobutton.h>
-#include <qhbuttongroup.h>
+#include <qhbox.h>
+#include <qcombobox.h>
 
 #define PORTSETTINGS_CHECK 0
 #define PORTSETTINGS_PROVIDE 1
 #define PORTSETTINGS_DISABLE 2
 
-class PortSettingsBar:public QHButtonGroup
+class PortSettingsBar:public QHBox
 {
    Q_OBJECT
    public:
       PortSettingsBar(const QString& title, QWidget *parent=0);
       virtual ~PortSettingsBar() {};
-      int selected();
+      int selected() const;
       void setChecked(int what);
    signals:
       void changed();
    protected:
-      QRadioButton *m_checkButton;
-      QRadioButton *m_provideButton;
-      QRadioButton *m_disableButton;
+      QComboBox *m_box;
 };
 
 #endif
