@@ -127,7 +127,7 @@ LANProtocol::LANProtocol(int isLanIoslave, const QCString &pool, const QCString
 
    m_hostInfoCache.setAutoDelete(true);
 
-   delete config;
+//   delete config; //this one causes a crash , Alex
 }
 
 LANProtocol::~LANProtocol()
