@@ -418,7 +418,7 @@ bool Interface_wireless_wirelessextensions::poll_device_info ()
   essid = (WIFI_CONFIG(info,essid_on) ? WIFI_CONFIG(info,essid) : "any");
   char
     ap_addr[256];
-  iw_pr_ether (ap_addr, (const unsigned char *) info.ap_addr.sa_data);
+  iw_ether_ntop ( (const ether_addr *) info.ap_addr.sa_data, ap_addr);
   if (access_point_address != ap_addr)
     emitStatusChanged = true;
   access_point_address = ap_addr;
