@@ -193,7 +193,7 @@ KWiFiManagerApp::slotChangeTrayIcon ()
     }
   QPixmap* ICON;
   int sig, noi, str;
-  double freq;
+  double freq = 0.;
   bool validdata = device->get_current_quality (sig, noi, str);
   if ( settingsUseAlternateCalc->isChecked() ) str = sig - noi;
   int mode;
