@@ -18,16 +18,20 @@
 #ifndef PICTURE_H
 #define PICTURE_H
 
+class Interface_wireless;
+class QSize;
+
 class Picture:public QWidget
 {
 public:
-  Picture (QWidget * parent);
-    ~Picture ();
+  Picture (QWidget * parent, Interface_wireless * device);
+  QSize mySizeHint();
+  ~Picture ();
 private:
   void paintEvent (QPaintEvent *);
   QPixmap *NO_CARD, *ALL_ALONE, *AD_HOC, *AP_CONNECT;
   QString kdedir;
+  Interface_wireless *device;
 };
 
 #endif
-
