@@ -21,11 +21,12 @@
 #include "statistics.h"
 #include "interface_wireless.h"
 
-Statistics::Statistics (Interface_wireless * device):QWidget (0,
+Statistics::Statistics (Interface_wireless * device, bool showStatsNoise):QWidget (0,
 	 "KWiFiManager")
 {
   this->setCaption (i18n ("Statistics - KWiFiManager"));
   this->device = device;
+  this->showStatsNoise = showStatsNoise;
 }
 
 void
@@ -91,8 +92,10 @@ Statistics::paintEvent (QPaintEvent *)
   // Only paint the point array if there is one valid entry
   if (atLeastOneValid)
     {
-      statpainter->setPen (red);
-      statpainter->drawPolyline (datensatz2, 1);
+      if (showStatsNoise) {
+        statpainter->setPen (red);
+        statpainter->drawPolyline (datensatz2, 1);
+      }
       statpainter->setPen (blue);
       statpainter->drawPolyline (datensatz, 1);
     }
